\name{DiggleGratton}
\alias{DiggleGratton}
\title{Diggle-Gratton model}
\description{
  Creates an instance of the Diggle-Gratton pairwise interaction
  point process model, which can then be fitted to point pattern data.
}
\usage{
  DiggleGratton(delta, rho)
}
\arguments{
  \item{delta}{lower threshold \eqn{\delta}{delta}}
  \item{rho}{upper threshold \eqn{\rho}{rho}}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of a point process. 
}
\details{
  Diggle and Gratton (1984, pages 208-210)
  introduced the pairwise interaction point
  process with pair potential \eqn{h(t)} of the form
  \deqn{
    h(t) = \left( \frac{t-\delta}{\rho-\delta} \right)^\kappa
    \quad\quad \mbox{  if  } \delta \le t \le \rho
  }{
    h(t) = ((t - delta)/(rho - delta))^kappa, {    } delta <= t <= rho
  }
  with \eqn{h(t) = 0} for \eqn{t < \delta}{t < delta}
  and  \eqn{h(t) = 1} for \eqn{t > \rho}{t > rho}.
  Here \eqn{\delta}{delta}, \eqn{\rho}{rho} and \eqn{\kappa}{kappa}
  are parameters.

  Note that we use the symbol \eqn{\kappa}{kappa}
  where Diggle and Gratton (1984) and Diggle, Gates and Stibbard (1987)
  use \eqn{\beta}{beta}, since in \code{spatstat} we reserve the symbol
  \eqn{\beta}{beta} for an intensity parameter.

  The parameters must all be nonnegative,
  and must satisfy \eqn{\delta \le \rho}{delta <= rho}.

  The potential is inhibitory, i.e.\ this model is only appropriate for
  regular point patterns. The strength of inhibition increases with
  \eqn{\kappa}{kappa}. For \eqn{\kappa=0}{kappa=0} the model is
  a hard core process with hard core radius \eqn{\delta}{delta}.
  For \eqn{\kappa=\infty}{kappa=infinity} the model is a hard core
  process with hard core radius \eqn{\rho}{rho}.

  The irregular parameters 
  \eqn{\delta, \rho}{delta, rho} must be given in the call to
  \code{DiggleGratton}, while the
  regular parameter \eqn{\kappa}{kappa} will be estimated.
}
\seealso{
  \code{\link{ppm}},
  \code{\link{ppm.object}},
  \code{\link{Pairwise}}
}
\examples{
   data(cells)
   ppm(cells, ~1, DiggleGratton(0.05, 0.1))
}
\references{
  Diggle, P.J., Gates, D.J. and Stibbard, A. (1987)
  A nonparametric estimator for pairwise-interaction point processes.
  \emph{Biometrika} \bold{74}, 763 -- 770.

  Diggle, P.J. and Gratton, R.J. (1984)
  Monte Carlo methods of inference for implicit statistical models.
  \emph{Journal of the Royal Statistical Society, series B}
  \bold{46}, 193 -- 212.
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}


\eof
\name{Fest}
\alias{Fest}
\alias{empty.space}
\title{Estimate the empty space function F}
\description{
  Estimates the empty space function \eqn{F(r)} from a point pattern in a 
  window of arbitrary shape.
}
\synopsis{
Fest(X, eps, r=NULL, breaks=NULL)
}
\usage{
Fest(X, eps)
Fest(X, eps, r)
Fest(X, eps, breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of \eqn{F(r)} will be computed.
    An object of class \code{ppp}, or data
    in any format acceptable to \code{\link{as.ppp}()}.
  }
  \item{eps}{A positive number.
    The resolution of the discrete approximation to Euclidean
    distance (see below). There is a sensible default.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which \eqn{F(r)} should be evaluated. There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
}
\value{
  An object of class \code{"fv"}, see \code{\link{fv.object}},
  which can be plotted directly using \code{\link{plot.fv}}.

  Essentially a data frame containing six columns:
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{F(r)} has been  estimated
  }
  \item{rs}{the ``reduced sample'' or ``border correction''
    estimator of \eqn{F(r)}
  }
  \item{km}{the spatial Kaplan-Meier estimator of \eqn{F(r)}
  }
  \item{hazard}{the hazard rate \eqn{\lambda(r)}{lambda(r)}
    of \eqn{F(r)} by the spatial Kaplan-Meier method
  }
  \item{raw}{the uncorrected estimate of \eqn{F(r)},
  i.e. the empirical distribution of the distance from 
  a random point in the window to the nearest point of
  the data pattern \code{X}
  }
  \item{theo}{the theoretical value of \eqn{F(r)}
  for a stationary Poisson process of the same estimated intensity.
  }
}
\details{
  The empty space function 
  (also called the ``\emph{spherical contact distribution}''
  or the ``\emph{point-to-nearest-event}'' distribution)
  of a stationary point process \eqn{X}
  is the cumulative distribution function \eqn{F} of the distance
  from a fixed point in space to the nearest point of \eqn{X}.

  An estimate of \eqn{F} derived from a spatial point pattern dataset
  can be used in exploratory data analysis and formal inference
  about the pattern (Cressie, 1991; Diggle, 1983; Ripley, 1988).
  In exploratory analyses, the estimate of \eqn{F} is a useful statistic 
  summarising the sizes of gaps in the pattern.
  For inferential purposes, the estimate of \eqn{F} is usually compared to the 
  true value of \eqn{F} for a completely random (Poisson) point process,
  which is
  \deqn{F(r) = 1 - e^{ - \lambda \pi r^2}}{%
    F(r) = 1 - exp( - lambda * pi * r^2)      %
  }
  where \eqn{\lambda}{lambda}
  is the intensity (expected number of points per unit area).
  Deviations between the empirical and theoretical \eqn{F} curves
  may suggest spatial clustering or spatial regularity.

  This algorithm estimates the empty space function \eqn{F} 
  from the point pattern \code{X}. It assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window. 
  The window (which is specified in \code{X}) may have arbitrary shape. 

  The argument \code{X} is interpreted as a point pattern object 
  (of class \code{"ppp"}, see \code{\link{ppp.object}}) and can
  be supplied in any of the formats recognised
  by \code{\link{as.ppp}}.

  The algorithm uses two discrete approximations which are controlled
  by the parameter \code{eps} and by the spacing of values of \code{r}
  respectively. (See below for details.)
  First-time users are strongly advised not to specify these arguments.

  The estimation of \eqn{F} is hampered by edge effects arising from 
  the unobservability of points of the random pattern outside the window. 
  An edge correction is needed to reduce bias (Baddeley, 1998; Ripley, 1988). 
  The two edge corrections implemented here are the border method or
  "\emph{reduced sample}" estimator, and the spatial Kaplan-Meier estimator
  (Baddeley and Gill, 1997). 

  Our implementation makes essential use of the distance transform algorithm
  of image processing (Borgefors, 1986). A fine grid of pixels is 
  created in the observation window. The Euclidean distance between two pixels
  is approximated by the length of the shortest path joining them in the grid,
  where a path is a sequence of steps between adjacent pixels, and 
  horizontal, vertical and diagonal steps have length
  \eqn{1}, \eqn{1} and \eqn{\sqrt 2}{sqrt(2)}
  respectively in pixel units. If the pixel grid is sufficiently fine then
  this is an accurate approximation. 

  The parameter \code{eps}
  is the pixel width of the rectangular raster
  used to compute the distance transform (see below). It must not be too
  large: the absolute error in distance values due to discretisation is bounded
  by \code{eps}.

  If \code{eps} is not specified, the function
  checks whether the window \code{X$window} contains pixel raster
  information. If so, then \code{eps} is set equal to the 
  pixel width of the raster; otherwise, \code{eps}
  defaults to 1/100 of the width of the observation window.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{F(r)} should be evaluated. 
  It is also used to determine the breakpoints
  (in the sense of \code{\link{hist}}
  for the computation of histograms of distances. The reduced-sample and
  Kaplan-Meier estimators are computed from histogram counts. 
  In the case of the Kaplan-Meier estimator this introduces a discretisation
  error which is controlled by the fineness of the breakpoints.

  First-time users would be strongly advised not to specify \code{r}.
  However, if it is specified, \code{r} must satisfy \code{r[1] = 0}, 
  and \code{max(r)} must be larger than the radius of the largest disc 
  contained in the window. Furthermore, the spacing of successive
  \code{r} values must be very fine (ideally not greater than \code{eps/4}).

  The algorithm also returns an estimate of the hazard rate function, 
  \eqn{\lambda(r)}{lambda(r)}, of \eqn{F(r)}. The hazard rate is
  defined by
  \deqn{\lambda(r) = - \frac{d}{dr} \log(1 - F(r))}{%
    lambda(r) = - (d/dr) log(1 - F(r)) %
  }
  The hazard rate of \eqn{F} has been proposed as a useful
  exploratory statistic (Baddeley and Gill, 1994).
  The estimate of \eqn{\lambda(r)}{lambda(r)} given here
  is a discrete approximation to the hazard rate of the 
  Kaplan-Meier estimator of \eqn{F}. Note that \eqn{F} is 
  absolutely continuous (for any stationary point process \eqn{X}), 
  so the hazard function always exists (Baddeley and Gill, 1997). 

  The naive empirical distribution of distances from each location
  in the window to the nearest point of the data pattern, is a biased
  estimate of \eqn{F}. However this is also returned by the algorithm,
  as it is sometimes useful in other contexts.
  Care should be taken not to use the uncorrected
  empirical \eqn{F} as if it were an unbiased estimator of \eqn{F}.
}
\note{
  Sizeable amounts of memory may be needed during the calculation.
}
\references{
  Baddeley, A.J. Spatial sampling and censoring.
     In O.E. Barndorff-Nielsen, W.S. Kendall and
     M.N.M. van Lieshout (eds) 
     \emph{Stochastic Geometry: Likelihood and Computation}.
     Chapman and Hall, 1998.
     Chapter 2, pages 37-78.
  
  Baddeley, A.J. and Gill, R.D. 
    The empty space hazard of a spatial pattern.
    Research Report 1994/3, Department of Mathematics,
    University of Western Australia, May 1994.

  Baddeley, A.J. and Gill, R.D.
     Kaplan-Meier estimators of interpoint distance
		distributions for spatial point processes.
     \emph{Annals of Statistics} \bold{25} (1997) 263-292.

  Borgefors, G.
     Distance transformations in digital images.
     \emph{Computer Vision, Graphics and Image Processing}
     \bold{34} (1986) 344-371.

  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
    Academic Press, 1983.

  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J.
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag, 1995.
}
\section{Warnings}{
  The reduced sample (border method)
  estimator of \eqn{F} is pointwise approximately 
  unbiased, but need not be a valid distribution function; it may 
  not be a nondecreasing function of \eqn{r}. Its range is always 
  within \eqn{[0,1]}.

  The spatial Kaplan-Meier estimator of \eqn{F} is always nondecreasing
  but its maximum value may be less than \eqn{1}.

  The estimate of \eqn{\lambda(r)}{lambda(r)}
  returned by the algorithm is an approximately
  unbiased estimate for the integral of \eqn{\lambda()}{lambda()}
  over the corresponding histogram cell.
  It may exhibit oscillations due to discretisation effects.
  We recommend modest smoothing, such as kernel smoothing with 
  kernel width equal to the width of a histogram cell.
}
\seealso{
  \code{\link{Gest}},
  \code{\link{Jest}},
  \code{\link{Kest}},
  \code{\link{km.rs}},
  \code{\link{reduced.sample}},
  \code{\link{kaplan.meier}}
}
\examples{
   data(cells)
   Fc <- Fest(cells, 0.01)

   # Tip: don't use F for the left hand side!
   # That's an abbreviation for FALSE

   plot(Fc)

   # P-P style plot
   plot(Fc, cbind(km, theo) ~ theo)

   # The empirical F is above the Poisson F
   # indicating an inhibited pattern

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
  }
\keyword{spatial}


\eof
\name{Gcross}
\alias{Gcross}
\title{
  Multitype Nearest Neighbour Distance Function (i-to-j)
}
\description{
  For a multitype point pattern, 
  estimate the distribution of the distance
  from a point of type \eqn{i}
  to the nearest point of type \eqn{j}.
}
\synopsis{
Gcross(X, i=1, j=2, r=NULL, breaks=NULL, \dots)
}
\usage{
Gcross(X, i=1, j=2)
Gcross(X, i=1, j=2, r)
Gcross(X, i=1, j=2, breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of the cross type distance distribution function
    \eqn{G_{ij}(r)}{Gij(r)} will be computed.
    It must be a multitype point pattern (a marked point pattern
    whose marks are a factor). See under Details.
  }
  \item{i}{Number or character string identifying the type (mark value)
    of the points in \code{X} from which distances are measured.
  }
  \item{j}{Number or character string identifying the type (mark value)
    of the points in \code{X} to which distances are measured.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which the distribution function
    \eqn{G_{ij}(r)}{Gij(r)} should be evaluated.
    There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).
  
  Essentially a data frame containing six numeric columns 
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{G_{ij}(r)}{Gij(r)} has been  estimated
  }
  \item{rs}{the ``reduced sample'' or ``border correction''
    estimator of \eqn{G_{ij}(r)}{Gij(r)}
  }
  \item{km}{the spatial Kaplan-Meier estimator of \eqn{G_{ij}(r)}{Gij(r)}
  }
  \item{hazard}{the hazard rate \eqn{\lambda(r)}{lambda(r)}
    of \eqn{G_{ij}(r)}{Gij(r)} by the spatial Kaplan-Meier method
  }
  \item{raw}{the uncorrected estimate of \eqn{G_{ij}(r)}{Gij(r)},
  i.e. the empirical distribution of the distances from 
  each point of type \eqn{i} to the nearest point of type \eqn{j}
  }
  \item{theo}{the theoretical value of \eqn{G_{ij}(r)}{Gij(r)}
    for a marked Poisson process with the same estimated intensity
    (see below).
  }
}
\details{
  This function \code{Gcross} and its companions
  \code{\link{Gdot}} and \code{\link{Gmulti}}
  are generalisations of the function \code{\link{Gest}}
  to multitype point patterns. 

  A multitype point pattern is a spatial pattern of
  points classified into a finite number of possible
  ``colours'' or ``types''. In the \code{spatstat} package,
  a multitype pattern is represented as a single 
  point pattern object in which the points carry marks,
  and the mark value attached to each point
  determines the type of that point.
  
  The argument \code{X} must be a point pattern (object of class
  \code{"ppp"}) or any data that are acceptable to \code{\link{as.ppp}}.
  It must be a marked point pattern, and the mark vector
  \code{X$marks} must be a factor.
  The arguments \code{i} and \code{j} will be interpreted as
  levels of the factor \code{X$marks}. (Warning: this means that
  an integer value \code{i=3} will be interpreted as the 3rd smallest level,
  not the number 3). 
  
  The ``cross-type'' (type \eqn{i} to type \eqn{j})
  nearest neighbour distance distribution function 
  of a multitype point process 
  is the cumulative distribution function \eqn{G_{ij}(r)}{Gij(r)}
  of the distance from a typical random point of the process with type \eqn{i}
  the nearest point of type \eqn{j}. 

  An estimate of \eqn{G_{ij}(r)}{Gij(r)}
  is a useful summary statistic in exploratory data analysis
  of a multitype point pattern.
  If the process of type \eqn{i} points
  were independent of the process of type \eqn{j} points,
  then \eqn{G_{ij}(r)}{Gij(r)} would equal \eqn{F_j(r)}{Fj(r)},
  the empty space function of the type \eqn{j} points.
  For a multitype Poisson point process where the type \eqn{i} points
  have intensity \eqn{\lambda_i}{lambda[i]}, we have
  \deqn{G_{ij}(r) = 1 - e^{ - \lambda_j \pi r^2} }{%
    Gij(r) = 1 - exp( - lambda[j] * pi * r^2)}
  Deviations between the empirical and theoretical \eqn{G_{ij}}{Gij} curves
  may suggest dependence between the points of types \eqn{i} and \eqn{j}.

  This algorithm estimates the distribution function \eqn{G_{ij}(r)}{Gij(r)} 
  from the point pattern \code{X}. It assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape.
  Biases due to edge effects are
  treated in the same manner as in \code{\link{Gest}}.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{G_{ij}(r)}{Gij(r)} should be evaluated. 
  It is also used to determine the breakpoints
  (in the sense of \code{\link{hist}})
  for the computation of histograms of distances. The reduced-sample and
  Kaplan-Meier estimators are computed from histogram counts. 
  In the case of the Kaplan-Meier estimator this introduces a discretisation
  error which is controlled by the fineness of the breakpoints.

  First-time users would be strongly advised not to specify \code{r}.
  However, if it is specified, \code{r} must satisfy \code{r[1] = 0}, 
  and \code{max(r)} must be larger than the radius of the largest disc 
  contained in the window. Furthermore, the successive entries of \code{r}
  must be finely spaced.

  The algorithm also returns an estimate of the hazard rate function, 
  \eqn{\lambda(r)}{lambda(r)}, of \eqn{G_{ij}(r)}{Gij(r)}. 
  This estimate should be used with caution as \eqn{G_{ij}(r)}{Gij(r)}
  is not necessarily differentiable.

  The naive empirical distribution of distances from each point of
  the pattern \code{X} to the nearest other point of the pattern, 
  is a biased estimate of \eqn{G_{ij}}{Gij}.
  However this is also returned by the algorithm, as it is sometimes 
  useful in other contexts. Care should be taken not to use the uncorrected
  empirical \eqn{G_{ij}}{Gij} as if it were an unbiased estimator of
  \eqn{G_{ij}}{Gij}.
}
\references{
  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
    Academic Press, 1983.

  Diggle, P. J. (1986).
  Displaced amacrine cells in the retina of a
  rabbit : analysis of a bivariate spatial point pattern. 
  \emph{J. Neurosci. Meth.} \bold{18}, 115--125.
 
  Harkness, R.D and Isham, V. (1983)
  A bivariate spatial point pattern of ants' nests.
  \emph{Applied Statistics} \bold{32}, 293--303
 
  Lotwick, H. W. and Silverman, B. W. (1982).
  Methods for analysing spatial processes of several types of points.
  \emph{J. Royal Statist. Soc. Ser. B} \bold{44}, 406--413.

  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J.
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag, 1995.

  Van Lieshout, M.N.M. and Baddeley, A.J. (1999)
  Indices of dependence between types in multivariate point patterns.
  \emph{Scandinavian Journal of Statistics} \bold{26}, 511--532.

}
\section{Warnings}{
  The arguments \code{i} and \code{j} are interpreted as
  levels of the factor \code{X$marks}. Beware of the usual
  trap with factors: numerical values are not
  interpreted in the same way as character values. See the first example.

  The function \eqn{G_{ij}}{Gij} does not necessarily have a density. 

  The reduced sample estimator of \eqn{G_{ij}}{Gij} is pointwise approximately 
  unbiased, but need not be a valid distribution function; it may 
  not be a nondecreasing function of \eqn{r}. Its range is always 
  within \eqn{[0,1]}.

  The spatial Kaplan-Meier estimator of \eqn{G_{ij}}{Gij}
  is always nondecreasing
  but its maximum value may be less than \eqn{1}.
}
\seealso{
 \code{\link{Gdot}},
 \code{\link{Gest}},
 \code{\link{Gmulti}}
}
\examples{
    data(betacells)
     # cat retina data
    G01 <- Gcross(betacells, "off", "on") 
    plot(G01)

    # empty space function of `on' points
    \dontrun{
       F1 <- Fest(betacells[betacells == "on"], r = G01$r, eps=10.0)
       lines(F1$r, F1$km, lty=3)
    }

    # synthetic example    
    pp <- runifpoispp(50)
    pp <- pp \%mark\% factor(sample(0:1, pp$n, replace=TRUE))
    G <- Gcross(pp, "0", "1")   # note: "0" not 0
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Gdot}
\alias{Gdot}
\title{
  Multitype Nearest Neighbour Distance Function (i-to-any)
}
\description{
  For a multitype point pattern, 
  estimate the distribution of the distance
  from a point of type \eqn{i}
  to the nearest other point of any type.
}
\synopsis{
Gdot(X, i=1, r=NULL, breaks=NULL, \dots)
}
\usage{
Gdot(X, i=1)
Gdot(X, i=1, r)
Gdot(X, i=1, breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of the 
    distance distribution function
    \eqn{G_{i\bullet}(r)}{Gi.(r)} will be computed.
    It must be a multitype point pattern (a marked point pattern
    whose marks are a factor). See under Details.
  }
  \item{i}{Number or character string identifying the type (mark value)
    of the points in \code{X} from which distances are measured.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which the distribution function
    \eqn{G_{i\bullet}(r)}{Gi.(r)} should be evaluated.
    There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).
  
  Essentially a data frame containing six numeric columns 
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{G_{i\bullet}(r)}{Gi.(r)} has been  estimated
  }
  \item{rs}{the ``reduced sample'' or ``border correction''
    estimator of \eqn{G_{i\bullet}(r)}{Gi.(r)}
  }
  \item{km}{the spatial Kaplan-Meier estimator of \eqn{G_{i\bullet}(r)}{Gi.(r)}
  }
  \item{hazard}{the hazard rate \eqn{\lambda(r)}{lambda(r)}
    of \eqn{G_{i\bullet}(r)}{Gi.(r)} by the spatial Kaplan-Meier method
  }
  \item{raw}{the uncorrected estimate of \eqn{G_{i\bullet}(r)}{Gi.(r)},
  i.e. the empirical distribution of the distances from 
  each point of type \eqn{i} to the nearest other point of any type.
  }
  \item{theo}{the theoretical value of \eqn{G_{i\bullet}(r)}{Gi.(r)}
    for a marked Poisson process with the same estimated intensity
    (see below).
  }
}
\details{
  This function \code{Gdot} and its companions
  \code{\link{Gcross}} and \code{\link{Gmulti}}
  are generalisations of the function \code{\link{Gest}}
  to multitype point patterns.

  A multitype point pattern is a spatial pattern of
  points classified into a finite number of possible
  ``colours'' or ``types''. In the \code{spatstat} package,
  a multitype pattern is represented as a single 
  point pattern object in which the points carry marks,
  and the mark value attached to each point
  determines the type of that point.
  
  The argument \code{X} must be a point pattern (object of class
  \code{"ppp"}) or any data that are acceptable to \code{\link{as.ppp}}.
  It must be a marked point pattern, and the mark vector
  \code{X$marks} must be a factor.
  The argument will be interpreted as a
  level of the factor \code{X$marks}. (Warning: this means that
  an integer value \code{i=3} will be interpreted as the 3rd smallest level,
  not the number 3). 
  
  The ``dot-type'' (type \eqn{i} to any type)
  nearest neighbour distance distribution function 
  of a multitype point process 
  is the cumulative distribution function \eqn{G_{i\bullet}(r)}{Gi.(r)}
  of the distance from a typical random point of the process with type \eqn{i}
  the nearest other point of the process, regardless of type. 

  An estimate of \eqn{G_{i\bullet}(r)}{Gi.(r)}
  is a useful summary statistic in exploratory data analysis
  of a multitype point pattern.
  If the type \eqn{i} points
  were independent of all other points,
  then \eqn{G_{i\bullet}(r)}{Gi.(r)} would equal \eqn{G_{ii}(r)}{Gii(r)},
  the nearest neighbour distance distribution function of the type
  \eqn{i} points alone.
  For a multitype Poisson point process with total intensity
  \eqn{\lambda}{lambda}, we have
  \deqn{G_{i\bullet}(r) = 1 - e^{ - \lambda \pi r^2} }{%
    Gi.(r) = 1 - exp( - lambda * pi * r^2)}
  Deviations between the empirical and theoretical
  \eqn{G_{i\bullet}}{Gi.} curves
  may suggest dependence of the type \eqn{i} points on the other points.

  This algorithm estimates the distribution function
  \eqn{G_{i\bullet}(r)}{Gi.(r)} 
  from the point pattern \code{X}. It assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape.
  Biases due to edge effects are
  treated in the same manner as in \code{\link{Gest}}.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{G_{i\bullet}(r)}{Gi.(r)} should be evaluated. 
  It is also used to determine the breakpoints
  (in the sense of \code{\link{hist}})
  for the computation of histograms of distances. The reduced-sample and
  Kaplan-Meier estimators are computed from histogram counts. 
  In the case of the Kaplan-Meier estimator this introduces a discretisation
  error which is controlled by the fineness of the breakpoints.

  First-time users would be strongly advised not to specify \code{r}.
  However, if it is specified, \code{r} must satisfy \code{r[1] = 0}, 
  and \code{max(r)} must be larger than the radius of the largest disc 
  contained in the window. Furthermore, the successive entries of \code{r}
  must be finely spaced.

  The algorithm also returns an estimate of the hazard rate function, 
  \eqn{\lambda(r)}{lambda(r)}, of \eqn{G_{i\bullet}(r)}{Gi.(r)}. 
  This estimate should be used with caution as
  \eqn{G_{i\bullet}(r)}{Gi.(r)}
  is not necessarily differentiable.

  The naive empirical distribution of distances from each point of
  the pattern \code{X} to the nearest other point of the pattern, 
  is a biased estimate of \eqn{G_{i\bullet}}{Gi.}.
  However this is also returned by the algorithm, as it is sometimes 
  useful in other contexts. Care should be taken not to use the uncorrected
  empirical \eqn{G_{i\bullet}}{Gi.} as if it were an unbiased estimator of
  \eqn{G_{i\bullet}}{Gi.}.
}
\references{
  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
    Academic Press, 1983.

  Diggle, P. J. (1986).
  Displaced amacrine cells in the retina of a
  rabbit : analysis of a bivariate spatial point pattern. 
  \emph{J. Neurosci. Meth.} \bold{18}, 115--125.
 
  Harkness, R.D and Isham, V. (1983)
  A bivariate spatial point pattern of ants' nests.
  \emph{Applied Statistics} \bold{32}, 293--303
 
  Lotwick, H. W. and Silverman, B. W. (1982).
  Methods for analysing spatial processes of several types of points.
  \emph{J. Royal Statist. Soc. Ser. B} \bold{44}, 406--413.

  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J.
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag, 1995.

  Van Lieshout, M.N.M. and Baddeley, A.J. (1999)
  Indices of dependence between types in multivariate point patterns.
  \emph{Scandinavian Journal of Statistics} \bold{26}, 511--532.

}
\section{Warnings}{
  The argument \code{i} is interpreted as a
  level of the factor \code{X$marks}. Beware of the usual
  trap with factors: numerical values are not
  interpreted in the same way as character values. See the first example.

  The function \eqn{G_{i\bullet}}{Gi.} does not necessarily have a density. 

  The reduced sample estimator of \eqn{G_{i\bullet}}{Gi.}
  is pointwise approximately 
  unbiased, but need not be a valid distribution function; it may 
  not be a nondecreasing function of \eqn{r}. Its range is always 
  within \eqn{[0,1]}.

  The spatial Kaplan-Meier estimator of \eqn{G_{i\bullet}}{Gi.}
  is always nondecreasing
  but its maximum value may be less than \eqn{1}.
}
\seealso{
 \code{\link{Gcross}},
 \code{\link{Gest}},
 \code{\link{Gmulti}}
}
\examples{
    data(betacells)
     # cat retina data
    G0. <- Gdot(betacells, "off") 
    plot(G0.)

    # synthetic example    
    pp <- runifpoispp(50)
    pp <- pp \%mark\% factor(sample(0:1, pp$n, replace=TRUE))
    G <- Gdot(pp, "0") # note: "0" not 0
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}




\eof
\name{Gest}
\alias{Gest}
\alias{nearest.neighbour}
\title{
  Nearest Neighbour Distance Function G
}
\description{
Estimates the nearest neighbour distance distribution
function \eqn{G(r)} from a point pattern in a 
window of arbitrary shape.
}
\synopsis{
Gest(X, r=NULL, breaks=NULL, \dots)
}
\usage{
Gest(X)
Gest(X, r)
Gest(X, breaks)
nearest.neighbour(X)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of \eqn{G(r)} will be computed.
    An object of class \code{ppp}, or data
    in any format acceptable to \code{\link{as.ppp}()}.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which \eqn{G(r)} should be evaluated. There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
}
\value{
  An object of class \code{"fv"}, see \code{\link{fv.object}},
  which can be plotted directly using \code{\link{plot.fv}}.

  Essentially a data frame containing six columns:
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{G(r)} has been  estimated
  }
  \item{rs}{the ``reduced sample'' or ``border correction''
    estimator of \eqn{G(r)}
  }
  \item{km}{the spatial Kaplan-Meier estimator of \eqn{G(r)}
  }
  \item{hazard}{the hazard rate \eqn{\lambda(r)}{lambda(r)}
    of \eqn{G(r)} by the spatial Kaplan-Meier method
  }
  \item{raw}{the uncorrected estimate of \eqn{G(r)},
  i.e. the empirical distribution of the distances from 
  each point in the pattern \code{X} to the nearest other point of
  the pattern
  }
  \item{theo}{the theoretical value of \eqn{G(r)}
  for a stationary Poisson process of the same estimated intensity.
  }
}
\details{
  The nearest neighbour distance distribution function 
  (also called the ``\emph{event-to-event}'' or
  ``\emph{inter-event}'' distribution)
  of a point process \eqn{X}
  is the cumulative distribution function \eqn{G} of the distance
  from a typical random point of \eqn{X} to
  the nearest other point of \eqn{X}.

  An estimate of \eqn{G} derived from a spatial point pattern dataset
  can be used in exploratory data analysis and formal inference
  about the pattern (Cressie, 1991; Diggle, 1983; Ripley, 1988).
  In exploratory analyses, the estimate of \eqn{G} is a useful statistic 
  summarising one aspect of the ``clustering'' of points.
  For inferential purposes, the estimate of \eqn{G} is usually compared to the 
  true value of \eqn{G} for a completely random (Poisson) point process,
  which is
  \deqn{G(r) = 1 - e^{ - \lambda \pi r^2} }{%
    G(r) = 1 - exp( - lambda * pi * r^2)}
  where \eqn{\lambda}{lambda} is the intensity
  (expected number of points per unit area).
  Deviations between the empirical and theoretical \eqn{G} curves
  may suggest spatial clustering or spatial regularity.

  This algorithm estimates the nearest neighbour distance distribution
  function \eqn{G}
  from the point pattern \code{X}. It assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape. 

  The argument \code{X} is interpreted as a point pattern object 
  (of class \code{"ppp"}, see \code{\link{ppp.object}}) and can
  be supplied in any of the formats recognised
  by \code{\link{as.ppp}()}. 

  The estimation of \eqn{G} is hampered by edge effects arising from 
  the unobservability of points of the random pattern outside the window. 
  An edge correction is needed to reduce bias (Baddeley, 1998; Ripley, 1988). 
  The two edge corrections implemented here are the border method or
  ``\emph{reduced sample}'' estimator, and the spatial Kaplan-Meier estimator
  (Baddeley and Gill, 1997). 

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{G(r)} should be evaluated. 
  It is also used to determine the breakpoints
  (in the sense of \code{\link{hist}})
  for the computation of histograms of distances. The reduced-sample and
  Kaplan-Meier estimators are computed from histogram counts. 
  In the case of the Kaplan-Meier estimator this introduces a discretisation
  error which is controlled by the fineness of the breakpoints.

  First-time users would be strongly advised not to specify \code{r}.
  However, if it is specified, \code{r} must satisfy \code{r[1] = 0}, 
  and \code{max(r)} must be larger than the radius of the largest disc 
  contained in the window. Furthermore, the successive entries of \code{r}
  must be finely spaced.

  The algorithm also returns an estimate of the hazard rate function, 
  \eqn{\lambda(r)}{lambda(r)}, of \eqn{G(r)}. The hazard rate is
  defined as the derivative
  \deqn{\lambda(r) = - \frac{d}{dr} \log (1 - G(r))}{%
    lambda(r) = - (d/dr) log(1 - G(r))}
  This estimate should be used with caution as \eqn{G} is not necessarily
  differentiable.

  The naive empirical distribution of distances from each point of
  the pattern \code{X} to the nearest other point of the pattern, 
  is a biased estimate of \eqn{G}.
  However this is also returned by the algorithm, as it is sometimes 
  useful in other contexts. Care should be taken not to use the uncorrected
  empirical \eqn{G} as if it were an unbiased estimator of  \eqn{G}.
}
\references{
    Baddeley, A.J. Spatial sampling and censoring.
     In O.E. Barndorff-Nielsen, W.S. Kendall and
     M.N.M. van Lieshout (eds) 
     \emph{Stochastic Geometry: Likelihood and Computation}.
     Chapman and Hall, 1998.
     Chapter 2, pages 37-78.
  
  Baddeley, A.J. and Gill, R.D.
     Kaplan-Meier estimators of interpoint distance
		distributions for spatial point processes.
     \emph{Annals of Statistics} \bold{25} (1997) 263-292.

  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
    Academic Press, 1983.

  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J.
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag, 1995.
}
\section{Warnings}{
  The function \eqn{G} does not necessarily have a density. 
  Any valid c.d.f. may appear as the nearest neighbour distance
  distribution function of a stationary point process.

  The reduced sample estimator of \eqn{G} is pointwise approximately 
  unbiased, but need not be a valid distribution function; it may 
  not be a nondecreasing function of \eqn{r}. Its range is always 
  within \eqn{[0,1]}.

  The spatial Kaplan-Meier estimator of \eqn{G} is always nondecreasing
  but its maximum value may be less than \eqn{1}.
}
\seealso{
 \code{\link{Fest}},
  \code{\link{Jest}},
  \code{\link{Kest}},
  \code{\link{km.rs}},
  \code{\link{reduced.sample}},
  \code{\link{kaplan.meier}}
}
\examples{
  data(cells)
  G <- Gest(cells)
  plot(G)

  # P-P style plot
  plot(G, cbind(km,theo) ~ theo)

  # the empirical G is below the Poisson G,
  # indicating an inhibited pattern

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Geyer}
\alias{Geyer}
\title{Geyer's Saturation Point Process Model}
\description{
Creates an instance of Geyer's ``saturation point process'' model
which can then be fitted to point pattern data.
}
\usage{
  Geyer(r,sat)
}
\arguments{
  \item{r}{Interaction radius. A positive real number.}
  \item{sat}{Saturation threshold. A positive real number.}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of Geyer's ``saturation point process''
  with interaction radius \eqn{r} and saturation threshold \code{sat}.
}
\details{
  Geyer (1999) introduced the ``saturation process'', a modification of the
  Strauss process (see \code{\link{Strauss}})
  in which the total contribution
  to the potential  from each point (from its pairwise interaction with all 
  other points) is trimmed to a maximum value \eqn{s}. 
  This model is implemented in the function \code{\link{Geyer}()}.

  The saturation point process with interaction radius \eqn{r},
  saturation threshold \eqn{s}, and 
  parameters \eqn{\beta}{beta} and \eqn{\gamma}{gamma},
  is the point process
  in which each point
  \eqn{x_i}{x[i]} in the pattern \eqn{X}
  contributes a factor
  \deqn{
    \beta \gamma^{\min(s, t(x_i, X))}
  }{
    beta gamma^min(s, t(x[i],X))
  }
  to the probability density of the point pattern,
  where \eqn{t(x_i, X)}{t(x[i],X)} denotes the
  number of ``close neighbours'' of \eqn{x_i}{x[i]} in the pattern
  \eqn{X}. A close neighbour of \eqn{x_i}{x[i]} is a point
  \eqn{x_j}{x[j]} with \eqn{j \neq i}{j != i}
  such that the distance between 
  \eqn{x_i}{x[i]} and \eqn{x_j}{x[j]} is less than or equal to \eqn{r}.

  If the saturation threshold \eqn{s} is set to infinity,
  this model reduces to the Strauss process (see \code{\link{Strauss}})
  with interaction parameter \eqn{\gamma^2}{gamma^2}.
  If \eqn{s = 0}, the model reduces to the Poisson point process.
  If \eqn{s} is a finite positive number, then the interaction parameter
  \eqn{\gamma}{gamma} may take any positive value (unlike the case
  of the Strauss process), with
  values \eqn{\gamma < 1}{gamma < 1}
  describing an ``ordered'' or ``inhibitive'' pattern,
  and 
  values \eqn{\gamma > 1}{gamma > 1}
  describing a ``clustered or ``attractive'' pattern.
 
  The nonstationary saturation process is similar except that 
  the value \eqn{\beta}{beta} 
  is replaced by a function \eqn{\beta(x_i)}{beta(x[i])}
  of location.
 
  The function \code{\link{ppm}()}, which fits point process models to 
  point pattern data, requires an argument 
  of class \code{"interact"} describing the interpoint interaction
  structure of the model to be fitted. 
  The appropriate description of the saturation process interaction is
  yielded by \code{Geyer(r, sat)} where the
  arguments \code{r} and \code{sat} specify
  the Strauss interaction radius \eqn{r} and the saturation threshold
  \eqn{s}, respectively. See the examples below.
 
  Note the only arguments are the interaction radius \code{r}
  and the saturation threshold \code{sat}.
  When \code{r} and \code{sat} are fixed,
  the model becomes an exponential family.
  The canonical parameters \eqn{\log(\beta)}{log(beta)}
  and \eqn{\log(\gamma)}{log(gamma)}
  are estimated by \code{\link{ppm}()}, not fixed in
  \code{Geyer()}. 
}
\seealso{
  \code{\link{ppm}},
  \code{\link{pairwise.family}},
  \code{\link{ppm.object}},
  \code{\link{Strauss}}
}
\references{
Geyer, C.J. (1999)
Likelihood Inference for Spatial Point Processes.
Chapter 3 in 
O.E. Barndorff-Nielsen, W.S. Kendall and M.N.M. Van Lieshout (eds)
\emph{Stochastic Geometry: Likelihood and Computation},
Chapman and Hall / CRC, 
Monographs on Statistics and Applied Probability, number 80.
Pages 79--140.
}

\examples{
   data(cells) 
   ppm(cells, ~1, Geyer(r=0.07, sat=2), rbord=0.07)
   # fit the stationary saturation process to `cells'
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Gmulti}
\alias{Gmulti}
\title{
  Marked Nearest Neighbour Distance Function
}
\description{
  For a marked point pattern, 
  estimate the distribution of the distance
  from a typical point in subset \code{I}
  to the nearest point of subset \eqn{J}.
}
\synopsis{
Gmulti(X, I, J, r=NULL, breaks=NULL, \dots)
}
\usage{
Gmulti(X, I, J)
Gmulti(X, I, J, r)
Gmulti(X, I, J, breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of the multitype distance distribution function
    \eqn{G_{IJ}(r)}{GIJ(r)} will be computed.
    It must be a marked point pattern.
    See under Details.
  }
  \item{I}{Subset of points of \code{X} from which distances are
    measured. 
  }
  \item{J}{Subset of points in \code{X} to which distances are measured.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which the distribution function
    \eqn{G_{IJ}(r)}{GIJ(r)} should be evaluated.
    There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).
  
  Essentially a data frame containing six numeric columns 
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{G_{IJ}(r)}{GIJ(r)} has been  estimated
  }
  \item{rs}{the ``reduced sample'' or ``border correction''
    estimator of \eqn{G_{IJ}(r)}{GIJ(r)}
  }
  \item{km}{the spatial Kaplan-Meier estimator of \eqn{G_{IJ}(r)}{GIJ(r)}
  }
  \item{hazard}{the hazard rate \eqn{\lambda(r)}{lambda(r)}
    of \eqn{G_{IJ}(r)}{GIJ(r)} by the spatial Kaplan-Meier method
  }
  \item{raw}{the uncorrected estimate of \eqn{G_{IJ}(r)}{GIJ(r)},
  i.e. the empirical distribution of the distances from 
  each point of type \eqn{i} to the nearest point of type \eqn{j}
  }
  \item{theo}{the theoretical value of \eqn{G_{IJ}(r)}{GIJ(r)}
    for a marked Poisson process with the same estimated intensity
  }
}
\details{
  The function \code{Gmulti}
  generalises \code{\link{Gest}} (for unmarked point
  patterns) and \code{\link{Gdot}} and \code{\link{Gcross}} (for
  multitype point patterns) to arbitrary marked point patterns.

  Suppose \eqn{X_I}{X[I]}, \eqn{X_J}{X[J]} are subsets, possibly
  overlapping, of a marked point process. This function computes an
  estimate of the cumulative
  distribution function \eqn{G_{IJ}(r)}{GIJ(r)} of the distance
  from a typical point of  \eqn{X_I}{X[I]} to the nearest distinct point of
  \eqn{X_J}{X[J]}. 

  The argument \code{X} must be a point pattern (object of class
  \code{"ppp"}) or any data that are acceptable to \code{\link{as.ppp}}.

  The arguments \code{I} and \code{J} specify two subsets of the
  point pattern. They may be logical vectors of length equal to
  \code{X$n}, or integer vectors with entries in the range 1 to
  \code{X$n}, etc.

  This algorithm estimates the distribution function \eqn{G_{IJ}(r)}{GIJ(r)} 
  from the point pattern \code{X}. It assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape.
  Biases due to edge effects are
  treated in the same manner as in \code{\link{Gest}}.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{G_{IJ}(r)}{GIJ(r)} should be evaluated. 
  It is also used to determine the breakpoints
  (in the sense of \code{\link{hist}})
  for the computation of histograms of distances. The reduced-sample and
  Kaplan-Meier estimators are computed from histogram counts. 
  In the case of the Kaplan-Meier estimator this introduces a discretisation
  error which is controlled by the fineness of the breakpoints.

  First-time users would be strongly advised not to specify \code{r}.
  However, if it is specified, \code{r} must satisfy \code{r[1] = 0}, 
  and \code{max(r)} must be larger than the radius of the largest disc 
  contained in the window. Furthermore, the successive entries of \code{r}
  must be finely spaced.

  The algorithm also returns an estimate of the hazard rate function, 
  \eqn{\lambda(r)}{lambda(r)}, of \eqn{G_{IJ}(r)}{GIJ(r)}. 
  This estimate should be used with caution as \eqn{G_{IJ}(r)}{GIJ(r)}
  is not necessarily differentiable.

  The naive empirical distribution of distances from each point of
  the pattern \code{X} to the nearest other point of the pattern, 
  is a biased estimate of \eqn{G_{IJ}}{GIJ}.
  However this is also returned by the algorithm, as it is sometimes 
  useful in other contexts. Care should be taken not to use the uncorrected
  empirical \eqn{G_{IJ}}{GIJ} as if it were an unbiased estimator of
  \eqn{G_{IJ}}{GIJ}.
}
\references{
  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
    Academic Press, 1983.

  Diggle, P. J. (1986).
  Displaced amacrine cells in the retina of a
  rabbit : analysis of a bivariate spatial point pattern. 
  \emph{J. Neurosci. Meth.} \bold{18}, 115--125.
 
  Harkness, R.D and Isham, V. (1983)
  A bivariate spatial point pattern of ants' nests.
  \emph{Applied Statistics} \bold{32}, 293--303
 
  Lotwick, H. W. and Silverman, B. W. (1982).
  Methods for analysing spatial processes of several types of points.
  \emph{J. Royal Statist. Soc. Ser. B} \bold{44}, 406--413.

  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J.
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag, 1995.

  Van Lieshout, M.N.M. and Baddeley, A.J. (1999)
  Indices of dependence between types in multivariate point patterns.
  \emph{Scandinavian Journal of Statistics} \bold{26}, 511--532.

}
\section{Warnings}{
  The function \eqn{G_{IJ}}{GIJ} does not necessarily have a density. 

  The reduced sample estimator of \eqn{G_{IJ}}{GIJ} is pointwise approximately 
  unbiased, but need not be a valid distribution function; it may 
  not be a nondecreasing function of \eqn{r}. Its range is always 
  within \eqn{[0,1]}.

  The spatial Kaplan-Meier estimator of \eqn{G_{IJ}}{GIJ}
  is always nondecreasing
  but its maximum value may be less than \eqn{1}.
}
\seealso{
 \code{\link{Gcross}},
 \code{\link{Gdot}},
 \code{\link{Gest}}
}
\examples{
    data(longleaf)
     # Longleaf Pine data: marks represent diameter
    \testonly{
      longleaf <- longleaf[seq(1,longleaf$n, by=50), ]
    }
    Gm <- Gmulti(longleaf, longleaf$marks <= 15, longleaf$marks >= 25)
    plot(Gm)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Jcross}
\alias{Jcross}
\title{
  Multitype J Function (i-to-j)
}
\description{
  For a multitype point pattern, 
  estimate the multitype \eqn{J} function 
  summarising the interpoint dependence between
  points of type \eqn{i} and of type \eqn{j}.
}
\synopsis{
Jcross(X, i=1, j=2, eps=NULL, r=NULL, breaks=NULL)
}
\usage{
Jcross(X, i=1, j=2)
Jcross(X, i=1, j=2, eps, r)
Jcross(X, i=1, j=2, eps, breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of the multitype \eqn{J} function
    \eqn{J_{ij}(r)}{Jij(r)} will be computed.
    It must be a multitype point pattern (a marked point pattern
    whose marks are a factor). See under Details.
  }
  \item{i}{Number or character string identifying the type (mark value)
    of the points in \code{X} \bold{from} which distances are measured.
  }
  \item{j}{Number or character string identifying the type (mark value)
    of the points in \code{X} \bold{to} which distances are measured.
  }
  \item{eps}{A positive number.
    The resolution of the discrete approximation to Euclidean
    distance (see below). There is a sensible default.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which the function
    \eqn{J_{ij}(r)}{Jij(r)} should be evaluated.
    There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).

  Essentially a data frame containing six numeric columns 
  \item{J}{the recommended
    estimator of \eqn{J_{ij}(r)}{Jij(r)},
    currently the Kaplan-Meier estimator.
  }
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{J_{ij}(r)}{Jij(r)} has been  estimated
  }
  \item{km}{the Kaplan-Meier 
    estimator of \eqn{J_{ij}(r)}{Jij(r)}
  }
  \item{rs}{the ``reduced sample'' or ``border correction''
    estimator of \eqn{J_{ij}(r)}{Jij(r)}
  }
  \item{un}{the ``uncorrected'' 
    estimator of \eqn{J_{ij}(r)}{Jij(r)}
    formed by taking the ratio of uncorrected empirical estimators
    of \eqn{1 - G_{ij}(r)}{1 - Gij(r)}
    and \eqn{1 - F_{j}(r)}{1 - Fj(r)}, see
    \code{\link{Gdot}} and \code{\link{Fest}}.
  }
  \item{theo}{the theoretical value of  \eqn{J_{ij}(r)}{Jij(r)}
    for a marked Poisson process, namely 1.
  }
  The result also has two attributes \code{"G"} and \code{"F"}
  which are respectively the outputs of \code{\link{Gcross}}
  and \code{\link{Fest}} for the point pattern.
}
\details{
  This function \code{Jcross} and its companions
  \code{\link{Jdot}} and \code{\link{Jmulti}}
  are generalisations of the function \code{\link{Jest}}
  to multitype point patterns. 

  A multitype point pattern is a spatial pattern of
  points classified into a finite number of possible
  ``colours'' or ``types''. In the \code{spatstat} package,
  a multitype pattern is represented as a single 
  point pattern object in which the points carry marks,
  and the mark value attached to each point
  determines the type of that point.
  
  The argument \code{X} must be a point pattern (object of class
  \code{"ppp"}) or any data that are acceptable to \code{\link{as.ppp}}.
  It must be a marked point pattern, and the mark vector
  \code{X$marks} must be a factor.
  The argument \code{i} will be interpreted as a
  level of the factor \code{X$marks}. (Warning: this means that
  an integer value \code{i=3} will be interpreted as the 3rd smallest level,
  not the number 3). 
  
  The ``type \eqn{i} to type \eqn{j}'' multitype \eqn{J} function 
  of a stationary multitype point process \eqn{X}
  was introduced by Van lieshout and Baddeley (1999). It is defined by
  \deqn{J_{ij}(r) = \frac{1 - G_{ij}(r)}{1 -
      F_{j}(r)}}{Jij(r) = (1 - Gij(r))/(1-Fj(r))}
  where \eqn{G_{ij}(r)}{Gij(r)} is the distribution function of
  the distance from a type \eqn{i} point to the nearest point of type \eqn{j},
  and \eqn{F_{j}(r)}{Fj(r)} is the distribution
  function of the distance from a fixed point in space to the nearest
  point of type \eqn{j} in the pattern.

  An estimate of \eqn{J_{ij}(r)}{Jij(r)}
  is a useful summary statistic in exploratory data analysis
  of a multitype point pattern. 
  If the subprocess of type \eqn{i} points is independent
  of the subprocess of points of type \eqn{j},
  then \eqn{J_{ij}(r) \equiv 1}{Jij(r) = 1}.
  Hence deviations of the empirical estimate of
  \eqn{J_{ij}}{Jij} from the value 1
  may suggest dependence between types.

  This algorithm estimates \eqn{J_{ij}(r)}{Jij(r)} 
  from the point pattern \code{X}. It assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape.
  Biases due to edge effects are
  treated in the same manner as in \code{\link{Jest}},
  using the Kaplan-Meier and border corrections.
  The main work is done by \code{\link{Gmulti}} and \code{\link{Fest}}.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{J_{ij}(r)}{Jij(r)} should be evaluated. 
  The values of \eqn{r} must be increasing nonnegative numbers
  and the maximum \eqn{r} value must exceed the radius of the
  largest disc contained in the window.
}
\references{
  Van Lieshout, M.N.M. and Baddeley, A.J. (1996)
  A nonparametric measure of spatial interaction in point patterns.
  \emph{Statistica Neerlandica} \bold{50}, 344--361.

  Van Lieshout, M.N.M. and Baddeley, A.J. (1999)
  Indices of dependence between types in multivariate point patterns.
  \emph{Scandinavian Journal of Statistics} \bold{26}, 511--532.

}
\section{Warnings}{
  The argument \code{i} is interpreted as
  a level of the factor \code{X$marks}. Beware of the usual
  trap with factors: numerical values are not
  interpreted in the same way as character values. See the first example.
}
\seealso{
 \code{\link{Jdot}},
 \code{\link{Jest}},
 \code{\link{Jmulti}}
}
\examples{
     # Lansing woods data: 6 types of trees
    data(lansing)

    \testonly{
       lansing <- lansing[seq(1,lansing$n, by=30), ]
    }
    Jhm <- Jcross(lansing, "hickory", "maple")
    # diagnostic plot for independence between hickories and maples
    plot(Jhm)

    # synthetic example with two marks "a" and "b"
    pp <- runifpoispp(50)
    pp <- pp \%mark\% sample(c("a","b"), pp$n, replace=TRUE)
    J <- Jcross(pp, "a", "b")
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Jdot}
\alias{Jdot}
\title{
  Multitype J Function (i-to-any)
}
\description{
  For a multitype point pattern, 
  estimate the multitype \eqn{J} function 
  summarising the interpoint dependence between
  the type \eqn{i} points and the points of any type.
}
\synopsis{
Jdot(X, i=1, eps=NULL, r=NULL, breaks=NULL)
}
\usage{
Jdot(X, i=1)
Jdot(X, i=1, eps, r)
Jdot(X, i=1, eps, breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of the multitype \eqn{J} function
    \eqn{J_{i\bullet}(r)}{Ji.(r)} will be computed.
    It must be a multitype point pattern (a marked point pattern
    whose marks are a factor). See under Details.
  }
  \item{i}{Number or character string identifying the type (mark value)
    of the points in \code{X} from which distances are measured.
  }
  \item{eps}{A positive number.
    The resolution of the discrete approximation to Euclidean
    distance (see below). There is a sensible default.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which the function
    \eqn{J_{i\bullet}(r)}{Ji.(r)} should be evaluated.
    There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).

  Essentially a data frame containing six numeric columns 
  \item{J}{the recommended
    estimator of \eqn{J_{i\bullet}(r)}{Ji.(r)},
    currently the Kaplan-Meier estimator.
  }
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{J_{i\bullet}(r)}{Ji.(r)} has been  estimated
  }
  \item{km}{the Kaplan-Meier 
    estimator of \eqn{J_{i\bullet}(r)}{Ji.(r)}
  }
  \item{rs}{the ``reduced sample'' or ``border correction''
    estimator of \eqn{J_{i\bullet}(r)}{Ji.(r)}
  }
  \item{un}{the ``uncorrected'' 
    estimator of \eqn{J_{i\bullet}(r)}{Ji.(r)}
    formed by taking the ratio of uncorrected empirical estimators
    of \eqn{1 - G_{i\bullet}(r)}{1 - Gi.(r)}
    and \eqn{1 - F_{\bullet}(r)}{1 - F.(r)}, see
    \code{\link{Gdot}} and \code{\link{Fest}}.
  }
  \item{theo}{the theoretical value of  \eqn{J_{i\bullet}(r)}{Ji.(r)}
    for a marked Poisson process, namely 1.
  }
  The result also has two attributes \code{"G"} and \code{"F"}
  which are respectively the outputs of \code{\link{Gdot}}
  and \code{\link{Fest}} for the point pattern.
}
\details{
  This function \code{Jdot} and its companions
  \code{\link{Jcross}} and \code{\link{Jmulti}}
  are generalisations of the function \code{\link{Jest}}
  to multitype point patterns. 

  A multitype point pattern is a spatial pattern of
  points classified into a finite number of possible
  ``colours'' or ``types''. In the \code{spatstat} package,
  a multitype pattern is represented as a single 
  point pattern object in which the points carry marks,
  and the mark value attached to each point
  determines the type of that point.
  
  The argument \code{X} must be a point pattern (object of class
  \code{"ppp"}) or any data that are acceptable to \code{\link{as.ppp}}.
  It must be a marked point pattern, and the mark vector
  \code{X$marks} must be a factor.
  The argument \code{i} will be interpreted as a
  level of the factor \code{X$marks}. (Warning: this means that
  an integer value \code{i=3} will be interpreted as the 3rd smallest level,
  not the number 3). 
  
  The ``type \eqn{i} to any type'' multitype \eqn{J} function 
  of a stationary multitype point process \eqn{X}
  was introduced by Van lieshout and Baddeley (1999). It is defined by
  \deqn{J_{i\bullet}(r) = \frac{1 - G_{i\bullet}(r)}{1 -
      F_{\bullet}(r)}}{Ji.(r) = (1 - Gi.(r))/(1-F.(r))}
  where \eqn{G_{i\bullet}(r)}{Gi.(r)} is the distribution function of
  the distance from a type \eqn{i} point to the nearest other point
  of the pattern, and \eqn{F_{\bullet}(r)}{F.(r)} is the distribution
  function of the distance from a fixed point in space to the nearest
  point of the pattern.

  An estimate of \eqn{J_{i\bullet}(r)}{Ji.(r)}
  is a useful summary statistic in exploratory data analysis
  of a multitype point pattern. If the pattern is 
  a marked Poisson point process, then
  \eqn{J_{i\bullet}(r) \equiv 1}{Ji.(r) = 1}.
  If the subprocess of type \eqn{i} points is independent
  of the subprocess of points of all types not equal to \eqn{i},
  then \eqn{J_{i\bullet}(r)}{Ji.(r)} equals
  \eqn{J_{ii}(r)}{Jii(r)}, the ordinary \eqn{J} function
  (see \code{\link{Jest}} and Van Lieshout and Baddeley (1996))
  of the points of type \eqn{i}. 
  Hence deviations from zero of the empirical estimate of
  \eqn{J_{i\bullet} - J_{ii}}{Ji.-Jii} 
  may suggest dependence between types.

  This algorithm estimates \eqn{J_{i\bullet}(r)}{Ji.(r)} 
  from the point pattern \code{X}. It assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape.
  Biases due to edge effects are
  treated in the same manner as in \code{\link{Jest}},
  using the Kaplan-Meier and border corrections.
  The main work is done by \code{\link{Gmulti}} and \code{\link{Fest}}.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{J_{i\bullet}(r)}{Ji.(r)} should be evaluated. 
  The values of \eqn{r} must be increasing nonnegative numbers
  and the maximum \eqn{r} value must exceed the radius of the
  largest disc contained in the window.
}
\references{
  Van Lieshout, M.N.M. and Baddeley, A.J. (1996)
  A nonparametric measure of spatial interaction in point patterns.
  \emph{Statistica Neerlandica} \bold{50}, 344--361.

  Van Lieshout, M.N.M. and Baddeley, A.J. (1999)
  Indices of dependence between types in multivariate point patterns.
  \emph{Scandinavian Journal of Statistics} \bold{26}, 511--532.

}
\section{Warnings}{
  The argument \code{i} is interpreted as
  a level of the factor \code{X$marks}. Beware of the usual
  trap with factors: numerical values are not
  interpreted in the same way as character values. See the first example.
}
\seealso{
 \code{\link{Jcross}},
 \code{\link{Jest}},
 \code{\link{Jmulti}}
}
\examples{
     # Lansing woods data: 6 types of trees
    data(lansing)

    \testonly{
        lansing <- lansing[seq(1,lansing$n, by=30), ]
    }
    Jh. <- Jdot(lansing, "hickory")
    plot(Jh.)
    # diagnostic plot for independence between hickories and other trees
    Jhh <- Jest(lansing[lansing$marks == "hickory", ])
    plot(Jhh, add=TRUE)

    # synthetic example with two marks "a" and "b"
    pp <- runifpoispp(50)
    pp <- pp \%mark\% sample(c("a","b"), pp$n, replace=TRUE)
    J <- Jdot(pp, "a")
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Jest}
\alias{Jest}
\title{Estimate the J-function}
\description{
  Estimates the summary function \eqn{J(r)} for a point pattern in a 
  window of arbitrary shape.
}
\synopsis{
  Jest(X, eps=NULL, r=NULL, breaks=NULL)
}
\usage{
  Jest(X)
  Jest(X, eps)
  Jest(X, eps, r)
  Jest(X, eps, breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of \eqn{J(r)} will be computed.
    An object of class \code{"ppp"}, or data
    in any format acceptable to \code{\link{as.ppp}()}.
  }
  \item{eps}{
    the resolution of the discrete approximation to Euclidean distance
    (see below). There is a sensible default.
  }
  \item{r}{vector of values for the argument \eqn{r} at which \eqn{J(r)} 
    should be evaluated. There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \code{r}.
  }
  \item{breaks}{
    An alternative to the argument \code{r}. Not normally invoked by the user.
    See Details section.
  }
}
\value{
  An object of class \code{"fv"}, see \code{\link{fv.object}},
  which can be plotted directly using \code{\link{plot.fv}}.

  Essentially a data frame containing
  \item{r}{the vector of values of the argument \eqn{r} 
    at which the function \eqn{J} has been  estimated}
  \item{J}{the recommended estimate of \eqn{J(r)}, which is the 
    Kaplan-Meier estimate \code{km}}
  \item{rs}{the ``reduced sample'' or ``border correction''
              estimator of \eqn{J(r)} computed from
	      the border-corrected estimates of \eqn{F} and \eqn{G} }
  \item{km}{the spatial Kaplan-Meier estimator of \eqn{J(r)} computed from
    the Kaplan-Meier estimates of \eqn{F} and \eqn{G} }
  \item{un}{the uncorrected estimate of \eqn{J(r)}
             computed from the uncorrected estimates of \eqn{F} and
	     \eqn{G}
  }
  \item{theo}{the theoretical value of \eqn{J(r)}
    for a stationary Poisson process: identically equal to \eqn{1}
  }
  The data frame also has \bold{attributes}
  \item{F}{
    the output of \code{\link{Fest}} for this point pattern,
    containing three estimates of the empty space function \eqn{F(r)}
    and an estimate of its hazard function
  }
  \item{G}{
    the output of \code{\link{Gest}} for this point pattern,
    containing three estimates of the nearest neighbour distance distribution
    function \eqn{G(r)} and an estimate of its hazard function
  }
}
\note{
  Sizeable amounts of memory may be needed during the calculation.
}
\details{
  The \eqn{J} function (Van Lieshout and Baddeley ,1996)
  of a stationary point process is defined as 
  \deqn{J(r) = \frac{1-G(r)}{1-F(r)} }{ %
    J(r) = (1-G(r))/(1-F(r))}
  where \eqn{G(r)} is the nearest neighbour distance distribution
  function of the point process (see \code{\link{Gest}}) 
  and \eqn{F(r)} is its empty space function (see \code{\link{Fest}}).

  For a completely random (uniform Poisson) point process,
  the \eqn{J}-function is identically equal to \eqn{1}. 
  Deviations \eqn{J(r) < 1} or \eqn{J(r) > 1}
  typically indicate spatial clustering or spatial regularity, respectively.
  The \eqn{J}-function is one of the few characteristics that can be
  computed explicitly for a wide range of point processes. 
  See Van Lieshout and Baddeley (1996), Baddeley et al (2000),
  Thonnes and Van Lieshout (1999)  for further information.

  An estimate of \eqn{J} derived from a spatial point pattern dataset
  can be used in exploratory data analysis and formal inference
  about the pattern. The estimate of \eqn{J(r)} is compared against the 
  constant function \eqn{1}.
  Deviations \eqn{J(r) < 1} or \eqn{J(r) > 1}
  may suggest spatial clustering or spatial regularity, respectively.

  This algorithm estimates the \eqn{J}-function
  from the point pattern \code{X}. It assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window. 
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape. 

  The argument \code{X} is interpreted as a point pattern object 
  (of class \code{"ppp"}, see \code{\link{ppp.object}}) and can
  be supplied in any of the formats recognised by
  \code{\link{as.ppp}()}. 

  The functions \code{\link{Fest}} and \code{\link{Gest}} are called to 
  compute estimates of \eqn{F(r)} and \eqn{G(r)} respectively.
  These estimates are then combined by simply taking the ratio
  \eqn{J(r) = (1-G(r))/(1-F(r))}.

  In fact three different estimates are computed
  using different edge corrections (Baddeley, 1998).
  The Kaplan-Meier estimate (returned as \code{km}) is the ratio 
  \code{J = (1-G)/(1-F)} of the Kaplan-Meier estimates of
  \eqn{1-F} and \eqn{1-G} computed by
  \code{\link{Fest}} and \code{\link{Gest}} respectively.
  The reduced-sample or border corrected estimate
  (returned as \code{rs}) is
  the same ratio \code{J = (1-G)/(1-F)}
  of the border corrected estimates. 
  These estimators are slightly biased for \eqn{J}, 
  since they are ratios
  of approximately unbiased estimators. The logarithm of the
  Kaplan-Meier estimate is unbiased for \eqn{\log J}{log J}.

  The uncorrected estimate (returned as \code{un})
  is the ratio \code{J = (1-G)/(1-F)}
  of the uncorrected (``raw'') estimates of the survival functions
  of \eqn{F} and \eqn{G},
  which are the empirical distribution functions of the 
  empty space distances \code{Fest(X,\dots)$raw}
  and of the nearest neighbour distances 
  \code{Gest(X,\dots)$raw}. The uncorrected estimates
  of \eqn{F} and \eqn{G} are severely biased.
  However the uncorrected estimate of \eqn{J}
  is approximately unbiased (if the process is close to Poisson);
  it is insensitive to edge effects, and should be used when
  edge effects are severe (see Baddeley et al, 2000).

  The algorithm for \code{\link{Fest}}
  uses two discrete approximations which are controlled
  by the parameter \code{eps} and by the spacing of values of \code{r}
  respectively. See \code{\link{Fest}} for details.
  First-time users are strongly advised not to specify these arguments.

  Note that the value returned by \code{Jest} includes 
  the output of \code{\link{Fest}} and \code{\link{Gest}}
  as attributes (see the last example below).
  If the user is intending to compute the \code{F,G} and \code{J}
  functions for the point pattern, it is only necessary to
  call \code{Jest}.
}
\references{
  Baddeley, A.J. Spatial sampling and censoring.
     In O.E. Barndorff-Nielsen, W.S. Kendall and
     M.N.M. van Lieshout (eds) 
     \emph{Stochastic Geometry: Likelihood and Computation}.
     Chapman and Hall, 1998.
     Chapter 2, pages 37--78.
  
  Baddeley, A.J. and Gill, R.D. 
    The empty space hazard of a spatial pattern.
    Research Report 1994/3, Department of Mathematics,
    University of Western Australia, May 1994.

  Baddeley, A.J. and Gill, R.D.
     Kaplan-Meier estimators of interpoint distance
		distributions for spatial point processes.
     \emph{Annals of Statistics} \bold{25} (1997) 263--292.

  Baddeley, A., Kerscher, M., Schladitz, K. and Scott, B.T.
  Estimating the \emph{J} function without edge correction.
  \emph{Statistica Neerlandica} \bold{54} (2000) 315--328.

  Borgefors, G.
     Distance transformations in digital images.
     \emph{Computer Vision, Graphics and Image Processing}
     \bold{34} (1986) 344--371.

  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
    Academic Press, 1983.

  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J.
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag, 1995.

  Thonnes, E. and Van Lieshout, M.N.M,
  A comparative study on the power of Van Lieshout and Baddeley's J-function.
  \emph{Biometrical Journal} \bold{41} (1999) 721--734.

  Van Lieshout, M.N.M. and Baddeley, A.J.
  A nonparametric measure of spatial interaction in point patterns.
  \emph{Statistica Neerlandica} \bold{50} (1996) 344--361.

}
\seealso{
  \code{\link{Fest}},
  \code{\link{Gest}},
  \code{\link{Kest}},
  \code{\link{km.rs}},
  \code{\link{reduced.sample}},
  \code{\link{kaplan.meier}}
}
\examples{
   data(cells)
   J <- Jest(cells, 0.01)
   plot(J, main="cells data")
   # values are far above J= 1, indicating regular pattern

   data(redwood)
   J <- Jest(redwood, 0.01)
   plot(J, main="redwood data")
   # values are below J= 1, indicating clustered pattern
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Jmulti}
\alias{Jmulti}
\title{
  Marked J Function
}
\description{
  For a marked point pattern, 
  estimate the multitype \eqn{J} function
  summarising dependence between the
  points in subset \code{I}
  and those in subset \eqn{J}.
}
\synopsis{
  Jmulti(X, I, J, eps=NULL, r=NULL, breaks=NULL)
}
\usage{
Jmulti(X, I, J)
Jmulti(X, I, J, eps, r)
Jmulti(X, I, J, eps, breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of the multitype distance distribution function
    \eqn{J_{IJ}(r)}{JIJ(r)} will be computed.
    It must be a marked point pattern.
    See under Details.
  }
  \item{I}{Subset of points of \code{X} from which distances are
    measured. 
  }
  \item{J}{Subset of points in \code{X} to which distances are measured.
  }
  \item{eps}{A positive number.
    The pixel resolution of the discrete approximation to Euclidean
    distance (see \code{\link{Jest}}). There is a sensible default.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which the distribution function
    \eqn{J_{IJ}(r)}{JIJ(r)} should be evaluated.
    There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).

  Essentially a data frame containing six numeric columns 
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{J_{IJ}(r)}{JIJ(r)} has been  estimated
  }
  \item{rs}{the ``reduced sample'' or ``border correction''
    estimator of \eqn{J_{IJ}(r)}{JIJ(r)}
  }
  \item{km}{the spatial Kaplan-Meier estimator of \eqn{J_{IJ}(r)}{JIJ(r)}
  }
  \item{un}{the uncorrected estimate of \eqn{J_{IJ}(r)}{JIJ(r)},
    formed by taking the ratio of uncorrected empirical estimators
    of \eqn{1 - G_{IJ}(r)}{1 - GIJ(r)}
    and \eqn{1 - F_{J}(r)}{1 - FJ(r)}, see
    \code{\link{Gdot}} and \code{\link{Fest}}.
  }
  \item{theo}{the theoretical value of \eqn{J_{IJ}(r)}{JIJ(r)}
    for a marked Poisson process with the same estimated intensity,
    namely 1.
  }
}
\details{
  The function \code{Jmulti}
  generalises \code{\link{Jest}} (for unmarked point
  patterns) and \code{\link{Jdot}} and \code{\link{Jcross}} (for
  multitype point patterns) to arbitrary marked point patterns.

  Suppose \eqn{X_I}{X[I]}, \eqn{X_J}{X[J]} are subsets, possibly
  overlapping, of a marked point process. Define
  \deqn{J_{IJ}(r) = \frac{1 - G_{IJ}(r)}{1 - F_J(r)}}{
    JIJ(r) = (1 - GIJ(r))/(1 - FJ(r))}
  where \eqn{F_J(r)}{FJ(r)} is the cumulative distribution function of
  the distance from a fixed location to the nearest point
  of \eqn{X_J}{X[J]}, and \eqn{G_{IJ}(r)}{GJ(r)}
  is the distribution function of the distance
  from a typical point of  \eqn{X_I}{X[I]} to the nearest distinct point of
  \eqn{X_J}{X[J]}. 

  The argument \code{X} must be a point pattern (object of class
  \code{"ppp"}) or any data that are acceptable to \code{\link{as.ppp}}.

  The arguments \code{I} and \code{J} specify two subsets of the
  point pattern. They may be logical vectors of length equal to
  \code{X$n}, or integer vectors with entries in the range 1 to
  \code{X$n}, etc.

  It is assumed that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape.
  Biases due to edge effects are
  treated in the same manner as in \code{\link{Jest}}.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{J_{IJ}(r)}{JIJ(r)} should be evaluated. 
  It is also used to determine the breakpoints
  (in the sense of \code{\link{hist}})
  for the computation of histograms of distances. The reduced-sample and
  Kaplan-Meier estimators are computed from histogram counts. 
  In the case of the Kaplan-Meier estimator this introduces a discretisation
  error which is controlled by the fineness of the breakpoints.

  First-time users would be strongly advised not to specify \code{r}.
  However, if it is specified, \code{r} must satisfy \code{r[1] = 0}, 
  and \code{max(r)} must be larger than the radius of the largest disc 
  contained in the window. Furthermore, the successive entries of \code{r}
  must be finely spaced.
}
\references{
  Van Lieshout, M.N.M. and Baddeley, A.J. (1999)
  Indices of dependence between types in multivariate point patterns.
  \emph{Scandinavian Journal of Statistics} \bold{26}, 511--532.

}
\seealso{
 \code{\link{Jcross}},
 \code{\link{Jdot}},
 \code{\link{Jest}}
}
\examples{
    data(longleaf)
     # Longleaf Pine data: marks represent diameter
    \testonly{
        longleaf <- longleaf[seq(1,longleaf$n, by=50), ]
    }
    Jm <- Jmulti(longleaf, longleaf$marks <= 15, longleaf$marks >= 25)
    plot(Jm)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Kcross}
\alias{Kcross}
\title{
  Multitype K Function (Cross-type)
}
\description{
  For a multitype point pattern, 
  estimate the multitype \eqn{K} function
  which counts the expected number of points of type \eqn{j}
  within a given distance of a point of type \eqn{i}.
}
\synopsis{
Kcross(X, i=1, j=2, r=NULL, breaks=NULL, correction, \dots)
}
\usage{
Kcross(X, i=1, j=2)
Kcross(X, i=1, j=2, correction=c("border", "isotropic", "Ripley", "translate"))
Kcross(X, i=1, j=2, r, correction)
Kcross(X, i=1, j=2, breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of the cross type \eqn{K} function
    \eqn{K_{ij}(r)}{Kij(r)} will be computed.
    It must be a multitype point pattern (a marked point pattern
    whose marks are a factor). See under Details.
  }
  \item{i}{Number or character string identifying the type (mark value)
    of the points in \code{X} from which distances are measured.
  }
  \item{j}{Number or character string identifying the type (mark value)
    of the points in \code{X} to which distances are measured.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which the distribution function
    \eqn{K_{ij}(r)}{Kij(r)} should be evaluated.
    There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
  \item{correction}{
    A character vector containing any selection of the
    options \code{"border"}, \code{"bord.modif"},
    \code{"isotropic"}, \code{"Ripley"} or \code{"translate"}.
    It specifies the edge correction(s) to be applied.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).

  Essentially a data frame containing numeric columns 
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{K_{ij}(r)}{Kij(r)} has been  estimated
  }
  \item{theo}{the theoretical value of  \eqn{K_{ij}(r)}{Kij(r)}
    for a marked Poisson process, namely \eqn{\pi r^2}{pi * r^2}
  }
  together with a column or columns named 
  \code{"border"}, \code{"bord.modif"},
  \code{"iso"} and/or \code{"trans"},
  according to the selected edge corrections. These columns contain
  estimates of the function \eqn{K_{ij}(r)}{Kij(r)}
  obtained by the edge corrections named.
}
\details{
  This function \code{Kcross} and its companions
  \code{\link{Kdot}} and \code{\link{Kmulti}}
  are generalisations of the function \code{\link{Kest}}
  to multitype point patterns. 

  A multitype point pattern is a spatial pattern of
  points classified into a finite number of possible
  ``colours'' or ``types''. In the \code{spatstat} package,
  a multitype pattern is represented as a single 
  point pattern object in which the points carry marks,
  and the mark value attached to each point
  determines the type of that point.
  
  The argument \code{X} must be a point pattern (object of class
  \code{"ppp"}) or any data that are acceptable to \code{\link{as.ppp}}.
  It must be a marked point pattern, and the mark vector
  \code{X$marks} must be a factor.
  The arguments \code{i} and \code{j} will be interpreted as
  levels of the factor \code{X$marks}. (Warning: this means that
  an integer value \code{i=3} will be interpreted as the 3rd smallest level,
  not the number 3). 
  
  The ``cross-type'' (type \eqn{i} to type \eqn{j})
  \eqn{K} function 
  of a stationary multitype point process \eqn{X} is defined so that
  \eqn{\lambda_j K_{ij}(r)}{lambda[j] Kij(r)} equals the expected number of
  additional random points of type \eqn{j}
  within a distance \eqn{r} of a
  typical point of type \eqn{i} in the process \eqn{X}.
  Here \eqn{\lambda_j}{lambda[j]}
  is the intensity of the type \eqn{j} points,
  i.e. the expected number of points of type \eqn{j} per unit area.
  The function \eqn{K_{ij}}{Kij} is determined by the 
  second order moment properties of \eqn{X}.

  An estimate of \eqn{K_{ij}(r)}{Kij(r)}
  is a useful summary statistic in exploratory data analysis
  of a multitype point pattern.
  If the process of type \eqn{i} points
  were independent of the process of type \eqn{j} points,
  then \eqn{K_{ij}(r)}{Kij(r)} would equal \eqn{\pi r^2}{pi * r^2}.
  Deviations between the empirical \eqn{K_{ij}}{Kij} curve
  and the theoretical curve \eqn{\pi r^2}{pi * r^2} 
  may suggest dependence between the points of types \eqn{i} and \eqn{j}.

  This algorithm estimates the distribution function \eqn{K_{ij}(r)}{Kij(r)} 
  from the point pattern \code{X}. It assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape.
  Biases due to edge effects are
  treated in the same manner as in \code{\link{Kest}},
  using the border correction.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{K_{ij}(r)}{Kij(r)} should be evaluated. 
  The values of \eqn{r} must be increasing nonnegative numbers
  and the maximum \eqn{r} value must exceed the radius of the
  largest disc contained in the window.

  The pair correlation function can also be applied to the
  result of \code{Kcross}; see \code{\link{pcf}}.
}
\references{
  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
    Academic Press, 1983.

  Harkness, R.D and Isham, V. (1983)
  A bivariate spatial point pattern of ants' nests.
  \emph{Applied Statistics} \bold{32}, 293--303
 
  Lotwick, H. W. and Silverman, B. W. (1982).
  Methods for analysing spatial processes of several types of points.
  \emph{J. Royal Statist. Soc. Ser. B} \bold{44}, 406--413.

  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J.
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag, 1995.

}
\section{Warnings}{
  The arguments \code{i} and \code{j} are interpreted as
  levels of the factor \code{X$marks}. Beware of the usual
  trap with factors: numerical values are not
  interpreted in the same way as character values. See the first example.

  The reduced sample estimator of \eqn{K_{ij}}{Kij} is pointwise approximately 
  unbiased, but need not be a valid distribution function; it may 
  not be a nondecreasing function of \eqn{r}. Its range is always 
  within \eqn{[0,1]}.
}
\seealso{
 \code{\link{Kdot}},
 \code{\link{Kest}},
 \code{\link{Kmulti}},
 \code{\link{pcf}}
}
\examples{
    data(betacells)
     # cat retina data
    K01 <- Kcross(betacells, "off", "on") 
    plot(K01)

    K10 <- Kcross(betacells, "on", "off")

    # synthetic example    
    pp <- runifpoispp(50)
    pp <- pp \%mark\% factor(sample(0:1, pp$n, replace=TRUE))
    K <- Kcross(pp, "0", "1") # note: "0" not 0
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Kdot}
\alias{Kdot}
\title{
  Multitype K Function (i-to-any)
}
\description{
  For a multitype point pattern, 
  estimate the multitype \eqn{K} function
  which counts the expected number of other points of the process
  within a given distance of a point of type \eqn{i}.
}
\synopsis{
Kdot(X, i=1, r=NULL, breaks=NULL, correction, \dots)
}
\usage{
Kdot(X, i=1)
Kdot(X, i=1, correction=c("border", "isotropic", "Ripley", "translate"))
Kdot(X, i=1, r, correction)
Kdot(X, i=1, breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of the multitype \eqn{K} function
    \eqn{K_{i\bullet}(r)}{Ki.(r)} will be computed.
    It must be a multitype point pattern (a marked point pattern
    whose marks are a factor). See under Details.
  }
  \item{i}{Number or character string identifying the type (mark value)
    of the points in \code{X} from which distances are measured.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which the distribution function
    \eqn{K_{i\bullet}(r)}{Ki.(r)} should be evaluated.
    There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
  \item{correction}{
    A character vector containing any selection of the
    options \code{"border"}, \code{"bord.modif"},
    \code{"isotropic"}, \code{"Ripley"} or \code{"translate"}.
    It specifies the edge correction(s) to be applied.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).

  Essentially a data frame containing numeric columns 
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{K_{i\bullet}(r)}{Ki.(r)} has been  estimated
  }
  \item{theo}{the theoretical value of  \eqn{K_{i\bullet}(r)}{Ki.(r)}
    for a marked Poisson process, namely \eqn{\pi r^2}{pi * r^2}
  }
  together with a column or columns named 
  \code{"border"}, \code{"bord.modif"},
  \code{"iso"} and/or \code{"trans"},
  according to the selected edge corrections. These columns contain
  estimates of the function \eqn{K_{i\bullet}(r)}{Ki.(r)}
  obtained by the edge corrections named.
}
\details{
  This function \code{Kdot} and its companions
  \code{\link{Kcross}} and \code{\link{Kmulti}}
  are generalisations of the function \code{\link{Kest}}
  to multitype point patterns. 

  A multitype point pattern is a spatial pattern of
  points classified into a finite number of possible
  ``colours'' or ``types''. In the \code{spatstat} package,
  a multitype pattern is represented as a single 
  point pattern object in which the points carry marks,
  and the mark value attached to each point
  determines the type of that point.
  
  The argument \code{X} must be a point pattern (object of class
  \code{"ppp"}) or any data that are acceptable to \code{\link{as.ppp}}.
  It must be a marked point pattern, and the mark vector
  \code{X$marks} must be a factor.
  The argument \code{i} will be interpreted as a
  level of the factor \code{X$marks}. (Warning: this means that
  an integer value \code{i=3} will be interpreted as the 3rd smallest level,
  not the number 3). 
  
  The ``type \eqn{i} to any type'' multitype \eqn{K} function 
  of a stationary multitype point process \eqn{X} is defined so that
  \eqn{\lambda K_{i\bullet}(r)}{lambda Ki.(r)}
  equals the expected number of
  additional random points within a distance \eqn{r} of a
  typical point of type \eqn{i} in the process \eqn{X}.
  Here \eqn{\lambda}{lambda}
  is the intensity of the process,
  i.e. the expected number of points of \eqn{X} per unit area.
  The function \eqn{K_{i\bullet}}{Ki.} is determined by the 
  second order moment properties of \eqn{X}.

  An estimate of \eqn{K_{i\bullet}(r)}{Ki.(r)}
  is a useful summary statistic in exploratory data analysis
  of a multitype point pattern.
  If the subprocess of type \eqn{i} points were independent
  of the subprocess of points of all types not equal to \eqn{i},
  then \eqn{K_{i\bullet}(r)}{Ki.(r)} would equal \eqn{\pi r^2}{pi * r^2}.
  Deviations between the empirical \eqn{K_{i\bullet}}{Ki.} curve
  and the theoretical curve \eqn{\pi r^2}{pi * r^2} 
  may suggest dependence between types.

  This algorithm estimates the distribution function \eqn{K_{i\bullet}(r)}{Ki.(r)} 
  from the point pattern \code{X}. It assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape.
  Biases due to edge effects are
  treated in the same manner as in \code{\link{Kest}},
  using the border correction.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{K_{i\bullet}(r)}{Ki.(r)} should be evaluated. 
  The values of \eqn{r} must be increasing nonnegative numbers
  and the maximum \eqn{r} value must exceed the radius of the
  largest disc contained in the window.

  The pair correlation function can also be applied to the
  result of \code{Kdot}; see \code{\link{pcf}}.
}
\references{
  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
    Academic Press, 1983.

  Harkness, R.D and Isham, V. (1983)
  A bivariate spatial point pattern of ants' nests.
  \emph{Applied Statistics} \bold{32}, 293--303
 
  Lotwick, H. W. and Silverman, B. W. (1982).
  Methods for analysing spatial processes of several types of points.
  \emph{J. Royal Statist. Soc. Ser. B} \bold{44}, 406--413.

  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J.
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag, 1995.

}
\section{Warnings}{
  The argument \code{i} is interpreted as
  a level of the factor \code{X$marks}. Beware of the usual
  trap with factors: numerical values are not
  interpreted in the same way as character values. See the first example.

  The reduced sample estimator of \eqn{K_{i\bullet}}{Ki.} is pointwise approximately 
  unbiased, but need not be a valid distribution function; it may 
  not be a nondecreasing function of \eqn{r}. Its range is always 
  within \eqn{[0,1]}.
}
\seealso{
 \code{\link{Kdot}},
 \code{\link{Kest}},
 \code{\link{Kmulti}},
 \code{\link{pcf}}
}
\examples{
     # Lansing woods data: 6 types of trees
    data(lansing)

    \dontrun{
    Kh. <- Kdot(lansing, "hickory") 
    }
    \testonly{
    sub <- lansing[seq(1,lansing$n, by=80), ]
    Kh. <- Kdot(sub, "hickory") 
    }
    # diagnostic plot for independence between hickories and other trees
    plot(Kh.)

    # synthetic example with two marks "a" and "b"
    pp <- runifpoispp(50)
    pp <- pp \%mark\% sample(c("a","b"), pp$n, replace=TRUE)
    K <- Kdot(pp, "a")
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Kest}
\alias{Kest}
\title{K-function}
\description{
Estimates the reduced second moment function \eqn{K(r)} 
from a point pattern in a window of arbitrary shape.
}
\synopsis{
  Kest(X, r=NULL, breaks=NULL, slow,
     correction=c("border", "isotropic", "Ripley", "translate"), \dots)
}
\usage{
  Kest(X)
  Kest(X, r)
  Kest(X, r, correction=c("border", "isotropic", "Ripley", "translate"))
  Kest(X, breaks=breaks)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of \eqn{K(r)} will be computed.
    An object of class \code{"ppp"}, or data
    in any format acceptable to \code{\link{as.ppp}()}.
    }
    \item{r}{
      vector of values for the argument \eqn{r} at which \eqn{K(r)} 
      should be evaluated. There is a sensible default.
    }
    \item{breaks}{
      An alternative to the argument \code{r}.
      Not normally invoked by the user.
      See Details.
    }
    \item{correction}{
      A character vector containing any selection of the
      options \code{"border"}, \code{"bord.modif"},
      \code{"isotropic"}, \code{"Ripley"} or \code{"translate"}.
      It specifies the edge correction(s) to be applied.
    }
}
\value{
  An object of class \code{"fv"}, see \code{\link{fv.object}},
  which can be plotted directly using \code{\link{plot.fv}}.

  Essentially a data frame containing columns
  \item{r}{the vector of values of the argument \eqn{r} 
    at which the function \eqn{K} has been  estimated
  }
  \item{theo}{the theoretical value \eqn{K(r) = \pi r^2}{K(r) = pi * r^2}
    for a stationary Poisson process
  }
  together with columns named 
  \code{"border"}, \code{"bord.modif"},
  \code{"iso"} and/or \code{"trans"},
  according to the selected edge corrections. These columns contain
  estimates of the function \eqn{K(r)} obtained by the edge corrections
  named.
}
\details{
  The \eqn{K} function (variously called ``Ripley's K-function''
  and the ``reduced second moment function'')
  of a stationary point process \eqn{X} is defined so that
  \eqn{\lambda K(r)}{lambda K(r)} equals the expected number of
  additional random points within a distance \eqn{r} of a
  typical random point of \eqn{X}. Here \eqn{\lambda}{lambda}
  is the intensity of the process,
  i.e. the expected number of points of \eqn{X} per unit area.
  The \eqn{K} function is determined by the 
  second order moment properties of \eqn{X}.
 
  An estimate of \eqn{K} derived from a spatial point pattern dataset
  can be used in exploratory data analysis and formal inference
  about the pattern (Cressie, 1991; Diggle, 1983; Ripley, 1988).
  In exploratory analyses, the estimate of \eqn{K} is a useful statistic 
  summarising aspects of inter-point ``dependence'' and ``clustering''.
  For inferential purposes, the estimate of \eqn{K} is usually compared to the 
  true value of \eqn{K} for a completely random (Poisson) point process,
  which is \eqn{K(r) = \pi r^2}{K(r) = pi * r^2}.
  Deviations between the empirical and theoretical \eqn{K} curves
  may suggest spatial clustering or spatial regularity.
 
  This routine \code{Kest} estimates the \eqn{K} function
  of a stationary point process, given observation of the process
  inside a known, bounded window. 
  The argument \code{X} is interpreted as a point pattern object 
  (of class \code{"ppp"}, see \code{\link{ppp.object}}) and can
  be supplied in any of the formats recognised by
  \code{\link{as.ppp}()}.

  The estimation of \eqn{K} is hampered by edge effects arising from 
  the unobservability of points of the random pattern outside the window. 
  An edge correction is needed to reduce bias (Baddeley, 1998; Ripley, 1988). 
  The corrections implemented here are
  \describe{
    \item{border}{the border method or
      ``reduced sample'' estimator (see Ripley, 1988). This is
      the least efficient (statistically) and the fastest to compute.
      It can be computed for a window of arbitrary shape.
    }
    \item{isotropic/Ripley}{Ripley's isotropic correction
      (see Ripley, 1988; Ohser, 1983).
      This is currently implemented only for rectangular windows.
    }
    \item{translate}{Translation correction (Ohser, 1983).
      Implemented for all window geometries, but slow for
      complex windows. 
    }
  }
  Note that the estimator assumes the process is stationary (spatially
  homogeneous). For inhomogeneous point patterns, see
  \code{\link{Kinhom}}.

  The estimator \code{Kest} ignores marks.
  Its counterparts for multitype point patterns
  are \code{\link{Kcross}}, \code{\link{Kdot}},
  and for general marked point patterns
  see \code{\link{Kmulti}}. 

  Some writers, particularly Stoyan (1994, 1995) advocate the use of
  the ``pair correlation function''
  \deqn{
    g(r) = \frac{K'(r)}{2\pi r}
  }{
    g(r) = K'(r)/ ( 2 * pi * r) 
  }
  where \eqn{K'(r)} is the derivative of \eqn{K(r)}.
  See \code{\link{pcf}} on how to estimate this function.

}
\references{
Baddeley, A.J. Spatial sampling and censoring.
     In O.E. Barndorff-Nielsen, W.S. Kendall and
     M.N.M. van Lieshout (eds) 
     \emph{Stochastic Geometry: Likelihood and Computation}.
     Chapman and Hall, 1998.
     Chapter 2, pages 37--78.
  
  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
  Academic Press, 1983.

  Ohser, J. (1983)
  On estimators for the reduced second moment measure of
  point processes. \emph{Mathematische Operationsforschung und
  Statistik, series Statistics}, \bold{14}, 63 -- 71.
    
  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J. (1995)
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag.

  Stoyan, D. and Stoyan, H. (1994)
  Fractals, random shapes and point fields:
  methods of geometrical statistics.
  John Wiley and Sons.
} 
\section{Warnings}{
  The estimator of \eqn{K(r)} is approximately unbiased for each fixed \eqn{r}.
  Bias increases with \eqn{r} and depends on the window geometry.
  For a rectangular window it is prudent to restrict the \eqn{r} values to
  a maximum of \eqn{1/4} of the smaller side length of the rectangle.
  Bias may become appreciable for point patterns consisting of 
  fewer than 15 points.
 
  While \eqn{K(r)} is always a non-decreasing function, the estimator 
  of \eqn{K} is not guaranteed to be non-decreasing. This is rarely 
  a problem in practice.
}
\seealso{
  \code{\link{Fest}},
  \code{\link{Gest}},
  \code{\link{Jest}},
  \code{\link{pcf}},
  \code{\link{reduced.sample}},
  \code{\link{Kcross}},
  \code{\link{Kdot}},
  \code{\link{Kinhom}},
  \code{\link{Kmulti}}
}
\examples{
 pp <- runifpoint(50)
 K <- Kest(pp)
 data(cells)
 K <- Kest(cells, correction="isotropic")
 plot(K)
 plot(K, main="K function for cells")
 # plot the L function
 plot(K, sqrt(iso/pi) ~ r)
 plot(K, cbind(r, sqrt(iso/pi)) ~ r, ylab="L(r)", main="L function for cells")
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{Kest.fft}
\alias{Kest.fft}
\title{K-function using FFT}
\description{
Estimates the reduced second moment function \eqn{K(r)} 
from a point pattern in a window of arbitrary shape,
using the Fast Fourier Transform.
}
\usage{
  Kest.fft(X, sigma, r=NULL, breaks=NULL)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of \eqn{K(r)} will be computed.
    An object of class \code{"ppp"}, or data
    in any format acceptable to \code{\link{as.ppp}()}.
  }
  \item{sigma}{
    standard deviation of the isotropic Gaussian
    smoothing kernel.
  }
  \item{r}{
    vector of values for the argument \eqn{r} at which \eqn{K(r)} 
    should be evaluated. There is a sensible default.
  }
  \item{breaks}{
    An alternative to the argument \code{r}.
    Not normally invoked by the user.
    See Details.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).
  
  Essentially a data frame containing columns
  \item{r}{the vector of values of the argument \eqn{r} 
    at which the function \eqn{K} has been  estimated
  }
  \item{border}{the estimates of \eqn{K(r)} for these values of \eqn{r}
  }
  \item{theo}{the theoretical value \eqn{K(r) = \pi r^2}{K(r) = pi * r^2}
    for a stationary Poisson process
  }
}
\details{
  This is an alternative to the function \code{\link{Kest}}
  for estimating the \eqn{K} function. It may be useful for
  very large patterns of points.

  Whereas \code{\link{Kest}} computes the distance between
  each pair of points analytically, this function discretises the
  point pattern onto a rectangular pixel raster and applies
  Fast Fourier Transform techniques to estimate \eqn{K(t)}.
  The hard work is done by the function \code{\link{Kmeasure}}.

  The result is an approximation whose accuracy depends on the
  resolution of the pixel raster. The resolution is controlled
  by setting the parameter \code{npixel} in 
  \code{\link{spatstat.options}}.
}
\references{
  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
  Academic Press, 1983.

  Ohser, J. (1983)
  On estimators for the reduced second moment measure of
  point processes. \emph{Mathematische Operationsforschung und
  Statistik, series Statistics}, \bold{14}, 63 -- 71.
    
  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J. (1995)
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag.

  Stoyan, D. and Stoyan, H. (1994)
  Fractals, random shapes and point fields:
  methods of geometrical statistics.
  John Wiley and Sons.
} 
\seealso{
  \code{\link{Kest}},
  \code{\link{Kmeasure}},
  \code{\link{spatstat.options}}
}
\examples{
 pp <- runifpoint(10000)
 \dontrun{
 spatstat.options(npixel=512)
 }
 \testonly{
  spatstat.options(npixel=256)
 }
 Kpp <- Kest.fft(pp, 0.01)
 plot(Kpp)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{Kinhom}
\alias{Kinhom}
\title{Inhomogeneous K-function}
\description{
  Estimates the inhomogeneous \eqn{K} function of
  a non-stationary point pattern.
}
\usage{
  Kinhom(X, lambda, r = NULL, breaks = NULL, slow = FALSE,
    correction=c("border", "isotropic", "Ripley", "translate"), \dots)
}
\arguments{
  \item{X}{
    The observed data point pattern,
    from which an estimate of the inhomogeneous \eqn{K} function
    will be computed.
    An object of class \code{"ppp"}
    or in a format recognised by \code{\link{as.ppp}()}
  }
  \item{lambda}{
    Vector of values of the estimated intensity function,
    evaluated at the points of the pattern \code{X}.
    Alternatively this may be a matrix: 
    see Details.
  }
  \item{r}{
    vector of values for the argument \eqn{r} at which
    the inhomogeneous \eqn{K} function
    should be evaluated. Not normally given by the user;
    there is a sensible default.
  }
  \item{breaks}{
    An alternative to the argument \code{r}.
    Not normally invoked by the user.
    See Details.
  }
  \item{slow}{
    Not normally given by the user. 
    Logical flag which selects the algorithm used to compute the
    inhomogeneous \eqn{K} function. The default (\code{slow=FALSE})
    is faster than the alternative (\code{slow=TRUE}). The slow
    algorithm is retained for internal purposes as a check on
    validity.
  }
  \item{correction}{
      A character vector containing any selection of the
      options \code{"border"}, \code{"bord.modif"},
      \code{"isotropic"}, \code{"Ripley"} or \code{"translate"}.
      It specifies the edge correction(s) to be applied.
  }
  \item{\dots}{
    Currently ignored.
  }
} 
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).
  
  Essentially a data frame containing at least the following columns,
  \item{r}{the vector of values of the argument \eqn{r} 
    at which the pair correlation function \eqn{g(r)} has been  estimated
  }
  \item{theo}{vector of values of \eqn{\pi r^2}{pi * r^2},
    the theoretical value of \eqn{K_{\rm inhom}(r)}{Kinhom(r)}
    for an inhomogeneous Poisson process
  }
  and containing additional columns
  according to the choice specified in the \code{correction}
  argument. The additional columns are named
  \code{border}, \code{trans} and \code{iso}
  and give the estimated values of 
  \eqn{K_{\rm inhom}(r)}{Kinhom(r)}
  using the border correction, translation correction,
  and Ripley isotropic correction, respectively.
}
\details{
  This computes a generalisation of the \eqn{K} function
  for inhomogeneous point patterns, proposed by
  Baddeley, Moller and Waagepetersen (2000).
  
  The ``ordinary'' \eqn{K} function
  (variously known as the reduced second order moment function
  and Ripley's \eqn{K} function), is
  described under \code{\link{Kest}}. It is defined only
  for stationary point processes.
  
  The inhomogeneous \eqn{K} function
  \eqn{K_{\rm inhom}(r)}{Kinhom(r)}
  is a direct generalisation to nonstationary point processes.
  Suppose \eqn{x} is a point process with non-constant intensity
  \eqn{\lambda(u)}{lambda(u)} at each location \eqn{u}.
  Define \eqn{K_{\rm inhom}(r)}{Kinhom(r)} to be the expected
  value, given that \eqn{u} is a point of \eqn{x},
  of the sum of all terms
  \eqn{1/\lambda(u)\lambda(x_j)}{1/lambda(u)lambda(x[j])}
  over all points \eqn{x_j}{x[j]}
  in the process separated from \eqn{u} by a distance less than \eqn{r}.
  This reduces to the ordinary \eqn{K} function if
  \eqn{\lambda()}{lambda()} is constant.
  If \eqn{x} is an inhomogeneous Poisson process with intensity
  function \eqn{\lambda(u)}{lambda(u)}, then
  \eqn{K_{\rm inhom}(r) = \pi r^2}{Kinhom(r) = pi * r^2}.

  This allows us to inspect a point pattern for evidence of 
  interpoint interactions after allowing for spatial inhomogeneity
  of the pattern. Values 
  \eqn{K_{\rm inhom}(r) > \pi r^2}{Kinhom(r) > pi * r^2}
  are suggestive of clustering.

  The argument \code{lambda} should be a vector of length equal to the
  number of points in the pattern \code{X}. It will be interpreted as
  giving the (estimated) values of \eqn{\lambda(x_i)}{lambda(x[i])} for
  each point \eqn{x_i}{x[i]} of the pattern \eqn{x}.

  Alternatively \code{lambda} may be a square matrix of dimensions
  \eqn{n \times n}{n * n} where \eqn{n} is the number of points in
  \code{X}. In this case \code{lambda[i,j]} will be interpreted
  as an estimate of
  \eqn{\lambda(x_i)\lambda(x_j)}{lambda(x[i]) * lambda(x[j])}.

  Edge corrections are used to correct bias in the estimation
  of \eqn{K_{\rm inhom}}{Kinhom}, in exactly the same way
  as for the classical \eqn{K} function.
  See the documentation for \code{\link{Kest}}.
  
  The pair correlation function can also be applied to the
  result of \code{Kinhom}; see \code{\link{pcf}}.
}
\references{
  Baddeley, A., Moller, J. and Waagepetersen, R. (2000)
  Non- and semiparametric estimation of interaction in
  inhomogeneous point patterns.
  \emph{Statistica Neerlandica} \bold{54}, 329--350.
}
\seealso{
  \code{\link{Kest}},
  \code{\link{pcf}}
}
\examples{
  data(lansing)
  # inhomogeneous pattern of maples
  X <- unmark(lansing[lansing$marks == "maple",])
  \testonly{
     sub <- sample(c(TRUE,FALSE), X$n, replace=TRUE, prob=c(0.1,0.9))
     X <- X[sub , ]
  }
  # fit spatial trend
  fit <- ppm(X, ~ polynom(x,y,2), Poisson())
  # predict intensity values at points themselves
  lambda <- predict(fit, locations=X, type="trend")
  # inhomogeneous K function
  Ki <- Kinhom(X, lambda)
  plot(Ki)

  # SIMULATED DATA
  # known intensity function
  lamfun <- function(x,y) { 100 * x }
  # inhomogeneous Poisson process
  Y <- rpoispp(lamfun, 100, owin())
  # evaluate intensity at points of pattern
  lambda <- lamfun(Y$x, Y$y)
  # inhomogeneous K function
  Ki <- Kinhom(Y, lambda)
  plot(Ki)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Kmeasure}
\alias{Kmeasure}
\title{Reduced Second Moment Measure}
\description{
Estimates the reduced second moment measure \eqn{\kappa}{Kappa} 
from a point pattern in a window of arbitrary shape.
}
\usage{
  Kmeasure(X, sigma, edge=TRUE)
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of \eqn{\kappa}{Kappa} will be computed.
    An object of class \code{"ppp"}, or data
    in any format acceptable to \code{\link{as.ppp}()}.
    }
    \item{sigma}{
      standard deviation \eqn{\sigma}{sigma} of the Gaussian
      smoothing kernel.
    }
    \item{edge}{
      logical value indicating whether an edge correction
      should be applied.
    }
}
\value{
  A real-valued pixel image (an object of class \code{"im"},
  see \code{\link{im.object}}) whose pixel values are estimates
  of the value of the reduced second moment measure for each pixel
  (i.e. estimates of the integral of the second moment density
  over each pixel).
}
\details{
  The reduced second moment measure \eqn{\kappa}{Kappa}
  of a stationary point process \eqn{X} is defined so that,
  for a `typical' point \eqn{x} of the process, 
  the expected number of other points \eqn{y} of the process
  such that the vector \eqn{y - x} lies in a region \eqn{A},
  equals \eqn{\lambda \kappa(A)}{lambda Kappa(A)}.
  Here \eqn{\lambda}{lambda}
  is the intensity of the process,
  i.e. the expected number of points of \eqn{X} per unit area.

  The more familiar
  K-function \eqn{K(t)} is just the value of the reduced second moment measure
  for each disc centred at the origin; that is,
  \eqn{K(t) = \kappa(b(0,t))}{K(t) = Kappa(b(0,t))}.

  An estimate of \eqn{\kappa}{Kappa} derived from a spatial point
  pattern dataset can be useful in exploratory data analysis.
  Its advantage over the K-function is that it is also sensitive
  to anisotropy and directional effects. 

  This function computes an estimate of \eqn{\kappa}{Kappa}
  from a point pattern dataset \code{X},
  which is assumed to be a realisation of a stationary point process,
  observed inside a known, bounded window. Marks are ignored.

  The algorithm approximates the point pattern and its window by binary pixel
  images, introduces an isotropic Gaussian smoothing kernel
  and uses the Fast Fourier Transform \code{\link{fft}}
  to form a density estimate of \eqn{\kappa}{Kappa}. The calculation
  corresponds to the edge correction known as the ``translation
  correction''.

  The density estimate of \eqn{\kappa}{Kappa}
  is returned in the form of a real-valued pixel image.
  Pixel values are estimates of the
  integral of the second moment density over the pixel.
  (The uniform Poisson process would have values identically equal to
  \eqn{a} where \eqn{a} is the area of a pixel.)
  Sums of pixel values over a desired region \eqn{A} are estimates of the
  value of \eqn{\kappa(A)}{Kappa(A)}. The image \code{x} and \code{y}
  coordinates are on the same scale as vector displacements in the
  original point pattern window. The point \code{x=0, y=0} corresponds
  to the `typical point'.
  A peak in the image near \code{(0,0)} suggests clustering;
  a dip in the image near \code{(0,0)} suggests inhibition;
  peaks or dips at other positions suggest possible periodicity.
}
\references{
  Stoyan, D, Kendall, W.S. and Mecke, J. (1995)
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag.

  Stoyan, D. and Stoyan, H. (1994)
  Fractals, random shapes and point fields:
  methods of geometrical statistics.
  John Wiley and Sons.
} 
\seealso{
  \code{\link{Kest}},
  \code{\link{spatstat.options}},
  \code{\link{im.object}}
}
\examples{
 data(cells)
 image(Kmeasure(cells, 0.05))
 # shows pronounced dip around origin consistent with strong inhibition
 data(redwood)
 image(Kmeasure(redwood, 0.03), col=grey(seq(1,0,length=32)))
 # shows peaks at several places, reflecting clustering and ?periodicity
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{Kmulti}
\alias{Kmulti}
\title{
  Marked K-Function
}
\description{
  For a marked point pattern, 
  estimate the multitype \eqn{K} function
  which counts the expected number of points of subset \eqn{J}
  within a given distance from a typical point in subset \code{I}.
}
\synopsis{
Kmulti(X, I, J, r=NULL, breaks=NULL, correction, \dots)
}
\usage{
Kmulti(X, I, J, correction=c("border", "isotropic", "Ripley", "translate"))
Kmulti(X, I, J, r, correction=c("border", "isotropic", "Ripley", "translate"))
Kmulti(X, I, J, breaks, correction=c("border", "isotropic", "Ripley", "translate"))
}
\arguments{
  \item{X}{The observed point pattern, 
    from which an estimate of the multitype \eqn{K} function
    \eqn{K_{IJ}(r)}{KIJ(r)} will be computed.
    It must be a marked point pattern.
    See under Details.
  }
  \item{I}{Subset of points of \code{X} from which distances are
    measured. 
  }
  \item{J}{Subset of points in \code{X} to which distances are measured.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which the multitype \eqn{K} function
    \eqn{K_{IJ}(r)}{KIJ(r)} should be evaluated.
    There is a sensible default.
    First-time users are strongly advised not to specify this argument.
    See below for important conditions on \eqn{r}.
  }
  \item{breaks}{An alternative to the argument \code{r}.
    Not normally invoked by the user. See the \bold{Details} section.
  }
  \item{correction}{
    A character vector containing any selection of the
    options \code{"border"}, \code{"bord.modif"},
    \code{"isotropic"}, \code{"Ripley"} or \code{"translate"}.
    It specifies the edge correction(s) to be applied.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).
  
  Essentially a data frame containing numeric columns 
  \item{r}{the values of the argument \eqn{r} 
    at which the function \eqn{K_{IJ}(r)}{KIJ(r)} has been  estimated
  }
  \item{theo}{the theoretical value of  \eqn{K_{IJ}(r)}{KIJ(r)}
    for a marked Poisson process, namely \eqn{\pi r^2}{pi * r^2}
  }
  together with a column or columns named 
  \code{"border"}, \code{"bord.modif"},
  \code{"iso"} and/or \code{"trans"},
  according to the selected edge corrections. These columns contain
  estimates of the function \eqn{K_{IJ}(r)}{KIJ(r)}
  obtained by the edge corrections named.
}
\details{
  The function \code{Kmulti}
  generalises \code{\link{Kest}} (for unmarked point
  patterns) and \code{\link{Kdot}} and \code{\link{Kcross}} (for
  multitype point patterns) to arbitrary marked point patterns.

  Suppose \eqn{X_I}{X[I]}, \eqn{X_J}{X[J]} are subsets, possibly
  overlapping, of a marked point process.
  The multitype \eqn{K} function 
  is defined so that
  \eqn{\lambda_J K_{IJ}(r)}{lambda[J] KIJ(r)} equals the expected number of
  additional random points of \eqn{X_J}{X[J]} 
  within a distance \eqn{r} of a
  typical point of  \eqn{X_I}{X[I]}.
  Here \eqn{\lambda_J}{lambda[J]}
  is the intensity of \eqn{X_J}{X[J]} 
  i.e. the expected number of points of \eqn{X_J}{X[J]} per unit area.
  The function \eqn{K_{IJ}}{KIJ} is determined by the 
  second order moment properties of \eqn{X}.

  The argument \code{X} must be a point pattern (object of class
  \code{"ppp"}) or any data that are acceptable to \code{\link{as.ppp}}.

  The arguments \code{I} and \code{J} specify two subsets of the
  point pattern. They may be logical vectors of length equal to
  \code{X$n}, or integer vectors with entries in the range 1 to
  \code{X$n}, etc.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{K_{IJ}(r)}{KIJ(r)} should be evaluated. 
  It is also used to determine the breakpoints
  (in the sense of \code{\link{hist}})
  for the computation of histograms of distances.

  First-time users would be strongly advised not to specify \code{r}.
  However, if it is specified, \code{r} must satisfy \code{r[1] = 0}, 
  and \code{max(r)} must be larger than the radius of the largest disc 
  contained in the window. 

  This algorithm assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape.

  Biases due to edge effects are
  treated in the same manner as in \code{\link{Kest}}.
  The edge corrections implemented here are
  \describe{
    \item{border}{the border method or
      ``reduced sample'' estimator (see Ripley, 1988). This is
      the least efficient (statistically) and the fastest to compute.
      It can be computed for a window of arbitrary shape.
    }
    \item{isotropic/Ripley}{Ripley's isotropic correction
      (see Ripley, 1988; Ohser, 1983).
      This is currently implemented only for rectangular windows.
    }
    \item{translate}{Translation correction (Ohser, 1983).
      Implemented for all window geometries.
    }
  }

  The pair correlation function \code{\link{pcf}} can also be applied to the
  result of \code{Kmulti}.

}
\references{
  Cressie, N.A.C. \emph{Statistics for spatial data}.
    John Wiley and Sons, 1991.

  Diggle, P.J. \emph{Statistical analysis of spatial point patterns}.
    Academic Press, 1983.

  Diggle, P. J. (1986).
  Displaced amacrine cells in the retina of a
  rabbit : analysis of a bivariate spatial point pattern. 
  \emph{J. Neurosci. Meth.} \bold{18}, 115--125.
 
  Harkness, R.D and Isham, V. (1983)
  A bivariate spatial point pattern of ants' nests.
  \emph{Applied Statistics} \bold{32}, 293--303
 
  Lotwick, H. W. and Silverman, B. W. (1982).
  Methods for analysing spatial processes of several types of points.
  \emph{J. Royal Statist. Soc. Ser. B} \bold{44}, 406--413.

  Ripley, B.D. \emph{Statistical inference for spatial processes}.
  Cambridge University Press, 1988.

  Stoyan, D, Kendall, W.S. and Mecke, J.
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag, 1995.

  Van Lieshout, M.N.M. and Baddeley, A.J. (1999)
  Indices of dependence between types in multivariate point patterns.
  \emph{Scandinavian Journal of Statistics} \bold{26}, 511--532.

}
\section{Warnings}{
  The function \eqn{K_{IJ}}{KIJ} is not necessarily differentiable.

  The border correction (reduced sample) estimator of
  \eqn{K_{IJ}}{KIJ} used here is pointwise approximately 
  unbiased, but need not be a nondecreasing function of \eqn{r},
  while the true  \eqn{K_{IJ}}{KIJ} must be nondecreasing.
}
\seealso{
 \code{\link{Kcross}},
 \code{\link{Kdot}},
 \code{\link{Kest}},
 \code{\link{pcf}}
}
\examples{
    data(longleaf)
     # Longleaf Pine data: marks represent diameter
    \testonly{
        longleaf <- longleaf[seq(1,longleaf$n, by=50), ]
    }
    K <- Kmulti(longleaf, longleaf$marks <= 15, longleaf$marks >= 25)
    plot(K)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}



\eof
\name{LennardJones}
\alias{LennardJones}
\title{The Lennard-Jones Potential}
\description{
   Creates the Lennard-Jones pairwise interaction structure
   which can then be fitted to point pattern data.
}
\usage{
  LennardJones()
}
\value{
  An object of class \code{"interact"}
  describing the Lennard-Jones interpoint interaction
  structure.
}
\details{
  In a pairwise interaction point process with the
  Lennard-Jones pair potential, 
  each pair of points in the point pattern,
  a distance \eqn{d} apart,
  contributes a factor
  \deqn{
    \exp \left\{
	- 
          \left(
            \frac{\sigma}{d}
          \right)^{12}
    + \tau
          \left(
          \frac{\sigma}{d}
          \right)^6
    \right\}
  }{
    exp( - (sigma/d)^12 + tau (sigma/d)^6)
  }
  to the probability density,
  where \eqn{\sigma}{sigma} and \eqn{\tau}{tau} are
  positive parameters to be estimated. 

  See \bold{Examples} for a plot of this expression.
  
  This potential causes very strong inhibition between points at short range,
  and attraction between points at medium range.
  Roughly speaking, \eqn{\sigma}{sigma} controls the scale of both
  types of interaction, and \eqn{\tau}{tau} determines the strength of 
  attraction.
  The potential switches from inhibition to attraction at
  \eqn{d=\sigma/\tau^{1/6}}{d=sigma/tau^(1/6)}.
  Maximum attraction occurs at distance
  \eqn{d = (\frac 2 \tau)^{1/6} \sigma}{d = (2/tau)^(1/6) sigma}
  and the maximum achieved is \eqn{\exp(\tau^2/4)}{exp((tau^2)/4)}.
  Interaction is negligible for distances
  \eqn{d > 2 \sigma \max\{1,\tau^{1/6}\}}{d > 2 * sigma * max(1, tau^(1/6))}.

  This potential 
  is used (in a slightly different parameterisation)
  to model interactions between uncharged molecules in statistical physics.
  
  The function \code{\link{ppm}()}, which fits point process models to 
  point pattern data, requires an argument 
  of class \code{"interact"} describing the interpoint interaction
  structure of the model to be fitted. 
  The appropriate description of the Lennard-Jones pairwise interaction is
  yielded by the function \code{LennardJones()}.
  See the examples below.
 
  The ``canonical regular parameters'' estimated by \code{\link{ppm}} are
  \eqn{\theta_1 = \sigma^{12}}{theta1 = sigma^12}
  and 
  \eqn{\theta_2 = \tau \sigma^6}{theta2 = tau * sigma^6}.
}
\seealso{
  \code{\link{ppm}},
  \code{\link{pairwise.family}},
  \code{\link{ppm.object}}
}
\examples{
   X <- rpoispp(100)
   ppm(X, ~1, LennardJones(), correction="translate")
   # Typically yields very small values for theta_1, theta_2
   # so the values of sigma, tau may not be sensible
##########
   # How to plot the pair potential function (exponentiated)
   plotLJ <- function(sigma, tau) {
        dmax <- 2 * sigma * max(1, tau)^(1/6)
        d <- seq(dmax * 0.0001, dmax, length=1000)
        plot(d, exp(- (sigma/d)^12 + tau * (sigma/d)^6), type="l",
                ylab="Lennard-Jones",
                main=substitute(list(sigma==s, tau==t),
                     list(s=sigma,t=tau)))
        abline(h=1, lty=2)
   }
   plotLJ(1,1)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{MultiStrauss}
\alias{MultiStrauss}
\title{The Multitype Strauss Point Process Model}
\description{
Creates an instance of the multitype Strauss point process model
which can then be fitted to point pattern data.
}
\usage{
  MultiStrauss(types, radii)
}
\arguments{
  \item{types}{Vector of all possible types (i.e. the possible levels
    of the \code{marks} variable in the data)}
  \item{radii}{Matrix of interaction radii}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of the multitype Strauss process with
  interaction radii \eqn{radii[i,j]}.
}
\details{
  The (stationary) multitype
  Strauss process with \eqn{m} types, with interaction radii
  \eqn{r_{ij}}{r[i,j]} and 
  parameters \eqn{\beta_j}{beta[j]} and \eqn{\gamma_{ij}}{gamma[i,j]}
  is the pairwise interaction point process
  in which each point of type \eqn{j}
  contributes a factor \eqn{\beta_j}{beta[j]} to the 
  probability density of the point pattern, and a pair of points
  of types \eqn{i} and \eqn{j} closer than \eqn{r_{ij}}{r[i,j]}
  units apart contributes a factor
  \eqn{\gamma_{ij}}{gamma[i,j]} to the density.

  The nonstationary multitype Strauss process is similar except that 
  the contribution of each individual point \eqn{x_i}{x[i]}
  is a function \eqn{\beta(x_i)}{beta(x[i])}
  of location and type, rather than a constant beta. 
 
  The function \code{\link{ppm}()}, which fits point process models to 
  point pattern data, requires an argument 
  of class \code{"interact"} describing the interpoint interaction
  structure of the model to be fitted. 
  The appropriate description of the multitype
  Strauss process pairwise interaction is
  yielded by the function \code{MultiStrauss()}. See the examples below.

  The matrix \code{radii} must be symmetric, with entries
  which are either positive numbers or \code{NA}. 
  A value of \code{NA} indicates that no interaction term should be included
  for this combination of types.
  
  Note that only the interaction radii are specified in \code{MultiStrauss}.
  The canonical parameters \eqn{\log(\beta_j)}{log(beta[j])}
  and \eqn{\log(\gamma_{ij})}{log(gamma[i,j])}
  are estimated by \code{\link{ppm}()}, not fixed in
  \code{Strauss()}. 
}
\seealso{
  \code{\link{ppm}},
  \code{\link{pairwise.family}},
  \code{\link{ppm.object}},
  \code{\link{Strauss}}
}
\examples{
   r <- matrix(c(1,2,2,1), nrow=2,ncol=2)
   MultiStrauss(1:2, r)
   # prints a sensible description of itself
   data(betacells)
   r <- 30.0 * matrix(c(1,2,2,1), nrow=2,ncol=2)
   ppm(betacells, ~1, MultiStrauss(c("off","on"), r), rbord=60.0)
   # fit the stationary multitype Strauss process to `betacells'
   ppm(betacells, ~polynom(x,y,3), MultiStrauss(c("off","on"), r), rbord=60.0)
   # fit a nonstationary Strauss process with log-cubic polynomial trend
}
\section{Warnings}{
  The argument \code{types} is interpreted as a
  set of factor levels. That is,
  in order that \code{\link{ppm}} can fit the multitype Strauss model
  correctly to a point pattern \code{X},
  this must be a marked point pattern; the mark vector
  \code{X$marks} must be a factor; and 
  the argument \code{types} must
  equal \code{levels(X$marks)}.
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{MultiStraussHard}
\alias{MultiStraussHard}
\title{The Multitype/Hard Core Strauss Point Process Model}
\description{
Creates an instance of the multitype/hard core Strauss point process model
which can then be fitted to point pattern data.
}
\usage{
  MultiStraussHard(types, iradii, hradii)
}
\arguments{
  \item{types}{Vector of all possible types (i.e. the possible levels
    of the \code{marks} variable in the data)}
  \item{iradii}{Matrix of interaction radii}
  \item{hradii}{Matrix of hard core radii}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of the multitype/hard core Strauss process with
  interaction radii \eqn{iradii[i,j]}
  and hard core radii \eqn{hradii[i,j]}.
}
\details{
  This is a hybrid of the multitype Strauss process
  (see \code{\link{MultiStrauss}}) and the hard core process
  (case \eqn{\gamma=0}{gamma = 0} of the Strauss process).
  A pair of points
  of types \eqn{i} and \eqn{j}
  must not lie closer than \eqn{h_{ij}}{h[i,j]} units apart;
  if the pair lies more than \eqn{h_{ij}}{h[i,j]} and less than 
  \eqn{r_{ij}}{r[i,j]} units apart, it
  contributes a factor
  \eqn{\gamma_{ij}}{gamma[i,j]} to the probability density.

  The matrices \code{iradii} and \code{hradii}
  must be symmetric, with entries
  which are either positive numbers or \code{NA}. 
  A value of \code{NA} indicates that no interaction term should be included
  for this combination of types.
  
  Note that only the interaction radii and hardcore radii
  are specified in \code{MultiStraussHard}.
  The canonical parameters \eqn{\log(\beta_j)}{log(beta[j])}
  and \eqn{\log(\gamma_{ij})}{log(gamma[i,j])}
  are estimated by \code{\link{ppm}()}, not fixed in
  \code{MultiStraussHard()}. 
}
\seealso{
  \code{\link{ppm}},
  \code{\link{pairwise.family}},
  \code{\link{ppm.object}},
  \code{\link{MultiStrauss}},
  \code{\link{Strauss}}
}
\examples{
   r <- matrix(3, nrow=2,ncol=2)
   h <- matrix(c(1,2,2,1), nrow=2,ncol=2)
   MultiStraussHard(1:2, r, h)
   # prints a sensible description of itself
   data(betacells)
   r <- 30.0 * matrix(c(1,2,2,1), nrow=2,ncol=2)
   h <- 30.0 * matrix(c(NA,1,1,NA), nrow=2,ncol=2)
   ppm(betacells, ~1, MultiStraussHard(c("off","on"), r, h), rbord=60.0)
   # fit the stationary multitype hardcore Strauss process to `betacells'
}
\section{Warnings}{
  The argument \code{types} is interpreted as a
  set of factor levels. That is,
  in order that \code{\link{ppm}} can fit the multitype Strauss model
  correctly to a point pattern \code{X},
  this must be a marked point pattern; the mark vector
  \code{X$marks} must be a factor; and 
  the argument \code{types} must
  equal \code{levels(X$marks)}.
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Ord}
\alias{Ord}
\title{Generic Ord Interaction model}
\description{
Creates an instance of an Ord-type interaction point process model
which can then be fitted to point pattern data.
}
\usage{
  Ord(pot, name)
}
\arguments{
  \item{pot}{An S language function giving the user-supplied
    interaction potential.}
  \item{name}{Character string.}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of a point process. 
}
\details{
  Ord's point process model (Ord, 1977) is a Gibbs point process
  of infinite order. Each point \eqn{x_i}{x[i]} in the point pattern
  \eqn{x} contributes a factor \eqn{g(a_i)}{g(a[i])} where
  \eqn{a_i = a(x_i, x)}{a[i] = a(x[i], x)} is the area of the
  tile associated with \eqn{x_i}{x[i]}
  in the Dirichlet tessellation of \eqn{x}.

  Ord (1977) proposed fitting this model to forestry data
  when \eqn{g(a)} has a simple ``threshold'' form. That model is
  implemented in our function \code{\link{OrdThresh}}.
  The present function \code{Ord} implements the case of a
  completely general Ord potential \eqn{g(a)}
  specified as an S language function \code{pot}.

  This is experimental. 
}
\references{
  Baddeley, A. and Turner, R. (2000)
  Practical maximum pseudolikelihood for spatial point patterns.
  \emph{Australian and New Zealand Journal of Statistics}
  \bold{42}, 283--322.

  Ord, J.K. (1977) 
  Contribution to the discussion of Ripley (1977).

  Ord, J.K. (1978) 
  How many trees in a forest?
  \emph{Mathematical Scientist} \bold{3}, 23--33.

  Ripley, B.D. (1977)
  Modelling spatial patterns (with discussion).
  \emph{Journal of the Royal Statistical Society, Series B},
  \bold{39}, 172 -- 212.

}
\seealso{
  \code{\link{ppm}},
  \code{\link{ppm.object}},
  \code{\link{OrdThresh}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}


\eof
\name{OrdThresh}
\alias{OrdThresh}
\title{Ord's Interaction model}
\description{
Creates an instance of Ord's point process model
which can then be fitted to point pattern data.
}
\usage{
  OrdThresh(r)
}
\arguments{
  \item{r}{Positive number giving the threshold value
    for Ord's model.}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of a point process. 
}
\details{
  Ord's point process model (Ord, 1977) is a Gibbs point process
  of infinite order. Each point \eqn{x_i}{x[i]} in the point pattern
  \eqn{x} contributes a factor \eqn{g(a_i)}{g(a[i])} where
  \eqn{a_i = a(x_i, x)}{a[i] = a(x[i], x)} is the area of the
  tile associated with \eqn{x_i}{x[i]}
  in the Dirichlet tessellation of \eqn{x}. The function \eqn{g} is
  simply \eqn{g(a) = 1} if \eqn{a \ge r}{a >= r} and
  \eqn{g(a) = \gamma < 1}{g(a) = gamma < 1} if \eqn{a < r}{a < r},
  where \eqn{r} is called the threshold value.

  This function creates an instance of Ord's model with a given
  value of \eqn{r}. It can then be fitted to point process data
  using \code{\link{ppm}}. 
}
\seealso{
  \code{\link{ppm}},
  \code{\link{ppm.object}}
}
\references{
  Baddeley, A. and Turner, R. (2000)
  Practical maximum pseudolikelihood for spatial point patterns.
  \emph{Australian and New Zealand Journal of Statistics}
  \bold{42}, 283--322.

  Ord, J.K. (1977) 
  Contribution to the discussion of Ripley (1977).

  Ord, J.K. (1978) 
  How many trees in a forest?
  \emph{Mathematical Scientist} \bold{3}, 23--33.

  Ripley, B.D. (1977)
  Modelling spatial patterns (with discussion).
  \emph{Journal of the Royal Statistical Society, Series B},
  \bold{39}, 172 -- 212.

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}


\eof
\name{PairPiece}
\alias{PairPiece}
\title{The Piecewise Constant Pairwise Interaction Point Process Model}
\description{
  Creates an instance of a pairwise interaction point process model
  with piecewise constant potential function. The model
  can then be fitted to point pattern data.
}
\usage{
  PairPiece(r)
}
\arguments{
  \item{r}{vector of jump points for the potential function}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of a point process. The process is a pairwise interaction process,
  whose interaction potential is piecewise constant, with jumps
  at the distances given in the vector \eqn{r}.
}
\details{
  A pairwise interaction point process in a bounded region
  is a stochastic point process with probability density of the form
  \deqn{
    f(x_1,\ldots,x_n) =
    \alpha \prod_i b(x_i) \prod_{i < j} h(x_i, x_j)
  }{
    f(x_1,\ldots,x_n) =
    alpha . product { b(x[i]) } product { h(x_i, x_j) }
  }
  where \eqn{x_1,\ldots,x_n}{x[1],\ldots,x[n]} represent the 
  points of the pattern. The first product on the right hand side is
  over all points of the pattern; the second product is over all
  unordered pairs of points of the pattern.

  Thus each point \eqn{x_i}{x[i]} of the pattern contributes a factor 
  \eqn{b(x_i)}{b(x[i])} to the probability density, and each pair of
  points \eqn{x_i, x_j}{x[i], x[j]} contributes a factor
  \eqn{h(x_i,x_j)}{h(x[i], x[j])} to the density.

  The pairwise interaction term \eqn{h(u, v)} is called piecewise constant
  if it depends only on the distance between \eqn{u} and \eqn{v},
  say \eqn{h(u,v) = H(||u-v||)}, and \eqn{H} is a piecewise constant
  function (a function which is constant except for jumps at a finite
  number of places). 
 
  The function \code{\link{ppm}()}, which fits point process models to 
  point pattern data, requires an argument 
  of class \code{"interact"} describing the interpoint interaction
  structure of the model to be fitted. 
  The appropriate description of the piecewise constant pairwise
  interaction is yielded by the function \code{PairPiece()}.
  See the examples below.

  The entries of \code{r} must be strictly increasing, positive numbers.
  They are interpreted as the points of discontinuity of \eqn{H}.
  It is assumed that \eqn{H(s) =1} for all \eqn{s > r_{max}}{s > rmax}
  where \eqn{r_{max}}{rmax} is the maximum value in \code{r}. Thus the
  model has as many regular parameters (see \code{\link{ppm}}) 
  as there are entries in \code{r}. The \eqn{i}-th regular parameter
  \eqn{\theta_i}{theta[i]} is the logarithm of the value of the
  interaction function \eqn{H} on the interval
  \eqn{[r_{i-1},r_i)}{[r[i-1],r[i])}. 

  If \code{r} is a single number, this model is similar to the 
  Strauss process, see \code{\link{Strauss}}. The difference is that
  in \code{PairPiece} the interaction function is continuous on the
  right, while in \code{\link{Strauss}} it is continuous on the left.

  The analogue of this model for multitype point processes
  has not yet been implemented.
}
\seealso{
  \code{\link{ppm}},
  \code{\link{pairwise.family}},
  \code{\link{ppm.object}},
  \code{\link{Strauss}}
  \code{\link{rmh.ppm}}
}
\examples{
   PairPiece(c(0.1,0.2))
   # prints a sensible description of itself
   data(cells) 
   ppm(cells, ~1, PairPiece(r = c(0.05, 0.1, 0.2)), rbord=0.2)
   # fit a stationary piecewise constant pairwise interaction process
   ppm(cells, ~polynom(x,y,3), PairPiece(c(0.05, 0.1)), rbord=0.1)
   # nonstationary process with log-cubic polynomial trend
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Pairwise}
\alias{Pairwise}
\title{Generic Pairwise Interaction model}
\description{
Creates an instance of a pairwise interaction point process model
which can then be fitted to point pattern data.
}
\synopsis{
  Pairwise(pot, name, par, parnames, printfun)
}
\usage{
  Pairwise(pot, name)
  Pairwise(pot, name, par, parnames)
}
\arguments{
  \item{pot}{An S language function giving the user-supplied
    pairwise interaction potential.}
  \item{name}{Character string.}
  \item{par}{List of numerical values for irregular parameters}
  \item{parnames}{Vector of names of irregular parameters}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of a point process. 
}
\details{
  Advanced use only.
  
  This code constructs a member of the
  pairwise interaction family \code{\link{pairwise.family}}
  with arbitrary pairwise interaction potential given by
  the user.

  The function \code{pot} must take as its first argument
  a matrix of interpoint distances, and evaluate the
  potential for each of these distances. The result must be
  either a matrix with the same dimensions as its input,
  or an array with its first two dimensions the same as its input
  (the latter case corresponds to a vector-valued potential).

  If irregular parameters are present, then the second argument
  to \code{pot} should be a vector of the same type as \code{par}
  giving those parameter values.  
}
\seealso{
  \code{\link{ppm}},
  \code{\link{pairwise.family}},
  \code{\link{ppm.object}}
}
\examples{
   #This is the same as StraussHard(r=0.7,h=0.2)
   strpot <- function(t,par) {
         r <- par$r
         h <- par$h
         value <- (t <= r)
         value[t < h] <- -Inf
         value
   }
   mySH <- Pairwise(strpot, "StraussHard", list(r=0.7,h=0.2),
           c("interaction distance r", "hard core distance c"))
   data(cells)
   ppm(cells, ~ 1, mySH)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}


\eof
\name{Poisson}
\alias{Poisson}
\title{Poisson Point Process Model}
\description{
Creates an instance of the Poisson point process model
which can then be fitted to point pattern data.
}
\usage{
 Poisson()
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction 
  structure of the Poisson point process
  (namely, there are no interactions).
}
\details{
  The function \code{\link{ppm}()}, which fits point process models to 
  point pattern data, requires an argument \code{interaction}
  of class \code{"interact"}
  describing the interpoint interaction structure
  of the model to be fitted. 
  The appropriate description of the Poisson process is 
  provided by the value of the function \code{Poisson()}.

  This works for all types of Poisson processes including
  multitype and nonstationary Poisson processes.
}
\seealso{
  \code{\link{Strauss}},
  \code{\link{StraussHard}}
}
\examples{
 data(nztrees)
 ppm(nztrees, ~1, Poisson())
 # fit the stationary Poisson process to 'nztrees'
 # no edge correction needed

 data(longleaf)
 \testonly{
   longleaf <- longleaf[seq(1, longleaf$n, by=50)]
 }
 longadult <- longleaf[longleaf$marks >= 30, ]
 longadult <- unmark(longadult)
 ppm(longadult, ~ x, Poisson())
 # fit the nonstationary Poisson process 
 # with intensity lambda(x,y) = exp( a + bx)

 data(lansing)
 # trees marked by species
 \testonly{
     lansing <- lansing[seq(1,lansing$n, by=30), ]
 }
 ppm(lansing, ~ marks, Poisson())
 # fit stationary marked Poisson process
 # with different intensity for each species

\dontrun{
 ppm(lansing, ~ marks * polynom(x,y,3), Poisson())
}
 # fit nonstationary marked Poisson process
 # with different log-cubic trend for each species
\testonly{
 # equivalent functionality - smaller dataset
 data(betacells)
 ppm(betacells, ~ marks * polynom(x,y,2), Poisson())
}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{Saturated}
\alias{Saturated}
\title{Saturated Pairwise Interaction model}
\description{
  Experimental.
}
\usage{
  Saturated(pot, name)
}
\arguments{
  \item{pot}{An S language function giving the user-supplied
    pairwise interaction potential.}
  \item{name}{Character string.}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of a point process. 
}
\details{
  This is experimental. It constructs a member of the
  ``saturated pairwise'' family \code{\link{pairsat.family}}.
}
\seealso{
  \code{\link{ppm}},
  \code{\link{pairsat.family}},
  \code{\link{ppm.object}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}


\eof
\name{Softcore}
\alias{Softcore}
\title{The Soft Core Point Process Model}
\description{
Creates an instance of the Soft Core point process model
which can then be fitted to point pattern data.
}
\usage{
  Softcore(kappa)
}
\arguments{
  \item{kappa}{The exponent \eqn{\kappa}{kappa} of the Soft Core interaction}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of the Soft Core process with exponent \eqn{\kappa}{kappa}.
}
\details{
  The (stationary)
  Soft Core point process with parameters \eqn{\beta}{beta} and
  \eqn{\sigma}{sigma} and exponent \eqn{\kappa}{kappa}
  is the pairwise interaction point process in which 
  each point contributes a factor \eqn{\beta}{beta} to the 
  probability density of the point pattern, and each pair of points
  contributes a factor
  \deqn{
    \exp \left\{ - \left( \frac{\sigma}{d} \right)^{2/\kappa} \right\}
  }{
    exp( - (sigma/d)^(2/kappa) )
  }
  to the density, where \eqn{d} is the distance between the two points.

  Thus the process has probability density
  \deqn{
    f(x_1,\ldots,x_n) =
    \alpha \beta^{n(x)}
    \exp \left\{ - \sum_{i < j} \left(
                 \frac{\sigma}{||x_i-x_j||}
    \right)^{2/\kappa} \right\}
  }{
    f(x_1,\ldots,x_n) =
    alpha . beta^n(x) exp( - sum (sigma/||x[i]-x[j]||)^(2/kappa))
  }
  where \eqn{x_1,\ldots,x_n}{x[1],\ldots,x[n]} represent the 
  points of the pattern, \eqn{n(x)} is the number of points in the
  pattern, \eqn{\alpha}{alpha} is the normalising constant,
  and the sum on the right hand side is
  over all unordered pairs of points of the pattern. 

  This model describes an ``ordered'' or ``inhibitive'' process,
  with the interpoint interaction decreasing smoothly with distance.
  The strength of interaction is controlled by the
  parameter \eqn{\sigma}{sigma}, a positive real number,
  with larger values corresponding
  to stronger interaction; and by the exponent \eqn{\kappa}{kappa}
  in the range \eqn{(0,1)}, with larger values corresponding to
  weaker interaction.
  If \eqn{\sigma = 0}{sigma = 0}
  the model reduces to the Poisson point process.
  If \eqn{\sigma > 0}{sigma > 0},
  the process is well-defined only for \eqn{\kappa}{kappa} in \eqn{(0,1)}.
  The limit of the model as \eqn{\kappa \to 0}{kappa -> 0} is the
  hard core process with hard core distance \eqn{h=\sigma}{h=sigma}.
 
  The nonstationary Soft Core process is similar except that 
  the contribution of each individual point \eqn{x_i}{x[i]}
  is a function \eqn{\beta(x_i)}{beta(x[i])}
  of location, rather than a constant beta. 
 
  The function \code{\link{ppm}()}, which fits point process models to 
  point pattern data, requires an argument 
  of class \code{"interact"} describing the interpoint interaction
  structure of the model to be fitted. 
  The appropriate description of the Soft Core process pairwise interaction is
  yielded by the function \code{Softcore()}. See the examples below.
 
  Note the only argument is the exponent  \code{kappa}.
  When \code{kappa} is fixed, the model becomes an exponential family
  with canonical parameters \eqn{\log \beta}{log(beta)}
  and \deqn{
    \log \gamma = \frac{2}{\kappa} \log\sigma
  }{
    log(gamma) = (2/kappa) log(sigma)
  }
  The canonical parameters are estimated by \code{\link{ppm}()}, not fixed in
  \code{Softcore()}. 
}
\seealso{
  \code{\link{ppm}},
  \code{\link{pairwise.family}},
  \code{\link{ppm.object}}
}
\references{
  Ogata, Y, and Tanemura, M. (1981).
  Estimation of interaction potentials of spatial point patterns
  through the maximum likelihood procedure.
  \emph{Annals of the Institute of Statistical Mathematics}, B
  \bold{33}, 315--338.

  Ogata, Y, and Tanemura, M. (1984).
  Likelihood analysis of spatial point patterns.
  \emph{Journal of the Royal Statistical Society, series B}
  \bold{46}, 496--518.
}
\examples{
   data(cells) 
   ppm(cells, ~1, Softcore(kappa=0.5), rbord=0)
   # fit the stationary Soft Core process to `cells'
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{Strauss}
\alias{Strauss}
\title{The Strauss Point Process Model}
\description{
Creates an instance of the Strauss point process model
which can then be fitted to point pattern data.
}
\usage{
  Strauss(r)
}
\arguments{
  \item{r}{The interaction radius of the Strauss process}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of the Strauss process with interaction radius \eqn{r}.
}
\details{
  The (stationary) Strauss process with interaction radius \eqn{r} and 
  parameters \eqn{\beta}{beta} and \eqn{\gamma}{gamma}
  is the pairwise interaction point process
  in which each point contributes a factor \eqn{\beta}{beta} to the 
  probability density of the point pattern, and each pair of points
  closer than \eqn{r} units apart contributes a factor
  \eqn{\gamma}{gamma} to the density.

  Thus the probability density is
  \deqn{
    f(x_1,\ldots,x_n) =
    \alpha \beta^{n(x)} \gamma^{s(x)}
  }{
    f(x_1,\ldots,x_n) =
    alpha . beta^n(x) gamma^s(x)
  }
  where \eqn{x_1,\ldots,x_n}{x[1],\ldots,x[n]} represent the 
  points of the pattern, \eqn{n(x)} is the number of points in the
  pattern, \eqn{s(x)} is the number of distinct unordered pairs of
  points that are closer than \eqn{r} units apart,
  and \eqn{\alpha}{alpha} is the normalising constant.

  The interaction parameter \eqn{\gamma}{gamma} must be less than
  or equal to \eqn{1}
  so that this model describes an ``ordered'' or ``inhibitive'' pattern.
 
  The nonstationary Strauss process is similar except that 
  the contribution of each individual point \eqn{x_i}{x[i]}
  is a function \eqn{\beta(x_i)}{beta(x[i])}
  of location, rather than a constant beta. 
 
  The function \code{\link{ppm}()}, which fits point process models to 
  point pattern data, requires an argument 
  of class \code{"interact"} describing the interpoint interaction
  structure of the model to be fitted. 
  The appropriate description of the Strauss process pairwise interaction is
  yielded by the function \code{Strauss()}. See the examples below.
 
  Note the only argument is the interaction radius \code{r}.
  When \code{r} is fixed, the model becomes an exponential family.
  The canonical parameters \eqn{\log(\beta)}{log(beta)}
  and \eqn{\log(\gamma)}{log(gamma)}
  are estimated by \code{\link{ppm}()}, not fixed in
  \code{Strauss()}. 
}
\seealso{
  \code{\link{ppm}},
  \code{\link{pairwise.family}},
  \code{\link{ppm.object}}
}
\examples{
   Strauss(r=0.1)
   # prints a sensible description of itself
   data(cells) 
   ppm(cells, ~1, Strauss(r=0.07), rbord=0.07)
   # fit the stationary Strauss process to `cells'
   ppm(cells, ~polynom(x,y,3), Strauss(r=0.07), rbord=0.1)
   # fit a nonstationary Strauss process with log-cubic polynomial trend
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{StraussHard}
\alias{StraussHard}
\title{The Strauss / Hard Core Point Process Model}
\description{
Creates an instance of the ``Strauss/ hard core'' point process model
which can then be fitted to point pattern data.
}
\usage{
  StraussHard(r, hc)
}
\arguments{
  \item{r}{The interaction radius of the Strauss interaction}
  \item{hc}{The hard core distance}
}
\value{
  An object of class \code{"interact"}
  describing the interpoint interaction
  structure of the ``Strauss/hard core''
  process with Strauss interaction radius \eqn{r}
  and hard core distance \code{hc}.
}
\details{
  A Strauss/hard core process with interaction radius \eqn{r},
  hard core distance \eqn{h < r}, and 
  parameters \eqn{\beta}{beta} and \eqn{\gamma}{gamma},
  is a pairwise interaction point process
  in which
  \itemize{
    \item distinct points are not allowed to come closer
      than a distance \eqn{h} apart
    \item each pair of points closer than \eqn{r} units apart
      contributes a factor \eqn{\gamma}{gamma} to the probability density.
  }
  This is a hybrid of the Strauss process and the hard core process.

  The probability density is zero if any pair of points
  is closer than \eqn{h} units apart, and otherwise equals
  \deqn{
    f(x_1,\ldots,x_n) =
    \alpha \beta^{n(x)} \gamma^{s(x)}
  }{
    f(x_1,\ldots,x_n) =
    alpha . beta^n(x) gamma^s(x)
  }
  where \eqn{x_1,\ldots,x_n}{x[1],\ldots,x[n]} represent the 
  points of the pattern, \eqn{n(x)} is the number of points in the
  pattern, \eqn{s(x)} is the number of distinct unordered pairs of
  points that are closer than \eqn{r} units apart,
  and \eqn{\alpha}{alpha} is the normalising constant.

  The interaction parameter \eqn{\gamma}{gamma} may take any
  positive value (unlike the case for the Strauss process).
  If \eqn{\gamma = 1}{gamma = 1}, the process reduces to a classical
  hard core process.
  If \eqn{\gamma < 1}{gamma < 1},
  the model describes an ``ordered'' or ``inhibitive'' pattern.
  If \eqn{\gamma > 1}{gamma > 1},
  the model is ``ordered'' or ``inhibitive'' up to the distance
  \eqn{h}, but has an ``attraction'' between points lying at
  distances in the range between \eqn{h} and \eqn{r}.
  
  The function \code{\link{ppm}()}, which fits point process models to 
  point pattern data, requires an argument 
  of class \code{"interact"} describing the interpoint interaction
  structure of the model to be fitted. 
  The appropriate description of the Strauss/hard core process
  pairwise interaction is
  yielded by the function \code{StraussHard()}. See the examples below.
 
  The canonical parameter \eqn{\log(\gamma)}{log(gamma)}
  is estimated by \code{\link{ppm}()}, not fixed in
  \code{StraussHard()}. 
}
\seealso{
  \code{\link{ppm}},
  \code{\link{pairwise.family}},
  \code{\link{ppm.object}}
}
\references{
  Baddeley, A. and Turner, R. (2000)
  Practical maximum pseudolikelihood for spatial point patterns.
  \emph{Australian and New Zealand Journal of Statistics}
  \bold{42}, 283--322.

  Ripley, B.D. (1981) 
  \emph{Spatial statistics}.
  John Wiley and Sons.

  Strauss, D.J. (1975)
  A model for clustering.
  \emph{Biometrika} \bold{63}, 467--475.
}
\examples{
   StraussHard(r=1,hc=0.02)
   # prints a sensible description of itself

   data(cells) 
   ppm(cells, ~1, StraussHard(r=0.1, hc=0.05), rbord=0.1)
   # fit the stationary Strauss/hard core  process to `cells'

   ppm(cells, ~ polynom(x,y,3), StraussHard(r=0.1, hc=0.05), rbord=0.1)
   # fit a nonstationary Strauss/hard core process
   # with log-cubic polynomial trend
   }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{affine}
\alias{affine}
\title{Apply Affine Transformation}
\description{
  Applies any affine transformation of the plane (linear transformation
  plus vector shift) to a plane geometrical object,
  such as a point pattern or a window. 
}
\synopsis{
  affine(X, \dots)
}
\usage{
 affine(X, mat=diag(c(1,1)), vec=c(0,0))
}
\arguments{
  \item{X}{Any suitable dataset representing a two-dimensional
    object, such as a point pattern (object of class \code{"ppp"}),
    or a window (object of class \code{"owin"}).}
  \item{mat}{Matrix representing a linear transformation.}
  \item{vec}{Vector of length 2 representing a translation.}
}
\value{
  Another object of the same type, representing the
  result of applying the affine transformation.
}
\details{
  This is generic. Methods are provided for
  point patterns (\code{\link{affine.ppp}})
  and windows (\code{\link{affine.owin}}).

  First the linear transformation represented by
  \code{mat} is applied (multiplying on the left by \code{mat}),
  and then the result is translated by the vector \code{vec}.
  
  The argument \code{mat} must be a nonsingular \eqn{2 \times 2}{2 * 2}
  matrix. 
}
\seealso{
  \code{\link{affine.ppp}},
  \code{\link{affine.owin}},
  \code{\link{rotate}},
  \code{\link{shift}}
}
\examples{
  data(cells)
  # shear transformation
  X <- affine(cells, matrix(c(1,0,0.6,1),ncol=2))
  \dontrun{
  plot(X)
  # rescale y coordinates by factor 1.3
  plot(affine(cells, diag(c(1,1.3))))
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{affine.owin}
\alias{affine.owin}
\title{Apply Affine Transformation To Window}
\description{
  Applies any affine transformation of the plane (linear transformation
  plus vector shift) to a window. 
}
\usage{
 affine.owin(X, mat=diag(c(1,1)), vec=c(0,0), \dots)
}
\arguments{
  \item{X}{Window (object of class \code{"owin"}).}
  \item{mat}{Matrix representing a linear transformation.}
  \item{vec}{Vector of length 2 representing a translation.}
  \item{\dots}{Ignored}
}
\value{
  Another window (of class \code{"owin"}) representing the
  result of applying the affine transformation.
}
\details{
  The window is subjected first to the linear transformation represented by
  \code{mat} (multiplying on the left by \code{mat}),
  and then the result is translated by the vector \code{vec}.
  
  The argument \code{mat} must be a nonsingular \eqn{2 \times 2}{2 * 2}
  matrix.

  This is a method for the generic function \code{\link{affine}}.
}
\seealso{
  \code{\link{affine}},
  \code{\link{affine.ppp}},
  \code{\link{rotate}},
  \code{\link{shift}}
}
\examples{
  # shear transformation
  X <- affine(owin(), matrix(c(1,0,0.6,1),ncol=2))
  \dontrun{
  plot(X)
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{affine.ppp}
\alias{affine.ppp}
\title{Apply Affine Transformation To Point Pattern}
\description{
  Applies any affine transformation of the plane (linear transformation
  plus vector shift) to a point pattern. 
}
\usage{
 affine.ppp(X, mat=diag(c(1,1)), vec=c(0,0), \dots)
}
\arguments{
  \item{X}{Point pattern (object of class \code{"ppp"}).}
  \item{mat}{Matrix representing a linear transformation.}
  \item{vec}{Vector of length 2 representing a translation.}
  \item{\dots}{Ignored}
}
\value{
  Another point pattern (of class \code{"ppp"}) representing the
  result of applying the affine transformation.
}
\details{
  The point pattern, and its window, are subjected first to the
  linear transformation represented by
  \code{mat} (multiplying on the left by \code{mat}),
  and are then translated by the vector \code{vec}.
  
  The argument \code{mat} must be a nonsingular \eqn{2 \times 2}{2 * 2}
  matrix.

  This is a method for the generic function \code{\link{affine}}.
}
\seealso{
  \code{\link{affine}},
  \code{\link{affine.owin}},
  \code{\link{rotate}},
  \code{\link{shift}}
}
\examples{
  data(cells)
  # shear transformation
  X <- affine(cells, matrix(c(1,0,0.6,1),ncol=2))
  \dontrun{
  plot(X)
  # rescale y coordinates by factor 1.3
  plot(affine(cells, diag(c(1,1.3))))
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{allstats}
\alias{allstats}
\title{Calculate four standard summary functions of a point pattern.}
\description{
  Calculates the \eqn{F}, \eqn{G}, \eqn{J}, and \eqn{K}
  summary functions for an unmarked point pattern.
  Returns them as a function array (of class \code{"fasp"}, see
  \code{\link{fasp.object}}).
}
\usage{
  allstats(pp, dataname=NULL, verb=FALSE)
}
\arguments{
  \item{pp}{The observed point pattern, for which summary function
    estimates are required.  An object of class \code{"ppp"}.
    It must not be marked.
  }
  \item{dataname}{A character string giving an optional (alternative)
    name for the point pattern.
  }
  \item{verb}{A logical value meaning ``verbose''. If \code{TRUE},
    progress reports are printed during calculation.
  }
}
\details{
  This computes four standard summary statistics for a
  point pattern: the empty space function \eqn{F(r)},
  nearest neighbour distance distribution function \eqn{G(r)},
  van Lieshout-Baddeley function \eqn{J(r)}
  and Ripley's function \eqn{K(r)}.
  The real work is done by 
  \code{\link{Fest}}, \code{\link{Gest}}, \code{\link{Jest}} and
  \code{\link{Kest}} respectively. Consult the help files for these functions
  for further information about the statistical interpretation
  of \eqn{F}, \eqn{G}, \eqn{J} and \eqn{K}.

  If \code{verb} is \code{TRUE}, then ``progress reports''
  (just indications of completion) are printed out when the
  calculations are finished for each of the four function types.

  The overall title of the array of four functions
  (for plotting by \code{\link{plot.fasp}})
  will be formed from the argument \code{dataname}.
  If this is not given, it defaults to the expression
  for \code{pp} given in the call to \code{allstats}.
}
\value{
  A function array (an object of class \code{"fasp"},
  see \code{\link{fasp.object}}). This can be plotted
  using \code{\link{plot.fasp}}.

  The function array has dimensions \eqn{2 \times 2}{2 * 2}
  with the entries at positions \code{[1,1]},
  \code{[1,2]}, \code{[2,1]} and \code{[2,2]} 
  representing \eqn{F(r)}, \eqn{G(r)}, \eqn{J(r)} and \eqn{K(r)} respectively.
  
  Each function entry \code{fns[[i]]} retains the format
  of the output of the relevant estimating routine
  \code{\link{Fest}}, \code{\link{Gest}}, \code{\link{Jest}} or
  \code{\link{Kest}}. 

  The default formulae for plotting these functions are 
  \code{cbind(km,theo) ~ r} for F, G, and J, and
  \code{cbind(trans,theo) ~ r} for K.}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
  }
\seealso{
         \code{\link{plot.fasp}},
         \code{\link{fasp.object}},
         \code{\link{Fest}},
         \code{\link{Gest}},
         \code{\link{Jest}},
         \code{\link{Kest}},
	 \code{\link{alltypes}}
}

\examples{
	data(swedishpines)
        a <- allstats(swedishpines,dataname="Swedish Pines")
        \dontrun{
        plot(a)
        plot(a, subset=list("r<=15","r<=15","r<=15","r<=50"))
        }
}
\keyword{spatial}

\eof
\name{alltypes}
\alias{alltypes}
\title{Calculate Statistic for All Types in a Multitype Point Pattern}
\description{
  Given a marked point pattern, this computes the estimates of
  a selected summary function (\eqn{F},\eqn{G}, \eqn{J} or \eqn{K})
  of the pattern, for all possible combinations of marks.
  It returns these functions in
  a list (an object of class \code{"fasp"}) amenable to plotting
  by \code{\link{plot.fasp}()}.
}

\usage{
  alltypes(pp, fun="K",dataname=NULL,verb=FALSE)
}

\arguments{
  \item{pp}{The observed point pattern, for which summary function
    estimates are required.  An object of class \code{"ppp"}.
    If the pattern is not marked, the resulting ``array'' is
    \eqn{1 \times 1}{1 x 1}.
  }

  \item{fun}{Character string indicating the summary function
    required.  Must be one of the letters \code{"F"},
    \code{"G"}, \code{"J"}, \code{"K"}.
  }

  \item{dataname}{Character string giving an optional (alternative)
    name to the point pattern, different from what is given
    in the call.  This name, if supplied, may be used by
    \code{\link{plot.fasp}()} in forming the title of the plot.
    If not supplied it defaults to the parsing of the argument
    supplied as \code{pp} in the call.
  }

  \item{verb}{Logical value, meaning ``verbose''.  If verb is
   true then terse ``progress reports'' (just the values of the
   mark indices) are printed out when the calculations for that
   combination of marks are completed. 
   }
}

\details{
  This routine is a convenient way to analyse the dependence between
  types in a multitype point pattern.
  Suppose that the points have possible types \eqn{1,2,\ldots,m}
  and let \eqn{X_i}{X[i]} denote the pattern of points of type \eqn{i} only.
  If \code{fun="F"} then this routine
  calculates, for each possible type \eqn{i},
  an estimate of the Empty Space Function \eqn{F_i(r)} of
  \eqn{X_i}{X[i]}.
  If \code{fun} is \code{"G"}, \code{"J"} or \code{"K"},
  the routine calculates, for each pair of types \eqn{(i,j)},
  an estimate of the cross-type function
  \eqn{G_{ij}(r)}{G[i,j](r)},
  \eqn{J_{ij}(r)}{J[i,j](r)} or
  \eqn{K_{ij}(r)}{K[i,j](r)} respectively describing the
  dependence between 
  \eqn{X_i}{X[i]} and \eqn{X_j}{X[j]}.

  The real work is done by the functions \code{Fest}, \code{Gest},
  \code{Kest}, \code{Jest},
  \code{Gcross}, \code{Kcross}, and \code{Jcross}.
  One of the first four functions (according to
  \code{fun}) is invoked if the two marks under consideration are
  equal.  The latter three are invoked if the marks are distinct.
  (There is no \code{Fcross}; for the empty space function \eqn{F(r)}
  there is no cross-type version.)
}

\value{
  A function array (an object of class \code{"fasp"},
  see \code{\link{fasp.object}}). This can be plotted
  using \code{\link{plot.fasp}}.

  If \code{fun="F"},
  the function array has dimensions \eqn{m \times 1}{n * 1}
  where \eqn{m} is the number of different marks in the point pattern.
  The entry at position \code{[i,1]} in this array
  is the result of applying \code{\link{Fest}} to the
  points of type \code{i} only.

  If \code{fun} is \code{"G"}, \code{"J"} or \code{"K"}, 
  the function array has dimensions \eqn{m \times m}{m * m}.
  The \code{[i,j]} entry of the function array
  (for \eqn{i \neq j}{i != j}) is the
  result of applying the function \code{\link{Gcross}},
  \code{\link{Jcross}} or \code{\link{Kcross}} to
  the pair of types \code{(i,j)}. The diagonal
  \code{[i,i]} entry of the function array is the result of
  applying the univariate function \code{\link{Gest}},
  \code{\link{Jest}} or \code{\link{Kest}} to the
  points of type \code{i} only.
  
  Each function entry \code{fns[[i]]} retains the format
  of the output of the relevant estimating routine
  \code{\link{Fest}}, \code{\link{Gest}}, \code{\link{Jest}},
  \code{\link{Kest}},  \code{Gcross}, \code{Jcross}, or \code{Kcross}.

  The default formulae for plotting these functions are 
  \code{cbind(km,theo) ~ r} for F, G, and J, and
  \code{cbind(trans,theo) ~ r} for K.}
  }
}
\note{
  Sizeable amounts of memory may be needed during the calculation.
}

\seealso{
  \code{\link{plot.fasp}},
  \code{\link{fasp.object}},
  \code{\link{allstats}},
  \code{\link{Fest}},
  \code{\link{Gest}},
  \code{\link{Jest}},
  \code{\link{Kest}},
  \code{\link{Gcross}},
  \code{\link{Jcross}},
  \code{\link{Kcross}}
}
\examples{
   # bramblecanes (3 marks).
   data(bramblecanes)
   \dontrun{
   X.F <- alltypes(bramblecanes,fun="F",verb=TRUE)
   plot(X.F) 
   X.G <- alltypes(bramblecanes,fun="G",verb=TRUE)
   X.J <- alltypes(bramblecanes,fun="J",verb=TRUE)
   X.K <- alltypes(bramblecanes,fun="K",verb=TRUE)
   }
   \testonly{
      # smaller dataset
      bram <- bramblecanes[seq(1, bramblecanes$n, by=20), ]
      X.F <- alltypes(bram,fun="F",verb=TRUE)
      X.G <- alltypes(bram,fun="G",verb=TRUE)
      X.J <- alltypes(bram,fun="J",verb=TRUE)
      X.K <- alltypes(bram,fun="K",verb=TRUE)
   }
   
   # Swedishpines (unmarked).
   data(swedishpines)
   \testonly{
	swedishpines <- swedishpines[1:25]
   }
   X.K <- alltypes(swedishpines,fun="K")
   X.F <- alltypes(swedishpines,fun="F")
   X.G <- alltypes(swedishpines,fun="G")
   X.J <- alltypes(swedishpines,fun="J")

   # simulated data
   \dontrun{
   pp <- runifpoint(350, owin(c(0,1),c(0,1)))
   pp$marks <- factor(c(rep(1,50),rep(2,100),rep(3,200)))
   X.F <- alltypes(pp,fun="F",verb=TRUE,dataname="Fake Data")
   X.G <- alltypes(pp,fun="G",verb=TRUE,dataname="Fake Data")
   X.J <- alltypes(pp,fun="J",verb=TRUE,dataname="Fake Data")
   X.K <- alltypes(pp,fun="K",verb=TRUE,dataname="Fake Data")
   }

   # A setting where you might REALLY want to use dataname:
   \dontrun{
   xxx <- alltypes(ppp(Melvin$x,Melvin$y,
                window=as.owin(c(5,20,15,50)),marks=clyde),
                fun="F",verb=TRUE,dataname="Melvin")
   }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
  }
\keyword{spatial}

\eof
\name{amacrine}
\alias{amacrine}
\title{Hughes' Amacrine Cell Data}
\description{
Austin Hughes' data: a point pattern 
of displaced amacrine cells in the retina of a rabbit.
A marked point pattern.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of cell locations.
  Entries include
  \tabular{ll}{
    \code{x} \tab Cartesian \eqn{x}-coordinate of cell \cr
    \code{y} \tab Cartesian \eqn{y}-coordinate of cell \cr
    \code{marks} \tab factor with levels \code{off} and \code{on} \cr
                 \tab indicating ``off'' and ``on'' cells
    }
  See \code{\link{ppp.object}} for details of the format.
}
\usage{data(amacrine)}
\source{Peter Diggle, personal communication}
\section{Notes}{
Austin Hughes' data: a point pattern 
of displaced amacrine cells in the retina of a rabbit.
152 ``on'' cells and 142 ``off'' cells in a rectangular sampling frame.

The true dimensions of the rectangle are 1060 by 662 microns.
The coordinates here are scaled to a rectangle of height 1 and width
\eqn{1060/662 = 1.601} so the unit of measurement is approximately 662 microns.

The data were analysed by Diggle (1986).
}
\references{
Diggle, P. J. (1986).
Displaced amacrine cells in the retina of a
rabbit: analysis of a bivariate spatial point pattern. 
\emph{J. Neurosci. Meth.} \bold{18}, 115--125.
} 
\keyword{datasets}


\eof
\name{applynbd}
\alias{applynbd}
\title{Apply Function to Every Neighbourhood in a Point Pattern}
\description{
  Visit each point in a point pattern, find the neighbouring points,
  and apply a given function to them.
}
\usage{
   applynbd(X, FUN, N, R, criterion, exclude=FALSE, \dots)
}
\arguments{
  \item{X}{
    Point pattern. 
    An object of class \code{"ppp"},
    or data which can be converted into 
    this format by \code{\link{as.ppp}}.
  }
  \item{FUN}{
    Function to be applied to each neighbourhood.
    The arguments of \code{FUN} are described under \bold{Details}.
  }
  \item{N}{
    Integer. If this argument is present,
    the neighbourhood of a point of \code{X} is defined to consist of the
    \code{N} points of \code{X} which are closest to it.
    This argument is incompatible with \code{R} and \code{criterion}.
  }
  \item{R}{
    Nonnegative numeric value. If this argument is present,
    the neighbourhood of a point of \code{X} is defined to consist of
    all points of \code{X} which lie within a distance \code{R}
    of it.
    This argument is incompatible with \code{N} and \code{criterion}.
  }
  \item{criterion}{
    Function. If this argument is present, 
    the neighbourhood of a point of \code{X} is determined by
    evaluating this function. See under \bold{Details}.
    This argument is incompatible with \code{N} and \code{R}.
  }
  \item{exclude}{
    Logical. If \code{TRUE} then the point currently being visited
    is excluded from its own neighbourhood.
  }
  \item{\dots}{
    extra arguments passed to the function \code{FUN}.
    They must be given in the form \code{name=value}.
  }
}
\value{
  Similar to the result of \code{\link{apply}}.
  If each call to \code{FUN} returns a single numeric value,
  the result is a vector of dimension \code{X$n}, the number of points
  in \code{X}.
  If each call to \code{FUN} returns a vector of the same length
  \code{m}, then the result is a matrix of dimensions \code{c(m,n)};
  note the transposition of the indices, as usual for the family of
  \code{apply} functions.
  If the calls to \code{FUN} return vectors of different lengths,
  the result is a list of length \code{X$n}. 
}
\details{
  This is an analogue of \code{\link{apply}}
  for point patterns. It visits each point in the point pattern \code{X},
  determines which points of \code{X} are ``neighbours'' of the current
  point, applies the function \code{FUN} to this neighbourhood,
  and collects the values returned by \code{FUN}.

  The definition of ``neighbours'' depends on the arguments
  \code{N}, \code{R} and \code{criterion}, exactly one of which
  must be given.
  Also the argument \code{exclude} determines whether
  the current point is excluded from its own neighbourhood.

  If \code{N} is given, then the neighbours of the current
  point are the \code{N} points of \code{X} which are closest to
  the current point (including the current point itself
  unless \code{exclude=TRUE}).
  If \code{R} is given, then the neighbourhood of the current point
  consists of all points of \code{X} which lie closer than a distance \code{R}
  from the current point.
  If \code{criterion} is given, then it must be a function
  with two arguments \code{dist} and \code{drank} which will be
  vectors of equal length.
  The interpretation is that \code{dist[i]} will be the
  distance of a point from the current point, and
  \code{drank[i]} will be the rank of that distance (the three points
  closest to the current point will have rank 1, 2 and 3).
  This function must return a logical vector of the same length
  as \code{dist} and \code{drank} whose \code{i}-th entry is
  \code{TRUE} if the corresponding point should be included in
  the neighbourhood. See the examples below.

  Each point of \code{X} is visited; the neighbourhood
  of the current point is determined, and stored as a point pattern
  \code{Y}; then the function \code{FUN} is called as
  \code{FUN(Y, current, dists, dranks, \dots)}
  where \code{current} is a \code{list(x,y)} giving the location of the
  current point, \code{dists} is a vector of distances from the current
  point to each of the points in \code{Y}, 
  \code{dranks} is a vector of the ranks of these distances
  with respect to the full point pattern \code{X},
  and \code{\dots} are the arguments passed from the call to
  \code{applynbd}.

  The results of each call to \code{FUN} are collected and returned
  according to the usual rules for \code{\link{apply}} and its
  relatives. See \bold{Value} above.
}
\seealso{
  \code{\link{ppp.object}},
  \code{\link{apply}}
}
\examples{
  data(redwood)

  # count the number of points within radius 0.2 of each point of X
  nneighbours <- applynbd(redwood, R=0.2, function(Y, ...){Y$n-1})
  # equivalent to:
  nneighbours <- applynbd(redwood, R=0.2, function(Y, ...){Y$n}, exclude=TRUE)

  # compute the distance to the second nearest neighbour of each point
  secondnndist <- applynbd(redwood, N = 2, function(Y, cur, d, r){max(d)}, exclude=TRUE)

  # marked point pattern
  data(longleaf)
  \testonly{
	# smaller dataset
	longleaf <- longleaf[seq(1, longleaf$n, by=80)]
  }
  # compute the median of the marks of all neighbours of a point
  dbh.med <- applynbd(longleaf, R=40, exclude=TRUE,
                 function(Y,...) { median(Y$marks)})


  # ANIMATION explaining the definition of the K function
  # (arguments `fullpicture' and 'rad' are passed to FUN)

  showoffK <- function(Y, u, d, r, fullpicture,rad) { 
	plot(fullpicture, main="")
	points(Y[r>0], cex=2)
	points(u[1],u[2],pch="+",cex=3)
	theta <- seq(0,2*pi,length=100)
	polygon(u[1]+ rad * cos(theta),u[2]+rad*sin(theta))
	text(u[1]+rad/3,u[2]+rad/2,Y$n-1,cex=3)
	Sys.sleep(if(runif(1) < 0.1) 1.5 else 0.3)
	return(Y$n - 1)
  }
  applynbd(redwood, R=0.2, showoffK, fullpicture=redwood, rad=0.2)

  # animation explaining the definition of the G function

  showoffG <- function(Y, u, d, r, fullpicture) { 
	plot(fullpicture, main="")
	points(Y, cex=2)
	points(u[1],u[2],pch="+",cex=3)
	v <- c(Y$x[1],Y$y[1])
	segments(u[1],u[2],v[1],v[2],lwd=2)
	w <- (u + v)/2
	nnd <- sqrt(sum((u-v)^2))
	text(w[1],w[2],round(nnd,3),cex=2)
	Sys.sleep(if(runif(1) < 0.1) 1.5 else 0.3)
	return(nnd)
  }

  data(cells)
  applynbd(cells, N=1, showoffG, exclude=TRUE, fullpicture=cells)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 

\eof
\name{area.owin}
\alias{area.owin}
\title{Area of a Window}
\description{
  Computes the area of a window 
}
\usage{
 area.owin(w)
}
\arguments{
  \item{w}{A window, whose area will be computed.
    This should be an object of class \code{\link{owin}},
    or can be given in any format acceptable to \code{\link{as.owin}()}.
  }
}
\value{
  The numerical value of the area of the window. 
}
\details{
  If the window \code{W} is of type \code{"rectangle"} or \code{"polygonal"},
  the area of this rectangular window is computed by analytic geometry.
  If \code{W} is of type \code{"mask"} 
  the area of the discrete raster approximation of the window is
  computed by summing the binary image values and adjusting for
  pixel size.
}
\seealso{
  \code{\link{owin.object}},
  \code{\link{as.owin}}
}
\examples{
  w <- unit.square()
  area.owin(w)
       # returns 1.00000

  k <- 6
  theta <- 2 * pi * (0:(k-1))/k
  co <- cos(theta)
  si <- sin(theta)
  mas <- owin(c(-1,1), c(-1,1), poly=list(x=co, y=si))
  area.owin(mas)
      # returns approx area of k-gon
  
  mas <- as.mask(w, eps=0.01)
  X <- raster.x(mas)
  Y <- raster.y(mas)
  mas$m <- ((X - 0.5)^2 + (Y - 0.5)^2 <= 1)
  area.owin(mas)
       # returns 3.14 approx     

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{as.im}
\alias{as.im}
\title{Convert to Pixel Image}
\description{
  Converts various kinds of data to a pixel image
}
\usage{
  as.im(X, W, \dots)
}
\arguments{
  \item{X}{Data to be converted to a pixel image.}
  \item{W}{Window object required when \code{X} is a function.}
  \item{\dots}{Additional arguments passed to \code{X} when \code{X}
    is a function.}
}
\details{
  This function converts the data \code{x} into a pixel image
  object of class \code{"im"} (see \code{\link{im.object}}).

  Currently \code{X} may be any of the following:
  \itemize{
    \item
    a pixel image object, of class \code{"im"}. This object is just returned.
    \item
    a window object, of class \code{"owin"} (see \code{\link{owin.object}}).
    This window is first converted to a binary image mask
    by \code{\link{as.mask}}. Then the pixel entries 
    \code{TRUE} and \code{FALSE} are converted to
    \code{1} and \code{NA} respectively.
    The result is returned as an object of class \code{"im"}.
    \item
    a function of the form \code{function(x, y, ...)}
    which is to be evaluated to yield the image pixel values.
    In this case, the additional argument \code{W} must be
    a window object. This window will be converted to
    a binary image mask. Then the function \code{X} will be evaluated
    in the form \code{X(x, y, ...)} where \code{x} and \code{y} are
    \bold{vectors} containing the \eqn{x} and \eqn{y} coordinates
    of all the pixels in the image mask. This must return a numeric vector
    of the same length as the input vectors, giving the pixel values.
    \item
    a single numerical value. The result is an image
    with pixel entries equal to this numerical value
    inside the image \code{win}.
  }
}
\value{
  An image object of class \code{"im"}.
}
\examples{
  data(demopat)
  # window object
  W <- demopat$window
  plot(W)
  Z <- as.im(W)
  image(Z)
  # function
  Z <- as.im(function(x,y) {x^2 + y^2}, unit.square())
  image(Z)
  # function with extra arguments
  f <- function(x, y, x0, y0) {
      sqrt((x - x0)^2 + (y-y0)^2)
  }
  Z <- as.im(f, unit.square(), x0=0.5, y0=0.5)
  image(Z)
  # Revisit the Sixties
  data(letterR)
  Z <- as.im(f, letterR, x0=2.5, y0=2)
  image(Z)  
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{as.mask}
\alias{as.mask}
\title{Pixel Image Approximation of a Window}
\description{
  Obtain a discrete (pixel image) approximation of a given window
}
\usage{
 as.mask(w, eps=NULL, dimyx=NULL, xy=NULL)
}
\arguments{
  \item{w}{A window (object of class \code{"owin"}).}
  \item{eps}{(optional) width and height of pixels.}
  \item{dimyx}{(optional) pixel array dimensions}
  \item{xy}{(optional) pixel coordinates}
}
\value{
  A window (object of class \code{"owin"})
  of type \code{"mask"} representing a binary pixel image.
}
\details{
  This function generates a rectangular grid of locations in the plane,
  tests whether each of these locations lies inside the
  window \code{w}, and stores the results as a binary pixel image
  or `mask' (an object of class \code{"owin"}, see \code{\link{owin.object}}).

  The most common use of this function is to approximate the shape
  of another window \code{w} by a binary pixel image. In this case,
  we will usually want to have a very fine grid of pixels.

  This function can also be used to generate a coarsely-spaced grid of
  locations inside a window, for purposes such as subsampling
  and prediction.

  The grid spacing and location are controlled by the
  arguments \code{eps}, \code{dimyx} and \code{xy},
  which are mutually incompatible.

  If \code{eps} is given, then the grid spacing will be 
  approximately \code{eps} in both the \eqn{x} and \eqn{y} directions.

  If \code{dimyx} is given, then the pixel grid will be an
  \eqn{m \times n}{m x n} rectangular grid
  where \eqn{m, n} are given by \code{dimyx[2]}, \code{dimyx[1]}
  respectively.

  If \code{xy} is given, then this should be a structure
  containing two elements \code{x} and \code{y} which are the
  vectors of \eqn{x} and \code{y} coordinates of the margins
  of the grid. The pixel coordinates will be generated
  from these two vectors. In this case \code{w} may be omitted.
  
  If neither \code{eps} nor \code{dimyx} nor \code{xy} is given,
  the pixel raster dimensions are obtained from
  \code{\link{spatstat.options}("npixel")}.

  There is no inverse of this function!
}
\seealso{
  \code{\link{owin.object}},
  \code{\link{as.rectangle}},
  \code{\link{spatstat.options}}
}
\examples{
  w <- owin(c(0,10),c(0,10), poly=list(x=c(1,2,3,2,1), y=c(2,3,4,6,7)))
  \dontrun{plot(w)}
  m <- as.mask(w)
  \dontrun{plot(m)}
  x <- 1:9
  y <- seq(0.25, 9.75, by=0.5)
  m <- as.mask(w, xy=list(x=x, y=y))
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{as.owin}
\alias{as.owin}
\title{Convert Data To Class owin}
\description{
Converts data specifying an observation window
in any of several formats, into an object of class \code{"owin"}.
}
\usage{
 as.owin(W)
}
\arguments{
  \item{W}{Data specifying an observation window, in any of several formats
    described under \emph{Details} below.}
}
\value{
  An object of class \code{"owin"} (see \code{\link{owin.object}})
  specifying an observation window.
}
\details{
  The class \code{"owin"} is a way of specifying the observation window
  for a point pattern. See \code{\link{owin.object}} for an overview.
 
  This function converts data in any of several formats 
  into an object of class \code{"owin"} for use by the \code{spatstat}
  package.  The argument \code{W} may be
  \itemize{
    \item
    an object of class \code{"owin"}
    \item
    a structure with entries \code{xrange}, \code{yrange} specifying the 
    \eqn{x} and \eqn{y} dimensions of a rectangle
    \item
    a four-element vector
    (interpreted as \code{(xmin, xmax, ymin, ymax)})
    specifying the \eqn{x} and \eqn{y} dimensions of a rectangle
    \item
    a structure with entries \code{xl}, \code{xu}, \code{yl}, \code{yu}
    specifying the \eqn{x} and \eqn{y} dimensions of a rectangle
    as \code{(xmin, xmax) = (xl, xu)} and 
    \code{(ymin, ymax) = (yl, yu)}. This will accept objects of
    class \code{spp} used in the Venables and Ripley \code{spatial}
    library.
    \item
    an object of class \code{"ppp"} representing a point pattern.
    In this case, the object's \code{window} structure will be
    extracted.
    \item
    an object of class \code{"im"} representing a pixel image.
    In this case, a window of type \code{"mask"} will be returned,
    with the same pixel raster coordinates as the image.
    An image pixel value of \code{NA}, signifying that the pixel
    lies outside the window, is transformed into the logical value
    \code{FALSE}, which is the corresponding convention for window masks.
  }
}
\seealso{
  \code{\link{owin.object}},
  \code{\link{owin}}
}
\examples{
 w <- as.owin(c(0,1,0,1))
 w <- as.owin(list(xrange=c(0,5),yrange=c(0,10)))
 # point pattern
 data(demopat)
 w <- as.owin(demopat)
 # image
 Z <- as.im(function(x,y) { x + 3}, unit.square())
 w <- as.owin(Z)

 # Venables & Ripley 'spatial' package
 require(spatial)
 towns <- ppinit("towns.dat")
 w <- as.owin(towns)
 detach(package:spatial)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{as.ppp}
\alias{as.ppp}
\title{Convert Data To Class ppp}
\description{
Tries to coerce any reasonable kind of data to a point pattern
(an object of class \code{"ppp"})
for use by the \code{spatstat} package).
}
\synopsis{
  as.ppp(X, W=NULL, fatal=TRUE)
}
\usage{
  as.ppp(X)
  as.ppp(X, W)
  as.ppp(X, fatal=TRUE)
}
\arguments{
  \item{X}{Data which will be converted into a point pattern}
  \item{W}{Data which define a default window for the pattern}
  \item{fatal}{Logical value. See Details.}
}
\value{
  An object of class \code{"ppp"} (see \code{\link{ppp.object}})
  describing the point pattern and its window of observation.
  The value \code{NULL} may also be returned; see Details.
}
\details{
  This function tries to coerce the data \code{X} to a point pattern
  (an object of class \code{"ppp"}; see \code{\link{ppp.object}} for
  an overview).  The optional argument \code{W} is a default window for the
  pattern; it is used only if a window is not specified in \code{X}.

  The data \code{X} may be:
  \itemize{
    \item
    an object of class \code{"ppp"}  
    \item
    an object of class \code{"spp"} as defined in the 
    \code{spatial} library
    \item
    an object of class \code{"quad"} representing a quadrature scheme
    (see \code{\link{quad.object}})
    \item
    a two-column matrix
    \item
    a structure with entries \code{x}, \code{y}
  }
  In the last two cases, we need the second argument \code{W}
  which is converted to a window object
  by the function \code{\link{as.owin}}.
  In the first three cases, \code{W} will be ignored.

  The argument \code{fatal} indicates what to do when 
  \code{W} is missing and \code{X} contains no
  information about the window. If \code{fatal=TRUE}, a fatal error
  will be generated; if \code{fatal=FALSE}, the
  value \code{NULL} is returned.

  An \code{spp} object is the representation of a point pattern
  in the \code{spatial} library. Our implementation recognises
  the following formats:
  \itemize{
    \item
    a structure with entries \code{x}, \code{y}
    \code{xl}, \code{xu}, \code{yl}, \code{yu}
    \item
    a structure with entries
    \code{x}, \code{y} and \code{area},
    where \code{area} is a structure with entries
    \code{xl}, \code{xu}, \code{yl}, \code{yu}
  }
  (used in \code{spatial} versions 1 to 6 and version 7.1 respectively)
  where \code{x} and \code{y} are vectors of equal length
  giving the point coordinates, and \code{xl}, \code{xu}, \code{yl},
  \code{yu} are numbers giving the dimensions of a rectangular window.

  Point pattern datasets can also be created by the function
  \code{\link{ppp}}.
}
\seealso{
  \code{\link{ppp}},
  \code{\link{ppp.object}},
  \code{\link{as.owin}},
  \code{\link{owin.object}}
}
\section{Warnings}{
  If the format of \code{spp} objects
  is changed in future versions of the \code{spatial} library,
  then \code{as.ppp} may not be able to interpret them.
  It currently handles all versions of \code{spatial} up to 7.1-4.
}
\examples{
 \dontrun{
 plot(c(0,1),c(0,1),type="n")
 xy <- locator(20) # click on 20 points in plot window
 pp <- as.ppp(xy, c(0,1,0,1))
 
 w <- owin(c(0,1),c(0,1))
 plot(w)                      # neater
 xy <- locator(20)            # click on 20 points in plot window
 pp <- as.ppp(xy, w)
 } 
 
 xy <- matrix(runif(40), ncol=2)
 pp <- as.ppp(xy, c(0,1,0,1))
 
 # Venables-Ripley format
 require(spatial)
 towns <- ppinit("towns.dat")
 pp <- as.ppp(towns)   # converted to our format
 detach(package:spatial)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{as.rectangle}
\alias{as.rectangle}
\title{Window Frame}
\description{
  Get the window frame of an (irregular) window
}
\usage{
 as.rectangle(\dots)
}
\arguments{
  \item{\dots}{A window. Either an object of class \code{"owin"},
    or other data determining such a window. The argument(s)
    are passed to \code{\link{as.owin}}.}
}
\value{
  A window (object of class \code{"owin"})
  of type \code{"rectangle"} representing a rectangle.
}
\details{
  This function just extracts the outer bounding rectangle
  of the window \code{w} as given by its elements \code{xrange,yrange}.

  Use the function \code{\link{bounding.box}} to compute the smallest
  bounding rectangle.
}
\seealso{
  \code{\link{owin}},
  \code{\link{as.owin}},
  \code{\link{bounding.box}}
}
\examples{
  w <- owin(c(0,10),c(0,10), poly=list(x=c(1,2,3,2,1), y=c(2,3,4,6,7)))
  r <- as.rectangle(w)
  # returns a 10 x 10 rectangle
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{bdist.pixels}
\alias{bdist.pixels}
\title{Distance to Boundary of Window}
\description{
  Computes the distances 
  from each pixel in a window to the boundary of the window.
}
\usage{
 bdist.pixels(w, \dots, coords=TRUE)
}
\arguments{
  \item{w}{A window (object of class \code{"owin"}).}
  \item{\dots}{Arguments passed to \code{\link{as.mask}} to determine
    the pixel resolution.}
  \item{coords}{Logical: if \code{TRUE}, the result can be
    displayed using \code{persp}, \code{contour} etc.}
}
\value{
  If \code{coords} is false,
  a matrix giving the distances from each pixel in the image raster
  to the boundary of the window. Rows of this matrix correspond to
  the \eqn{y} coordinate and columns to the \eqn{x} coordinate.
  
  If \code{coords} is true, a list with three components
  \code{x,y,z}, where \code{x,y} are vectors of length \eqn{m,n}
  giving the \eqn{x} and \eqn{y} coordinates respectively,
  and \code{z} is an \eqn{m \times n}{m x n} matrix such that
  \code{z[i,j]} is the distance from \code{(x[i],y[j])} to the
  boundary of the window. Rows of this matrix correspond to the
  \eqn{x} coordinate and columns to the \eqn{y} coordinate.
  This result can be plotted with \code{persp}, \code{image}
  or \code{contour}.
}
\details{
  This function computes, for each pixel \eqn{u}
  in the window \code{w}, the shortest distance
  \eqn{d(u, W^c)}{dist(u, W')} from \eqn{u}
  to the boundary of \eqn{W}.

  If the window is not of type \code{"mask"} then it is first
  converted to that type. The arguments \code{"\dots"} are
  passed to \code{\link{as.mask}} to determine the pixel resolution.
}
\seealso{
  \code{\link{owin.object}},
  \code{\link{erode.owin}},
  \code{\link{bdist.points}},
}
\examples{
  u <- owin(c(0,1),c(0,1))
  d <- bdist.pixels(u, eps=0.01)
  image(d)
  d <- bdist.pixels(u, eps=0.01, coords=FALSE)
  mean(d >= 0.1)
  # value is approx (1 - 2 * 0.1)^2 = 0.64
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{bdist.points}
\alias{bdist.points}
\title{Distance to Boundary of Window}
\description{
  Computes the distances 
  from each point of a point pattern
  to the boundary of the window.
}
\usage{
 bdist.points(X)
}
\arguments{
  \item{X}{A point pattern (object of class \code{"ppp"}).}
}
\value{
  A numeric vector, giving the distances from each point of the pattern
  to the boundary of the window.
}
\details{
  This function computes, for each point \eqn{x_i}{x[i]}
  in the point pattern \code{X}, the shortest distance
  \eqn{d(x_i, W^c)}{dist(x[i], W')} from \eqn{x_i}{x[i]}
  to the boundary of the window \eqn{W} of observation.

  If the window \code{X$window} is of type \code{"rectangle"}
  or \code{"polygonal"}, then these distances are computed by
  analytic geometry and are exact, up to rounding errors.
  If the window is of type \code{"mask"} then the distances
  are computed using the real-valued distance transform,
  which is an approximation with maximum error equal to the width
  of one pixel in the mask.
}
\seealso{
  \code{\link{ppp.object}},
  \code{\link{erode.owin}}
}
\examples{
  data(cells)
  d <- bdist.points(cells)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{betacells}
\alias{betacells}
\alias{betacells.extra}
\title{Beta Ganglion Cells in Cat Retina} 
\description{
  Point pattern of cells in the retina, each cell classified as `on' or `off'.
  A bivariate point pattern.
} 
\format{
  \code{betacells} is an object of class \code{"ppp"}
  representing the point pattern of cell locations.
  Entries include
  \tabular{ll}{
    \code{x} \tab Cartesian \eqn{x}-coordinate of cell \cr
    \code{y} \tab Cartesian \eqn{y}-coordinate of cell \cr
    \code{marks} \tab factor with levels \code{off} and \code{on} \cr
                 \tab indicating ``off'' and ``on'' cells
  }
  See \code{\link{ppp.object}} for details of the format.
  Cartesian coordinates are given in microns.

  \code{betacells.extra} is a list with one component \code{area}
  which is the vector of areas (in square microns) of the cells
  in the pattern.
}
\usage{data(betacells)}
\source{
  W\"assle et al (1981), Figure 6(a),
  scanned and processed by Stephen Eglen
  \email{S.J.Eglen@damtp.cam.ac.uk}
}
\section{Notes}{
  This is a new, corrected version of the old dataset
  \code{\link{ganglia}}. See below.
  
  These data represent a pattern of beta-type ganglion cells
  in the retina of a cat recorded by W\"assle et al. (1981).
  Beta cells are associated
  with the resolution of fine detail in the cat's visual system.
  They can be classified anatomically as ``on'' or ``off''.
 
  Statistical independence of the arrangement of the
  ``on''- and ``off''-components
  would strengthen the evidence for Hering's (1878) `opponent theory'
  that there are two separate channels for sensing
  ``brightness'' and ``darkness''.
  See W\"assle et al (1981). There is considerable current interest
  in the arrangement of cell mosaics in the retina, see
  Rockhill et al (2000).

  The dataset is a multitype point pattern giving the locations
  and types (``on'' or ``off'') of beta cells observed
  in a rectangle of dimensions \eqn{750 \times 990}{750 x 990} microns.
  Coordinates are given in microns (thousandths of a millimetre).
  
  The original source is Figure 6 of W\"assle et al (1981),
  which is a manual drawing of the beta mosaic observed
  in a microscope field-of-view of a whole mount of the retina.
  Thus, all beta cells in the retina were effectively projected onto the same
  two-dimensional plane.
  
  The data were scanned in 2004 by Stephen Eglen from
  Figure 6(a) of W\"assle et al (1981).
  Image analysis software was used to identify the soma (cell
  body). The \eqn{x,y} location of each cell was taken to be the
  centroid of the soma. The type of each cell (``on'' or `off'')
  was identified by referring to Figures 6(b) and 6(d).

  The area of each soma (in square microns) was also computed,
  and is provided in the dataset \code{betacells.extra}.

  Note that this is a corrected version of the \code{\link{ganglia}}  
  dataset provided in earlier versions of \code{spatstat}.
  The earlier data \code{\link{ganglia}} were not faithful to the scale
  in the original paper and contain some scanning errors.
}
\examples{
   data(betacells)
   plot(betacells)
   plot(betacells$window, main="beta cells")
   symbols(betacells$x, betacells$y,
       circles=sqrt(betacells.extra$area/pi),
       inches=FALSE, add=TRUE)
}
\references{
Hering, E. (1878) Zur Lehre von Lichtsinn. Vienna.

Van Lieshout, M.N.M. and Baddeley, A.J. (1999)
Indices of dependence between types in multivariate point patterns.
\emph{Scandinavian Journal of Statistics} \bold{26}, 511--532.

Rockhill, R.L., Euler, T. and Masland, R.H. (2000)
Spatial order within but not between types of retinal neurons.
\emph{Proc. Nat. Acad. Sci. USA} \bold{97}(5), 2303--2307.

W\"assle, H., Boycott, B. B. & Illing, R.-B. (1981).
Morphology and mosaic of on- and off-beta cells in the cat retina and
some functional considerations.
\emph{Proc. Roy. Soc. London Ser. B} \bold{212}, 177--195.
}
\keyword{datasets}

\eof
\name{bounding.box}
\alias{bounding.box}
\title{Bounding Box of a Window}
\description{
  Find the smallest rectangle containing a given window(s)
}
\usage{
 bounding.box(\dots)
}
\arguments{
  \item{\dots}{One or more windows (objects of class \code{"owin"}).}
}
\value{
  A window (object of class \code{"owin"})
  of type \code{"rectangle"} representing a rectangle.
}
\details{
  If the argument is a single window object \code{w},
  this function finds the smallest rectangle (with sides parallel to
  the coordinate axes) containing \code{w}.

  If the argument is a list of windows, then
  this function finds the smallest rectangle that contains
  all of the windows.

  Note that the bounding box of a window \code{w} is usually smaller than
  the window frame (determined by \code{w$xrange} and
  \code{w$yrange} and extracted by \code{\link{as.rectangle}}).
}
\seealso{
  \code{\link{owin}},
  \code{\link{as.owin}},
  \code{\link{as.rectangle}}
}
\examples{
  w <- owin(c(0,10),c(0,10), poly=list(x=c(1,2,3,2,1), y=c(2,3,4,6,7)))
  r <- bounding.box(w)
  # returns rectangle [1,3] x [2,7]

  w2 <- unit.square()
  r <- bounding.box(w, w2)
  # returns rectangle [0,3] x [0,7]
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{bramblecanes}
\alias{bramblecanes}
\title{Hutchings' Bramble Canes data}
\description{
  Data giving the locations and ages of bramble canes in a field.
  A marked point pattern. 
} 
\format{
  An object of class \code{"ppp"} 
  representing the point pattern of plant locations.
  Entries include
  \tabular{ll}{
    \code{x} \tab Cartesian \eqn{x}-coordinate of plant \cr
    \code{y} \tab Cartesian \eqn{y}-coordinate of plant \cr
    \code{marks} \tab factor with levels 0,1, 2 indicating age
  }
  See \code{\link{ppp.object}} for details of the format.
}
\usage{data(bramblecanes)}
\source{Hutchings (1979), data published in Diggle (1983)}
\section{Notes}{
These data record the \eqn{(x,y)} locations and ages of bramble canes in a 
field \eqn{9} metres square, rescaled to the unit square. 
The canes were classified according to age as either newly emergent, 
one or two years old. These are encoded as marks 0, 1 and 2 respectively
in the dataset.

The data were recorded and analysed by Hutchings (1979)
and further analysed by Diggle (1981a, 1981b, 1983),
Diggle and Milne (1983), and Van Lieshout and Baddeley (1999).
All analyses found that the pattern of newly emergent canes
exhibits clustering, which Hutchings attributes to ``vigorous
vegetative reproduction''. 
}
\references{
  Diggle, P. J. (1981a)
  Some graphical methods in the analysis of spatial point patterns.
  In \emph{Interpreting multivariate data}, V. Barnett (Ed.)
  John Wiley and Sons. 
 
  Diggle, P. J. (1981b).
  Statistical analysis of spatial point patterns.
  \emph{N.Z. Statist.} \bold{16}, 22--41.
 
  Diggle, P.J. (1983)
  \emph{Statistical analysis of spatial point patterns}.
  Academic Press.

  Diggle, P. J. and Milne, R. K. (1983)
  Bivariate Cox processes: some models for bivariate spatial point patterns.
  \emph{Journal of the Royal Statistical Soc. Series B} 
  \bold{45}, 11--21.
 
  Hutchings, M. J. (1979)
  Standing crop and pattern in pure stands of Mercurialis
  perennis and Rubus fruticosus in mixed deciduous woodland.
  \emph{Oikos} \bold{31}, 351--357.
 
  Van Lieshout, M.N.M. and Baddeley, A.J. (1999)
  Indices of dependence between types in multivariate point patterns.
  \emph{Scandinavian Journal of Statistics} \bold{26}, 511--532.
}
\keyword{datasets}
 

\eof
\name{cells}
\alias{cells}
\title{
  Biological Cells Point Pattern
}
\description{
The data record the locations of the centres of 42 biological cells
observed under optical microscopy in a histological section. 
The microscope field-of-view has been rescaled to the unit square.

The data were recorded by F.H.C. Crick and B.D. Ripley,
and analysed in Ripley (1977, 1981) and Diggle (1983).
They are often used as a canonical example of an `ordered'
point pattern.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of cell centres.
  See \code{\link{ppp.object}} for details of the format.
}
\usage{data(cells)}
\source{Crick and Ripley, see Ripley (1977)}
\references{
  Diggle, P.J. (1983)
  \emph{Statistical analysis of spatial point patterns}.
  Academic Press.

  Ripley, B.D. (1977)
  Modelling spatial patterns (with discussion).
  \emph{Journal of the Royal Statistical Society, Series B}
  \bold{39}, 172--212.

  Ripley, B.D. (1981) 
  \emph{Spatial statistics}.
  John Wiley and Sons.
}
\keyword{datasets}

\eof
\name{centroid.owin}
\alias{centroid.owin}
\title{Centroid of a window}
\description{
  Computes the centroid (centre of mass) of a window 
}
\usage{
 centroid.owin(w)
}
\arguments{
  \item{w}{A window}
}
\value{
  A list with components \code{x, y} giving the coordinates of the
  centroid of the window \code{w}.
}
\details{
  The centroid of the window \code{w} is computed.
  The centroid (``centre of mass'') 
  is the point whose \eqn{x} and \eqn{y} coordinates 
  are the mean values of the \eqn{x} and \eqn{y} coordinates
  of all points in the window.

  The argument \code{w} should be a window (an object of class
  \code{"owin"}, see \code{\link{owin.object}} for details)
  or can be given in any format acceptable to \code{\link{as.owin}()}.

  The calculation uses an exact analytic formula for the case
  of polygonal windows.

  Note that the centroid of a window is not necessarily inside 
  the window. If the window is convex then it does contain its centroid.
}
\seealso{
  \code{\link{owin}},
  \code{\link{as.owin}}
}
\examples{
  w <- owin(c(0,1),c(0,1))
  centroid.owin(w) 
  # returns 0.5, 0.5

  data(demopat)
  w <- demopat$window
  # an irregular window
  \dontrun{
  plot(w)
  # plot the window
  points(centroid.owin(w))
  # mark its centroid 
  }

  wapprox <- as.mask(w)
  # pixel approximation of window
  \dontrun{
  points(centroid.owin(wapprox))
  # should be indistinguishable 
  }
  \testonly{
  centroid.owin(w)
  centroid.owin(wapprox)
  }	
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}





\eof
\name{coef.ppm}
\alias{coef.ppm}
\title{
  Coefficients of Fitted Point Process Model
}
\description{
  Given a point process model fitted to a point pattern,
  extract the coefficients of the fitted model.
  A method for \code{coef}.
}
\usage{
  coef.ppm(object, \dots)
}
\arguments{
  \item{object}{
    The fitted point process model (an object of class \code{"ppm"})
  }
  \item{\dots}{
    Ignored.
  }
}
\value{
  A vector containing the fitted coefficients.
}
\details{
  This function is a method for the generic function \code{\link{coef}}.
  
  The argument \code{object} must be a fitted point process model
  (object of class \code{"ppm"}). Such objects are produced by the maximum
  pseudolikelihood fitting algorithm \code{\link{ppm}}).

  This function extracts the vector of coefficients of the fitted model.
  This is the estimate of the parameter vector
  \eqn{\theta}{theta} such that the conditional intensity of the model
  is of the form
  \deqn{
    \lambda(u,x) = \exp(\theta S(u,x))
  }{
    lambda(u,x) = exp(theta . S(u,x))
  }
  where \eqn{S(u,x)} is a (vector-valued) statistic.

  For example, if the model \code{object} is the uniform Poisson process,
  then \code{coef(object)} will yield a single value
  (named \code{"(Intercept)"}) which is the logarithm of the
  fitted intensity of the Poisson process.

  Use \code{\link{print.ppm}} to print a more useful
  description of the fitted model.
}
\seealso{
 \code{\link{print.ppm}},
 \code{\link{ppm.object}},
 \code{\link{ppm}}
}
\examples{
    data(cells)

    poi <- ppm(cells, ~1, Poisson())
    coef(poi)
    # This is the log of the fitted intensity of the Poisson process

    stra <- ppm(cells, ~1, Strauss(r=0.07), rbord=0.07)
    coef(stra)

    # The two entries "(Intercept)" and "Interaction"
    # are respectively log(beta) and log(gamma)
    # in the usual notation for Strauss(beta, gamma, r)

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{complement.owin}
\alias{complement.owin}
\title{Take Complement of a Window}
\description{
  Take the set complement of a window, within its enclosing rectangle.
}
\usage{
 complement.owin(w)
}
\arguments{
  \item{w}{
    an object of class \code{"owin"} describing
    a window of observation for a point pattern.
  }
}
\value{
  Another object of class \code{"owin"} 
  representing the complement of the window, i.e. the inside
  of the window becomes the outside.
}
\details{
  If \code{w} is a rectangular window this produces an error.
  Otherwise, it yields a window object (of class \code{"owin"},
  see \code{\link{owin.object}}) representing the set complement
  of \code{w} inside its enclosing rectangle. For polygonal windows
  this is achieved by reversing the sign of each boundary polygon,
  while for binary masks it is achieved by negating the pixel values.
}
\seealso{
  \code{\link{owin}},
  \code{\link{owin.object}}
}
\examples{
   # polygonal
   data(demopat)
   w <- demopat$window
   outside <- complement.owin(w)
   # mask
   w <- as.mask(demopat$window)
   outside <- complement.owin(w)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{concatxy}
\alias{concatxy}
\title{Concatenate x,y Coordinate Vectors}
\description{
  Concatenate any number of pairs of \code{x} and \code{y}
  coordinate vectors.
}
\usage{
  concatxy(\dots)
}
\arguments{
  \item{\dots}{
    Any number of arguments, each of which is a structure
    containing elements \code{x} and \code{y}.
  }
}
\value{
  A list with two components \code{x} and \code{y}, which are the
  concatenations of all the corresponding \code{x} and \code{y}
  vectors in the argument list.
}
\details{
  This function can be used to superimpose two or more point patterns
  of unmarked points (but see also \code{\link{superimpose}} which is
  recommended). 
  
  It assumes that each of the arguments in
  \code{\dots} is a structure containing (at least) the elements
  \code{x} and \code{y}. It concatenates all the \code{x} elements
  into a vector \code{x}, and similarly for \code{y}, and returns these
  concatenated vectors.
}
\seealso{
  \code{\link{superimpose}},
  \code{\link{quadscheme}}
}
\examples{
  dat <- runifrect(30)
  xy <- list(x=runif(10),y=runif(10))
  new <- concatxy(dat, xy)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{corners}
\alias{corners}
\title{Corners of a rectangle}
\description{
  Returns the four corners of a rectangle 
}
\usage{
 corners(window)
}
\arguments{
  \item{window}{A window. 
    An object of class \code{\link{owin}},
    or data in any format acceptable to \code{\link{as.owin}()}.
  }
}
\value{
  A list with two components \code{x} and \code{y}, which are numeric
  vectors of length 4 giving the coordinates of the four corner points
  of the (bounding rectangle of the) window.
}
\details{
  This trivial function is occasionally convenient.
  If \code{window} is of type \code{"rectangle"} this returns the
  four corners of the window itself; 
  otherwise, it returns the corners of the bounding rectangle
  of the window.
}
\seealso{
  \code{\link{quad.object}},
  \code{\link{quadscheme}}
}
\examples{
  w <- unit.square()
  corners(w)
       # returns list(x=c(0,1,0,1),y=c(0,0,1,1))
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{cut.ppp}
\alias{cut.ppp}
\alias{cut}
\title{Convert Point Pattern Marks from Numeric to Factor}
\description{
  Transform the marks of a marked point pattern
  from numeric values into a factor.
}
\synopsis{
  cut.ppp(x, \dots)
}
\usage{
  cut(x, \dots)
  cut.ppp(x, \dots)
}
\arguments{
  \item{x}{
    A two-dimensional point pattern.
    An object of class \code{"ppp"}.
    This should be a marked point pattern, and the marks would normally
    be numerical values.
  }
  \item{\dots}{
    Arguments passed to the generic \code{\link{cut}} function.
    They determine the breakpoints for the mapping from numerical values to
    factor values. See \code{\link{cut}}.
  }
} 
\value{
  A multitype point pattern, that is, a point pattern object
  (of class \code{"ppp"}) with a \code{marks} vector that is a factor.
}
\details{
  This simple function applies the generic \code{\link{cut}} operation
  to the marks of the point pattern \code{x}. The range of values
  of the numerical marks is divided into several intervals, and each
  interval is associated with a level of a factor. 
  The result is a
  marked point pattern, with the same window and point locations as
  \code{x}, but with the numeric mark of each point discretised
  by replacing it by the factor level. 

  This function is a convenient
  way to transform a marked point pattern which has numeric marks
  into a multitype point pattern,
  for example to plot it or analyse it. See the examples.

  To select some points from a point pattern, use the subset operator
  \code{\link{[.ppp}} instead.
}
\seealso{
  \code{\link{cut}},
  \code{\link{ppp.object}}
}
\examples{
 data(longleaf)
 # Longleaf Pines data
 # the marks are positive real numbers indicating tree diameters.

 \testonly{
	# smaller dataset
	longleaf <- longleaf[seq(1, longleaf$n, by=80)]
 }
 \dontrun{
 plot(longleaf)
 }

 # cut the range of tree diameters into three intervals
 long3 <- cut(longleaf, 3)
 \dontrun{
 plot(long3)
 }

 # adult trees defined to have diameter at least 30 cm
 long2 <- cut(longleaf, breaks=c(0,30,100), labels=c("Sapling", "Adult"))
 plot(long2)
 plot(long2, cols=c("green","blue"))
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{data.ppm}
\alias{data.ppm}
\title{Extract Original Data from a Fitted Point Process Model}
\description{
  Given a fitted point process model,
  this function extracts the original point pattern dataset
  to which the model was fitted.
}
\usage{
  data.ppm(object)
}
\arguments{
  \item{object}{
    fitted point process model (an object of class \code{"ppm"}).
  }
}
\value{
  A point pattern (object of class \code{"ppp"}).
}
\details{
  An object of class \code{"ppm"} represents a point process model
  that has been fitted to data. It is typically produced by
  the model-fitting algorithm \code{\link{ppm}}.
  The object contains complete information about the original data
  point pattern to which the model was fitted.
  This function extracts the original data pattern.

  See \code{\link{ppm.object}} for a list of all operations that can be
  performed on objects of class \code{"ppm"}.
}
\seealso{
  \code{\link{ppm.object}},
  \code{\link{ppp.object}}
}
\examples{
 data(cells)
 fit <- ppm(cells, ~1, Strauss(r=0.1), rbord=0.1)
 X <- data.ppm(fit)
 # 'X' is identical to 'cells'
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{default.dummy}
\alias{default.dummy}
\title{Generate a Default Pattern of Dummy Points}
\description{
  Generates a default pattern of dummy points
  for use in a quadrature scheme.
}
\synopsis{
 default.dummy(X, nd, random=FALSE, ntile=NULL, \dots, verbose=FALSE)
}
\usage{
 default.dummy(X, nd, random=FALSE, \dots, verbose=FALSE)
}
\arguments{
  \item{X}{
    The observed data point pattern.
    An object of class \code{"ppp"}
    or in a format recognised by \code{\link{as.ppp}()}
  }
  \item{nd}{
    Integer, or integer vector of length 2, specifying an
    \code{nd * nd} or \code{nd[1] * nd[2]}
    rectangular array of dummy points. 
  }
  \item{random}{
    Logical value. If \code{TRUE}, the dummy points are
    randomised.
  }
  \item{\dots}{
    Ignored.
  }
  \item{verbose}{
    If \code{TRUE}, information about the construction of the
    quadrature scheme is printed.
  }
} 
\value{
  A point pattern (an object of class \code{"ppp"},
  see \code{\link{ppp.object}}) containing the dummy points.
}
\details{
  This function provides a sensible default for the dummy points
  in a quadrature scheme.

  A quadrature scheme consists of 
  the original data point pattern, an additional pattern of dummy points,
  and a vector of quadrature weights for all these points.
  See \code{\link{quad.object}} for further information about
  quadrature schemes.

  If \code{random} is false (the default),
  then the function creates dummy points
  in an \code{nd[1]} by \code{nd[1]} rectangular grid.
  If \code{random} is true, then the frame of the window is divided into
  an  \code{nd[1]} by \code{nd[1]} array of tiles, and one dummy point
  is generated at random inside each tile.
  In either case, the four corner points of the frame of the window
  are added. Then if the window is not rectangular, any dummy points
  lying outside it are deleted. 
  
  If \code{nd} is missing, 
  a default value (depending on the
  data pattern \code{X}) is computed by \code{default.ngrid}.

  Alternative functions for creating dummy patterns
  include \code{\link{corners}},
  \code{\link{gridcentres}},
  \code{\link{stratrand}} and
  \code{\link{spokes}}.
}
\seealso{
  \code{\link{quad.object}},
  \code{\link{quadscheme}},
  \code{\link{corners}},
  \code{\link{gridcentres}},
  \code{\link{stratrand}},
  \code{\link{spokes}}
}
\examples{
  data(simdat)
  P <- simdat
  D <- default.dummy(P, 100)
  \dontrun{plot(D)}
  Q <- quadscheme(P, D, "grid")
  \dontrun{plot(union.quad(Q))}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{demopat}
\alias{demopat}
\title{
   Artificial Data Point Pattern
}
\description{
  This is an artificial dataset, for use in testing and demonstrating the
  capabilities of the \code{spatstat} package.
  It is a multitype point pattern in an irregular polygonal window.
  There are two types of points. The window contains a polygonal hole.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern.

  See \code{\link{ppp.object}} for details of the format of a
  point pattern object.
}
\usage{data(demopat)}
\source{Adrian Baddeley}
}
\keyword{datasets}


 

\eof
\name{spatstat-deprecated}
\alias{mpl}
\title{Deprecated spatstat functions}
\description{
  Deprecated spatstat functions.
}
\usage{
mpl(Q, trend, interaction, data, correction, rbord, use.gam)
}

\details{
  \code{mpl} has been replaced by \code{\link{ppm}}.
}
\keyword{internal}

\eof
\name{diameter}
\alias{diameter}
\title{Diameter of a Window Frame}
\description{
  Computes the diameter of a window 
}
\usage{
 diameter(w)
}
\arguments{
  \item{w}{A window, whose diameter will be computed.}
}
\value{
  The numerical value of the diameter of the window. 
}
\details{
  It is intended that this function compute the 
  diameter of a window of arbitrary shape,
  i.e. the maximum distance between any two points
  in the window. 
  The current implementation just computes 
  the length of the diagonal of the rectangular frame
  surrounding the window.

  The argument \code{w} should be a window (an object of class
  \code{"owin"}, see \code{\link{owin.object}} for details)
  or can be given in any format acceptable to \code{\link{as.owin}()}.
  }
}
\seealso{
  \code{\link{owin}},
  \code{\link{as.owin}}
}
\examples{
  w <- owin(c(0,1),c(0,1))
  diameter(w) 
  # returns sqrt(2)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{dirichlet.weights}
\alias{dirichlet.weights}
\title{Compute Quadrature Weights Based on Dirichlet Tessellation}
\description{
  Computes quadrature weights for a given set of points,
  using the areas of tiles in the Dirichlet tessellation.
}
\usage{
 dirichlet.weights(X, window=NULL, exact=TRUE, \dots)
}
\arguments{
  \item{X}{Data defining a point pattern.}
  \item{window}{Default window for the point pattern}
  \item{exact}{Logical value. If \code{TRUE}, compute exact areas
    using the package \code{deldir}. If \code{FALSE}, compute
    approximate areas using a pixel raster.
  }
  \item{\dots}{
    Ignored.
  }
}
\value{
  Vector of nonnegative weights for each point in \code{X}.
}
\details{
  This function computes a set of quadrature weights
  for a given pattern of points
  (typically comprising both ``data'' and `dummy'' points).
  See \code{\link{quad.object}} for an explanation of quadrature
  weights and quadrature schemes.

  The weights are computed using the Dirichlet tessellation.
  First \code{X} and (optionally) \code{window} are converted into a
  point pattern object. Then the Dirichlet tessellation of the points
  of \code{X} is computed.
  The weight attached to a point of \code{X} is the area of
  its Dirichlet tile (inside the window \code{X$window}).

  If \code{exact=TRUE} the Dirichlet tessellation is computed exactly
  by the Lee-Schachter algorithm using the package \code{deldir}.
  Otherwise a pixel raster approximation is constructed and the areas
  are approximations to the true weights. In all cases the sum of the
  weights is equal to the area of the window.
}
\seealso{
  \code{\link{quad.object}},
  \code{\link{gridweights}}
}
\examples{
  Q <- quadscheme(runifpoispp(10))
  X <- as.ppp(Q) # data and dummy points together
  w <- dirichlet.weights(X, exact=FALSE)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{dummy.ppm}
\alias{dummy.ppm}
\title{Extract Dummy Points Used to Fit a Point Process Model}
\description{
  Given a fitted point process model,
  this function extracts the `dummy points' of the
  quadrature scheme used to fit the model.
}
\usage{
  dummy.ppm(object)
}
\arguments{
  \item{object}{
    fitted point process model (an object of class \code{"ppm"}).
  }
}
\value{
  A point pattern (object of class \code{"ppp"}).
}
\details{
  An object of class \code{"ppm"} represents a point process model
  that has been fitted to data. It is typically produced by
  the model-fitting algorithm \code{\link{ppm}}.
  
  The \code{\link{ppm}} algorithm approximates the pseudolikelihood
  integral by a sum over a finite set of quadrature points,
  which is constructed by augmenting
  the original data point pattern by a set of ``dummy'' points.
  The fitted model object returned by \code{\link{ppm}}
  contains complete information about this quadrature scheme.
  See \code{\link{ppm}} or \code{\link{ppm.object}} for further
  information.
  
  This function extracts the dummy points of the quadrature scheme.
  A typical use of this function would be to count the number of dummy
  points, to gauge the accuracy of the approximation to the
  exact pseudolikelihood. 

  See \code{\link{ppm.object}} for a list of all operations that can be
  performed on objects of class \code{"ppm"}.
}
\seealso{
  \code{\link{ppm.object}},
  \code{\link{ppp.object}},
  \code{\link{ppm}}
}
\examples{
 data(cells)
 fit <- ppm(cells, ~1, Strauss(r=0.1), rbord=0.1)
 X <- dummy.ppm(fit)
 X$n
 # this is the number of dummy points in the quadrature scheme
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{erode.owin}
\alias{erode.owin}
\title{Erode a Window}
\description{
  Perform morphological erosion of a window 
}
\usage{
 erode.owin(w, r, shrink.frame=TRUE, \dots)
}
\arguments{
  \item{w}{A window (object of class \code{"owin"}.}
  \item{r}{positive number: the radius of erosion.}
  \item{shrink.frame}{logical: if \code{TRUE}, erode the bounding
    rectangle as well.}
  \item{\dots}{extra arguments to \code{\link{as.mask}}
    controlling the pixel resolution}
}
\value{
  Another object of class \code{"owin"} representing the
  eroded window.
}
\details{
  The morphological erosion of a set \eqn{W} by a distance \eqn{r > 0}
  is the subset 
  consisting of all points \eqn{x \in W}{x in W} such that the
  distance from \eqn{x} to the boundary of \eqn{W} is greater than
  or equal to \eqn{r}. In other words it is the result of trimming
  a margin of width \eqn{r} off the set \eqn{W}.

  This function computes the erosion of the window \code{w}.
  If \code{w} is not
  a rectangle, it must be approximated by a binary pixel image,
  and the arguments \code{"\dots"} are passed to \code{\link{as.mask}}
  to determine the pixel resolution. There is a sensible default.
  
  If \code{shrink.frame} is false, the resulting window is given the
  same outer, bounding rectangle as the original window \code{w}.
  If \code{shrink.frame} is true, the original bounding rectangle
  is also eroded by the same distance \code{r}.

  To simply compute the area of the eroded window,
  use \code{\link{eroded.areas}}.
}
\seealso{
  \code{\link{owin}},
  \code{\link{as.owin}},
  \code{\link{eroded.areas}}
}
\examples{
  w <- owin(c(0,1),c(0,1))
  v <- erode.owin(w, 0.1) 
  # returns rectangle [0.1, 0.9] x [0.1,0.9]
  \dontrun{
  v <- erode.owin(w, 0.6)
  #fails - erosion is empty
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{eroded.areas}
\alias{eroded.areas}
\title{Areas of Morphological Erosions}
\description{
  Computes the areas of successive morphological erosions of a window.
}
\usage{
 eroded.areas(w, r)
}
\arguments{
  \item{w}{A window.}
  \item{r}{Numeric vector of radii at which erosions will be performed.}
}
\value{
  Numeric vector, of the same length as \code{r},
  giving the areas of the successive erosions.
}
\details{
  This function computes the areas of the erosions of the window
  \code{w} by each of the radii \code{r[i]}. 

  The morphological erosion of a set \eqn{W} by a distance \eqn{r > 0}
  is the subset 
  consisting of all points \eqn{x \in W}{x in W} such that the
  distance from \eqn{x} to the boundary of \eqn{W} is greater than
  or equal to \eqn{r}. In other words it is the result of trimming
  a margin of width \eqn{r} off the set \eqn{W}.

  The argument \code{r} should be a vector of positive numbers.
  The argument \code{w} should be a window (an object of class
  \code{"owin"}, see \code{\link{owin.object}} for details)
  or can be given in any format acceptable to \code{\link{as.owin}()}.

  Unless \code{w} is a rectangle, the computation is performed
  using a pixel raster approximation.

  To compute the eroded window itself, use \code{\link{erode.owin}}.
}
\seealso{
  \code{\link{owin}},
  \code{\link{as.owin}},
  \code{\link{erode.owin}}
}
\examples{
  w <- owin(c(0,1),c(0,1))
  a <- eroded.areas(w, seq(0.01,0.49,by=0.01))
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{fasp.object}
\alias{fasp.object}
\title{Function Arrays for Spatial Patterns}
\description{
  A class \code{"fasp"} to represent a ``matrix''
  of functions, amenable to plotting as a matrix of plot panels.
}
\details{
  An object of this class is a convenient way of storing
  (and later plotting, editing, etc)
  a set of functions \eqn{f_{i,j}(r)}{f[i,j](r)} of a real argument \eqn{r},
  defined for each possible pair \eqn{(i,j)} of indices
  \eqn{1 \le i,j \le n}{1 <= i,j <= n}. We may think of this
  as a matrix or array of functions \eqn{f_{i,j}}{f[i,j]}.

  Function arrays are particularly useful in the 
  analysis of a multitype point pattern (a point pattern in which 
  the points are identified as belonging to separate types).
  We may want to compute a summary function for the points
  of type \eqn{i} only, for each of the possible types \eqn{i}.
  This produces a \eqn{1 \times m}{1 * m} array of functions.
  Alternatively we may compute a summary function
  for each possible pair of types \eqn{(i,j)}.
  This produces an \eqn{m \times m}{m *  m} array of functions.

  For multitype point patterns the command \code{\link{alltypes}}
  will compute arrays of summary functions for each possible
  type or for each possible pair of types.
  For univariate (single-type) point patterns the command
  \code{\link{allstats}} will compute an array of
  different summary functions \eqn{F}, \eqn{G}, \eqn{J},
  \eqn{K} for the same dataset.
  Both \code{\link{alltypes}} and \code{\link{allstats}}
  return an object of class \code{"fasp"}.

  There are methods for \code{plot}, \code{print} and \code{"["} in this class.
  The plot method displays the entire array of functions.
  The method \code{\link{[.fasp}} selects a sub-array using the natural
  indices \code{i,j}. 

  An object of class \code{"fasp"} is a list containing at least the
  following components:
  
  \item{fns}{
    A list of data frames, each representing one of the functions.
  }
  \item{which}{
    A matrix representing the spatial arrangement of the
    functions. If \code{which[i,j] = k}
    then the function represented by \code{fns[[k]]} should be plotted
    in the panel at position \eqn{(i,j)}. If \code{which[i,j] = NA}
    then nothing is plotted in that position.
  }
  \item{titles}{
    A list of character strings, providing suitable plotting titles
    for the functions.
    }
  \item{default.formulae}{
    A list of default formulae for plotting each of the functions.
  }
  \item{title}{
    A character string, giving a default title for the array
    when it is plotted.
  }

}
\seealso{
  \code{\link{alltypes}},
  \code{\link{allstats}},
  \code{\link{plot.fasp}},
  \code{\link{[.fasp}}
}
\examples{
  # unmarked point pattern
  data(swedishpines)
  \testonly{
	# smaller dataset
	swedishpines <- swedishpines[1:30]
  }
  a <- allstats(swedishpines,dataname="Swedish Pines")
  a
  plot(a)
  plot(a[1,])

  # multitype point pattern
  data(amacrine)
  a <- alltypes(amacrine, "G")
  plot(a)

  # select the row corresponding to cells of type "on"
  b <- a["on", ]
  plot(b)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{finpines}
\alias{finpines}
\alias{finpines.extra}
\title{
  Pine saplings in Finland.
}
\description{
  The data record the locations of 126 pine saplings
  in a Finnish forest, their heights and their diameters.

  The main dataset \code{finpines} is a marked point pattern
  containing the locations of the saplings marked by their heights.
  Additional data in \code{finpines.extra} record the sapling diameters.

  Sapling locations are given in metres (to six significant digits);
  heights are in metres (rounded to the nearest 0.1 metre,
  except in one case to the nearest 0.05 metres);
  diameters are in centimetres (rounded to the nearest centimetre).
  
  The data were recorded by Professor Seppo Kellomaki, Faculty of
  Forestry, University of Joensuu, Finland,
  and subsequently massaged by Professor Antti Penttinen,
  Department of Statistics, University of Jyv\"askyl\"a, Finland.
  
  Originally the point locations were observed in polar coordinates with
  rather poor angular precision. Hence the coordinates are imprecise for large
  radius because of rounding errors: indeed the alignments can be observed by
  eye.
  
  The data were manipulated by Prof Penttinen by making small angular
  perturbations at random. After this transformation, the original data
  (in a circular plot) were clipped to a square window, for convenience.

  Professor Penttinen emphasises that the data were intended only
  for initial experimentation. They have some strange features.
  For example, if the height is less than 1.3 metres then the diameter
  can be uncertain. Also there are some very close pairs of points.

  These data have subsequently been analysed by Van Lieshout (2004).
} 
\format{
  \code{finpines} is an object of class \code{"ppp"}
  representing the point pattern of sapling locations marked by
  their heights.
  See \code{\link{ppp.object}} for details of the format.

  \code{finpines.extra} is a list with one component \code{diameter}
  which is a numeric vector containing the diameters of the points.
}
\usage{data(finpines)}
\examples{
    data(finpines)
    plot(unmark(finpines), main="Finnish pines: locations")
    plot(finpines, main="locations and heights")
    plot(finpines \%mark\% finpines.extra$diameter, main="diameters")
}
\source{Prof Antti Penttinen}
\references{
  Van Lieshout, M.N.M. (2004)
  A J-function for marked point patterns.
  Research Report PNA-R0404, June 2004.
  Centrum voor Wiskunde en Informatica (CWI), Amsterdam, 2004.
}
\keyword{datasets}

\eof
\name{fitted.ppm}
\alias{fitted.ppm}
\title{
  Fitted Conditional Intensity for Point Process Model
}
\description{
  Given a point process model fitted to a point pattern,
  compute the fitted conditional intensity of the model
  at the points of the quadrature scheme used to fit the model.
}
\usage{
  fitted.ppm(object, \dots, type="lambda")
}
\arguments{
  \item{object}{
    The fitted point process model (an object of class \code{"ppm"})
  }
  \item{\dots}{
    Ignored.
  }
  \item{type}{
    String (partially matched) indicating whether the fitted value is the
    conditional intensity (\code{"lambda"}) or the trend
    (\code{"trend"}).
  }
}
\value{
  A vector containing the values of the fitted conditional intensity
  or (if \code{type="trend"}) the fitted spatial trend.
  
  Entries in this vector correspond to the quadrature points (data or
  dummy points) used to fit the model. The quadrature points can be
  extracted from \code{object} by \code{union.quad(quad.ppm(object))}.
}
\details{
  The argument \code{object} must be a fitted point process model
  (object of class \code{"ppm"}). Such objects are produced by the 
  model-fitting algorithm \code{\link{ppm}}).

  This function evaluates the conditional intensity
  \eqn{\hat\lambda(u, x)}{lambdahat(u,x)}
  or spatial trend \eqn{\hat b(u)}{bhat(u)} of the fitted point process
  model for certain locations \eqn{u},
  where \code{x} is the original point pattern dataset to which
  the model was fitted.

  The locations \eqn{u} at which the fitted conditional intensity/trend
  is evaluated, are the points of the
  quadrature scheme used to fit the model in \code{\link{ppm}}.
  They include the data points (the points of the original point pattern
  dataset \code{x}) and other ``dummy'' points 
  in the window of observation.

  Use \code{\link{predict.ppm}} to compute the fitted conditional
  intensity at other locations or with other values of the
  explanatory variables.
}
\references{
  Baddeley, A., Moller, J. and Turner, R. (2004)
  Residuals for spatial point processes.
  In preparation.
}
\seealso{
 \code{\link{ppm.object}},
 \code{\link{ppm}},
 \code{\link{predict.ppm}}
}
\examples{
    data(cells)
    str <- ppm(cells, ~x, Strauss(r=0.15), rbord=0.15)
    lambda <- fitted(str)

    # extract quadrature points in corresponding order
    quadpoints <- union.quad(quad.ppm(str))

    # plot conditional intensity values
    # as circles centred on the quadrature points 
    quadmarked <- setmarks(quadpoints, lambda)
    plot(quadmarked)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{fv.object}
\alias{fv.object}
\title{Data Frames of Function Values}
\description{
  A class \code{"fv"} to support the convenient plotting
  of several estimates of the same function.
}
\details{
  An object of this class is a convenient way of storing and plotting
  several different estimates of the same function.

  It is a data frame with extra attributes indicating
  the recommended way of plotting the function, and other information.

  There are methods for \code{print} and \code{plot} for
  this class.
  
  Objects of class \code{"fv"} are returned by
  \code{\link{Fest}}, \code{\link{Gest}},\code{\link{Jest}},
  and \code{\link{Kest}}.
}
\seealso{
  \code{\link{Fest}},
  \code{\link{Gest}},
  \code{\link{Jest}},
  \code{\link{Kest}}
}
\examples{
    data(cells)
    K <- Kest(cells)

    class(K)

    K  # prints a sensible summary

    plot(K)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{ganglia}
\alias{ganglia}
\title{Beta Ganglion Cells in Cat Retina, Old Version} 
\description{
  Point pattern of retinal ganglion cells identified as `on' or `off'.
  A marked point pattern.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of cell locations.
  Entries include
  \tabular{ll}{
    \code{x} \tab Cartesian \eqn{x}-coordinate of cell \cr
    \code{y} \tab Cartesian \eqn{y}-coordinate of cell \cr
    \code{marks} \tab factor with levels \code{off} and \code{on} \cr
                 \tab indicating ``off'' and ``on'' cells
  }
  See \code{\link{ppp.object}} for details of the format.
}
\usage{data(ganglia)}
\source{W\"assle et al (1981), data supplied by Marie-Colette van
  Lieshout and attributed to Peter Diggle}
\section{Notes}{
  \bold{Important: these data are INCORRECT.  See below.}
  
  The data represent a pattern of beta-type ganglion cells in the
  retina of a cat recorded in Figure 6(a) of W\"assle et al. (1981).

  The pattern was first analysed by W\"assle et al (1981) using
  nearest neighbour distances. The data used in their analysis
  are not available.

  The present dataset \code{\link{ganglia}} was
  scanned from Figure 6(a) of W\"assle et al (1981)
  in the early 1990's, but we have no further information.
  This dataset is the one analysed by Van Lieshout and Baddeley (1999)
  using multitype J functions, and by Stoyan (1995) using second
  order methods (pair correlation and mark correlation).
  
  It has now been discovered that these data are \bold{incorrect}.
  They are not faithful to the scale in Figure 6 of W\"assle et al (1981),
  and they contain some scanning errors.
  Hence they should not be used to address the original scientific question.
  They have been retained only for comparison with other analyses
  in the statistical literature.

  A new, corrected dataset, scanned from the original microscope image,
  has been provided under the name \code{\link{betacells}}.  Use that
  dataset for any further study.
}
\section{Warnings}{
  These data are incorrect.
  Use the new corrected dataset \code{\link{betacells}}.  
}
\references{
  Stoyan, D. (1995) Personal communication.
  
  Van Lieshout, M.N.M. and Baddeley, A.J. (1999) Indices of
  dependence between types in multivariate point patterns.
  \emph{Scandinavian Journal of Statistics} \bold{26}, 511--532.

  W\"assle, H., Boycott, B. B. & Illing, R.-B. (1981).  Morphology
  and mosaic of on- and off-beta cells in the cat retina and some
  functional considerations.  \emph{Proc. Roy. Soc. London Ser. B}
  \bold{212}, 177--195.
}
\keyword{datasets}



\eof
\name{gridcentres}
\alias{gridcentres}
\alias{gridcenters}
\title{Rectangular grid of points}
\description{
  Generates a rectangular grid of points in a window
}
\usage{
 gridcentres(window, nx, ny)
}
\arguments{
  \item{window}{A window. 
    An object of class \code{\link{owin}},
    or data in any format acceptable to \code{\link{as.owin}()}.
  }
  \item{nx}{Number of points
    in each row of the rectangular grid.
  }
  \item{ny}{Number of points
    in each column of the rectangular grid.
  }
}
\value{
  A list with two components \code{x} and \code{y}, which are numeric
  vectors giving the coordinates of the points of the
  rectangular grid.
}
\details{
  This function creates a rectangular grid of points in the window.
  
  The bounding rectangle of the \code{window} is divided into
  a regular \eqn{nx \times ny}{nx * ny} grid of rectangular tiles.
  The function returns the \eqn{x,y} coordinates of the
  centres of these tiles.

  Note that some of these grid points may lie outside the window,
  if \code{window} is not of type \code{"rectangle"}. The function
  \code{\link{inside.owin}} can be used to select those grid points
  which do lie inside the window. See the examples.

  This function is useful in creating dummy points for quadrature
  schemes (see \code{\link{quadscheme}}) and for other miscellaneous
  purposes.
}
\seealso{
  \code{\link{quad.object}},
  \code{\link{quadscheme}},
  \code{\link{inside.owin}},
  \code{\link{stratrand}}
}
\examples{
  w <- unit.square()
  xy <- gridcentres(w, 10,15)
  \dontrun{
  plot(w)
  points(xy)
  }

  bdry <- list(x=c(0.1,0.3,0.7,0.4,0.2),
               y=c(0.1,0.1,0.5,0.7,0.3))
  w <- owin(c(0,1), c(0,1), poly=bdry)
  xy <- gridcentres(w, 30, 30)
  ok <- inside.owin(xy$x, xy$y, w)
  \dontrun{
  plot(w)
  points(xy$x[ok], xy$y[ok])
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{gridweights}
\alias{gridweights}
\title{Compute Quadrature Weights Based on Grid Counts}
\description{
  Computes quadrature weights for a given set of points,
  using the ``counting weights'' for a grid of rectangular tiles.
}
\usage{
 gridweights(X, ntile, \dots, window=NULL, verbose=FALSE)
}
\arguments{
  \item{X}{Data defining a point pattern.}
  \item{ntile}{Number of tiles
    in each row and column of the rectangular grid.
    An integer vector of length 1 or 2.
  }
  \item{\dots}{Ignored.}
  \item{window}{Default window for the point pattern}
  \item{verbose}{Logical flag. If \code{TRUE}, information will be printed
    about the computation of the grid weights.
  }
}
\value{
  Vector of nonnegative weights for each point in \code{X}.
}
\details{
  This function computes a set of quadrature weights
  for a given pattern of points
  (typically comprising both ``data'' and `dummy'' points).
  See \code{\link{quad.object}} for an explanation of quadrature
  weights and quadrature schemes.

  The weights are computed by the ``counting weights'' rule
  based on a regular grid of rectangular tiles.
  First \code{X} and (optionally) \code{window} are converted into a
  point pattern object. Then the bounding rectangle of the window of
  the point pattern is
  divided into a regular \code{ntile[1] * ntile[2]} grid of rectangular tiles.
  The weight attached to a point of \code{X} is the area of the tile
  in which it lies, divided by the number of points of \code{X} lying in
  that tile.
}
\seealso{
  \code{\link{quad.object}},
  \code{\link{dirichlet.weights}}
}
\examples{
  Q <- quadscheme(runifpoispp(10))
  X <- as.ppp(Q) # data and dummy points together
  w <- gridweights(X, 10)
  w <- gridweights(X, c(10, 10))
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{hamster}
\alias{hamster}
\title{Aherne's hamster tumour data} 
\description{
  Point pattern of cell nuclei in hamster kidney, each nucleus classified as
  either `dividing' or `pyknotic'.
  A multitype point pattern.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of cell locations.
  Entries include
  \tabular{ll}{
    \code{x} \tab Cartesian \eqn{x}-coordinate of cell \cr
    \code{y} \tab Cartesian \eqn{y}-coordinate of cell \cr
    \code{marks} \tab factor with levels \code{"dividing"}
    and \code{"pyknotic"}.
  }
  See \code{\link{ppp.object}} for details of the format.
}
\usage{data(hamster)}
\source{Dr W. A. Aherne, Department of Pathology, University of
  Newcastle-upon-Tyne, UK. Data supplied by Prof. Peter Diggle}
\section{Notes}{
  These data were presented and analysed by Diggle (1983, section 7.3).

  The data give the positions of the centres of the nuclei of certain
  cells in a histological
  section of tissue from a laboratory-induced metastasising lymphoma
  in the kidney of a hamster.

  The nuclei are classified as either
  "pyknotic" (corresponding to dying cells) or "dividing" (corresponding
  to cells arrested in metaphase, i.e. in the act of dividing). The
  background void is occupied by unrecorded, interphase cells in
  relatively large numbers. 

  The sampling window is a square, originally about 0.25 mm square
  in real units, which has been rescaled to the unit square.
}
\references{
  Diggle, P.J. (1983)
  \emph{Statistical analysis of spatial point patterns}.
  Academic Press.
}
\keyword{datasets}

\eof
\name{harmonic}
\alias{harmonic}
\title{Basis for Harmonic Functions}
\description{
  Evaluates a basis for the harmonic polynomials in \eqn{x} and \eqn{y}
  of degree less than or equal to \eqn{n}.
}
\usage{
   harmonic(x, y, n)
}
\arguments{
  \item{x}{
    Vector of \eqn{x} coordinates
  }
  \item{y}{
    Vector of \eqn{y} coordinates
  }
  \item{n}{
    Maximum degree of polynomial
  }
}
\value{
  A data frame with \code{2 * n} columns giving the values of the
  basis functions at the coordinates. Each column is labelled by an
  algebraic expression for the corresponding basis function.
}
\details{
  This function computes a basis for the harmonic polynomials
  in two variables \eqn{x} and \eqn{y} up to a given degree \eqn{n}
  and evaluates them at given \eqn{x,y} locations.
  It can be used in model formulas (for example in
  the model-fitting functions
  \code{\link{lm},\link{glm},\link{gam}} and \code{\link{ppm}}) to specify a
  linear predictor which is a harmonic function.

  A function \eqn{f(x,y)} is harmonic if
  \deqn{\frac{\partial^2}{\partial x^2} f
    + \frac{\partial^2}{\partial y^2}f = 0.}{
    (d/dx)^2 f + (d/dy)^2 f = 0.}
  The harmonic polynomials of degree less than or equal to
  \eqn{n} have a basis consisting of \eqn{2 n} functions.

  This function was implemented on a suggestion of P. McCullagh
  for fitting nonstationary spatial trend to point process models.
}
\seealso{
  \code{\link{ppm}}
}
\examples{
   data(longleaf)
   X <- unmark(longleaf)
   # inhomogeneous point pattern
   \testonly{
	# smaller dataset
	longleaf <- longleaf[seq(1,longleaf$n, by=50)]
   }

   # fit Poisson point process with log-cubic intensity
   fit.3 <- ppm(X, ~ polynom(x,y,3), Poisson())

   # fit Poisson process with log-cubic-harmonic intensity
   fit.h <- ppm(X, ~ harmonic(x,y,3), Poisson())

   # Likelihood ratio test
   lrts <- 2 * (fit.3$maxlogpl - fit.h$maxlogpl)
   x <- X$x
   y <- X$y
   df <- ncol(polynom(x,y,3)) - ncol(harmonic(x,y,3))
   pval <- 1 - pchisq(lrts, df=df)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{identify.ppp}
\alias{identify.ppp}
\alias{identify}
\title{Identify Points in a Point Pattern}
\description{
  If a point pattern is plotted in the graphics window,
  this function will find the point of the pattern which is nearest to
  the mouse position, and print its mark value (or its serial number
  if there is no mark).
}
\synopsis{
  identify.ppp(x, \dots)
}
\usage{
  identify(x, \dots)
  identify.ppp(x, \dots)
}
\arguments{
  \item{x}{
    A point pattern (object of class \code{"ppp"}).
  }
  \item{\dots}{
    Arguments passed to \code{\link{identify.default}}.
  }
}
\value{
  If \code{x} is unmarked, the result is 
  a vector containing the serial numbers of the points in the pattern
  \code{x} that were identified.
  If \code{x} is marked, the result is a 
  2-column matrix, the first column containing the serial numbers
  and the second containing the marks for these points.
}
\details{
  This is a method for the generic function \code{\link{identify}}
  for point pattern objects.

  The point pattern \code{x} should first be plotted
  using \code{\link{plot.ppp}}. Then \code{identify(x)}
  reads the position of the graphics pointer each time the
  left mouse button is pressed.  It then finds 
  the point of the pattern \code{x} closest to the mouse position.
  If this closest point is sufficiently close to the mouse pointer,
  its index (and its mark if any) 
  will be returned as part of the value of the call.

  Each time a point of the pattern is identified,
  text will be displayed next to the point,
  showing its serial number (if \code{x} is unmarked)
  or its mark value (if \code{x} is marked).
}
\seealso{
  \code{\link{identify}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{im}
\alias{im}
\title{Create a Pixel Image Object}
\description{
  Creates an object of
  class \code{"im"} representing a two-dimensional pixel image.
}
\usage{
  im(mat, xcol=seq(ncol(mat)), yrow=seq(nrow(mat)))
}
\arguments{
  \item{mat}{
    matrix of grey level pixel values of the image.
  }
  \item{xcol}{
    vector of \eqn{x} coordinates for the pixels
  }
  \item{yrow}{
    vector of \eqn{y} coordinates for the pixels
  }
}
\details{
  This function creates an object of class \code{"im"} representing
  a two-dimensional pixel image. See \code{\link{im.object}}
  for details of this class.

  Note that the \bold{row} index of the matrix \code{mat} corresponds
  to increasing \bold{y} coordinate, while the column index of \code{mat}
  corresponds to increasing \bold{x} coordinate. Thus
  \code{xrow} has one entry for each row of \code{mat}
  and \code{ycol} has one entry for each column of \code{mat}. A correct
  display of the image would be obtained by transposing, e.g.
  \code{image.default(xcol, yrow, t(mat))}, if you wanted to do it by hand.
}
\seealso{
  \code{\link{im.object}},
  \code{\link{Kmeasure}},
  \code{\link{setcov}}
}
\section{Warnings}{
  The internal representation of images is likely to change in the
  next release of this package.
}
\examples{
   whitenoise <- im(matrix(rnorm(10000), 100, 100))
   image(whitenoise)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{im.object}
\alias{im.object}
\title{Class of Images}
\description{
  A class \code{"im"} to represent a two-dimensional pixel image.
}
\details{
  An object of this class represents
  a two-dimensional pixel image. It specifies
  \itemize{
    \item the dimensions of the rectangular array of pixels
    \item \eqn{x} and \eqn{y} coordinates for the pixels
    \item a numeric value (``grey value'') at each pixel
  }
  If \code{X} is an object of type \code{im},
  it contains the following elements:
  \tabular{ll}{
    \code{v} \tab matrix of values \cr
    \code{dim} \tab dimensions of matrix \code{v} \cr
    \code{xrange} \tab range of \eqn{x} coordinates of image window \cr
    \code{yrange} \tab range of \eqn{y} coordinates of image window \cr
    \code{xstep} \tab width of one pixel \cr
    \code{ystep} \tab height of one pixel \cr
    \code{xcol} \tab vector of \eqn{x} coordinates of centres of pixels \cr
    \code{yrow} \tab vector of \eqn{y} coordinates of centres of pixels 
  }
  Users are strongly advised not to manipulate these entries
  directly.

  Objects of class \code{"im"}
  may be created by the function
  \code{\link{im}}. They are also returned by the functions
  \code{\link{Kmeasure}} and
  \code{\link{setcov}}.
  They may be displayed using the methods
  \code{image.im}, \code{persp.im}
  and \code{contour.im}.
  Values of an image may be looked-up using
  \code{lookup.im}.

  Note that the \bold{row} index of the matrix \code{v} corresponds
  to increasing \bold{y} coordinate, while the column index of \code{m}
  corresponds to increasing \bold{x} coordinate. Thus a correct
  display of the image would be obtained by transposing, e.g.
  \code{image.default(xcol, yrow, t(im))}, if you wanted to do it by hand.
}
\seealso{
  \code{\link{im}},
  \code{\link{Kmeasure}},
  \code{\link{setcov}}
}
\section{Warnings}{
  The internal representation of images is likely to change in the
  next release of this package.
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{inside.owin}
\alias{inside.owin}
\title{Test Whether Points Are Inside A Window}
\description{
 Test whether points lie inside or outside
 a given window.
}
\usage{
 inside.owin(x, y, w)
}
\arguments{
  \item{x}{
    Vector of \eqn{x} coordinates of points to be tested.
  }
  \item{y}{
    Vector of \eqn{y} coordinates of points to be tested.
  }
  \item{w}{A window.
    This should be an object of class \code{\link{owin}},
    or can be given in any format acceptable to \code{\link{as.owin}()}.
  }
}
\value{
  Logical vector whose \code{i}th entry is 
  \code{TRUE} if the corresponding point \code{(x[i],y[i])}
  is inside \code{w}. 
}
\details{
  This function tests whether each of the points 
  \code{(x[i],y[i])} lies inside or outside
  the window \code{w} and returns \code{TRUE} if it is inside.
  
  The boundary of the window is treated as being inside.

  If \code{w} is of type \code{"rectangle"} or 
  \code{"polygonal"}, the algorithm uses analytic geometry
  (the discrete Stokes theorem).
  Computation time is linear in the number of points
  and (for polygonal windows) in the number of vertices of the
  boundary polygon. Boundary cases are correct to single
  precision accuracy.
  
  If \code{w} is of type \code{"mask"} then the 
  pixel closest to \code{(x[i],y[i])} is tested. The
  results may be incorrect for points lying within 
  one pixel diameter of the window boundary.
}
\seealso{
  \code{\link{owin.object}},
  \code{\link{as.owin}}
}
\examples{
  # hexagonal window
  k <- 6
  theta <- 2 * pi * (0:(k-1))/k
  co <- cos(theta)
  si <- sin(theta)
  mas <- owin(c(-1,1), c(-1,1), poly=list(x=co, y=si))
  \dontrun{
  plot(mas)
  }

  # random points in rectangle
  x <- runif(30,min=-1, max=1)
  y <- runif(30,min=-1, max=1)

  ok <- inside.owin(x, y, mas)

  \dontrun{
  points(x[ok], y[ok])
  points(x[!ok], y[!ok], pch="x")
  }  
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{spatstat-internal}
\alias{affinexy}
\alias{apply23sum}
\alias{area.xypolygon}       
\alias{as.breakpts}
\alias{as.fv}
\alias{as.polygonal}
\alias{bind.fv}
\alias{bdrylength.xypolygon} 
\alias{breakpts}
\alias{breakpts.from.r}
\alias{cartesian}
\alias{checkfields}          
\alias{check.hist.lengths}
\alias{conspire}
\alias{contour.im}
\alias{countingweights}
\alias{crossdist}            
\alias{default.ngrid}
\alias{default.ntile}
\alias{discretise}
\alias{distpl}               
\alias{distppl}
\alias{distppll}
\alias{edge.Ripley}
\alias{edge.Trans}
\alias{equals.quad}          
\alias{erode.mask}
\alias{even.breaks.owin}
\alias{exactdt}              
\alias{exactPdt}
\alias{fasp}
\alias{fv}
\alias{getfields}
\alias{gridindex}            
\alias{handle.r.b.args}
\alias{identical.formulae}
\alias{image.im}            
\alias{inside.xypolygon}     
\alias{intX.owin}     
\alias{intX.xypolygon}     
\alias{intY.owin}     
\alias{intY.xypolygon}     
\alias{is.cadlag}
\alias{is.data}
\alias{is.fv}
\alias{is.marked.default}    
\alias{is.poisson.ppm}
\alias{is.stationary.ppm}    
\alias{Kount}
\alias{Kwtsum}               
\alias{lookup.im}
\alias{make.even.breaks}
\alias{markspace.integral}
\alias{marks.quad}           
\alias{matcolall}
\alias{matcolany}
\alias{matcolsum}            
\alias{matrowall}
\alias{matrowany}
\alias{matrowsum}
\alias{meanX.owin}
\alias{meanY.owin}
\alias{mkcor}
\alias{mpl.engine}
\alias{mpl.get.covariates}
\alias{mpl.prepare}
\alias{MultiPair.checkmatrix}
\alias{multipair.family}
\alias{nearest.pixel}
\alias{no.trend.ppm}
\alias{n.quad}               
\alias{overlap.owin}
\alias{overlap.trapezium}
\alias{overlap.xypolygon}    
\alias{param.quad}
\alias{persp.im}
\alias{pixellate}
\alias{plot.im}
\alias{polynom}
\alias{print.fasp}       
\alias{print.fv}       
\alias{print.interact}       
\alias{print.isf}
\alias{print.summary.owin}
\alias{print.summary.ppp}
\alias{quad}
\alias{quadscheme.replicated}
\alias{quadscheme.spatial}
\alias{rasterx.im}
\alias{rastery.im}
\alias{resolve.defaults}
\alias{reverse.xypolygon}    
\alias{rotxy}
\alias{runifdisc}
\alias{runifpoispp}          
\alias{runifrect}
\alias{rmhmodel.ppm}
\alias{rmpoint.I.allim}
\alias{rpoint.multi}
\alias{scanpp}
\alias{second.moment.calc}
\alias{setcov}
\alias{shiftxy}              
\alias{spatstat.rawdata.location}
\alias{sympoly}
\alias{termsinformula}
\alias{tilecentroids}        
\alias{tilemiddles}
\alias{try.FGJKest}
\alias{try.Kcross}           
\alias{update.interact}
\alias{validate.mask}        
\alias{verifyclass}
\alias{verify.xypolygon}
\alias{whist}               
\alias{w.quad}               
\alias{x.quad}
\alias{y.quad}               
\title{Internal spatstat functions}
\description{
  Internal spatstat functions.
}
\usage{
affinexy(X, mat = diag(c(1, 1)), vec = c(0, 0))
apply23sum(x)
area.xypolygon(polly)       
as.breakpts(\dots)
as.fv(x)
as.polygonal(W)
bind.fv(x, y, labl, desc, preferred)
bdrylength.xypolygon(polly)
breakpts(val, maxi, even = FALSE, npos = NULL, step = NULL)
breakpts.from.r(r)
cartesian(pp, markset, fac = TRUE)
checkfields(X,L)          
check.hist.lengths(hist,breaks)
conspire(\dots)
contour.im(x, \dots)
countingweights(id, areas, check = TRUE)
crossdist(x1, y1, x2, y2)            
default.ngrid(X)
default.ntile(X)
discretise(x, xrange, nx)
distpl(p, l)               
distppl(p, l)
distppll(p, l)
edge.Ripley(X, r, W)
edge.Trans(X, Y, W, exact, trim)
equals.quad(Q)          
erode.mask(w,r)
even.breaks.owin(w)
exactdt(X, \dots)              
exactPdt(im)
fv(x, argu, ylab, valu, fmla, alim, labl, desc)
fasp((fns, titles, formulae, which, dataname, title)
getfields(X, L, fatal = TRUE)
gridindex(x, y, xrange, yrange, nx, ny)            
handle.r.b.args(r = NULL, breaks = NULL, window, eps = NULL)
identical.formulae(x,y)
image.im(x, \dots)
inside.xypolygon(pts, polly, test01 = TRUE)     
intX.owin(w)
intX.xypolygon(polly)
intY.owin(w)
intY.xypolygon(polly)
is.cadlag(s)
is.data(Q)
is.fv(x)
is.marked(X, \dots)
is.marked.default(\dots)  
is.marked.ppp(X, na.action="warn", \dots)
is.poisson.ppm(x)
is.stationary.ppm(x)    
km.rs(o, cc, d, breaks)
Kount(d, b, breaks, slow = FALSE)
Kwtsum(d, b, weight, breaks, slow)
lookup.im(im, x, y, naok)
make.even.breaks(bmax, npos, bstep)
markspace.integral(X)
marks.quad(Q)           
matcolall(x)
matcolany(x)
matcolsum(x)            
matrowall(x)
matrowany(x)
matrowsum(x)
meanX.owin(w)            
meanY.owin(w)
mkcor(d, ff, wt, Ef, rvals, method="smrep", ..., nwtsteps=500)
mpl.engine(Q, trend, interaction, covariates, correction,
	 rbord, use.gam)
mpl.get.covariates(covariates, locations, type)
mpl.prepare(Q, X, P, trend, interaction, covariates,
            want.trend, want.inter, correction, rbord)
MultiPair.checkmatrix(mat, n, name)
multipair.family
nearest.pixel(x, y, im)
no.trend.ppm(x)
n.quad(Q)               
overlap.owin(A,B)
overlap.trapezium(xa, ya, xb, yb, verb = FALSE)
overlap.xypolygon(P, Q)   
param.quad(Q)
persp.im(x, \dots)
pixellate(x, \dots, weights)
plot.im(x, \dots)
polynom(x, \dots)
print.fasp(x, \dots)
print.fv(x, \dots)
print.interact(x, \dots)       
print.isf(x, \dots)
print.summary.owin(x, \dots)
print.summary.ppp(x, \dots, dp=3)
quad(data, dummy, w, param)
quadscheme.replicated(data, dummy, method = "grid", \dots)
quadscheme.spatial(data, dummy, method = "grid", \dots)
rasterx.im(x)
rastery.im(x)
resolve.defaults(\dots)
reverse.xypolygon(p)    
rotxy(X, angle = pi/2)
rmhmodel.ppm(model, win, \dots, verbose, project)
rmpoint.I.allim(n, f, types)
rpoint.multi(n, f, fmax=NULL, marks = NULL, win = unit.square(), giveup = 1000, verbose = FALSE)
runifdisc(n, r = 1, x = 0, y = 0)
runifpoispp(lambda, win = owin(c(0, 1), c(0, 1)))
runifrect(n, win = owin(c(0, 1), c(0, 1)))
scanpp(filename, window, header = TRUE, dir = "", multitype = FALSE)
second.moment.calc(x, sigma, edge=TRUE, what="Kmeasure", debug=FALSE, \dots)
setcov(W)
shiftxy(X, vec = c(0, 0))
spatstat.rawdata.location()             
sympoly(x, y, n)
termsinformula(x)
tilecentroids(W, nx, ny)        
tilemiddles(W, nx, ny)
try.FGJKest(niter = 20, lambda = 25, r = seq(0, sqrt(2), 0.02), eps = 0.01, slow = FALSE)
try.Kcross(niter = 20, lambda1 = 25, lambda2 = 25, r = seq(0, 1, 0.02), R = 0.2)           
update.interact(object, \dots)
validate.mask(w, fatal=TRUE)        
verifyclass(X, C, N = deparse(substitute(X)), fatal = TRUE)
verify.xypolygon(p, fatal=TRUE)
whist(x,breaks,weights)
w.quad(Q)               
x.quad(Q)
y.quad(Q)               
}

\details{
  These are usually not to be called by the user.
}
\keyword{internal}

\eof
\name{intersect.owin}
\alias{intersect.owin}
\alias{union.owin}
\title{Intersection or Union of Two Windows}
\description{
  Yields the intersection or union of two windows.
}
\usage{
   intersect.owin(A, B)
   union.owin(A,B)
}
\arguments{
  \item{A}{A window object (see Details).}
  \item{B}{A window object.}
}
\value{
  A window object.
}
\details{
  The function \code{intersect.owin} computes the intersection between the
  two windows \code{A} and \code{B}, while
  \code{union.owin} computes their union.

  The arguments \code{A} and \code{B} must be window objects
  (either objects of class \code{"owin"}, or data that can be
  coerced to this class by \code{\link{as.owin}}).

  At present the intersection or union of two polygons
  is computed by discretising them, yielding a binary image mask.
  
  If the intersection is empty, an error occurs.
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\seealso{
  \code{\link{is.subset.owin}},
  \code{\link{overlap.owin}},
  \code{\link{bounding.box}},
  \code{\link{owin.object}}
}
\examples{
# rectangles
   u <- unit.square()
   v <- owin(c(0.5,3.5), c(0.4,2.5))
# polygon
   data(letterR)
# mask
   m <- as.mask(letterR)

# two rectangles
   intersect.owin(u, v) 
   union.owin(u,v)

# polygon and rectangle
   intersect.owin(letterR, v)
   union.owin(letterR,v)

# mask and rectangle
   intersect.owin(m, v)
   union.owin(m,v)
#
   A <- letterR
   B <- rotate(letterR, 0.2)
   plot(bounding.box(A,B), main="intersection")
   w <- intersect.owin(A, B)
   plot(w, add=TRUE)
   plot(A, add=TRUE)
   plot(B, add=TRUE)

   plot(bounding.box(A,B), main="union")
   w <- union.owin(A,B)
   plot(w, add=TRUE)   
   plot(A, add=TRUE)
   plot(B, add=TRUE)
}
\keyword{spatial}

\eof
\name{is.im}
\alias{is.im}
\title{Test Whether An Object Is A Pixel Image}
\description{
  Tests whether its argument is a pixel image
  (object of class \code{"im"}).
}
\usage{
is.im(x)
}
\arguments{
  \item{x}{Any object.}
}
\details{
  This function tests whether the argument \code{x} is a
  pixel image object of class \code{"im"}. For details of this
  class, see \code{\link{im.object}}.
  
  The object is determined to be an image if it inherits from
  class \code{"im"}.
}
\value{
  \code{TRUE} if \code{x} is a pixel image, otherwise \code{FALSE}.
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{is.marked}
\alias{is.marked}
\title{Test Whether Marks Are Present}
\description{
  Generic function to test whether a given object (usually a point
  pattern or something related to a point pattern) has ``marks''
  attached to the points.
}
\usage{
  is.marked(X, \dots) 
}
\arguments{
  \item{X}{
    Object to be inspected
  }
  \item{\dots}{
    Other arguments.
  }
}
\value{
  Logical value, equal to \code{TRUE} if \code{X} is marked.
}
\details{
  ``Marks'' are observations attached to each point of a point pattern.
  For example the \code{\link{longleaf}} dataset contains the locations
  of trees, each tree being marked by its diameter;
  the \code{\link{amacrine}} dataset gives the locations of cells
  of two types (on/off) and the type of cell may be regarded as a mark attached
  to the location of the cell.

  Other objects related to point patterns, such as point process models,
  may involve marked points.

  This function tests whether the object \code{X}
  contains or involves marked points.
  It is generic; methods are provided
  for point patterns (objects of class \code{"ppp"})
  and point process models (objects of class \code{"ppm"}).
}
\seealso{
  \code{\link{is.marked.ppp}},
  \code{\link{is.marked.ppm}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{is.marked.ppm}
\alias{is.marked.ppm}
\title{Test Whether A Point Process Model is Marked}
\description{
  Tests whether a fitted point process model involves ``marks''
  attached to the points.
}
\usage{
  is.marked.ppm(X, \dots) 
}
\arguments{
  \item{X}{
    Fitted point process model (object of class \code{"ppm"})
    usually obtained from \code{\link{ppm}}.
  }
  \item{\dots}{
    Ignored.
  }
}
\value{
  Logical value, equal to \code{TRUE} if
  \code{X} is a model that was fitted to a marked point pattern dataset.
}
\details{
  ``Marks'' are observations attached to each point of a point pattern.
  For example the \code{\link{longleaf}} dataset contains the locations
  of trees, each tree being marked by its diameter;
  the \code{\link{amacrine}} dataset gives the locations of cells
  of two types (on/off) and the type of cell may be regarded as a mark attached
  to the location of the cell.

  The argument \code{X} is a fitted point process model
  (an object of class \code{"ppm"}) typically obtained
  by fitting a model to point pattern data using \code{\link{ppm}}.

  This function returns \code{TRUE} if the \emph{original data}
  (to which the model \code{X} was fitted) were a marked point pattern.

  Note that this is not the same as testing whether the
  model involves terms that depend on the marks (i.e. whether the
  fitted model ignores the marks in the data).
  Currently we have not implemented a test for this.

  If this function returns \code{TRUE}, the implications are
  (for example) that
  any simulation of this model will require simulation of random marks
  as well as random point locations.
}
\seealso{
  \code{\link{is.marked}},
  \code{\link{is.marked.ppm}}
}
\examples{
   data(lansing)
   # Multitype point pattern --- trees marked by species

   \testonly{
      # Smaller dataset
      data(betacells)
      lansing <- betacells[seq(2, 135, by=3), ]
   }

  fit1 <- ppm(lansing, ~ marks, Poisson())
  is.marked(fit1)
  # TRUE

  fit2 <- ppm(lansing, ~ 1, Poisson())
  is.marked(fit2)
  # TRUE

  data(cells)
  # Unmarked point pattern

  fit3 <- ppm(cells, ~ 1, Poisson())
  is.marked(fit3)
  # FALSE

}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{is.marked.ppp}
\alias{is.marked.ppp}
\title{Test Whether A Point Pattern is Marked}
\description{
  Tests whether a point pattern has ``marks''
  attached to the points.
}
\usage{
  is.marked.ppp(X, na.action="warn", \dots) 
}
\arguments{
  \item{X}{
    Point pattern (object of class \code{"ppp"})
  }
  \item{na.action}{
    String indicating what to do if \code{NA} values are
    encountered amongst the marks.
    Options are \code{"warn"}, \code{"fatal"} and \code{"ignore"}.
  }
  \item{\dots}{
    Ignored.
  }
}
\value{
  Logical value, equal to \code{TRUE} if \code{X} is a marked point pattern.
}
\details{
  ``Marks'' are observations attached to each point of a point pattern.
  For example the \code{\link{longleaf}} dataset contains the locations
  of trees, each tree being marked by its diameter;
  the \code{\link{amacrine}} dataset gives the locations of cells
  of two types (on/off) and the type of cell may be regarded as a mark attached
  to the location of the cell.

  This function tests whether the point pattern \code{X}
  contains or involves marked points.
  It is a method for the generic function \code{\link{is.marked}}.

  The argument \code{na.action} determines what action will be taken
  if the point pattern has a vector of marks but some or all of the
  marks are \code{NA}. Options are   \code{"fatal"} to cause a fatal
  error; \code{"warn"} to issue a warning and then return \code{TRUE};
  and \code{"ignore"} to take no action except returning \code{TRUE}.
}
\seealso{
  \code{\link{is.marked}},
  \code{\link{is.marked.ppm}}
}
\examples{
   data(cells)
   is.marked(cells)  #FALSE
   data(longleaf)
   is.marked(longleaf) #TRUE
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{is.owin}
\alias{is.owin}
\title{Test Whether An Object Is A Window}
\description{
  Checks whether its argument is a window
  (object of class \code{"owin"}).
}
\usage{
is.owin(x)
}
\arguments{
  \item{x}{Any object.}
}
\details{
  This function tests whether the object \code{x}
  is a window object of class
  \code{"owin"}. See \code{\link{owin.object}} for details
  of this class.

  The result is determined to be \code{TRUE} if \code{x}
  inherits from \code{"owin"}, i.e. if \code{x}
  has \code{"owin"} amongst its classes.
}
\value{
  \code{TRUE} if \code{x} is a point pattern,
  otherwise \code{FALSE}.
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{is.ppm}
\alias{is.ppm}
\title{Test Whether An Object Is A Fitted Point Process Model}
\description{
  Checks whether its argument is a fitted point process model
  (object of class \code{"ppm"}).
}
\usage{
is.ppm(x)
}
\arguments{
  \item{x}{Any object.}
}
\details{
  This function tests whether the object \code{x}
  is a fitted point process model object of class
  \code{"ppm"}. See \code{\link{ppm.object}} for details
  of this class.
}
\value{
  \code{TRUE} if \code{x} has \code{"ppm"} amongst its classes,
  otherwise \code{FALSE}.
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{is.ppp}
\alias{is.ppp}
\title{Test Whether An Object Is A Point Pattern}
\description{
  Checks whether its argument is a point pattern
  (object of class \code{"ppp"}).
}
\usage{
is.ppp(x)
}
\arguments{
  \item{x}{Any object.}
}
\details{
  This function tests whether the object \code{x}
  is a point pattern object of class
  \code{"ppp"}. See \code{\link{ppm.object}} for details
  of this class.

  The result is determined to be \code{TRUE} if \code{x}
  inherits from \code{"ppp"}, i.e. if \code{x}
  has \code{"ppp"} amongst its classes.
}
\value{
  \code{TRUE} if \code{x} is a point pattern,
  otherwise \code{FALSE}.
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{is.subset.owin}
\alias{is.subset.owin}
\title{Determine Whether One Window is Contained In Another}
\description{
  Tests whether window \code{A} is a subset of window \code{B}.
}
\usage{
is.subset.owin(A, B)
}
\arguments{
  \item{A}{A window object (see Details).}
  \item{B}{A window object (see Details).}
}
\value{
  Logical scalar; \code{TRUE} if \code{A} is a sub-window of \code{B},
  otherwise \code{FALSE}.
}
\details{
  This function tests whether the window \code{A} is a subset
  of the window \code{B}.

  The arguments \code{A} and \code{B} must be window objects
  (either objects of class \code{"owin"}, or data that can be
  coerced to this class by \code{\link{as.owin}}).

  Various algorithms are used, depending on the geometrical type
  of the two windows.

  Note that if \code{B} is not rectangular, the algorithm proceeds by
  discretising \code{A}, converting it to a pixel mask using 
  \code{\link{as.mask}}. In this case the resulting
  answer is only ``approximately correct''. The accuracy of the
  approximation can be controlled: see \code{\link{as.mask}}.
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}

\examples{
   w1 <- as.owin(c(0,1,0,1))
   w2 <- as.owin(c(-1,2,-1,2))
   is.subset.owin(w1,w2)  # Returns TRUE.
   is.subset.owin(w2,w1)  # Returns FALSE.
}
\keyword{spatial}

\eof
\name{japanesepines}
\alias{japanesepines}
\title{
  Japanese Pines Point Pattern
}
\description{
  The data give the locations of Japanese black pine saplings
  in a square sampling region in a natural forest.
  The observations were originally collected by Numata (1961).

  These data are used as a standard example in the textbook of 
  Diggle (2003); see pages 1, 14, 19, 22, 24, 56--57 and 61.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of tree locations
  in a 5.7 x 5.7 metre square, rescaled to the unit square
  and rounded to t

  See \code{\link{ppp.object}} for details of the format of a
  point pattern object.
}
\usage{data(japanesepines)}
\source{Diggle (2003), obtained from Numata (1961)}

\references{
  Diggle, P.J. (2003)
  \emph{Statistical Analysis of Spatial Point Patterns}.
  Arnold Publishers.

  Numata, M. (1961)
  Forest vegetation in the vicinity of Choshi. Coastal flora and
  vegetation at Choshi, Chiba Prefecture. IV.
  \emph{Bulletin of Choshi Marine Laboratory, Chiba University}
  \bold{3}, 28--48 (in Japanese).
}
\keyword{datasets}

\eof
\name{kaplan.meier}
\alias{kaplan.meier}
\title{Kaplan-Meier Estimator using Histogram Data}
\description{
  Compute the Kaplan-Meier estimator of a survival time distribution
  function, from histogram data
}
\usage{
  kaplan.meier(obs, nco, breaks)
}
\arguments{
  \item{obs}{vector of \eqn{n} integers giving the histogram of
    all observations (censored or uncensored survival times)
  }
  \item{nco}{vector of \eqn{n} integers giving the histogram of
    uncensored observations (those survival times that are less than or
    equal to the censoring time)
  }
  \item{breaks}{Vector of \eqn{n+1} breakpoints which were used to form
    both histograms.
  }
}
\value{
  A list with two elements:
  \item{km}{Kaplan-Meier estimate of the survival time c.d.f. \eqn{F(t)}
  }
  \item{lambda}{corresponding Nelson-Aalen estimate of the
    hazard rate \eqn{\lambda(t)}{lambda(t)}
  }
  These are numeric vectors of length \eqn{n}.
}
\details{
  This function is needed mainly for internal use in \code{spatstat},
  but may be useful in other applications where you want to form the
  Kaplan-Meier estimator from a huge dataset.

  Suppose \eqn{T_i}{T[i]} are the survival times of individuals
  \eqn{i=1,\ldots,M} with unknown distribution function \eqn{F(t)}
  which we wish to estimate. Suppose these times are right-censored
  by random censoring times \eqn{C_i}{C[i]}.
  Thus the observations consist of right-censored survival times
  \eqn{\tilde T_i = \min(T_i,C_i)}{T*[i] = min(T[i],C[i])}
  and non-censoring indicators
  \eqn{D_i = 1\{T_i \le C_i\}}{D[i] = 1(T[i] <= C[i])}
  for each \eqn{i}.

  If the number of observations \eqn{M} is large, it is efficient to
  use histograms.
  Form the histogram \code{obs} of all observed times \eqn{\tilde T_i}{T*[i]}.
  That is, \code{obs[k]} counts the number of values 
  \eqn{\tilde T_i}{T*[i]} in the interval
  \code{(breaks[k],breaks[k+1]]} for \eqn{k > 1}
  and \code{[breaks[1],breaks[2]]} for \eqn{k = 1}.
  Also form the histogram \code{nco} of all uncensored times,
  i.e. those \eqn{\tilde T_i}{T*[i]} such that \eqn{D_i=1}{D[i]=1}.
  These two histograms are the arguments passed to \code{kaplan.meier}.
  
  The vectors \code{km} and \code{lambda} returned by \code{kaplan.meier}
  are (histogram approximations to) the Kaplan-Meier estimator
  of \eqn{F(t)} and its hazard rate \eqn{\lambda(t)}{lambda(t)}.
  Specifically, \code{km[k]} is an estimate of
  \code{F(breaks[k+1])}, and \code{lambda[k]} is an estimate of
  the average of \eqn{\lambda(t)}{lambda(t)} over the interval
  \code{(breaks[k],breaks[k+1])}.
}
\seealso{
  \code{\link{reduced.sample}},
  \code{\link{km.rs}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
  }
\keyword{spatial}


\eof
\name{km.rs}
\alias{km.rs}
\title{Kaplan-Meier and Reduced Sample Estimator using Histograms}
\description{
  Compute the Kaplan-Meier and Reduced Sample estimators of a
  survival time distribution function, using histogram techniques
}
\usage{
  km.rs(o, cc, d, breaks)
}
\arguments{
  \item{o}{vector of observed survival times
  }
  \item{cc}{vector of censoring times
  }
  \item{d}{vector of non-censoring indicators
  }
  \item{breaks}{Vector of breakpoints to be used to form histograms.
  }
}
\value{
  A list with five elements
  \item{rs}{Reduced-sample estimate of the survival time c.d.f. \eqn{F(t)}
  }
  \item{km}{Kaplan-Meier estimate of the survival time c.d.f. \eqn{F(t)}
  }
  \item{hazard}{corresponding Nelson-Aalen estimate of the
    hazard rate \eqn{\lambda(t)}{lambda(t)}
  }
  \item{r}{values of \eqn{t} for which \eqn{F(t)} is estimated
  }
  \item{breaks}{the breakpoints vector
  }
}
\details{
  This function is needed mainly for internal use in \code{spatstat},
  but may be useful in other applications where you want to form the
  Kaplan-Meier estimator from a huge dataset.

  Suppose \eqn{T_i}{T[i]} are the survival times of individuals
  \eqn{i=1,\ldots,M} with unknown distribution function \eqn{F(t)}
  which we wish to estimate. Suppose these times are right-censored
  by random censoring times \eqn{C_i}{C[i]}.
  Thus the observations consist of right-censored survival times
  \eqn{\tilde T_i = \min(T_i,C_i)}{T*[i] = min(T[i],C[i])}
  and non-censoring indicators
  \eqn{D_i = 1\{T_i \le C_i\}}{D[i] = 1(T[i] <= C[i])}
  for each \eqn{i}.

  The arguments to this function are 
  vectors \code{o}, \code{cc}, \code{d}
  of observed values of \eqn{\tilde T_i}{T*[i]}, \eqn{C_i}{C[i]}
  and \eqn{D_i}{D[i]} respectively.
  The function computes histograms and forms the reduced-sample
  and Kaplan-Meier estimates of  \eqn{F(t)} by
  invoking the functions \code{\link{kaplan.meier}}
  and \code{\link{reduced.sample}}.
  This is efficient if the lengths of \code{o}, \code{cc}, \code{d}
  (i.e. the number of observations) is large.

  The vectors \code{km} and \code{hazard} returned by \code{kaplan.meier}
  are (histogram approximations to) the Kaplan-Meier estimator
  of \eqn{F(t)} and its hazard rate \eqn{\lambda(t)}{lambda(t)}.
  Specifically, \code{km[k]} is an estimate of
  \code{F(breaks[k+1])}, and \code{lambda[k]} is an estimate of
  the average of \eqn{\lambda(t)}{lambda(t)} over the interval
  \code{(breaks[k],breaks[k+1])}. This approximation is exact only if the
  survival times are discrete and the 
  histogram breaks are fine enough to ensure that each interval
  \code{(breaks[k],breaks[k+1])} contains only one possible value of
  the survival time. 

  The vector \code{rs} is the reduced-sample estimator,
  \code{rs[k]} being the reduced sample estimate of \code{F(breaks[k+1])}.
  This value is exact, i.e. the use of histograms does not introduce any
  approximation error in the reduced-sample estimator.
}
\seealso{
  \code{\link{reduced.sample}},
  \code{\link{kaplan.meier}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
  }
\keyword{spatial}


\eof
\name{ksmooth.ppp}
\alias{ksmooth.ppp}
\title{Kernel Smoothed Intensity of Point Pattern}
\description{
  Compute a kernel smoothed intensity function from a point pattern.
}
\synopsis{
  ksmooth.ppp(x, sigma, ..., edge=TRUE)
}
\usage{
  ksmooth.ppp(x, sigma, weights, edge=TRUE)
}
\arguments{
  \item{x}{
    Point pattern (object of class \code{"ppp"}) to be smoothed.
  }
  \item{sigma}{
    Standard deviation of isotropic Gaussian smoothing kernel.
  }
  \item{weights}{
    Optional vector of weights to be attached to the points.
    May include negative values. 
  }
  \item{edge}{
    Logical flag: if \code{TRUE}, apply edge correction.
  }
}
\value{
  A pixel image (object of class \code{"im"}).
}
\details{
  A kernel estimate of the intensity of the point pattern
  is computed. The result is 
  the convolution of the isotropic Gaussian kernel with
  standard deviation \code{sigma} and point masses at each of the data
  points.   The default is to assign
  a unit weight to each point.
  If \code{weights} is present, the point masses have these
  weights (which may be signed real numbers).

  Computation is performed using the Fast Fourier Transform.
}
\seealso{
  \code{\link{ppp.object}},
  \code{\link{im.object}}
}
\examples{
  data(cells)
  Z <- ksmooth.ppp(cells, 0.05)
  plot(Z)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}}
\keyword{spatial}

\eof
\name{lansing}
\alias{lansing}
\title{
  Lansing Woods Point Pattern
}
\description{
  Locations and botanical classification of trees in Lansing Woods.

  The data come from an investigation of a 924 ft x 924 ft (19.6 acre)
  plot in Lansing Woods, Clinton County, Michigan USA
  by D.J. Gerrard. The data give the locations of 2251 trees and 
  their botanical classification (into hickories, maples, red oaks,
  white oaks, black oaks and miscellaneous trees).
  The original plot size (924 x 924 feet)
  has been rescaled to the unit square.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of tree locations.
  Entries include
  \tabular{ll}{
    \code{x} \tab Cartesian \eqn{x}-coordinate of tree \cr
    \code{y} \tab Cartesian \eqn{y}-coordinate of tree \cr
    \code{marks} \tab factor with levels indicating species of
      each tree
  }
  The levels of \code{marks} are
  \code{blackoak},
  \code{hickory},
  \code{maple},
  \code{misc},
  \code{redoak} and
  \code{whiteoak}.
  See \code{\link{ppp.object}} for details of the format of a
  point pattern object.
}
\usage{data(lansing)}
\source{}
\section{Notes}{
}
\references{
Besag, J. (1978)
Some methods of statistical analysis for spatial data.
\emph{Bull. Internat. Statist. Inst.} \bold{44}, 77--92.

Cox, T.F. (1976)
The robust estimation of the density of a forest
stand using a new conditioned distance method.
\emph{Biometrika} \bold{63}, 493--500.

Cox, T.F. (1979)
A method for mapping the dense and sparse regions of
a forest stand.
\emph{Applied Statistics} \bold{28}, 14--19.

Cox, T.F. and Lewis, T. (1976)
A conditioned distance ratio method for analysing spatial patterns.
\emph{Biometrika} \bold{63}, 483--492.

Diggle, P.J. (1979a)
The detection of random heterogeneity in plant populations.
\emph{Biometrics} \bold{33}, 390--394.

Diggle, P.J. (1979b)
Statistical methods for spatial point patterns in ecology.
\emph{Spatial and temporal analysis in ecology}.
R.M. Cormack and J.K. Ord (eds.)
Fairland: International Co-operative Publishing House.
pages 95--150.

Diggle, P.J. (1981)
Some graphical methods in the analysis of spatial point patterns.
In \emph{Interpreting Multivariate Data}.
V. Barnett (eds.) John Wiley and Sons. Pages 55--73.

Diggle, P.J. (1983)
\emph{Statistical analysis of spatial point patterns}.
Academic Press.

Gerrard, D.J. (1969)
Competition quotient: a new measure of the competition
affecting individual forest trees.
Research Bulletin 20, Agricultural Experiment Station,
Michigan State University.

Lotwick, H.W. (1981)
\emph{Spatial stochastic point processes}.
PhD thesis, University of Bath, UK.

Ord, J.K. (1978) 
How many trees in a forest?
\emph{Mathematical Scientist} \bold{3}, 23--33.

}
\keyword{datasets}

\eof
\name{letterR}
\alias{letterR}
\title{Window in Shape of Letter R}
\description{
  A window in the shape of the capital letter R,
  for use in demonstrations.
} 
\format{
  An object of class \code{"owin"}
  representing the capital letter R,
  in the same font as the R package logo.
  See \code{\link{owin.object}} for details of the format.
}
\usage{
 data(letterR)
}
\source{Adrian Baddeley}
\keyword{datasets}

\eof
\name{longleaf}
\alias{longleaf}
\title{
  Longleaf Pines Point Pattern
}
\description{
  Locations and sizes of Longleaf pine trees.
  A marked point pattern.

  The data record the locations and diameters of 
  584 Longleaf pine (\emph{Pinus palustris}) trees 
  in a 200 x 200 metre region in southern Georgia (USA).
  They were collected and analysed by Platt, Evans and Rathbun (1988).
 
  This is a marked point pattern; the mark associated with a tree is its
  diameter at breast height (\code{dbh}), a convenient measure of its size. 
  Several analyses have considered only the ``adult'' trees which
  are conventionally defined as those trees with \code{dbh}
  greater than or equal to 30 cm.
 
  The pattern is regarded as spatially inhomogeneous.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of tree locations.
  Entries include
  \tabular{ll}{
    \code{x} \tab Cartesian \eqn{x}-coordinate of tree \cr
    \code{y} \tab Cartesian \eqn{y}-coordinate of tree \cr
    \code{marks} \tab diameter at breast height, in centimetres.
  }
  See \code{\link{ppp.object}} for details of the format of a
  point pattern object.
}
\usage{data(longleaf)}
\source{Platt, Evans and Rathbun (1988)}
\references{
Platt, W. J., Evans, G. W. and Rathbun, S. L. (1988)
The population dynamics of a long-lived Conifer (Pinus palustris).
\emph{The American Naturalist} \bold{131}, 491--525.

Rathbun, S. L. and Cressie, N. (1994)
A space-time survival point process for a longleaf
pine forest in southern Georgia.
\emph{Journal of the American Statistical Association} \bold{89}, 1164--1173.
}
\keyword{datasets}

\eof
\name{markcorr}
\alias{markcorr}
\title{
  Mark Correlation Function
}
\description{
  Estimate the marked correlation function
  of a marked point pattern.
}
\usage{
markcorr(X, f = function(m1,m2) { m1 * m2 }, r=NULL,
         slow=FALSE, correction=c("border", "isotropic", "Ripley", "translate"),
         method="density", \dots)
}
\arguments{
  \item{X}{The observed point pattern.
    An object of class \code{"ppp"} or something acceptable to
    \code{\link{as.ppp}}. 
  }
  \item{f}{Function \eqn{f} used in the definition of the
    mark correlation function.
  }
  \item{r}{numeric vector. The values of the argument \eqn{r}
    at which the mark correlation function 
    \eqn{\rho_f(r)}{rho_f(r)}
    should be evaluated.
    There is a sensible default.
  }
  \item{correction}{
    A character vector containing any selection of the
    options \code{"border"}, 
    \code{"isotropic"}, \code{"Ripley"} or \code{"translate"}.
    It specifies the edge correction(s) to be applied.
  }
  \item{method}{
    A character vector indicating the user's choice of
    density estimation technique to be used. Options are
    \code{"density"}, 
    \code{"loess"},
    \code{"sm"} and \code{"smrep"}.
  }
  
  \item{slow}{
    Logical vector indicating whether to use exact analytic geometry
    to calculate 
    the edge correction weights for the translation correction
    in the case where the window of observation of \code{X}
    is polygonal. These calculations are extremely slow and should
    be avoided unless you are a developer investigating the
    package.
  }
  \item{\dots}{
    Arguments passed to the density estimation routine
    (\code{\link{density}}, \code{\link{loess}} or \code{sm.density})
    selected by \code{method}.
  }
}
\value{
  An object of class \code{"fv"} (see \code{\link{fv.object}}).
  
  Essentially a data frame containing numeric columns 
  \item{r}{the values of the argument \eqn{r} 
    at which the mark correlation function \eqn{\rho_f(r)}{rho_f(r)}
    has been  estimated
  }
  \item{theo}{the theoretical value of \eqn{\rho_f(r)}{rho_f(r)}
    when the marks attached to different points are independent,
    namely 1
  }
  together with a column or columns named 
  \code{"border"}, 
  \code{"iso"} and/or \code{"trans"},
  according to the selected edge corrections. These columns contain
  estimates of the function \eqn{\rho_f(r)}{rho_f(r)}
  obtained by the edge corrections named.
}
\details{
  The mark correlation function \eqn{\rho_f(r)}{rho_f(r)}
  of a marked point process \eqn{X}
  is a measure of the dependence between the marks of two 
  points of the process a distance \eqn{r} apart.
  It is informally defined as
  \deqn{
    \rho_f(r) = \frac{E[f(M_1,M_2)]}{E[f(M,M')]}
  }{
    rho_f(r) = E[f(M1,M2)]/E[f(M,M')]
  }
  where \eqn{E[ ]} denotes expectation and \eqn{M_1,M_2}{M1,M2}
  are the marks attached to two points of the process
  separated by a distance \eqn{r}, while \eqn{M,M'} are
  independent realisations of the marginal distribution of marks.

  Here \eqn{f} is any function
  \eqn{f(m_1,m_2)}{f(m1,m2)}
  with two arguments which are possible marks of the pattern,
  and which returns a nonnegative real value.
  Common choices of \eqn{f} are:
  for continuous real-valued marks,
  \deqn{f(m_1,m_2) = m_1 m_2}{f(m1,m2)= m1 * m2}
  for discrete marks (multitype point patterns),
  \deqn{f(m_1,m_2) = 1(m_1 = m_2)}{f(m1,m2)= (m1 == m2)}
  and for marks taking values in \eqn{[0,2\pi)}{[0,2 * pi)},
  \deqn{f(m_1,m_2) = \sin(m_1 - m_2)}{f(m1,m2) = sin(m1-m2)}.
  
  Note that \eqn{\rho_f(r)}{rho_f(r)} is not a ``correlation''
  in the usual statistical sense. It can take any 
  nonnegative real value. The value 1 suggests ``lack of correlation'':
  if the marks attached to the points of \code{X} are independent
  and identically distributed, then
  \eqn{\rho_f(r) \equiv 1}{rho_f(r) =  1}.
  The interpretation of values larger or smaller than 1 depends
  on the choice of function \eqn{f}.

  The argument \code{X} must be a point pattern (object of class
  \code{"ppp"}) or any data that are acceptable to \code{\link{as.ppp}}.
  It must be a marked point pattern.

  The argument \code{f}
  must be a function, accepting two arguments \code{m1}
  and \code{m2} which are vectors of equal length containing mark
  values (of the same type as the marks of \code{X}).
  It must return a vector of numeric
  values of the same length as \code{m1} and \code{m2}.
  The values must be non-negative.

  The argument \code{r} is the vector of values for the
  distance \eqn{r} at which \eqn{\rho_f(r)}{rho_f(r)} is estimated.

  This algorithm assumes that \code{X} can be treated
  as a realisation of a stationary (spatially homogeneous) 
  random spatial point process in the plane, observed through
  a bounded window.
  The window (which is specified in \code{X} as \code{X$window})
  may have arbitrary shape.

  Biases due to edge effects are
  treated in the same manner as in \code{\link{Kest}}.
  The edge corrections implemented here are
  \describe{
    \item{border}{the border method or
      ``reduced sample'' estimator (see Ripley, 1988). This is
      the least efficient (statistically) and the fastest to compute.
      It can be computed for a window of arbitrary shape.
    }
    \item{isotropic/Ripley}{Ripley's isotropic correction
      (see Ripley, 1988; Ohser, 1983).
      This is currently implemented only for rectangular windows.
    }
    \item{translate}{Translation correction (Ohser, 1983).
      Implemented for all window geometries, but slow for
      complex windows. 
    }
  }
  Note that the estimator assumes the process is stationary (spatially
  homogeneous). 

  The numerator and denominator of the mark correlation function
  (in the expression above) are estimated using density estimation
  techniques. The user can choose between
  \describe{
    \item{\code{"density"}}{
      which uses the standard kernel
      density estimation routine \code{\link{density}}, and
      works only for evenly-spaced \code{r} values;
    }
    \item{\code{"loess"}}{
      which uses the function \code{loess} in the
      package \code{modreg};
    }
    \item{\code{"sm"}}{
      which uses the function \code{sm.density} in the
      package \code{sm} and is extremely slow;
    }
    \item{\code{"smrep"}}{
      which uses the function \code{sm.density} in the
      package \code{sm} and is relatively fast.
    }
  }
}
\references{
  Stoyan, D. and Stoyan, H. (1994)
  Fractals, random shapes and point fields:
  methods of geometrical statistics.
  John Wiley and Sons.
}
\seealso{
 \code{\link{Kest}},
 \code{\link{Kmulti}}
}
\examples{
    # CONTINUOUS-VALUED MARKS:
    # (1) Longleaf Pine data
    # marks represent tree diameter
    data(longleaf)
    # Subset of this large pattern
    swcorner <- owin(c(0,100),c(0,100))
    sub <- longleaf[ , swcorner]
    # mark correlation function
    mc <- markcorr(sub)
    plot(mc)

    # (2) simulated data with independent marks
    X <- rpoispp(100)
    X <- X \%mark\% runif(X$n)
    Xc <- markcorr(X)
    plot(Xc)
    
    # MULTITYPE DATA:
    # Hughes' amacrine data
    # Cells marked as 'on'/'off'
    data(amacrine)
    # (3) Kernel density estimate with Epanecnikov kernel
    # (as proposed by Stoyan & Stoyan)
    M <- markcorr(amacrine, function(m1,m2) {m1==m2},
                  correction="translate", method="density",
                  kernel="epanechnikov")
    plot(M)
    # Note: kernel="epanechnikov" comes from help(density)

    # (4) Same again with explicit control over bandwidth
    M <- markcorr(amacrine, function(m1,m2) {m1==m2},
                  correction="translate", method="density",
                  kernel="epanechnikov", bw=0.02)
    # see help(density) for correct interpretation of 'bw'

   \testonly{
    data(betacells)
    niets <- markcorr(betacells, function(m1,m2){m1 == m2}, method="loess")
    niets <- markcorr(X, correction="isotropic", method="smrep")
    }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}



\eof
\name{nearest.raster.point}
\alias{nearest.raster.point}
\title{Find Pixel Nearest to a Given Point}
\description{
  Given cartesian coordinates, find the nearest pixel.
}
\usage{
 nearest.raster.point(x,y,w)
}
\arguments{
  \item{x}{Numeric vector of \eqn{x} coordinates of any points}
  \item{y}{Numeric vector of \eqn{y} coordinates of any points}
  \item{w}{A window (an object of class \code{"owin"})
    of type \code{"mask"} representing a binary pixel image.
  }
}
\value{
  List containing two vectors \code{rr} and \code{cc}
  giving row and column positions (in the image matrix).
}
\details{
  The argument \code{w} should be a window (an object of class
  \code{"owin"}, see \code{\link{owin.object}} for details).
  A window of type \code{"mask"} represents a binary pixel image.

  This function returns a list containing two vectors \code{rr} and
  \code{cc} giving row and column positions (in the image matrix).
  For the location \code{(x[i],y[i])} the nearest
  pixel is at row \code{rr[i]} and column \code{cc[i]} of
  the image.
}
\seealso{
  \code{\link{owin.object}},
  \code{\link{as.mask}}
}
\examples{
  w <- owin(c(0,1), c(0,1), mask=matrix(TRUE, 100,100))  # 100 x 100 grid
  nearest.raster.point(0.5, 0.3, w)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{nndist}
\alias{nndist}
\title{Nearest neighbour distances}
\description{
  Computes the distance from each point to its nearest neighbour
  in a point pattern.
}
\usage{
  nndist(x, y=NULL, method="C")
}
\arguments{
  \item{x,y}{
    Arguments specifying the \eqn{x} and \eqn{y} coordinates of
    a set of points. Typically \code{x} and \code{y} would be
    numeric vectors of equal length. Alternatively \code{y} may be
    omitted and \code{x} may be
    a point pattern (object of class \code{"ppp"})
    or a list with two components \code{x} and \code{y},
    or a matrix with two columns.
  }
  \item{method}{String specifying which method of calculation to use.
    Values are \code{"C"} and \code{"interpreted"}.
  }
}
\value{
  Numeric vector of the nearest neighbour distances for each point.
}
\details{
  This function computes the Euclidean distance from each point
  in a point pattern to its nearest neighbour (the nearest other
  point of the pattern).

  If \code{method = "interpreted"} then the distances are
  computed using interpreted R code only. If \code{method="C"}
  then C code is used. The C code is faster by two to three orders of magnitude
  and uses much less memory.
  
  If there is only one point (if \code{x} has length 1),
  then a nearest neighbour distance of \code{Inf} is returned.
  If there are no points (if \code{x} has length zero)
  a numeric vector of length zero is returned.
}
\section{Warnings}{
  An infinite value is returned if there is only one point
  in the point pattern.
}
\seealso{
  \code{\link{pairdist}},
  \code{\link{Gest}}
}
\examples{
   x <- runif(100)
   y <- runif(100)
   d <- nndist(x, y)
   data(cells)
   d <- nndist(cells)
}
\author{Pavel Grabarnik
  \email{pavel.grabar@issp.serpukhov.su}
  and
  Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
}
\keyword{spatial}


\eof
\name{nztrees}
\alias{nztrees}
\title{
   New Zealand Trees Point Pattern
}
\description{
  The data give the locations of trees in a forest plot.

  They were collected by Mark and Esler (1970) and
  were extracted and analysed by Ripley (1981, pp. 169-175). 
  They represent the 
  positions of 86 trees in a forest plot approximately 140 by 85 feet.
  
  Ripley discarded from his analysis the eight trees at the right-hand edge of
  the plot (which appear to be part of a planted border)
  and trimmed the window by a 5-foot margin accordingly.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of tree locations.
  The Cartesian coordinates are in feet.

  See \code{\link{ppp.object}} for details of the format of a
  point pattern object.
}
\usage{data(nztrees)}
\source{Mark and Esler (1970), Ripley (1981).}
\section{Note}{
  To trim a 5-foot margin off the window, type
  \code{nzsub <- nztrees[ , owin(c(0,148),c(0,95)) ]}
}
\references{
  Ripley, B.D. (1981) 
  \emph{Spatial statistics}.
  John Wiley and Sons.

  Mark, A.F. and Esler, A.E. (1970)
  An assessment of the point-centred quarter method of plotless
  sampling in some New Zealand forests.
  \emph{Proceedings of the New Zealand Ecological Society}
  \bold{17}, 106--110.
}
\keyword{datasets}


 

\eof
\name{ord.family}
\alias{ord.family}
\title{Ord Interaction Process Family}
\description{
  An object describing the family of all Ord interaction point processes
}
\details{
  \bold{Advanced Use Only!}
  
  This structure would not normally be touched by
  the user. It describes 
  the family of point process models introduced by Ord (1977).
 
  If you need to create a specific Ord-type model for use in 
  analysis, use the function \code{\link{OrdThresh}} or
  \code{\link{Ord}}.
 
  Anyway, \code{ord.family} is an object of class \code{"isf"}
  containing a function \code{ord.family$eval} for
  evaluating the sufficient statistics of any Ord type
  point process model taking an exponential family form. 
} 
\seealso{
  \code{\link{pairwise.family}},
  \code{\link{pairsat.family}},
  \code{\link{Poisson}},
  \code{\link{Pairwise}},
  \code{\link{PairPiece}},
  \code{\link{Strauss}},
  \code{\link{StraussHard}},
  \code{\link{Softcore}},
  \code{\link{Geyer}},
  \code{\link{Saturated}},
  \code{\link{Ord}},
  \code{\link{OrdThresh}}
}
\references{
  Baddeley, A. and Turner, R. (2000)
  Practical maximum pseudolikelihood for spatial point patterns.
  \emph{Australian and New Zealand Journal of Statistics}
  \bold{42}, 283--322.

  Ord, J.K. (1977) 
  Contribution to the discussion of Ripley (1977).

  Ord, J.K. (1978) 
  How many trees in a forest?
  \emph{Mathematical Scientist} \bold{3}, 23--33.

  Ripley, B.D. (1977)
  Modelling spatial patterns (with discussion).
  \emph{Journal of the Royal Statistical Society, Series B},
  \bold{39}, 172 -- 212.
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{owin}
\alias{owin}
\title{Create a Window}
\description{
  Creates an object of class \code{"owin"} representing 
  an observation window in the two-dimensional plane
}
\synopsis{
  owin(xrange=c(0,1), yrange=c(0,1), poly=NULL, mask=NULL)
}
\usage{
 owin()
 owin(xrange, yrange)
 owin(poly=xy)
 owin(xrange, yrange, poly=xy)
 owin(xrange, yrange, mask=mat)
 owin(mask=mat)
}
\arguments{
  \item{xrange}{\eqn{x} coordinate limits of enclosing box}
  \item{yrange}{\eqn{y} coordinate limits of enclosing box}
  \item{poly}{polygonal boundary of window}
  \item{mask}{logical matrix giving binary image of window}
}
\value{
An object of class \code{"owin"} 
describing a window in the two-dimensional plane.
}
\details{
  In the \code{spatstat} library, a point pattern dataset must include
  information about the window of observation. This is represented by
  an object of class \code{"owin"}.
  See \code{\link{owin.object}} for an overview.

  To create a window in its own right, 
  users would normally invoke \code{owin},
  although sometimes \code{\link{as.owin}} may be convenient.

  A window may be rectangular, polygonal, or a mask (a binary image).
  \itemize{
    \item
    \bold{rectangular windows:}
    If only \code{xrange} and \code{yrange} are given, then
    the window will be rectangular, with its \eqn{x} and \eqn{y}
    coordinate dimensions given by these two arguments
    (which must be vectors of length 2).
    If no arguments are given at all, the default is the unit square
    with dimensions \code{xrange=c(0,1)} and \code{yrange=c(0,1)}.
    \item
    \bold{polygonal windows:}
    If \code{poly} is given, then the window will be polygonal.
    \itemize{
      \item
      \emph{single polygon:}
      If \code{poly} is a structure with
      two component vectors \code{x} and \code{y} of equal length,
      then these vectors are interpreted as the cartesian coordinates
      of the vertices of a polygon circumscribing the window.
      The vertices must be listed \emph{anticlockwise}.
      No vertex should be repeated (i.e. do not repeat the first
      vertex).
      \item
      \emph{multiple polygons or holes:}
      If \code{poly} is a list, each entry \code{poly[[i]]}
      of which is a structure with
      two component vectors \code{x} and \code{y} of equal length,
      then the successive list members \code{poly[[i]]}
      are interpreted as separate polygons which together
      make up the boundary of the window.
      The vertices of each polygon must be listed \emph{anticlockwise}
      if the polygon is part of the external boundary,
      but \emph{clockwise}
      if the polygon is the boundary of a hole in the window.
      Again, do not repeat any vertex.
    }
    \item
    \bold{binary masks:}
    If \code{mask} is given, then the window will be a binary image.
    The argument \code{mask} should be a logical matrix
    such that \code{mask[i,j]} is \code{TRUE} if the point
    \code{(x[j],y[i])} belongs to the window, and \code{FALSE} if it
    does not. Note carefully that rows of \code{mask} correspond to the
    \eqn{y} coordinate, and columns to the \eqn{x} coordinate.
    Here \code{x} and \code{y} are vectors of \eqn{x} and \eqn{y}
    coordinates equally spaced over \code{xrange} and \code{yrange}
    respectively. 
    }    
  To create a window which is mathematically
  defined by inequalities in the Cartesian coordinates, 
  use \code{\link{raster.x}()} and \code{\link{raster.y}()}
  as in the examples below.
}
\seealso{
  \code{\link{owin.object}},
  \code{\link{as.owin}},
  \code{\link{complement.owin}},
  \code{\link{ppp.object}},
  \code{\link{ppp}}
}
\examples{
  w <- owin()
  w <- owin(c(0,1), c(0,1))
  # the unit square

  w <- owin(c(10,20), c(10,30))
  # a rectangle of dimensions 10 x 20 units
  # with lower left corner at (10,10)

  w <- owin(poly=list(x=c(0.5,1,0.5,0),y=c(0,1,2,1)))
  w <- owin(c(0,1), c(0,2), poly=list(x=c(0.5,1,0.5,0),y=c(0,1,2,1)))
  # diamond shape

  w <- owin(c(-1,1), c(-1,1), mask=matrix(TRUE, 100,100))
          # 100 x 100 image, all TRUE
  X <- raster.x(w)
  Y <- raster.y(w)
  wm <- owin(w$xrange, w$yrange, mask=(X^2 + Y^2 <= 1))
          # discrete approximation to the unit disc

  \dontrun{
  plot(c(0,1),c(0,1),type="n")
  bdry <- locator()
  # click the vertices of a polygon (anticlockwise)
  }
  \testonly{
  bdry <- list(x=c(0.1,0.3,0.7,0.4,0.2),
               y=c(0.1,0.1,0.5,0.7,0.3))
  }
  w <- owin(poly=bdry)
  \dontrun{plot(w)}
 
 \dontrun{
 im <- as.logical(matrix(scan("myfile"), nrow=128, ncol=128))
 # read in an arbitrary 128 x 128 digital image from text file
 rim <- im[, 128:1]
 # Assuming it was given in row-major order in the file
 # i.e. scanning left-to-right in rows from top-to-bottom,
 # the use of matrix() has effectively transposed rows & columns,
 # so to convert it to our format just reverse the column order.
 w <- owin(mask=rim)
 plot(w)
 # display it to check!
 }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{owin.object}
\alias{owin.object}
\title{Class owin}
\description{
  A class \code{owin} to define the ``observation window'' of a point pattern
}
\details{
  In the \code{spatstat} library, a point pattern dataset must include
  information about the window or region in which the pattern was
  observed. A window is described by an object of class \code{"owin"}.
  Windows of arbitrary shape are supported.
  
  An object of class \code{"owin"} has one of three types:
  \tabular{ll}{
    \code{"rectangle"}: \tab
      a rectangle in the two-dimensional plane with edges parallel to the axes
    \cr
    \code{"polygonal"}: \tab
    a region whose boundary is a polygon or several polygons.
    The region may have holes and may consist of several disconnected pieces.
    \cr
    \code{"mask"}: \tab
      a binary image (a logical matrix)
      set to \code{TRUE} for pixels inside the window and
      \code{FALSE} outside the window.
  }
  Objects of class \code{"owin"} may be created by the function
  \code{\link{owin}}
  and converted from other types of data by the function
  \code{\link{as.owin}}.

  They may be manipulated by the functions 
  \code{\link{as.rectangle}},
  \code{\link{as.mask}}, 
  \code{\link{complement.owin}},
  \code{\link{rotate}},
  \code{\link{shift}},
  \code{\link{affine}},
  \code{\link{erode.owin}},
  and
  \code{erode.mask}.

  Geometrical calculations available for windows include
  \code{\link{area.owin}},
  \code{\link{bounding.box}},
  \code{\link{diameter}},
  \code{\link{eroded.areas}},
  \code{\link{bdist.points}},
  \code{\link{bdist.pixels}},
  and
  \code{even.breaks.owin}.
  The mapping between continuous coordinates and pixel raster indices
  is facilitated by the functions
  \code{\link{raster.x}},
  \code{\link{raster.y}} and
  \code{\link{nearest.raster.point}}.

  There is a \code{plot} method for window objects,
  \code{\link{plot.owin}}. This may be useful if you wish to
  plot a point pattern's window without the points for graphical
  purposes.

  There are also methods for
  \code{summary} and \code{print}. 
}
\seealso{
  \code{\link{owin}},
  \code{\link{as.owin}},
  \code{\link{as.rectangle}},
  \code{\link{as.mask}},
  \code{\link{summary.owin}},
  \code{\link{print.owin}},
  \code{\link{complement.owin}},
  \code{\link{erode.owin}},
  \code{\link{affine.owin}},
  \code{\link{shift.owin}},
  \code{\link{rotate.owin}},
  \code{\link{raster.x}},
  \code{\link{raster.y}},
  \code{\link{nearest.raster.point}},
  \code{\link{plot.owin}},
  \code{\link{area.owin}},
  \code{\link{bounding.box}},
  \code{\link{diameter}},
  \code{\link{eroded.areas}},
  \code{\link{bdist.points}},
  \code{\link{bdist.pixels}}
}
\section{Warnings}{
  In a window of type \code{"mask"}, the 
  row index corresponds to increasing \eqn{y} coordinate,
  and the column index corresponds to increasing \eqn{x} coordinate.
}
\examples{
 w <- owin()
 w <- owin(c(0,1), c(0,1))
 # the unit square
  
 w <- owin(c(0,1), c(0,2))
 \dontrun{
 plot(w)
 # plots edges of a box 1 unit x 2 units
 v <- locator() 
 # click on points in the plot window
 # to be the vertices of a polygon 
 # traversed in anticlockwise order 
 u <- owin(c(0,1), c(0,2), poly=v)
 plot(u)
 # plots polygonal boundary using polygon()
 plot(as.mask(u, eps=0.02))
 # plots discrete pixel approximation to polygon
 }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{pairdist}
\alias{pairdist}
\title{Pairwise distances}
\description{
  Computes the matrix of distances between all pairs of points
  in a point pattern.
}
\usage{
  pairdist(x, y=NULL, method="C")
}
\arguments{
  \item{x,y}{
    Arguments specifying the \eqn{x} and \eqn{y} coordinates of
    a set of points. Typically \code{x} and \code{y} would be
    numeric vectors of equal length. Alternatively \code{y} may be
    omitted and \code{x} may be
    a point pattern (object of class \code{"ppp"})
    or a list with two components \code{x} and \code{y},
    or a matrix with two columns.
  }
  \item{method}{String specifying which method of calculation to use.
    Values are \code{"C"} and \code{"interpreted"}.
  }
}
\value{
  A square matrix whose \code{[i,j]} entry is the distance
  between the points numbered \code{i} and \code{j}.
}
\details{
  This function computes the Euclidean distances between all pairs of
  points, and returns the matrix of distances.

  If \code{method = "interpreted"} then the distances are
  computed using interpreted R code only. If \code{method="C"}
  then C code is used. The C code is marginally faster.
}
\seealso{
  \code{\link{nndist}},
  \code{\link{Kest}}
}
\examples{
   x <- runif(100)
   y <- runif(100)
   d <- pairdist(x, y)
   data(cells)
   d <- pairdist(cells)
}
\author{Pavel Grabarnik
  \email{pavel.grabar@issp.serpukhov.su}
  and 
  Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
}
\keyword{spatial}


\eof
\name{pairsat.family}
\alias{pairsat.family}
\title{Saturated Pairwise Interaction Point Process Family}
\description{
  An object describing the Saturated Pairwise Interaction
  family of point process models
}
\details{
  \bold{Advanced Use Only!}
  
  This structure would not normally be touched by
  the user. It describes the ``saturated pairwise interaction''
  family of point process models.
 
  If you need to create a specific interaction model for use in 
  spatial pattern analysis, use the function \code{\link{Saturated}()}
  or the one existing implementation of a model in this family,
  \code{\link{Geyer}()}.
 
  Geyer (1999) introduced the ``saturation process'', a modification of the
  Strauss process in which the total contribution
  to the potential  from each point (from its pairwise interaction with all 
  other points) is trimmed to a maximum value \eqn{c}. 
  This model is implemented in the function \code{\link{Geyer}()}.
 
  The present class \code{pairsat.family} is the 
  extension of this saturation idea to all pairwise interactions.
  Note that the resulting models are no longer pairwise interaction
  processes - they have interactions of infinite order.
 
  \code{pairsat.family} is an object of class \code{"isf"} 
  containing a function \code{pairwise$eval} for
  evaluating the sufficient statistics of any saturated pairwise interaction
  point process model in which the original pair potentials 
  take an exponential family form. 
} 
\references{
Geyer, C.J. (1999)
Likelihood Inference for Spatial Point Processes.
Chapter 3 in 
O.E. Barndorff-Nielsen, W.S. Kendall and M.N.M. Van Lieshout (eds)
\emph{Stochastic Geometry: Likelihood and Computation},
Chapman and Hall / CRC, 
Monographs on Statistics and Applied Probability, number 80.
Pages 79--140.
}
\seealso{
  \code{\link{pairwise.family}},
  \code{\link{Geyer}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{pairwise.family}
\alias{pairwise.family}
\title{Pairwise Interaction Process Family}
\description{
  An object describing the family of all pairwise interaction point processes
}
\details{
  \bold{Advanced Use Only!}
  
  This structure would not normally be touched by
  the user. It describes 
  the pairwise interaction family of point process models.
 
  If you need to create a specific pairwise interaction model for use in 
  modelling, use the function \code{\link{Pairwise}} or one of the existing
  functions (listed below, starting with a capital letter).
 
  Anyway, \code{pairwise.family} is an object of class \code{"isf"}
  containing a function \code{pairwise$eval} for
  evaluating the sufficient statistics of any pairwise interaction
  point process model taking an exponential family form. 
} 
\seealso{
  \code{\link{pairsat.family}},
  \code{\link{ord.family}},
  \code{\link{Poisson}},
  \code{\link{Pairwise}},
  \code{\link{PairPiece}},
  \code{\link{Strauss}},
  \code{\link{StraussHard}},
  \code{\link{Softcore}},
  \code{\link{Geyer}},
  \code{\link{Saturated}},
  \code{\link{Ord}},
  \code{\link{OrdThresh}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{pcf}
\alias{pcf}
\title{Pair Correlation Function}
\description{
  Estimates the pair correlation function of
  a point pattern.
}
\usage{
 pcf(X, \dots, method="c")
}
\arguments{
  \item{X}{
    Either the observed data point pattern,
    or an estimate of its \eqn{K} function,
    or an array of multitype \eqn{K} functions
    (see Details).
  }
  \item{\dots}{
    Arguments controlling the smoothing spline
    function \code{smooth.spline}.
  }
  \item{method}{
    Letter \code{"a"}, \code{"b"} or \code{"c"} indicating the
    method for deriving the pair correlation function from the
    \code{K} function.
  }
} 
\value{
  Either a function value table
  (object of class \code{"fv"}, see \code{\link{fv.object}})
  representing a pair correlation function,
  or a function array (object of class \code{"fasp"},
  see \code{\link{fasp.object}})
  representing an array of pair correlation functions.

  If \code{X} is an unmarked point pattern, the return value is
  a function value table (class \code{"fv"}). It is
  essentially a data frame containing (at least) the variables
  \item{r}{the vector of values of the argument \eqn{r} 
    at which the pair correlation function \eqn{g(r)} has been  estimated
  }
  \item{pcf}{vector of values of \eqn{g(r)}
  }
  If code{X} is a function value table (class \code{"fv"}) representing
  the estimated \eqn{K} function of a point pattern
  (obtained from \code{\link{Kest}}, \code{\link{Kinhom}}
  or \code{\link{Kest.fft}}),
  then the return value is again a function value table,
  representing the pair correlation function.

  If \code{X} is a multitype point pattern,
  the return value is a function array (class \code{"fasp"}).
  This can be thought of as a matrix \code{Y} each of whose entries
  \code{Y[i,j]} is a function value table (class \code{"fv"})
  representing the pair correlation function between
  points of type \code{i} and points of type \code{j}.

  If \code{X} is a function array (class \code{"fasp"})
  representing an array of estimated \eqn{K} functions
  (obtained from \code{\link{alltypes}}),
  the return value is another function array, containing
  the corresponding pair correlation functions.
}
\details{
  The pair correlation function of a stationary point process is
  \deqn{
    g(r) = \frac{K'(r)}{2\pi r}
  }{
    g(r) = K'(r)/ ( 2 * pi * r) 
  }
  where \eqn{K'(r)} is the derivative of \eqn{K(r)}, the
  reduced second moment function (aka ``Ripley's \eqn{K} function'')
  of the point process. See \code{\link{Kest}} for information
  about \eqn{K(r)}. For a stationary Poisson process, the
  pair correlation function is identically equal to 1. Values
  \eqn{g(r) < 1} suggest inhibition between points;
  values greater than 1 suggest clustering.

  We also apply the same definition to
  other variants of the classical \eqn{K} function,
  such as the multitype \eqn{K} functions
  (see \code{\link{Kcross}}, \code{\link{Kdot}}) and the
  inhomogeneous \eqn{K} function (see \code{\link{Kinhom}}).
  For all these variants, the benchmark value of
  \eqn{K(r) = \pi r^2}{K(r) = pi * r^2} corresponds to
  \eqn{g(r) = 1}.

  This routine computes an estimate of \eqn{g(r)}
  from an estimate of \eqn{K(r)} or its variants,
  using smoothing splines to approximate the derivative.

  The argument \code{X} may be either
  \itemize{
    \item
    a point pattern for which an estimate of the pair correlation function
    should be computed. This should be an object of class \code{"ppp"},
    or in a format recognised by \code{\link{as.ppp}()}.
    \item
    an estimated \eqn{K} function,
    given as a function value table (object of class \code{"fv"},
    see \code{\link{fv.object}}).
    This object should be the value returned by
    \code{\link{Kest}}, \code{\link{Kcross}}, \code{\link{Kmulti}}
    or \code{\link{Kinhom}}.
    \item
    a function array (object of class \code{"fasp"},
    see \code{\link{fasp.object}})
    containing several estimates of \eqn{K} functions.
    This should have been obtained from \code{\link{alltypes}}
    with the argument \code{fun="K"}.
  }
  If \code{X} is a point pattern, the \eqn{K} function is
  first estimated by \code{\link{Kest}}.
  
  The smoothing spline operations are performed by
  \code{\link{smooth.spline}} and \code{\link{predict.smooth.spline}}
  from the \code{modreg} library.
  Three numerical methods are available:
  \itemize{
    \item
    \bold{"a"} apply smoothing to \eqn{K(r)},
    estimate its derivative, and plug in to the formula above;
    \item 
    \bold{"b"} apply smoothing to
    \eqn{Y(r) = \frac{K(r)}{2 \pi r}}{Y(r) = K(r)/(2 * pi * r)}
    constraining \eqn{Y(0) = 0},
    estimate the derivative of \eqn{Y}, and solve;
    \item
    \bold{"c"} apply smoothing to 
    \eqn{Z(r) = \frac{K(r)}{\pi r^2}}{Y(r) = K(r)/(pi * r^2)}
    constraining \eqn{Z(0)=1},
    estimate its derivative, and solve.
  }
  Method \code{"c"} seems to be the best at 
  suppressing variability for small values of \eqn{r}.
  However it effectively constrains \eqn{g(0) = 1}.
  If the point pattern seems to have inhibition at small distances,
  you may wish to experiment with method \code{"b"} which effectively
  constrains \eqn{g(0)=0}. Method \code{"a"} seems
  comparatively unreliable.

  Useful arguments to control the splines
  include the smoothing tradeoff parameter \code{spar}
  and the degrees of freedom \code{df}. See \code{\link{smooth.spline}}
  for details.
}
\references{
  Stoyan, D, Kendall, W.S. and Mecke, J. (1995)
  \emph{Stochastic geometry and its applications}.
  2nd edition. Springer Verlag.

  Stoyan, D. and Stoyan, H. (1994)
  Fractals, random shapes and point fields:
  methods of geometrical statistics.
  John Wiley and Sons.
}
\seealso{
  \code{\link{Kest}},
  \code{\link{Kinhom}},
  \code{\link{Kcross}},
  \code{\link{Kdot}},
  \code{\link{Kmulti}},
  \code{\link{alltypes}},
  \code{\link{smooth.spline}},
  \code{\link{predict.smooth.spline}}
}
\examples{
  # univariate point pattern
  data(simdat)
  p <- pcf(simdat, spar=0.5, method="b")
  plot(p, main="pair correlation function for simdat")
  # indicates inhibition at distances r < 0.3

  # multitype point pattern
  data(betacells)
  p <- pcf(alltypes(betacells, "K"), spar=0.5, method="b")
  plot(p)
  # short range inhibition between all types
  # strong inhibition between "on" and "off"
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{plot.fasp}
\alias{plot.fasp}
\alias{plot}
\title{Plot a Function Array}
\description{
   Plots an array of summary functions, usually associated with a
   point pattern, stored in an object of class \code{"fasp"}.
   A method for \code{plot}.
}

\synopsis{
   plot.fasp(x,formula=NULL,subset=NULL,lty=NULL,col=NULL,title=NULL,\dots)
}

\usage{
plot(x)
plot(x, formula=formula)
plot(x, formula=formula, subset)
plot(x, formula=formula, subset, lty, col, title, \dots)
}

\arguments{
  \item{x}{An object of class \code{"fasp"} representing a
    function array.
  }

  \item{formula}{A formula or list of formulae indicating what
    variables are to be plotted against what variable.  If
    \code{formula} is a list, its \eqn{k^{th}}{k-th} component
    should be applicable to the \eqn{(i,j)^{th}}{(i,j)-th}
    plot where \code{x$which[i,j]=k}.  If the formula is left
    as \code{NULL}, then \code{plot.fasp} attempts to use the component
    \code{default.formula} of \code{x}.  If that component is NULL
    as well, it gives up.

    In \bold{S-PLUS}, if this argument is given, then either it \bold{must}
    be supplied in the ``name=value'' format, \bold{or} the name
    of the plotting function \bold{must} be used explicitly.
    I.e. the call must use the function name \code{plot.fasp}
    and \bold{not} \code{plot}.  Otherwise the plotting function
    falls over.  See \bold{Warnings}.  There is no problem in R.
  }

  \item{subset}{A logical vector, or a vector of indices, or an
     expression or a character string, or a \bold{list} of such,
     indicating a subset of the data to be included in each plot.
     If \code{subset} is a list, its \eqn{k^{th}}{k-th} component
     should be applicable to the \eqn{(i,j)^{th}}{(i,j)-th} plot
     where \code{x$which[i,j]=k}.
  }

  \item{lty}{A vector of integers indicating line types to be
    used in forming the plot.
  }

  \item{col}{
    A vector of integers indicating colours for the different
    lines which form the plot.
  }

  \item{title}{
    Overall title for the plot.
  }
  \item{\dots}{
    Arguments passed to \code{\link{plot.default}} to control other
    features of the individual plot panels.
  }
}

\details{
  An object of class \code{"fasp"} represents
  an array of summary functions, usually associated with a point
  pattern. See \code{\link{fasp.object}} for details.
  Such an object might be created, for example, by \code{\link{alltypes}}
  or \code{\link{allstats}}.

  The function \code{plot.fasp} is
  a method for \code{plot}.  It calls \code{\link{plot.fv}} to plot the
  individual panels.

  For information about the interpretation of the
  arguments \code{formula}, \code{subset}, \code{lty} and \code{col},
  see \code{\link{plot.fv}}.

  The argument \code{title}, if present, will determine the
  overall title of the plot. If it is absent, it defaults to \code{x$title}.
  Titles for the individual plot panels will be taken from
  \code{x$titles}.
}

\value{None.}

\section{Warnings}{
  (Each component of) the \code{subset} argument may be a
  logical vector (of the same length as the vectors of data which
  are extracted from \code{x}), or a vector of indices, or an
  \bold{expression} such as \code{expression(r<=0.2)}, or a text string,
  such as \code{"r<=0.2"}.

  Attempting a syntax such as \code{subset = r<=0.2} (without
  wrapping \code{r<=0.2} either in quote marks or in \code{expression()})
  will cause this function to fall over.

  Variables referred to in any formula must exist in the data frames
  stored in \code{x}.  What the names of these variables are will
  of course depend upon the nature of \code{x}.
}

\seealso{
  \code{\link{alltypes}},
  \code{\link{allstats}},
  \code{\link{plot.fv}},
  \code{\link{fasp.object}}
}

\examples{
   \dontrun{
   # Bramble Canes data.
   data(bramblecanes)

   X.G <- alltypes(bramblecanes,type="G",dataname="Bramblecanes",verb=TRUE)
   plot(X.G)
   plot(X.G,subset="r<=0.2")
   plot(X.G,formula=cbind(asin(sqrt(km)),
                    asin(sqrt(theo))) ~ asin(sqrt(theo)))
       plot(X.G,fo=cbind(km-theo,0)~r,"r<=0.2")

   # Swedish pines.
   data(swedishpines)
   X <- allstats(swedishpines,dataname="Swedish Pines")
   plot(X,subset=list("r<=20","r<=20","r<=20","r<=50"))

   # Simulated data.
   pp <- runifpoint(350, owin(c(0,1),c(0,1)))
   pp$marks <- factor(c(rep(1,50),rep(2,100),rep(3,200)))
   X.K <- alltypes(pp,type="K",verb=TRUE,dataname="Fake Data")
   plot(X.K,fo=cbind(border,theo)~theo,"theo<=0.75")
   }
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
  }
\keyword{spatial}

\eof
\name{plot.fv}
\alias{plot.fv}
\title{Plot Function Valuesn}
\description{
  Plot method for the class \code{"fv"}.
}
\usage{
plot.fv(x, fmla, subset=NULL, lty=NULL, col=NULL, xlim, ylim, xlab, ylab, \dots)
}
\arguments{
  \item{x}{
    An object of class \code{"fv"}, containing the variables to be plotted
    or variables from which the plotting coordinates can be computed.
  }
  \item{fmla}{
    an S language formula determining which variables or expressions
    are plotted. 
  }
  \item{subset}{
    (optional) subset of rows of the data frame that will be plotted.
  }
  \item{lty}{
    (optional) numeric vector of values of the graphical parameter
    \code{lty} controlling the line style of each plot.
  }
  \item{col}{
    (optional) numeric vector of values of the graphical parameter
    \code{col} controlling the colour of each plot.
  }
  \item{xlim}{
    (optional) range of x axis
  }
  \item{ylim}{
    (optional) range of y axis
  }
  \item{xlab}{
    (optional) label for x axis
  }
  \item{ylab}{
    (optional) label for y axis
  }
  \item{\dots}{
    Extra arguments passed to \code{plot.default}.
  }
}
\value{
  none. Side effect is a plot.
}
\details{
  This is the \code{plot} method for the class \code{"fv"}.

  The use of the argument \code{fmla} is like \code{plot.formula}, but offers
  some extra functionality.
  
  The left and right hand sides of \code{fmla}
  are evaluated in the data frame \code{x},
  and the results are plotted against each other
  (the left side on the \eqn{y} axis 
  against the right side on the \eqn{x} axis). 
  Both left and right sides may be variables in the data frame
  or expressions in these variables.

  Multiple curves may be specified by a single formula
  of the form 
  \code{cbind(y1,y2,\ldots,yn) ~ x}, where \code{x,y1,y2,\ldots,yn} are
  expressions involving the variables in the data frame.
  Each of the variables \code{y1,y2,\ldots,yn} in turn will be plotted
  against \code{x}. 
  See the examples.
}
\examples{
   data(cells)
   K <- Kest(cells)
   # K is an object of class "fv"

   plot(K, iso ~ r)                # plots iso against r

   plot(K, sqrt(iso/pi) ~ r)   # plots sqrt(iso/r)  against r

   plot(K, cbind(iso,theo) ~ r)   # plots iso against r  AND theo against r

   plot(K, cbind(iso,theo) ~ r, col=c(2,3))
                                   # plots iso against r  in colour 2
                                   # and theo against r in colour 3

   plot(K, iso ~ r, subset=quote(r < 0.2))
                                   # plots iso against r for r < 10
}
\seealso{
  \code{\link{fv.object}},
  \code{\link{Kest}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 

\eof
\name{plot.owin}
\alias{plot.owin}
\title{Plot a Spatial Window}
\description{
  Plot a two-dimensional window of observation for a spatial point pattern
}
\usage{
 plot.owin(x, main, add=FALSE, \dots, box=TRUE, edge=0.04)
}
\arguments{
  \item{x}{
    The window to be plotted.
    An object of class \code{\link{owin}},
    or data which can be converted into 
    this format by \code{\link{as.owin}()}.
  }
  \item{main}{
    text to be displayed as a title above the plot.
  }
  \item{add}{
    logical flag: if \code{TRUE}, draw the window in 
    the current plot; if \code{FALSE}, generate a new plot.
  }
  \item{\dots}{
    extra arguments passed to the generic \code{\link{plot}} function.
  }
  \item{box}{
    logical flag; if \code{TRUE}, plot the enclosing rectangular box
  }
  \item{edge}{
    nonnegative number; the plotting region will have coordinate limits
    that are \code{1 + edge}
    times as large as the limits of the rectangular box
    that encloses the pattern.
  }
}
\value{
  none.
}
\details{
  This is the \code{plot} method for the class \code{\link{owin}}.
  The action is to plot the boundary of the window on the current plot device,
  using equal scales on the \code{x} and \code{y} axes.

  If the window \code{x} is of type \code{"rectangle"} or \code{"polygonal"},
  the boundary of the window is plotted as a polygon or series of polygons.
  If \code{x} is of type \code{"mask"} 
  the discrete raster approximation of the window is displayed
  as a binary image (white inside the window, black outside).

  Graphical parameters controlling the display (e.g. setting the
  colours) may be passed directly via the \code{...} arguments,
  or indirectly reset using 
  \code{\link{spatstat.options}}.
  The parameter \code{par.binary} of \code{\link{spatstat.options}}
  controls the display when \code{x} is of type \code{"mask"}.
}
\seealso{
  \code{\link{owin.object}},
  \code{\link{plot.ppp}},
  \code{\link{spatstat.options}}
}
\examples{
\dontrun{
  # rectangular window
   data(nztrees)
   plot(nztrees$window)
   abline(v=148, lty=2)

  # polygonal window
  plot(c(0,1),c(0,1),type="n")
  bdry <- locator()
  # click the vertices of a polygon (anticlockwise)
  w <- owin(c(0,1), c(0,1), poly=bdry)
  plot(w)

  # binary mask
  we <- erode.owin(w, 0.05, FALSE)
  plot(we)
  spatstat.options(par.binary=list(col=grey(c(0.5,1))))
  plot(we)
}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 

\eof
\name{plot.plotppm}
\alias{plot.plotppm}
\title{Plot a plotppm Object Created by plot.ppm}
\description{
  The function plot.ppm produces objects which specify plots
  of fitted point process models.  The function plot.plotppm
  carries out the actual plotting of these objects.
}
\usage{
plot.plotppm(x, data = NULL, trend = TRUE, cif = TRUE, pause = TRUE,
             how = c("persp", "image", "contour"), ...)
}
\arguments{
  \item{x}{
    An object of class \code{plotppm} produced by
    \code{\link{plot.ppm}()}
  }.
  \item{data}{
    The point pattern (an object of class \code{ppp})
    to which the point process model was fitted (by code{\link{ppm}()}).
  }
  \item{trend}{
    Logical scalar; should the trend component of
    the fitted model be plotted?
  }
  \item{cif}{
    Logical scalar; should the complete conditional
    intensity of the fitted model be plotted?
  }
  \item{pause}{
    Logical scalar indicating whether to pause with a prompt 
    after each plot. Set \code{pause=FALSE} if plotting to a file.
  }
  \item{how}{
    Character string or character vector indicating the style or styles of
    plots to be performed.
  }
  \item{\dots}{
    Extra arguments to the plotting functions
    \code{\link{persp}}, \code{\link{image}} and \code{\link{contour}}.
  }
}
\details{
  If argument \code{data} is supplied then the point pattern will
  be superimposed on the image and contour plots.

  Sometimes a fitted model does not have a trend component, or the
  trend component may constitute all of the conditional intensity (if
  the model is Poisson).  In such cases the object \code{x} will not
  contain a trend component, or will contain only a trend component.
  This will also be the case if one of the arguments \code{trend}
  and \code{cif} was set equal to \code{FALSE} in the call to
  \code{plot.ppm()} which produced \code{x}.  If this is so then
  only the item which is present will be plotted.  Explicitly setting
  \code{trend=TRUE}, or \code{cif=TRUE}, respectively, will then give
  an error.
}
\value{
   None.
}

\section{Warning}{
  Arguments which are passed to \code{persp}, \code{image}, and
  \code{contour} via the \dots argument get passed to any of the
  other functions listed in the \code{how} argument, and won't be
  recognized by them.  This leads to a lot of annoying but harmless
  warning messages.  Arguments to \code{persp} may be supplied via
  \code{\link{spatstat.options}()} which alleviates the warning
  messages in this instance.
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\seealso{ \code{\link{plot.ppm}()} }
\examples{
 \dontrun{
 data(cells)
 Q <- quadscheme(cells)
 m <- ppm(Q, ~1, Strauss(0.05))
 mpic <- plot(m)
 # Perspective plot only, with altered parameters:
  plot(mpic,how="persp", theta=-30,phi=40,d=4)
 # All plots, with altered parameters for perspective plot:
 spatstat.options(par.persp=list(theta=-30,phi=40,d=4))
 plot(mpic)
 }
}
\keyword{spatial}




\eof
\name{plot.ppm}
\alias{plot.ppm}
\title{plot a Fitted Point Process Model}
\description{
  Given a fitted point process model obtained by \code{\link{ppm}},
  create spatial trend and conditional intensity surfaces of the model,
  in a form suitable for plotting, and (optionally) plot these
  surfaces.
}
\usage{
 plot.ppm(x, ngrid = c(40,40), superimpose = TRUE, 
                  trend = TRUE, cif = TRUE, pause = TRUE,
                  how=c("persp","image", "contour"), plot.it = TRUE,
                  locations = NULL, covariates=NULL, \dots)
}
\arguments{
  \item{x}{
    A fitted point process model, typically obtained from
    the model-fitting algorithm \code{\link{ppm}}.
    An object of class \code{"ppm"}.
  }
  \item{ngrid}{
    The dimensions for a grid on which to evaluate,
    for plotting, the spatial trend and conditional intensity.
    A vector of 1 or 2 integers. If it is of length 1,
    \code{ngrid} is replaced by \code{c(ngrid,ngrid)}.
  }
  \item{superimpose}{
    logical flag; if \code{TRUE} (and if \code{plot=TRUE}) the
    original data point pattern will be superimposed on the plots.
  }
  \item{trend}{
    logical flag; if \code{TRUE}, the spatial trend surface will be produced.
  }
  \item{cif}{
    logical flag; if \code{TRUE}, the conditional intensity surface will be
    produced.
  }
  \item{pause}{
    logical flag indicating whether to pause with a prompt 
    after each plot. Set \code{pause=FALSE} if plotting to a file.
    Ignored if \code{plot=FALSE}.
  }
  \item{how}{
    character string or character vector indicating the style or styles of
    plots to be performed. Ignored if \code{plot=FALSE}.  
  }
  \item{plot.it}{
    logical scalar; should a plot be produced immediately?
  }
  \item{locations}{
    If present, this determines the locations of the pixels
    at which predictions are computed. It must be a binary pixel image
    (an object of class \code{"owin"} with type \code{"mask"}).
    (Incompatible with \code{ngrid}).
  }
  \item{covariates}{
    Values of external covariates required by the fitted model.
    Passed to \code{\link{predict.ppm}}.
  }
  \item{\dots}{
    extra arguments to the plotting functions \code{\link{persp}},
    \code{\link{image}} and \code{\link{contour}}.
  }
}
\value{
  An object of class \code{plotppm}.  Such objects may be plotted by
  \code{\link{plot.plotppm}()}.

  This is a list with components named \code{trend} and \code{cif},
  either of which may
  be missing. They will be missing if the corresponding component
  does not make sense for the model, or if the corresponding
  argument was set equal to \code{FALSE}.

  Both \code{trend} and \code{cif} are lists of images.
  If the model is an unmarked point process, then they are lists of
  length 1, so that \code{trend[[1]]} is an image of the spatial trend
  and \code{cif[[1]]} is an image of the conditional intensity.

  If the model is a marked point process, then \code{trend[[i]]}
  is an image of the spatial trend for the mark \code{m[i]},
  and \code{cif[[1]]} is an image of the conditional intensity
  for the mark \code{m[i]}, where \code{m} is the vector of levels
  of the marks.
}
\details{
  This is the \code{plot} method for the class \code{"ppm"}
  (see \code{\link{ppm.object}} for details of this class).
  
  It invokes \code{\link{predict.ppm}} to compute the spatial 
  trend and conditional intensity of the fitted point process model.
  See \code{\link{predict.ppm}} for more explanation about spatial trend
  and conditional intensity.
 
  The default action is to create a rectangular grid
  of points in (the bounding box of) the observation window of
  the data point pattern, and evaluate the spatial trend and
  conditional intensity of the fitted spatial point process model
  \code{x} at these locations.  If the argument \code{locations=}
  is supplied, then the spatial trend
  and conditional intensity are calculated at the grid of points
  specified by this argument.

  The argument \code{locations}, if present, should be a
  binary image mask (an object of class \code{"owin"}
  and type \code{"mask"}). This determines a rectangular grid
  of locations, or a subset of such a grid, at which predictions
  will be computed. Binary image masks
  are conveniently created using \code{\link{as.mask}}.

  The argument \code{covariates} gives the values of any spatial covariates
  at the prediction locations.
  If the trend formula in the fitted model 
  involves spatial covariates (other than
  the Cartesian coordinates \code{x}, \code{y})
  then \code{covariates} is required.

  The argument \code{covariates} has the same format and interpretation
  as in \code{\link{predict.ppm}}. It may be
  either a data frame (the number of whose rows must match
  the number of pixels in \code{locations} multiplied by the number of
  possible marks in the point pattern),  or a list of images.
  If argument \code{locations}
  is not supplied, and \code{covariates} \bold{is} supplied, then
  it \bold{must} be a list of images.

  If the fitted model was a marked (multitype) point process, then 
  predictions are made for each possible mark value in turn.
 
  If the fitted model had no spatial trend, then the default is 
  to omit calculating this (flat) surface, unless \code{trend=TRUE}
  is set explicitly.
 
  If the fitted model was Poisson, so that there were no spatial interactions,
  then the conditional intensity and spatial trend are identical, and the
  default is to omit the conditional intensity, unless \code{cif=TRUE} is set
  explicitly.

  If \code{plot.it=TRUE} then \code{\link{plot.plotppm}()} is called
  upon to plot the class \code{plotppm} object which is produced.
  (That object is also returned, silently.)
  
  Plots are produced successively using \code{\link{persp}},
  \code{\link{image}} and \code{\link{contour}} (or only a
  selection of these three, if \code{how} is given).  Extra
  graphical parameters controlling the display may be passed
  directly via the arguments \code{...} or indirectly reset using
  \code{\link{spatstat.options}}.
}
\seealso{
  \code{\link{plot.plotppm}},
  \code{\link{ppm}},
  \code{\link{ppm.object}},
  \code{\link{predict.ppm}},
  \code{\link{print.ppm}},
  \code{\link{persp}},
  \code{\link{image}},
  \code{\link{contour}},
  \code{\link{plot}},
  \code{\link{spatstat.options}}
}
\section{Warnings}{
  See warnings in \code{\link{predict.ppm}}.
}
\examples{
 \dontrun{
 data(cells)
 m <- ppm(cells, ~1, Strauss(0.05))
 pm <- plot(m) # The object ``pm'' will be plotted as well as saved
               # for future plotting.
 }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{plot.ppp}
\alias{plot.ppp}
\title{plot a Spatial Point Pattern}
\description{
  Plot a two-dimensional spatial point pattern
}
\usage{
 plot.ppp(x, main, \dots, chars, cols, use.marks=TRUE, add=FALSE, maxsize)
}
\arguments{
  \item{x}{
    The spatial point pattern to be plotted.
    An object of class \code{"ppp"},
    or data which can be converted into 
    this format by \code{\link{as.ppp}()}.
  }
  \item{main}{
    text to be displayed as a title above the plot.
  }
  \item{\dots}{
    extra arguments that will be passed to the plotting functions
    \code{\link{plot.default}} (see \code{\link{par}} for possible
    options) or \code{\link{symbols}}.
  }
  \item{chars}{
    the plotting characters which should be used to represent
    the points of different types, in the case of a multitype
    point pattern. 
  }
  \item{cols}{
    the colours which should be used to plot the points of
    different types, in the case of a multitype point pattern.
  }
  \item{use.marks}{
    logical flag; if \code{TRUE}, plot points using a different
    plotting symbol for each mark;
    if \code{FALSE}, only the locations of the points will be plotted,
    using \code{\link{points}()}.
  }
  \item{add}{
    logical flag; if \code{TRUE},
    just the points are plotted, over the existing plot.
    A new plot is not created, and
    the window is not plotted.
  }
  \item{maxsize}{
    the maximum radius of the circles plotted.
    If \code{x} is a marked point pattern with 
    numerical marks, the marks are plotted as circles with
    maximum radius \code{maxsize} 
    (in the same units as the coordinates of
    the point pattern). There is a sensible default.
  }
}
\value{
  \code{NULL}, or a vector giving the correspondence between 
  mark values and plotting characters.
}
\details{
  This is the \code{plot} method for 
  point pattern datasets (of class \code{"ppp"}, see \code{\link{ppp.object}}).

  First the observation window \code{x$window} is plotted 
  using \code{\link{plot.owin}}.
  Then the locations of the points are plotted. 
 
  If the points do not have marks (i.e. \code{x$marks} is absent)
  or if \code{use.marks = FALSE},
  then the locations of the points will be plotted 
  using a single plot character. This character can be changed
  by the extra argument \code{pch};  see the examples.

  For a marked point pattern (where \code{x$marks} is not null)
  each point will be represented by a graphical symbol plotted at the
  location of the point.
  The graphical representation of the marks depends
  on their storage mode:
  \describe{
    \item{multitype point pattern:}{
      If \code{x$marks} is a factor, then 
      each level of the factor is 
      represented by a different plot character.
    }
    \item{continuous marks:}{
      If \code{x$marks} is a numeric vector,
      the marks are rescaled to the unit interval and
      each point is represented by a circle 
      with radius proportional to the rescaled mark
      (if the value is positive) or a square with side proportional
      to the absolute value of the rescaled mark (if the value is negative).
    }
    \item{otherwise:}{
      Each possible mark will be represented by a
      different plotting character. The default is to
      represent the \eqn{i}th smallest mark value by
      \code{points(..., pch=i)}.
    }
  }
  If the arguments \code{chars} and/or \code{cols} are supplied,
  they should be vectors of the same length
  as \code{sort(unique(x$marks))}, and then the \eqn{i}th smallest mark
  will be plotted using character \code{chars[i]} and colour
  \code{cols[i]}.

  The argument \code{cols} is incompatible with
  the generic plot argument \code{col}. If both are given,
  an error is generated and no plot is produced.
}
\seealso{
  \code{\link{ppp.object}},
  \code{\link{plot}},
  \code{\link{par}},
  \code{\link{points}},
  \code{\link{plot.owin}},
  \code{\link{symbols}}
}
\examples{
   \dontrun{
   data(cells)
   plot(cells)

   # multitype 
   data(lansing)
   plot(lansing)

   # marked by a real number
   data(longleaf)
   plot(longleaf)

   # just plot the points
   plot(longleaf, use.marks=FALSE)
   plot(unmark(longleaf)) # equivalent

   # controlling COLOURS
   plot(cells, col="blue")
   plot(lansing, cols=c("black", "yellow", "green", "pink",
                        "blue","red","white")
   plot(longleaf, fg="blue")

   # use selected plot characters
   lma <- sort(unique(longleaf$marks))
   adult <- ifelse(lma >= 30, "o", "+")
   plot(longleaf, chars = adult)

   # make the plotting symbols larger (for publication at reduced scale)
   plot(cells, cex=2)

  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 

\eof
\name{plot.quad}
\alias{plot.quad}
\title{plot a Spatial Quadrature Scheme}
\description{
  Plot a two-dimensional spatial quadrature scheme.
}
\usage{
 plot.quad(x, ..., main=deparse(substitute(x)), dum=list())
}
\arguments{
  \item{x}{
    The spatial quadrature scheme to be plotted.
    An object of class \code{"quad"}.
  }
  \item{\dots}{
    extra arguments controlling the plotting
    of the data points of the quadrature scheme.
  }
  \item{dum}{
    list of extra arguments controlling the plotting of the dummy points of the
    quadrature scheme. See below.
  }
  \item{main}{
    text to be displayed as a title above the plot.
  }
}
\value{
  \code{NULL}.
}
\details{
  This is the \code{plot} method for 
  quadrature schemes (objects of class \code{"quad"},
  see \code{\link{quad.object}}).

  First the data points of the quadrature scheme
  are plotted (in their observation window) using 
  \code{\link{plot.ppp}} with any arguments specified in \code{...}

  Then the dummy points of the quadrature scheme are plotted
  using \code{\link{plot.ppp}} with any arguments specified in
  \code{dum}.

  By default the dummy points are superimposed onto the plot of data
  points. This can be overridden by including the argument
  \code{add=FALSE} in the list \code{dum} as shown in the examples.
  In this case the data and dummy point patterns are plotted separately.

  See \code{\link{par}} and \code{\link{plot.ppp}}
  for other possible arguments controlling the plots.
}
\seealso{
  \code{\link{quad.object}},
  \code{\link{plot.ppp}},
  \code{\link{par}}
}
\examples{
   data(nztrees)
   Q <- quadscheme(nztrees)

   plot(Q, main="NZ trees: quadrature scheme")

   par(mfrow=c(2,1))
   plot(Q, main="NZ trees", dum=list(add=FALSE))
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 

\eof
\name{plot.splitppp}
\alias{plot.splitppp}
\title{Plot a List of Point Patterns}
\description{
  Plots a list of point patterns.
}
\usage{
  plot.splitppp(x, \dots, arrange=TRUE)
}
\arguments{
  \item{x}{
    A named list of point patterns,
    typically obtained from \code{\link{split.ppp}}.
  }
  \item{\dots}{
    Arguments passed to \code{\link{plot.ppp}} which control the
    appearance of each plot panel.
  }
  \item{arrange}{
    Logical flag indicating whether to plot the point patterns
    side-by-side. Set this to \code{FALSE} if you want to control
    the arrangement of the plots yourself.
  }
}
\value{
  Null.
}
\details{
  This is the \code{plot} method for the class \code{"splitppp"}.
  It is typically used to plot the result of the function
  \code{\link{split.ppp}} but it may also be used to plot any list
  of point patterns created by the user.

  The argument \code{x} should be a named list of point patterns
  (objects of class \code{"ppp"}, see \code{\link{ppp.object}}).
  Each of these point patterns will be plotted in turn
  using \code{\link{plot.ppp}}. 
}
\seealso{
  \code{\link{split.ppp}},
  \code{\link{plot.ppp}},
  \code{\link{ppp.object}}
}
\examples{
# Multitype point pattern
 data(amacrine)
 plot(split(amacrine))
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{ppm}
\alias{ppm}
\title{
  Fit Point Process Model to Data
}
\description{
  Fits a point process model to an observed point pattern
}
\usage{
 ppm(Q, trend=~1, interaction=NULL, covariates=NULL,
correction="border", rbord=0, use.gam=FALSE, method="mpl")
}
\arguments{
  \item{Q}{
    A data point pattern (of class \code{"ppp"})
    to which the model will be fitted,
    or preferably a quadrature scheme (of class \code{"quad"})
    containing this pattern.
  }
  \item{trend}{
  An \R formula object specifying the spatial trend to be fitted. 
  The default formula, \code{~1}, indicates the model is stationary
  and no trend is to be fitted. 
  }
  \item{interaction}{
    An object of class \code{"interact"}
    describing the point process interaction
    structure, or \code{NULL} indicating that a Poisson process (stationary
    or nonstationary) should be fitted.
  }
  \item{covariates}{
    The values of any spatial covariates (other than the Cartesian
    coordinates) required by the model.
    Either a data frame, or a list of images.
    See Details.
  }
  \item{correction}{
    The name of the edge correction to be used. The default 
    is \code{"border"} indicating the border correction.
    Other possibilities may include \code{"Ripley"}, \code{"isotropic"},
    \code{"translate"} and \code{"none"}, depending on the 
    \code{interaction}.
  }
  \item{rbord}{
    If \code{correction = "border"}
    this argument specifies the distance by which
    the window should be eroded for the border correction.
  }
  \item{use.gam}{
    Logical flag; if \code{TRUE} then computations are performed
    using \code{gam} instead of \code{\link{glm}}.
  }
  \item{method}{
    The method used to fit the model. Currently the only option
    is \code{"mpl"} indicating the method of Maximum PseudoLikelihood.
  }
}
\value{
  An object of class \code{"ppm"} describing a fitted point process
  model.
 
  The fitted parameters can be obtained just by printing this object.
  Fitted spatial trends can be extracted using the \code{predict} method
  for this object (see \code{\link{predict.ppm}}).

  See \code{\link{ppm.object}} for details of the format of this object.
}
\details{
  This function fits a point process model
  to an observed point pattern.
  The model may include
  spatial trend, interpoint interaction, and dependence on covariates.
 
  Model-fitting is currently performed by
  the method of maximum pseudolikelihood (Besag, 1975).
  Other options will be added in future versions.
  
  The algorithm is an implementation of the method of
  Baddeley and Turner (2000), which approximates the pseudolikelihood
  by a special type of quadrature sum generalising the Berman-Turner (1992) 
  approximation. 
 
  The argument \code{Q} should be either a point pattern
  or a quadrature scheme. If it is a point pattern, it is converted
  into a quadrature scheme.

  A quadrature scheme is an object of class \code{"quad"}
  (see \code{\link{quad.object}})
  which specifies both the data point pattern and the dummy points
  for the quadrature scheme, as well as the quadrature weights
  associated with these points.
  If \code{Q} is simply a point pattern
  (of class \code{"ppp"}, see \code{\link{ppp.object}})
  then it is interpreted as specifying the
  data points only; a set of dummy points specified
  by \code{\link{default.dummy}()} is added, and the default weighting rule is
  invoked to compute the quadrature weights.
 
  The usage of \code{ppm()} is closely analogous to the Splus/\R functions
  \code{\link{glm}} and \code{gam}.
  The analogy is:
  \tabular{ll}{
  \bold{glm} \tab \bold{ppm} \cr
  \code{formula} \tab \code{trend} \cr
  \code{family} \tab \code{interaction}
  }
  The point process model to be fitted is specified by the 
  arguments \code{trend} and \code{interaction}
  which are respectively analogous to
  the \code{formula} and \code{family} arguments of glm(). 
 
  Systematic effects (spatial trend and/or dependence on 
  spatial covariates) are specified by the argument
  \code{trend}. This is an Splus/\R formula object, which may be expressed
  in terms of the Cartesian coordinates \code{x}, \code{y},
  the marks \code{marks},
  or the variables in \code{covariates} (if supplied), or both.
  It specifies the \bold{logarithm} of the first order potential
  of the process.
  The formula should not use any names beginning with \code{.mpl}
  as these are reserved for internal use.
  If \code{trend} is absent or equal to the default, \code{~1}, then
  the model to be fitted is stationary (or at least, its first order 
  potential is constant). 
 
  Stochastic interactions between random points of the point process
  are defined by the argument \code{interaction}. This is an object of
  class \code{"interact"} which is initialised in a very similar way to the
  usage of family objects in \code{\link{glm}} and \code{gam}.
  See the examples below.
 
  If \code{interaction} is missing or \code{NULL}, then the model to be fitted
  has no interpoint interactions, that is, it is a Poisson process
  (stationary or nonstationary according to \code{trend}). In this case
  the method of maximum pseudolikelihood
  coincides with maximum likelihood.

  To fit a model involving spatial covariates
  other than the Cartesian coordinates \eqn{x} and \eqn{y},
  the values of the covariates should be supplied in the
  argument \code{covariates}. 
  Note that it is not sufficient to have observed
  the covariate only at the points of the data point pattern; 
  the covariate must also have been observed at other 
  locations in the window.

  The argument \code{covariates}, if supplied, should be either
  a data frame or a list of images.
  If it is a data frame, it must have
  as many rows as there are points in \code{Q}.
  The \eqn{i}th row of \code{covariates} should contain the values of
  spatial variables which have been observed
  at the \eqn{i}th point of \code{Q}. In this case
  the argument \code{Q} must be a quadrature scheme,
  not merely a point pattern.

  Alternatively, \code{covariates} may be a list of images,
  each image giving the values of a spatial covariate at 
  a fine grid of locations. 
  The argument \code{covariates} should then be a named list,
  with the names corresponding to
  the names of covariates in the model formula \code{trend}.
  Each entry in the list must be an image object (of class \code{"im"},
  see \code{\link{im.object}}).
  The software will look up
  the pixel values of each image at the quadrature points.
  In this case the argument \code{Q} may be either a quadrature
  scheme or a point pattern.

  The variable names \code{x}, \code{y} and \code{marks}
  are reserved for the Cartesian 
  coordinates and the mark values,
  and these should not be used for variables in \code{covariates}.
  
  The argument \code{correction} is the name of an edge correction method.
  The default \code{correction="border"} specifies the border correction,
  in which the quadrature window (the domain of integration of the 
  pseudolikelihood) is obtained by trimming off a margin of width \code{rbord}
  from the observation window of the data pattern.
  Not all edge corrections are implemented (or implementable)
  for arbitrary windows.
  Other options depend on the argument \code{interaction}, but these generally 
  include \code{"periodic"} (the periodic or toroidal edge correction
  in which opposite edges of a rectangular window are identified)
  and \code{"translate"}
  (the translation correction, see Baddeley 1998 and Baddeley and Turner
  2000).
  For pairwise interaction there is also Ripley's isotropic correction,
  identified by \code{"isotropic"} or \code{"Ripley"}.
 
  The fitted point process model returned by this function can be printed 
  (by the print method \code{\link{print.ppm}})
  to inspect the fitted parameter values.
  If a nonparametric spatial trend was fitted, this can be extracted using
  the predict method \code{\link{predict.ppm}}.

  This algorithm approximates the log pseudolikelihood
  by a sum over a finite set of quadrature points.
  Finer quadrature schemes (i.e. those with more
  quadrature points) generally yield a better approximation, at the
  expense of higher computational load. 
  Complete control over the quadrature scheme is possible.
  See \code{\link{quadscheme}} for an overview.

  Note that the method of maximum pseudolikelihood is
  believed to be inefficient and biased for point processes with strong
  interpoint interactions. In such cases, it is advisable to use
  iterative maximum likelihood
  methods such as Monte Carlo Maximum Likelihood (Geyer, 1999) 
  provided the appropriate simulation algorithm exists. 
  The maximum pseudolikelihood parameter estimate often serves
  as a good initial starting point for these iterative methods. 
  Maximum pseudolikelihood may also be used profitably for
  model selection in the initial phases of modelling.

  The warning message ``Algorithm did not converge in: glm.fit( ...''
  is sometimes obtained. It means that the glm fitting algorithm
  did not converge in a reasonable number of iterations. In most cases
  this can be fixed by taking a finer quadrature scheme.
  See \code{\link{quadscheme}}.
}
\references{
  Baddeley, A. and Turner, R.
  Practical maximum pseudolikelihood for spatial point patterns.
  \emph{Australian and New Zealand Journal of Statistics}
  \bold{42} (2000) 283--322.
 
  Berman, M. and Turner, T.R. 
  Approximating point process likelihoods with GLIM.
  \emph{Applied Statistics} \bold{41} (1992) 31--38.
 
  Besag, J.
  Statistical analysis of non-lattice data.
  \emph{The Statistician} \bold{24} (1975) 179-195.
 
  Diggle, P.J., Fiksel, T., Grabarnik, P., Ogata, Y., Stoyan, D. and
  Tanemura, M.
  On parameter estimation for pairwise interaction processes.
  \emph{International Statistical Review} \bold{62} (1994) 99-117.
 
  Jensen, J.L. and Moeller, M.
  Pseudolikelihood for exponential family models of spatial point processes.
  \emph{Annals of Applied Probability} \bold{1} (1991) 445--461.
 
  Jensen, J.L. and Kuensch, H.R. 
  On asymptotic normality of pseudo likelihood
  estimates for pairwise interaction processes,
  \emph{Annals of the Institute of Statistical Mathematics}
  \bold{46} (1994) 475-486.
}

\seealso{
  \code{\link{ppp}}, 
  \code{\link{quadscheme}}, 
  \code{\link{ppm.object}},
  \code{\link{Poisson}},
  \code{\link{Strauss}},
  \code{\link{StraussHard}},
  \code{\link{MultiStrauss}},
  \code{\link{MultiStraussHard}},
  \code{\link{Softcore}},
  \code{\link{DiggleGratton}},
  \code{\link{Pairwise}},
  \code{\link{PairPiece}},
  \code{\link{Geyer}},
  \code{\link{LennardJones}},
  \code{\link{Saturated}},
  \code{\link{OrdThresh}},
  \code{\link{Ord}}
}
\section{Warnings}{
See the comments above about the possible inefficiency
and bias of the maximum pseudolikelihood estimator.
 
The accuracy of the Berman-Turner-Baddeley approximation to
the pseudolikelihood depends on the number of dummy points used
in the quadrature scheme. The number of dummy points should 
at least equal the number of data points.
 
The parameter values of the fitted model
do not necessarily determine a valid point process.
Some of the point process models are only defined when the parameter
values lie in a certain subset. For example the Strauss process only 
exists when the interaction parameter \eqn{\gamma}{gamma}
is less than or equal to \eqn{1},
corresponding to a value of \code{ppm()$theta[2]}
less than or equal to \code{0}.
The current version of \code{ppm} maximises the pseudolikelihood
without constraining the parameters, and does not apply any checks for
sanity after fitting the model. 
 
The \code{trend} formula should not use any variable names
beginning with the prefixes \code{.mpl} or \code{Interaction}
as these names are reserved
for internal use. The data frame \code{covariates} should have as many rows
as there are points in \code{Q}. It should not contain
variables called \code{x}, \code{y} or \code{marks}
as these names are reserved for the Cartesian coordinates
and the marks.
 
If the model formula involves one of the functions
\code{poly()}, \code{bs()}
or \code{ns()}
(e.g. applied to spatial coordinates \code{x} and \code{y}),
the fitted coefficients can be misleading.
The resulting fit is not to the raw spatial variates
(\code{x}, \code{x^2}, \code{x*y}, etc.) 
but to a transformation of these variates.  The transformation is implemented
by \code{poly()} in order to achieve better numerical stability.
However the
resulting coefficients are appropriate for use with the transformed
variates, not with the raw variates.  
This affects the interpretation of the constant
term in the fitted model, \code{logbeta}. 
Conventionally, \eqn{\beta}{beta} is the background intensity, i.e. the  
value taken by the conditional intensity function when all predictors
(including spatial or ``trend'' predictors) are set equal to \eqn{0}.
However the coefficient actually produced is the value that the
log conditional intensity takes when all the predictors, 
including the \emph{transformed}
spatial predictors, are set equal to \code{0}, which is not the same thing.

Worse still, the result of \code{\link{predict.ppm}} can be
completely wrong if the trend formula contains one of the
functions \code{poly()}, \code{bs()}
or \code{ns()}. This is a weakness of the underlying
function \code{\link{predict.glm}}. 

If you wish to fit a polynomial trend, 
we offer an alternative to \code{\link{poly}()},
namely \code{polynom()}, which avoids the
difficulty induced by transformations.  It is completely analogous
to \code{poly} except that it does not orthonormalise.
The resulting coefficient estimates then have
their natural interpretation and can be predicted correctly. 
Numerical stability may be compromised.

Values of the maximised pseudolikelihood are not comparable
if they have been obtained with different values of \code{rbord}.
}
\examples{
 data(nztrees)
 ppm(nztrees)
 # fit the stationary Poisson process
 # to point pattern 'nztrees'

 Q <- quadscheme(nztrees) 
 ppm(Q) 
 # equivalent.

 ppm(nztrees, ~ x)
 # fit the nonstationary Poisson process 
 # with intensity function lambda(x,y) = exp(a + bx)
 # where x,y are the Cartesian coordinates
 # and a,b are parameters to be estimated

 ppm(nztrees, ~ polynom(x,2))
 # fit the nonstationary Poisson process 
 # with intensity function lambda(x,y) = exp(a + bx + cx^2)

 library(splines)
 ppm(nztrees, ~ bs(x,df=3))
 #       WARNING: do not use predict.ppm() on this result
 # Fits the nonstationary Poisson process 
 # with intensity function lambda(x,y) = exp(B(x))
 # where B is a B-spline with df = 3
 
 ppm(nztrees, ~1, Strauss(r=10), rbord=10)
 # Fit the stationary Strauss process with interaction range r=10
 # using the border method with margin rbord=10
  
 ppm(nztrees, ~ x, Strauss(13), correction="periodic")
 # Fit the nonstationary Strauss process with interaction range r=13
 # and exp(first order potential) =  activity = beta(x,y) = exp(a+bx)
 # using the periodic correction.

 # COVARIATES
 #
 X <- rpoispp(42)
 weirdfunction <- function(x,y){ 10 * x^2 + runif(length(x))}
 Zimage <- as.im(weirdfunction, unit.square())
 #
 # (a) covariate values in pixel image
 ppm(X, ~ y + Z, covariates=list(Z=Zimage))
 #
 # (b) covariate values in data frame
 Q <- quadscheme(X)
 xQ <- x.quad(Q)
 yQ <- y.quad(Q)
 Zvalues <- weirdfunction(xQ,yQ)
 ppm(Q, ~ y + Z, covariates=data.frame(Z=Zvalues))
 # Note Q not X


 ## MULTITYPE POINT PROCESSES ### 
 data(lansing)
 # Multitype point pattern --- trees marked by species
\testonly{
 # equivalent functionality - smaller dataset
 data(betacells)
 }

 # fit stationary marked Poisson process
 # with different intensity for each species
\dontrun{ppm(lansing, ~ marks, Poisson())}
\testonly{ppm(betacells, ~ marks, Poisson())}

 # fit nonstationary marked Poisson process
 # with different log-cubic trend for each species
\dontrun{ppm(lansing, ~ marks * polynom(x,y,3), Poisson())}
\testonly{ppm(betacells, ~ marks * polynom(x,y,2), Poisson())}

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{ppm.object}
\alias{ppm.object}
\title{Class of Fitted Point Process Models}
\description{
  A class \code{ppm} to represent a fitted stochastic model
  for a point process. The output of \code{\link{ppm}}.
}
\details{
  An object of class \code{ppm} represents a stochastic point process
  model that has been fitted to a point pattern dataset.
  Typically it is the output of the model fitter,
  \code{\link{ppm}}.

  There are methods \code{\link{print.ppm}},
  \code{\link{plot.ppm}}, \code{\link{predict.ppm}}, \code{\link{fitted.ppm}}
  and \code{\link{coef.ppm}} for the generic functions
  \code{\link{print}}, \code{\link{plot}}, \code{\link{predict}},
  \code{\link{fitted}} and \code{\link{coef}} respectively.

  See also (for example) \code{\link{Strauss}}
  to understand how to specify 
  a point process model with unknown parameters.

  Information about the data (to which the model was fitted)
  can be extracted using \code{\link{data.ppm}}, \code{\link{dummy.ppm}}
  and \code{\link{quad.ppm}}.

  If you really need to get at the internals,
  a \code{ppm} object contains at least the following entries:
  \tabular{ll}{
    \code{coef} \tab  the fitted regular parameters (as returned by
                     \code{glm}) \cr
    \code{trend} \tab  the trend formula or \code{NULL} \cr
    \code{interaction} \tab the point process interaction family 
                        (an object of class \code{"interact"})
			or \code{NULL} \cr
    \code{Q} \tab      the quadrature scheme used \cr
    \code{maxlogpl} \tab the maximised value of log pseudolikelihood \cr
    \code{correction} \tab  name of edge correction method used \cr
  }
  See \code{\link{ppm}} for explanation of these concepts.
  The irregular parameters (e.g. the interaction radius of the
  Strauss process) are encoded in the \code{interaction} entry.
  However see the Warnings.
}
\seealso{
  \code{\link{ppm}},
  \code{\link{coef.ppm}},
  \code{\link{fitted.ppm}},
  \code{\link{print.ppm}},
  \code{\link{predict.ppm}},
  \code{\link{plot.ppm}}.
}
\section{Warnings}{
  The internal representation may change in the next few releases
  of the \code{spatstat} package.
}
\examples{
  data(cells)
  fit <- ppm(cells, ~ x, Strauss(0.1), correction="periodic")
  fit
  coef(fit)
  \dontrun{
  pred <- predict(fit)
  }
  pred <- predict(fit, ngrid=20, type="trend")
  \dontrun{
  plot(fit)
  }  
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{ppp}
\alias{ppp}
\title{Create a Point Pattern}
\description{
  Creates an object of class \code{"ppp"} representing 
  a point pattern dataset in the two-dimensional plane.
}
\synopsis{
  ppp(x,y, \dots, window, marks)
}
\usage{
  ppp(x,y, xrange, yrange, marks)
  ppp(x,y, window, marks)
  ppp(x,y, poly, marks)
  ppp(x,y, mask, marks)
  ppp(x,y, \dots, marks)
}
\arguments{
  \item{x}{Vector of \eqn{x} coordinates of data points}
  \item{y}{Vector of \eqn{y} coordinates of data points}
  \item{xrange}{\eqn{x} coordinate limits of enclosing box}
  \item{yrange}{\eqn{y} coordinate limits of enclosing box}
  \item{marks}{(optional) vector of mark values}
  \item{poly}{vertices of polygonal boundary of window}
  \item{mask}{logical matrix giving binary image of window}
  \item{window}{window of observation,
    an object of class \code{"owin"}}
  \item{\dots}{arguments passed to \code{\link{owin}} to create the
    window}
}
\value{
  An object of class \code{"ppp"} 
  describing a point pattern in the two-dimensional plane
  (see \code{\link{ppp.object}}).
}
\details{
  In the \code{spatstat} library, a point pattern dataset is
  described by an object of class \code{"ppp"}. This function
  creates such objects.

  The vectors \code{x} and \code{y} must be numeric vectors of
  equal length. They are interpreted as the cartesian coordinates
  of the points in the pattern.

  A point pattern dataset is assumed to have been observed within a specific
  region of the plane called the observation window.
  An object of class \code{"ppp"} representing a point pattern
  contains information specifying the observation window.
  This window must always be specified when creating a point pattern dataset;
  there is intentionally no default action of ``guessing'' the window
  dimensions from the data points alone. 

  You can specify the observation window in several
  (mutually exclusive) ways:
  \itemize{
    \item
    \code{xrange, yrange} specify a rectangle
    with these dimensions;
    \item
    \code{poly} specifies a polygonal boundary.
    If the boundary is a single polygon then \code{poly}
    must be a list with components \code{x,y}
    giving the coordinates of the vertices.
    If the boundary consists of several disjoint polygons
    then \code{poly} must be a list of such lists
    so that \code{poly[[i]]$x} gives the \eqn{x} coordinates
    of the vertices of the \eqn{i}th boundary polygon.
    \item
    \code{mask} specifies a binary pixel image with entries
    that are \code{TRUE} if the corresponding pixel is inside
    the window.
    \item
    \code{window} is an object of class \code{"owin"}
    (see \code{\link{owin.object}}) specifying the window.
  }
  The arguments \code{xrange, yrange} or \code{poly}
  or \code{mask} are passed to the window creator function
  \code{\link{owin}} for interpretation. See
  \code{\link{owin}} for further details.

  The argument \code{window}, if given, must be an object of class
  \code{"owin"}. It is a full description of the window geometry,
  and could have been obtained from \code{\link{owin}} or
  \code{\link{as.owin}}, or by just extracting the observation window
  of another point pattern, or by manipulating such windows.
  See \code{\link{owin}} or the Examples below.

  The optional argument \code{marks} is given if the point pattern
  is marked, i.e. if each data point carries additional information.
  For example, points which are classified into two or more different
  types, or colours, may be regarded as having a mark which identifies
  which colour they are. Data recording the locations and heights of
  trees in a forest can be regarded as a marked point pattern where the
  mark is the tree height.

  In the current implementation, \code{marks} must be a vector, of
  the same length as \code{x} and \code{y}, which is interpreted so
  that \code{marks[i]} is the mark attached to the point
  \code{(x[i],y[i])}. If the mark is a real number then \code{marks}
  should be a numeric vector, while if the mark takes only a finite
  number of possible values (e.g. colours or types) then
  \code{marks} should be a \code{factor}.
  
  See \code{\link{ppp.object}} for a description of the
  class \code{"ppp"}.

  Users would normally invoke \code{ppp} to create a point pattern,
  but the functions \code{\link{as.ppp}} and 
  \code{scanpp} may sometimes be convenient.
}
\seealso{
  \code{\link{ppp.object}},
  \code{\link{as.ppp}},
  \code{\link{owin.object}},
  \code{\link{owin}},
  \code{\link{as.owin}}
}
\examples{
  # some arbitrary coordinates in [0,1]
  x <- runif(20)
  y <- runif(20)

  # the following are equivalent
  X <- ppp(x, y, c(0,1), c(0,1))
  X <- ppp(x, y)
  X <- ppp(x, y, window=owin(c(0,1),c(0,1)))

  \dontrun{plot(X)}

  # marks
  m <- sample(1:2, 20, replace=TRUE)
  m <- factor(m, levels=1:2)
  X <- ppp(x, y, c(0,1), c(0,1), marks=m)
  \dontrun{plot(X)}

  # polygonal window
  X <- ppp(x, y, poly=list(x=c(0,10,0), y=c(0,0,10)))
  \dontrun{plot(X)}

  # copy the window from another pattern
  data(cells)
  X <- ppp(x, y, window=cells$window)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{ppp.object}
\alias{ppp.object}
\title{Class of Point Patterns}
\description{
  A class \code{"ppp"} to represent a two-dimensional point
  pattern. Includes information about the window in which the
  pattern was observed. Optionally includes marks.
}
\details{
  This class represents
  a two-dimensional point pattern dataset. It specifies
  \itemize{
    \item the locations of the points
    \item the window in which the pattern was observed
    \item optionally, a ``mark'' attached to each point
      (extra information such as a type label).
    }
  If \code{X} is an object of type \code{ppp},
  it contains the following elements:
  \tabular{ll}{
    \code{x} \tab vector of \eqn{x} coordinates of data points \cr
    \code{y} \tab vector of \eqn{y} coordinates of data points \cr
    \code{n} \tab number of points \cr
    \code{window} \tab window of observation \cr
                  \tab (an object of class \code{\link{owin}}) \cr
    \code{marks} \tab optional vector of marks
  }
  Users are strongly advised not to manipulate these entries
  directly.
  
  Objects of class \code{"ppp"}
  may be created by the function
  \code{\link{ppp}}
  and converted from other types of data by the function
  \code{\link{as.ppp}}.
  Note that you must always specify the window of observation;
  there is intentionally no default action of ``guessing'' the window
  dimensions from the data points alone.

  Standard point pattern datasets provided with the package
  include
  \code{\link{amacrine}},
  \code{\link{betacells}},
  \code{\link{bramblecanes}},
  \code{\link{cells}},
  \code{\link{demopat}},
  \code{\link{ganglia}},
  \code{\link{lansing}},
  \code{\link{longleaf}},
  \code{\link{nztrees}},
  \code{\link{redwood}},
  \code{\link{simdat}} and
  \code{\link{swedishpines}}.
  Use \code{\link{data}(xxx)} to access the dataset \code{xxx}.
  
  Point patterns may be scanned from your own data files by
  \code{\link{scanpp}} or by using \code{\link{read.table}} and
  \code{\link{as.ppp}}.
  
  They may be manipulated by the functions 
  \code{\link{subset.ppp}},
  \code{\link{[.ppp}} and
  \code{\link{superimpose}}.

  Point pattern objects can be plotted just by typing \code{plot(X)}
  which invokes the \code{plot} method for point pattern objects,
  \code{\link{plot.ppp}}. See \code{\link{plot.ppp}} for further information.

  There are also methods for \code{summary} and \code{print}
  for point patterns. Use \code{summary(X)} to see a useful description
  of the data.
  
  Patterns may be generated at random by
   \code{\link{runifpoint}},
   \code{\link{rpoispp}},
   \code{\link{rMaternI}},
   \code{\link{rMaternII}},
   \code{\link{rSSI}},
   \code{\link{rNeymanScott}},
   \code{\link{rMatClust}},
   and
   \code{\link{rThomas}}.

   Most functions which are intended to operate on a window
   (of class \code{\link{owin}})
   will, if presented with a \code{\link{ppp}} object instead,
   automatically extract the window information from the point pattern.
}
\seealso{
  \code{\link{owin}},
  \code{\link{ppp}},
  \code{\link{as.ppp}},
  \code{\link{[.ppp}}
}
\section{Warnings}{
  The internal representation of marks is likely to change in the
  next release of this package.
}
\examples{
  x <- runif(100)
  y <- runif(100)
  X <- ppp(x, y, c(0,1),c(0,1))
  X
  \dontrun{plot(X)}
  mar <- sample(1:3, 100, replace=TRUE)
  mm <- ppp(x, y, c(0,1), c(0,1), marks=mar)
  \dontrun{plot(mm)}
  # points with mark equal to 2
  ss <- mm[ mm$marks == 2 , ]
  \dontrun{plot(ss)}
  # left half of pattern 'mm'
  lu <- owin(c(0,0.5),c(0,1))
  mmleft <- mm[ , lu]
  \dontrun{plot(mmleft)}
  \dontrun{
  # input data from file
  qq <- scanpp("my.table", unit.square())

  # interactively build a point pattern
  plot(unit.square())
  X <- as.ppp(locator(10), unit.square())
  plot(X)
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{predict.ppm}
\alias{predict.ppm}
\title{Prediction from a Fitted Point Process Model}
\description{
Given a fitted point process model obtained by \code{\link{ppm}},	
evaluate the spatial trend and the conditional intensity of the model
at new locations.
}
\usage{
   predict.ppm(object, window, ngrid=NULL, locations=NULL,
   covariates=NULL, type="trend", \dots)
}
\arguments{
  \item{object}{
    A fitted point process model, typically obtained from
    the model-fitting algorithm \code{\link{ppm}}. An object of
    class \code{"ppm"} (see \code{\link{ppm.object}}).
  }
  \item{window}{
    window delimiting the locations where predictions
    should be computed. Defaults to the window of the
    original data used to fit the model \code{object}.
  }
  \item{ngrid}{dimensions (either (\code{ngrid[1]} by \code{ngrid[2]}
    or \code{ngrid} by \code{ngrid}) of a rectangular grid of locations
    inside \code{window} where predictions should be computed.
    (Incompatible with \code{locations})
  }
  \item{locations}{
    data giving the \eqn{x,y} coordinates (and marks, if required)
    at which predictions should be computed. Either a data frame
    or a binary image mask.
    (Incompatible with \code{ngrid})
  }
  \item{covariates}{
    Values of external covariates required by the model.
    Either a data frame or a list of images.
    See Details.
  }
  \item{type}{
    character string.
    Indicates which property of the fitted model should be predicted.
    Options are \code{"trend"} for the spatial trend, and 
    \code{"cif"} or \code{"lambda"} for the conditional intensity.
  }
  \item{\dots}{
    Ignored.
  }
}
\value{
  \emph{If \code{locations} is given and is a data frame:}
  a vector of predicted values for the spatial locations
  (and marks, if required) given in \code{locations}.

  \emph{If \code{ngrid} is given, or if \code{locations} is given
    and is a binary image mask:}
  If \code{object} is an unmarked point process,
  the result is an image object (of class \code{"im"}, see
  \code{\link{im.object}}) containing the predictions. 
  If \code{object} is a multitype point process,
  the result is a list of images, containing the predictions
  for each type at the same grid of locations.

  The ``predicted values'' are either values of the spatial trend
  (if \code{type="trend"}) or values of the conditional intensity
  (if \code{type="cif"} or \code{type="lambda"}).
}
\details{
  This function computes the spatial trend
  and the conditional intensity of a fitted spatial point process model.
  See Baddeley and Turner (2000) for explanation and examples.
 
  Given a point pattern dataset, we may fit
  a point process model to the data using the 
  model-fitting algorithm \code{\link{ppm}}. This
  returns an object of class \code{"ppm"} representing 
  the fitted point process model (see \code{\link{ppm.object}}).
  The parameter estimates in this fitted model can be read off 
  simply by printing the \code{ppm} object.
  The spatial trend and conditional intensity of the 
  fitted model are evaluated using this function \code{predict.ppm}.

  The default action is to create a rectangular grid of points
  in the observation window of the data point pattern, and evaluate
  the spatial trend and conditional intensity at these locations.

  Note that by ``spatial trend'' we mean the
  (exponentiated) first order potential
  and not the intensity of the process. [For example if we fit the
  stationary Strauss process with parameters
  \eqn{\beta}{beta} and \eqn{\gamma}{gamma},
  then the spatial trend is constant and equal to \eqn{\beta}{beta}. ]
  The conditional intensity \eqn{\lambda(u, X)}{lambda(u,X)} of the
  fitted model is evaluated at each required spatial location \eqn{u},
  with respect to the data point pattern \eqn{X}.

  If the argument \code{ngrid} is present, then
  predictions are performed at an \code{ngrid} by \code{ngrid}
  pixel grid of locations in the window \code{window}. 
  The result of prediction will be a pixel image or images.
  
  If \code{locations} is present, then predictions
  will be performed at the spatial locations given by
  this dataset. The result of prediction will be either a
  vector of values or a pixel image or a list of images, depending
  on the format of \code{locations}. 

  The argument \code{locations} may be either a data frame or list
  specifying arbitrary locations,
  or a binary image mask (an object of class \code{"owin"}
  with type \code{"mask"}) specifying (a subset of) a rectangular
  grid of locations. 

  If \code{locations} is a data frame or list, then it must contain
  vectors \code{locations$x} and \code{locations$y} specifying the
  \eqn{x,y} coordinates of the prediction locations. Additionally, if
  the model is a marked point process, then \code{locations} must also contain
  a factor \code{locations$marks} specifying the marks of the
  prediction locations. These vectors must have equal length.
  The result of prediction will be a vector of predicted values,
  of the same length.
  
  If \code{locations} is a binary image mask, then prediction will be
  performed at each pixel in this binary image where the pixel value
  is \code{TRUE} (in other words, at each pixel that is inside the
  window). If the fitted model is an unmarked point process, then the
  result of prediction will be an image. If the fitted model is a
  marked point process, then prediction will
  be performed for each possible value of the mark at each such
  location, and the result of prediction will be a 
  list of images, one for each mark value.
  
  If neither \code{ngrid} nor \code{locations} is given, then
  \code{ngrid} is assumed. It defaults to 50.

  The argument \code{covariates} gives the values of any spatial covariates
  at the prediction locations.
  If the trend formula in the fitted model 
  involves spatial covariates (other than
  the Cartesian coordinates \code{x}, \code{y})
  then \code{covariates} is required.

  The format and use of \code{covariates} are analogous to those of the
  argument of the same name in \code{\link{ppm}}.
  It is either a data frame or a list of images.
  
  If \code{covariates} is a list of images, then
  the names of the entries should correspond to
  the names of covariates in the model formula \code{trend}.
  Each entry in the list must be an image object (of class \code{"im"},
  see \code{\link{im.object}}).
  The software will look up
  the pixel values of each image at the quadrature points.

  If \code{covariates} is a data frame, then the
  \code{i}th row of \code{covariates}
  is assumed to contain covariate data for the \code{i}th location.
  When \code{locations} is a data frame,
  this just means that each row of \code{covariates} contains the
  covariate data for the location specified in the corresponding row of
  \code{locations}. When \code{locations} is a binary image
  mask, the row \code{covariates[i,]} must correspond to the location
  \code{x[i],y[i]} where \code{x = as.vector(raster.x(locations))}
  and \code{y = as.vector(raster.y(locations))}.

  Note that if you only want to use prediction in order to
  generate a plot of the predicted values,
  it may be easier to use \code{\link{plot.ppm}} which calls
  this function and plots the results.

}
\references{
  Baddeley, A. and Turner, R.
  Practical maximum pseudolikelihood for spatial point patterns.
  \emph{Australian and New Zealand Journal of Statistics}
  \bold{42} (2000) 283--322.
 
  Berman, M. and Turner, T.R. 
  Approximating point process likelihoods with GLIM.
  \emph{Applied Statistics} \bold{41} (1992) 31--38.
}
\seealso{
  \code{\link{ppm}},
  \code{\link{ppm.object}},
  \code{\link{plot.ppm}},
  \code{\link{print.ppm}},
  \code{\link{fitted.ppm}}
}
\section{Warnings}{
  The current implementation invokes \code{\link{predict.glm}}
  so that \bold{prediction is wrong} if the trend formula in
  \code{object} involves terms in \code{ns()},
  \code{bs()} or \code{poly()}.
  This is a weakness of \code{\link{predict.glm}} itself!
  
  Error messages may be very opaque,
  as they tend to come from deep in the workings of 
  \code{\link{predict.glm}}.
  If you are passing the \code{covariates} argument
  and the function crashes,
  it is advisable to start by checking that all the conditions 
  listed above are satisfied.
}
\examples{
  data(cells)
  m <- ppm(cells, ~ polynom(x,y,2), Strauss(0.05), rbord=0.05)
  trend <- predict(m, type="trend")
  \dontrun{
  image(trend)
  points(cells)
  }
  cif <- predict(m, type="cif")
  \dontrun{
  persp(cif)
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{print.im}
\alias{print.im}
\title{Print Brief Details of an Image}
\description{
  Prints a very brief description of a pixel image object.
}
\synopsis{
  print.im(x, \dots)
}
\usage{
 print.im(x)
 x
}
\arguments{
  \item{x}{Pixel image (object of class \code{"im"}).}
}
\details{
  A very brief description of the pixel image \code{x} is printed.

  This is a method for the generic function \code{\link{print}}.
}
\seealso{
  \code{\link{print}},
  \code{\link{im.object}},
  \code{\link{summary.im}}
}
\examples{
  data(letterR)
  U <- as.im(letterR)
  U
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{print.owin}
\alias{print.owin}
\title{Print Brief Details of a Spatial Window}
\description{
  Prints a very brief description of a window object.
}
\synopsis{
  print.owin(x, \dots)
}
\usage{
 print.owin(x)
 x
}
\arguments{
  \item{x}{Window (object of class \code{"owin"}).}
}
\details{
  A very brief description of the window \code{x} is printed.

  This is a method for the generic function \code{\link{print}}.
}
\seealso{
  \code{\link{print}},
  \code{\link{print.ppp}},
  \code{\link{summary.owin}}
}
\examples{
  owin()  # the unit square

  data(demopat)
  W <- demopat$window  
  W                    # just says it is polygonal
  as.mask(W)           # just says it is a binary image 

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{print.ppm}
\alias{print.ppm}
\title{Print a Fitted Point Process Model}
\description{
  Default \code{print} method for a fitted point process model.
}
\synopsis{
 print.ppm(x,\dots)
}
\usage{
 print.ppm(x)
 x
}
\arguments{
  \item{x}{
    A fitted point process model, typically obtained from
    the model-fittingg algorithm \code{\link{ppm}}.
    An object of class \code{"ppm"}.
  }
}
\value{
  none.
}
\details{
  This is the \code{print} method for the class \code{"ppm"}.
  It prints information about the fitted model in a sensible format.

  See \code{\link{ppm.object}} for details of the class \code{"ppm"}.
}
\seealso{
  \code{\link{ppm}},
  \code{\link{ppm.object}},
  \code{\link{plot.ppm}},
  \code{\link{predict.ppm}}
}
\examples{
 \dontrun{
 data(cells)
 Q <- quadscheme(cells)
 m <- ppm(Q, ~1, Strauss(0.05))
 m
 }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{print.ppp}
\alias{print.ppp}
\title{Print Brief Details of a Point Pattern Dataset}
\description{
  Prints a very brief description of a point pattern dataset.
}
\synopsis{
  print.ppp(x, \dots)
}
\usage{
 print.ppp(x)
 x
}
\arguments{
  \item{x}{Point pattern (object of class \code{"ppp"}).}
}
\details{
  A very brief description of the point pattern \code{x} is printed.

  This is a method for the generic function \code{\link{print}}.
}
\seealso{
  \code{\link{print}},
  \code{\link{print.owin}},
  \code{\link{summary.ppp}}
}
\examples{
  data(cells)      # plain vanilla point pattern
  cells

  data(lansing)    # multitype point pattern
  lansing          
  
  data(longleaf)    # numeric marks
  longleaf          

  data(demopat)     # weird polygonal window
  demopat
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{print.quad}
\alias{print.quad}
\title{Print a Quadrature Scheme}
\description{
  \code{print} method for a quadrature scheme.
}
\synopsis{
 print.quad(x,\dots)
}
\usage{
 print.quad(x)
 x
}
\arguments{
  \item{x}{
    A quadrature scheme object, typically obtained from
    \code{\link{quadscheme}}.
    An object of class \code{"quad"}.
  }
}
\value{
  none.
}
\details{
  This is the \code{print} method for the class \code{"quad"}.
  It prints simple information about the quadrature scheme.

  See \code{\link{quad.object}} for details of the class \code{"quad"}.
}
\seealso{
  \code{\link{quadscheme}},
  \code{\link{quad.object}},
  \code{\link{plot.quad}},
  \code{\link{summary.quad}}
}
\examples{
 data(cells)
 Q <- quadscheme(cells)
 Q
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{quad.object}
\alias{quad.object}
\title{Class of Quadrature Schemes}
\description{
  A class \code{"quad"} to represent a quadrature scheme.
}
\details{
  A (finite) quadrature scheme is a list of quadrature points
  \eqn{u_j}{u[j]} and associated weights \eqn{w_j}{w[j]}
  which is used to approximate an integral by a finite sum:
  \deqn{
    \int f(x) dx \approx \sum_j f(u_j) w_j
  }{
    integral(f(x) dx) ~= sum( f(u[j]) w[j] )
  }
  Given a point pattern dataset, a \emph{Berman-Turner}
  quadrature scheme is one which includes all these data points,
  as well as a nonzero number of other (``dummy'') points.

  These quadrature schemes are used to approximate the
  pseudolikelihood of a point process, in the method of
  Baddeley and Turner (2000) (see Berman and Turner (1992)).
  Accuracy and computation time both increase with the number of
  points in the quadrature scheme.

  An object of class \code{"quad"} represents a Berman-Turner
  quadrature scheme. It can be passed as an argument to
  the model-fitting function \code{\link{ppm}}, which
  requires a quadrature scheme.

  An object of this class contains at least the following elements:
  \tabular{ll}{
    \code{data}: \tab an object of class \code{"ppp"} \cr
                 \tab giving the locations (and marks) of the data points.\cr
    \code{dummy}: \tab an object of class \code{"ppp"} \cr
                 \tab giving the locations (and marks) of the dummy points.\cr
    \code{w}: \tab vector of nonnegative weights for the quadrature points\cr
  }
  Users are strongly advised not to manipulate these entries
  directly.
  
  The domain of quadrature is specified by \code{dummy$window}
  while the observation window (if this needs to be specified
  separately) is taken to be \code{data$window}. 

  The weights vector \code{w} may also have an attribute
  \code{attr(w, "zeroes")} equivalent to the logical vector
  \code{(w == 0)}. If this is absent then all points are known to
  have positive weights.
  
  To create an object of class \code{"quad"},
  users would typically call the
  high level function \code{\link{quadscheme}}.
  (They are actually
  created by the low level function \code{quad}.)
  
  Entries are extracted from a \code{"quad"} object by the functions
  \code{x.quad},
  \code{y.quad},
  \code{w.quad} and
  \code{marks.quad},
  which extract the \eqn{x} coordinates, \eqn{y} coordinates,
  weights, and marks, respectively. The function
  \code{n.quad} returns the total number of quadrature points
  (dummy plus data).

  An object of class \code{"quad"} can be converted into an ordinary
  point pattern by the function \code{\link{union.quad}} which simply
  takes the union of the data and dummy points.

  Quadrature schemes can be plotted using \code{\link{plot.quad}}
  (a method for the generic \code{\link{plot}}).
}
\seealso{
  \code{\link{quadscheme}},
  \code{\link{ppm}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{quad.ppm}
\alias{quad.ppm}
\title{Extract Quadrature Scheme Used to Fit a Point Process Model}
\description{
  Given a fitted point process model,
  this function extracts the 
  quadrature scheme used to fit the model.
}
\usage{
  quad.ppm(object)
}
\arguments{
  \item{object}{
    fitted point process model (an object of class \code{"ppm"}).
  }
}
\value{
  A quadrature scheme (object of class \code{"quad"}).
}
\details{
  An object of class \code{"ppm"} represents a point process model
  that has been fitted to data. It is typically produced by
  the model-fitting algorithm \code{\link{ppm}}.
  
  The \code{\link{ppm}} algorithm approximates the pseudolikelihood
  integral by a sum over a finite set of quadrature points,
  which is constructed by augmenting
  the original data point pattern by a set of ``dummy'' points.
  The fitted model object returned by \code{\link{ppm}}
  contains complete information about this quadrature scheme.
  See \code{\link{ppm}} or \code{\link{ppm.object}} for further
  information.
  
  This function extracts the quadrature scheme.
  A typical use of this function would be to inspect the quadrature scheme
  (points and weights) to gauge the accuracy of the approximation to the
  exact pseudolikelihood. 

  See \code{\link{ppm.object}} for a list of all operations that can be
  performed on objects of class \code{"ppm"}.
  See \code{\link{quad.object}} for a list of all operations that can be
  performed on objects of class \code{"quad"}.
}
\seealso{
  \code{\link{ppm.object}},
  \code{\link{quad.object}},
  \code{\link{ppm}}
}
\examples{
 data(cells)
 fit <- ppm(cells, ~1, Strauss(r=0.1), rbord=0.1)
 Q <- quad.ppm(fit)
 \dontrun{plot(Q)}
 Q$data$n
 Q$dummy$n
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{quadscheme}
\alias{quadscheme}
\title{Generate a Quadrature Scheme from a Point Pattern}
\description{
  Generates a quadrature scheme (an object of class \code{"quad"})
  from point patterns of data and dummy points.
}
\usage{
 quadscheme(data, dummy, method="grid", \dots)
}
\arguments{
  \item{data}{
    The observed data point pattern.
    An object of class \code{"ppp"}
    or in a format recognised by \code{\link{as.ppp}()}
  }
  \item{dummy}{
    The pattern of dummy points for the quadrature. 
    An object of class \code{"ppp"}
    or in a format recognised by \code{\link{as.ppp}()}
    Defaults to \code{default.dummy(data, ...)}
  }
  \item{method}{
    The name of the method for calculating quadrature weights: either
    \code{"grid"} or \code{"dirichlet"}.
  }
  \item{\dots}{
    Parameters of the weighting method (see below)
    and parameters for constructing the dummy points if necessary.
  }
} 
\value{
  An object of class \code{"quad"} describing the quadrature scheme
  (data points, dummy points, and quadrature weights)
  suitable as the argument \code{Q} of the function \code{\link{ppm}()} for
  fitting a point process model.
}
\details{
  This is the primary method for producing a quadrature schemes
  for use by \code{\link{ppm}}.
  
  The function \code{\link{ppm}} fits a point process model to an
  observed point pattern using 
  the Berman-Turner quadrature approximation (Berman and Turner, 1992;
  Baddeley and Turner, 2000) to the pseudolikelihood of the model. 
  It requires a quadrature scheme consisting of 
  the original data point pattern, an additional pattern of dummy points,
  and a vector of quadrature weights for all these points.
  Such quadrature schemes are represented by objects of class
  \code{"quad"}. See \code{\link{quad.object}} for a description of this class.

  Quadrature schemes are created by the function
  \code{quadscheme}.
  The arguments \code{data} and \code{dummy} specify the data and dummy
  points, respectively. There is a sensible default for the dummy 
  points (provided by \code{\link{default.dummy}}).
  Alternatively the dummy points
  may be specified arbitrarily and given in any format recognised by
  \code{\link{as.ppp}}.
  There are also functions for creating dummy patterns
  including \code{\link{corners}},
  \code{\link{gridcentres}},
  \code{\link{stratrand}} and
  \code{\link{spokes}}.
 
  The quadrature region is the region over which we are
  integrating, and approximating integrals by finite sums.
  If \code{dummy} is a point pattern object (class \code{"ppp"})
  then the quadrature region is taken to be \code{dummy$window}.
  If \code{dummy} is just a list of \eqn{x, y} coordinates
  then the quadrature region defaults to the observation window
  of the data pattern, \code{data$window}.

  If \code{dummy} is missing, then the optional arguments
  (for \code{...}) include an argument \code{nd}.
  An \code{nd[1]} by \code{nd[2]} grid of
  dummy points is generated by \code{\link{default.dummy}}.
  
  If \code{method = "grid"} then the optional arguments (for \code{\dots}) are 
  \code{(nd, ntile)}.
  The quadrature region (see below) is divided into
  an \code{ntile[1]} by \code{ntile[2]} grid of rectangular tiles.
  The weight for each
  quadrature point is the area of a tile divided by the number of
  quadrature points in that tile. 
 
  If \code{method="dirichlet"} then the optional arguments are
  \code{(exact=TRUE, nd)}.
  The quadrature points (both data and dummy) are used to construct the
  Dirichlet tessellation. The quadrature weight of each point is the
  area of its Dirichlet tile inside the quadrature region.
  If \code{exact == TRUE} then this area is computed exactly
  using the package \code{deldir}; otherwise it is computed
  approximately by discretisation.
}
\references{
  Baddeley, A. and Turner, R.
  Practical maximum pseudolikelihood for spatial point patterns.
  \emph{Australian and New Zealand Journal of Statistics}
  \bold{42} (2000) 283--322.
 
  Berman, M. and Turner, T.R. 
  Approximating point process likelihoods with GLIM.
  \emph{Applied Statistics} \bold{41} (1992) 31--38.
}
\seealso{
  \code{\link{ppm}},
  \code{\link{as.ppp}},
  \code{\link{quad.object}},
  \code{\link{gridweights}},
  \code{\link{dirichlet.weights}},
  \code{\link{corners}},
  \code{\link{gridcentres}},
  \code{\link{stratrand}},
  \code{\link{spokes}}
}
\examples{
  data(simdat)

  # grid weights
  Q <- quadscheme(simdat)
  Q <- quadscheme(simdat, , "grid")
  Q <- quadscheme(simdat, nd=50)           # 1 dummy point per tile
  Q <- quadscheme(simdat, ntile=25, nd=50) # 4 dummy points per tile

  # Dirichlet weights
  Q <- quadscheme(simdat, , "dirichlet", exact=FALSE)

  # random dummy pattern
  D <- runifpoint(250, simdat$window)
  Q <- quadscheme(simdat, D, "dirichlet", exact=FALSE)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rMatClust}
\alias{rMatClust}
\title{Simulate Matern Cluster Process}
\description{
  Generate a random point pattern using the
  Mat\'ern Cluster Process.
}
\usage{
 rMatClust(lambda, r, mu, win = owin(c(0,1),c(0,1)))
}
\arguments{
  \item{lambda}{
    Intensity of the Poisson process of cluster centres.
    A single positive number, a function, or a pixel image.
  }
  \item{r}{
    Radius parameter of the clusters.
  }
  \item{mu}{
    Mean number of points per cluster.
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This algorithm generates a realisation of Mat\'ern's cluster process
  inside the window \code{win}. The process is constructed by first
  generating a Poisson point process of ``parent'' points 
  with intensity \code{lambda}. Then each parent point is
  replaced by a random cluster of points, the number of points in each
  cluster being random with a Poisson (\code{mu}) distribution,
  and the points being placed independently and uniformly inside
  a disc of radius \code{r} centred on the parent point.

  In this implementation, parent points are not restricted to lie in the
  window; the parent process is effectively the uniform
  Poisson process on the infinite plane.
}
\seealso{
\code{\link{rpoispp}},
\code{\link{rNeymanScott}}
}
\examples{
 pp <- rMatClust(10, 0.05, 4)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rMaternI}
\alias{rMaternI}
\title{Simulate Matern Model I}
\description{
  Generate a random point pattern using the
  Mat\'ern Model I inhibition process.
}
\usage{
 rMaternI(lambda, r, win = owin(c(0,1),c(0,1)))
}
\arguments{
  \item{lambda}{
    Intensity of the Poisson process of proposal points.
    A single positive number.
  }
  \item{r}{
    Inhibition distance.
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This algorithm generates a realisation of Mat\'ern's Model I
  inhibition process 
  inside the window \code{win}.

  The process is constructed by first
  generating a uniform Poisson point process of ``proposal'' points 
  with intensity \code{lambda} inside the window.
  A proposal point is deleted if it lies within \code{r} units' distance
  of another proposal point. Otherwise it is retained.
  The retained points constitute Mat\'ern's Model I.
}
\seealso{
\code{\link{rpoispp}},
\code{\link{rMatClust}}
}
\examples{
 pp <- rMaternI(20, 0.05)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rMaternII}
\alias{rMaternII}
\title{Simulate Matern Model II}
\description{
  Generate a random point pattern using the
  Mat\'ern Model II inhibition process.
}
\usage{
 rMaternII(lambda, r, win = owin(c(0,1),c(0,1)))
}
\arguments{
  \item{lambda}{
    Intensity of the Poisson process of proposal points.
    A single positive number.
  }
  \item{r}{
    Inhibition distance.
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This algorithm generates a realisation of Mat\'ern's Model II
  inhibition process 
  inside the window \code{win}.

  The process is constructed by first
  generating a uniform Poisson point process of ``proposal'' points 
  with intensity \code{lambda} inside the window.
  Then each proposal point is marked by an ``arrival time'', a number
  uniformly distributed in \eqn{[0,1]} independently of other variables.
  
  A proposal point is deleted if it lies within \code{r} units' distance
  of another proposal point \emph{that has an earlier arrival time}.
  Otherwise it is retained.
  The retained points constitute Mat\'ern's Model II.

  The difference between Mat\'ern's Model I and II is the italicised
  statement above. Model II has a higher intensity
  for the same parameter values.
}
\seealso{
\code{\link{rpoispp}},
\code{\link{rMatClust}},
\code{\link{rMaternI}}
}
\examples{
 pp <- rMaternII(20, 0.05)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rNeymanScott}
\alias{rNeymanScott}
\title{Simulate Neyman-Scott Process}
\description{
  Generate a random point pattern using the
  Neyman-Scott cluster process.
}
\usage{
 rNeymanScott(lambda, rmax, rcluster, win = owin(c(0,1),c(0,1)), \dots, lmax=NULL)
}
\arguments{
  \item{lambda}{
    Intensity of the Poisson process of cluster centres.
    A single positive number, a function, or a pixel image.
  }
  \item{rmax}{
    Maximum radius of a random cluster.
  }
  \item{rcluster}{
    A function which generates random clusters.
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
  }
  \item{\dots}{
    Arguments passed to \code{rcluster}
  }
  \item{lmax}{
    Optional. Upper bound on the values of \code{lambda}
    when \code{lambda} is a function or pixel image.
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This algorithm generates a realisation of the
  general Neyman-Scott process, with the cluster mechanism
  given by the function \code{rcluster}. 
  The clusters must have a finite maximum possible radius \code{rmax}.

  First, the algorithm
  generates a Poisson point process of ``parent'' points 
  with intensity \code{lambda}. Here \code{lambda} may be a single
  positive number, a function \code{lambda(x, y)}, or a pixel image
  object of class \code{"im"} (see \code{\link{im.object}}).
  See \code{\link{rpoispp}} for details.
  
  Second, each parent point is
  replaced by a random cluster of points, created by calling the
  function \code{rcluster}.

  The function \code{rcluster} should expect to be called as
  \code{rcluster(xp[i],yp[i],\dots)} for each parent point at a location
  \code{(xp[i],yp[i])}. The return value of \code{rcluster}
  should be a list with elements
  \code{x,y} which are vectors of equal length giving the absolute
  \eqn{x} and \code{y} coordinates of the points in the cluster.
}
\seealso{
\code{\link{rpoispp}},
\code{\link{rMatClust}}
}
\examples{
  nclust <-  function(x0, y0, radius, n) {
                           return(runifdisc(n, radius, x0, y0))
                         }
  X <- rNeymanScott(10, 0.2, nclust, radius=0.2, n=5)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rSSI}
\alias{rSSI}
\title{Simple Sequential Inhibition}
\description{
  Generate a random point pattern using the
  Simple Sequential Inhibition (SSI) process.
}
\usage{
 rSSI(r, n, win = owin(c(0,1),c(0,1)), giveup = 1000)
}
\arguments{
  \item{r}{
    Inhibition distance.
  }
  \item{n}{
    Number of points to generate.
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
  }
  \item{giveup}{
    Number of rejected proposals after which the algorithm should terminate.
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This algorithm generates a realisation of the Simple Sequential
  Inhibition point process 
  inside the window \code{win}.

  Starting with an empty window, the algorithm adds points
  one-by-one. Each new point is generated uniformly in the window
  and independently of preceding points. If the new point lies
  closer than \code{r} units from an existing point, then it is rejected
  and another random point is generated.

  The algorithm terminates either when the desired number \code{n}
  of points is reached, or when the current point configuration
  has not changed for \code{giveup} iterations.
}
\seealso{
\code{\link{rpoispp}},
\code{\link{rMaternI}},
\code{\link{rMaternII}}
}
\examples{
 pp <- rSSI(0.05, 200)
 \dontrun{plot(pp)}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rThomas}
\alias{rThomas}
\title{Simulate Thomas Process}
\description{
  Generate a random point pattern using the
  Thomas cluster process.
}
\usage{
 rThomas(lambda, sigma, mu, win = owin(c(0,1),c(0,1)))
}
\arguments{
  \item{lambda}{
    Intensity of the Poisson process of cluster centres.
    A single positive number.
  }
  \item{sigma}{
    Standard deviation of displacement of a point from its cluster centre.
  }
  \item{mu}{
    Expected number of points per cluster.
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This algorithm generates a realisation of the
  Thomas process, a special case of the Neyman-Scott process.
  
  The algorithm 
  generates a uniform Poisson point process of ``parent'' points 
  with intensity \code{lambda}. Then each parent point is
  replaced by a random cluster of points, the number of points
  per cluster being Poisson (\code{mu}) distributed, and their
  positions being isotropic Gaussian displacements from the
  cluster parent location.
}
\seealso{
\code{\link{rpoispp}},
\code{\link{rNeymanScott}}
}
\examples{
  X <- rThomas(10, 0.2, 5)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{raster.x}
\alias{raster.x}
\alias{raster.y}
\title{Cartesian Coordinates for a Pixel Raster}
\description{
  Returns a matrix giving the \eqn{x} (or \eqn{y}) coordinates
  of each pixel in a binary pixel image.
}
\synopsis{
  raster.x(w)
}
\usage{
 raster.x(w)
 raster.y(w)
}
\arguments{
  \item{w}{A window (an object of class \code{"owin"})
    of type \code{"mask"} representing a binary pixel image.
  }
}
\value{
  A matrix of the same dimensions as the pixel grid in \code{w},
  and giving the value of the \eqn{x} (or \eqn{y}) coordinate
  of each pixel in the raster.
}
\details{
  The argument \code{w} should be a window (an object of class
  \code{"owin"}, see \code{\link{owin.object}} for details).
  A window of type \code{"mask"} represents a binary pixel image.
  This function returns a matrix of the same dimensions as the
  binary pixel image itself, with entries giving the \eqn{x} coordinate
  (for \code{raster.x}) or \eqn{y} coordinate (for \code{raster.y})
  of each pixel in the image.
}
\seealso{
  \code{\link{owin}},
  \code{\link{as.mask}}
}
\examples{
  u <- owin(c(-1,1),c(-1,1)) # square of side 2
  w <- as.mask(u, eps=0.01) # 200 x 200 grid
  X <- raster.x(w)
  Y <- raster.y(w)
  disc <- owin(c(-1,1), c(-1,1), mask=(X^2 + Y^2 <= 1))
  \dontrun{plot(disc)}
  # approximation to the unit disc
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{reduced.sample}
\alias{reduced.sample}
\title{Reduced Sample Estimator using Histogram Data}
\description{
  Compute the Reduced Sample estimator of a survival time distribution
  function, from histogram data
}
\usage{
  reduced.sample(nco, cen, ncc, show=FALSE)
}
\arguments{
  \item{nco}{vector of counts giving the histogram of
    uncensored observations (those survival times that are less than or
    equal to the censoring time)
  }
  \item{cen}{vector of counts giving the histogram of
    censoring times
  }
  \item{ncc}{vector of counts giving the histogram of
    censoring times for the uncensored observations only 
  }
  \item{show}{Logical value controlling the amount of detail
    returned by the function value (see below)
  }
}
\value{
  If \code{show = FALSE}, a numeric vector giving the values of
  the reduced sample estimator.
  If \code{show=TRUE}, a list with three components which are
  vectors of equal length,
  \item{rs}{Reduced sample estimate of the survival time c.d.f. \eqn{F(t)}
  }
  \item{numerator}{numerator of the reduced sample estimator
  }
  \item{denominator}{denominator of the reduced sample estimator
  }
}
\details{
  This function is needed mainly for internal use in \code{spatstat},
  but may be useful in other applications where you want to form the
  reduced sample estimator from a huge dataset.

  Suppose \eqn{T_i}{T[i]} are the survival times of individuals
  \eqn{i=1,\ldots,M} with unknown distribution function \eqn{F(t)}
  which we wish to estimate. Suppose these times are right-censored
  by random censoring times \eqn{C_i}{C[i]}.
  Thus the observations consist of right-censored survival times
  \eqn{\tilde T_i = \min(T_i,C_i)}{T*[i] = min(T[i],C[i])}
  and non-censoring indicators
  \eqn{D_i = 1\{T_i \le C_i\}}{D[i] = 1(T[i] <= C[i])}
  for each \eqn{i}.

  If the number of observations \eqn{M} is large, it is efficient to
  use histograms.
  Form the histogram \code{cen} of all censoring times \eqn{C_i}{C[i]}.
  That is, \code{obs[k]} counts the number of values 
  \eqn{C_i}{C[i]} in the interval
  \code{(breaks[k],breaks[k+1]]} for \eqn{k > 1}
  and \code{[breaks[1],breaks[2]]} for \eqn{k = 1}.
  Also form the histogram \code{nco} of all uncensored times,
  i.e. those \eqn{\tilde T_i}{T*[i]} such that \eqn{D_i=1}{D[i]=1},
  and the histogram of all censoring times for which the survival time
  is uncensored,
  i.e. those \eqn{C_i}{C[i]} such that \eqn{D_i=1}{D[i]=1}.
  These three histograms are the arguments passed to \code{kaplan.meier}.

  The return value \code{rs} is the reduced-sample estimator
  of the distribution function \eqn{F(t)}. Specifically,
  \code{rs[k]} is the reduced sample estimate of \code{F(breaks[k+1])}.
  The value is exact, i.e. the use of histograms does not introduce any
  approximation error.
}
\seealso{
  \code{\link{kaplan.meier}},
  \code{\link{km.rs}}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
  }
\keyword{spatial}


\eof
\name{redwood}
\alias{redwood}
\title{
  California Redwoods Point Pattern (Ripley's Subset)
}
\description{
  Locations of 62 seedlings and saplings 
  of California redwood trees.
 
  The data represent the locations of 62 seedlings and saplings 
  of California redwood trees in a square sampling region.  
  They originate from Strauss (1975);
  the present data are a subset extracted by Ripley (1977) 
  in a subregion that has been rescaled to a unit square.
 
  There are many further analyses of this dataset. It is often used as a 
  canonical example of a clustered point pattern
  (see e.g. Diggle, 1983).

  The original, full redwood dataset is supplied in the \code{spatstat}
  library as \code{redwoodfull}.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of tree locations.
  The window has been rescaled to the unit square.

  See \code{\link{ppp.object}} for details of the format of a
  point pattern object.
}
\usage{data(redwood)}
\source{Strauss (1975), subset extracted by Ripley (1977)}
\seealso{
  \code{\link{redwoodfull}}
}
\references{
  Diggle, P.J. (1983)
  \emph{Statistical analysis of spatial point patterns}.
  Academic Press.

  Ripley, B.D. (1977)
  Modelling spatial patterns (with discussion).
  \emph{Journal of the Royal Statistical Society, Series B}
  \bold{39}, 172--212.

  Strauss, D.J. (1975)
  A model for clustering.
  \emph{Biometrika} \bold{63}, 467--475.
}
\keyword{datasets}

\eof
\name{redwoodfull}
\alias{redwoodfull}
\alias{redwoodfull.extra}
\title{
  California Redwoods Point Pattern (Entire Dataset)
}
\description{
  These data represent the locations of 195 seedlings and saplings 
  of California redwood trees in a square sampling region.  
  They were described and analysed by Strauss (1975).
  This is the ``\bold{full}'' dataset; most writers have
  analysed a subset extracted by Ripley (1977)
  which is available as \code{\link{redwood}}.
 
  Strauss (1975) divided the sampling region into two subregions I and II
  demarcated by a diagonal line across the region. The spatial pattern
  appears to be slightly regular in region I and strongly clustered in 
  region II.

  The dataset \code{redwoodfull} contains the full point pattern
  of 195 trees. 
  The auxiliary information about the subregions is contained in 
  \code{redwoodfull.extra}, which is a list with entries
  \tabular{ll}{
    \code{diag}\tab The coordinates of the diagonal boundary\cr
               \tab between regions I and II \cr
    \code{regionI} \tab Region I as a window object \cr
    \code{regionII} \tab Region II as a window object \cr
    \code{regionR} \tab Ripley's subrectangle (approximate) \cr
    \code{plot}    \tab Function to plot the full data and auxiliary markings
  }

  Ripley (1977) extracted a subset of these data, containing 62 points,
  lying within a square subregion which overlaps regions I and II.
  He rescaled the data to the unit square. 
  This has been re-analysed many times, and is the dataset usually known as
  ``the redwood data'' in the spatial statistics literature.
  The exact dataset used by Ripley is supplied in the \code{spatstat}
  library as \code{\link{redwood}}.
  There are some minor inconsistencies with
  \code{redwood} since it originates from a different digitisation.

  The approximate position of the square chosen by Ripley
  within the \code{redwoodfull} pattern
  is indicated by the window \code{redwoodfull.extra$regionR}.
} 
\format{
  The dataset \code{redwoodfull} is an object of class \code{"ppp"}
  representing the point pattern of tree locations.
  The window has been rescaled to the unit square.
  See \code{\link{ppp.object}} for details of the format of a
  point pattern object.

  The dataset \code{redwoodfull.extra} is a list with entries
  \tabular{ll}{
    \code{diag}\tab coordinates of endpoints of a line,\cr
               \tab in format \code{list(x=numeric(2),y=numeric(2))} \cr
    \code{regionI} \tab a window object \cr
    \code{regionII} \tab a window object \cr
    \code{regionR} \tab a window object \cr
    \code{plot}    \tab Function with no arguments
  }
}
\usage{data(redwoodfull)}
\examples{
       data(redwoodfull)
       plot(redwoodfull)
       redwoodfull.extra$plot()
       # extract the pattern in region II 
       redwoodII <- redwoodfull[, redwoodfull.extra$regionII]
}
\source{Strauss (1975). The plot of the data published by Strauss (1975)
  was scanned and digitised by Sandra Pereira, University of
  Western Australia, 2002.
}
\seealso{
  \code{\link{redwood}}
}
\references{
  Diggle, P.J. (1983)
  \emph{Statistical analysis of spatial point patterns}.
  Academic Press.

  Ripley, B.D. (1977)
  Modelling spatial patterns (with discussion).
  \emph{Journal of the Royal Statistical Society, Series B}
  \bold{39}, 172--212.

  Strauss, D.J. (1975)
  A model for clustering.
  \emph{Biometrika} \bold{63}, 467--475.
}
\keyword{datasets}

\eof
\name{ripras}
\alias{ripras}
\title{Estimate window from points alone}
\description{
  Given an observed pattern of points,
  computes the Ripley-Rasson estimate of 
  the spatial domain from which they came.
}
\usage{
 ripras(x, y=NULL)
}
\arguments{
  \item{x}{vector of \code{x} coordinates of observed points,
	   or a 2-column matrix giving \code{x,y} coordinates,
	   or a list with components \code{x,y} giving coordinates.}
  \item{y}{(optional) vector of \code{y} coordinates of observed points,
           if \code{x} is a vector.}
}
\value{
  A window (an object of class \code{"owin"}).
}
\details{
  Given an observed pattern of points with coordinates 
  given by \code{x} and \code{y}, this function computes 
  an estimate due to Ripley and Rasson (1977) of the
  spatial domain from which the points came. 

  The points are
  assumed to have been generated independently and uniformly
  distributed inside an unknown domain \eqn{D}. The maximum
  likelihood estimate of \eqn{D} is the convex hull of the 
  points. Analogously to the problems of estimating the endpoint
  of a uniform distribution, the MLE is not optimal.
  Ripley and Rasson's estimator is a rescaled copy of the convex hull,
  centred at the centroid of the convex hull.
  The scaling factor is 
  \eqn{1/sqrt(1 - m/n)}{1/\sqrt{1 - \frac m n}}
  where \eqn{n} is the number of data points and 
  \eqn{m} the number of vertices of the convex hull.
}
\seealso{
  \code{\link{owin}},
  \code{\link{as.owin}}
}
\examples{
  \dontrun{
  plot(owin())
  }
  x <- runif(30)
  y <- runif(30)
  \dontrun{points(x,y)}
  w <- ripras(x,y)
  \dontrun{
  plot(w, box=FALSE)
  points(x,y)
  }
}
\references{
  Ripley, B.D. and Rasson, J.-P. (1977)
  Finding the edge of a Poisson forest.
  \emph{Journal of Applied Probability},
  \bold{14}, 483 -- 491.
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}





\eof
\name{rmh}
\alias{rmh}
\title{Simulate point patterns using the Metropolis-Hastings algorithm.}
\description{
  Generic function for running the Metropolis-Hastings algorithm
  to produce simulated realisations of a point process model.
}

\usage{rmh(model, \dots)}

\arguments{
  \item{model}{The point process model to be simulated.
  }
  \item{\dots}{Further arguments controlling the simulation.
  }
}

\details{
  The Metropolis-Hastings algorithm can be used to
  generate simulated realisations from a wide range of
  spatial point processes. For caveats, see below.
  
  The function \code{rmh} is generic; it has methods
  \code{\link{rmh.ppm}} (for objects of class \code{"ppm"})
  and  \code{\link{rmh.default}} (the default).
  The actual implementation of the Metropolis-Hastings algorithm is
  contained in \code{\link{rmh.default}}.
  For details of its use, see 
  \code{\link{rmh.ppm}} or \code{\link{rmh.default}}.

  [If the model is a Poisson process, then Metropolis-Hastings
  is not used; the Poisson model is generated directly
  using \code{\link{rpoispp}} or \code{\link{rmpoispp}}.]

  In brief, the Metropolis-Hastings algorithm is a Markov Chain,
  whose states are spatial point patterns, and whose limiting
  distribution is the desired point process. After
  running the algorithm for a very large number of iterations,
  we may regard the state of the algorithm as a realisation
  from the desired point process.

  However, there are difficulties in deciding whether the
  algorithm has run for ``long enough''. The convergence of the
  algorithm may indeed be extremely slow. No guarantees of
  convergence are given!

  While it is fashionable to decry the Metropolis-Hastings algorithm
  for its poor convergence and other properties, it has the advantage
  of being easy to implement for a wide range of models.
}

\value{
  A point pattern, in the form of an object of class \code{"ppp"}.
  See \code{\link{rmh.default}} for details.
}

\seealso{
  \code{\link{rmh.default}}
}

\examples{
    # See examples in rmh.default and rmh.ppm
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rmh.default}
\alias{rmh.default}
\title{Simulate Point Process Models using the Metropolis-Hastings Algorithm.}
\description{
  Generates a random point pattern, simulated from
  a chosen point process model, using the Metropolis-Hastings
  algorithm. 
}

\usage{rmh.default(model,start,control,verbose=TRUE,\dots) }

\arguments{
  \item{model}{A named list of objects specifying the point process model
    that is to be simulated, having (some of) the following components:
    \describe{
      \item{cif}{Character string specifying the choice of model}
      \item{par}{Parameters of the model}
      \item{w}{Spatial window in which to simulate}
      \item{trend}{Either a \bold{function} whose first two arguments
      are \code{x} and \code{y} (the coordinates of an abitrary
      point in the observation window) which calculates the value
      of the trend at the point \code{(x,y)} or an \bold{image}
      which specifies the value of the trend at (a grid of) points
      in the observation window.  Auxiliary arguments may be passed
      to the \code{trend} function via the \dots argument.
      If the model being simulated is multitype, then \code{trend}
      may be a \bold{list} of functions or images, with as many entries
      as there are types.}
      \item{types}{A vector of the possible levels of a factor forming
      the marks for a multitype process.  If the model being simulated
      is multitype and \code{types} is not specified, then this vector
      defaults to \code{1:ntypes} where \code{ntypes} is the number of
      types.}
    }
    See \emph{Details} for details.
  }
  \item{start}{List of parameters determining the initial state of
    the algorithm:
    \describe{
      \item{n.start}{number of initial points (randomly generated)}
      \item{x.start}{initial point pattern configuration}
      \item{iseed}{vector of seeds for random number generator}
    }
    The parameters \code{n.start} and \code{x.start} are incompatible;
    precisely \bold{one} of them should be specified.
    See \emph{Details} for details.
  }
  \item{control}{List of parameters controlling the iterative behaviour
    and termination of the algorithm:
    \describe{
      \item{p}{Probability of proposing a shift (as against a birth/death)}
      \item{q}{Conditional probability of proposing a death given that a
	birth or death will be proposed}
      \item{nrep}{Total number of steps (proposals) of Metropolis-Hastings
	algorithm that should be run}
      \item{expand}{Factor by which the window will be expanded}
      \item{periodic}{(Logical) whether to apply periodic boundary
	conditions}
      \item{ptypes}{For multitype point processes, the distribution of
	the mark attached to a new random point (when a birth is
	proposed)}
      \item{fixall}{(Logical) for multitype point processes,
	whether to fix the number of points of each type.}
      \item{nverb}{Progress reports will be printed every \code{nverb}
	iterations}
    }
    See \emph{Details} for details.
  }
  \item{verbose}{A logical scalar; if \code{verbose} is TRUE then
   warnings are printed out whenever the storage space alloted to
   the underlying Fortran code, to hold the generated points, gets
   increased.  If it is FALSE then this process proceeds silently.}
  \item{\dots}{Further arguments, e.g. to be passed to \bold{trend}
    functions.}
}

\value{A point pattern (an object of class \code{"ppp"}, see
  \code{\link{ppp.object}}).

  The returned value has an attribute \code{info} consisting of
  arguments supplied to the function (or default values of arguments
  which were not explicitly supplied).  These are given so that it
  is possible to reconstruct exactly the manner in which the pattern
  was generated.  The components of \code{info} are \code{model},
  \code{start}, and \code{control} which in turn are lists:

  \code{model=list(cif, par, trend)}
  
  \code{start=list(n.start,x.start,iseed)}

  \code{control=list(p=p,q=q,nrep=nrep,expand,periodic,
                     ptypes=ptypes,fixall=fixall)}

  Note that only one of \code{x.start} and \code{x.start} appear in
  in the \code{start} list.
}

\details{
  This function generates simulated realisations from any of a range of
  spatial point processes, using the Metropolis-Hastings algorithm.
  It is the default method for the generic function \code{rmh}.

  This function executes a Metropolis-Hastings algorithm
  with birth, death and shift proposals as described in
  Geyer and Moller (1994).

  The argument \code{model} specifies the point process model to be
  simulated. It is a list with the following components:

  \describe{
    \item{cif}{A character string specifying the choice of
      interpoint interaction for the point process. The current options are
      \describe{
	\item{\code{'strauss'}}{The Strauss process}
	\item{\code{'straush'}}{The Strauss process with hard core}
	\item{\code{'sftcr'}}{The Softcore process}
	\item{\code{'straussm'}}{ The multitype Strauss process}
        \item{\code{'straushm'}}{Multitype Strauss process with hard core}
        \item{\code{'dgs'}}{Diggle, Gates and Stibbard (1987) process}
	\item{\code{'diggra'}}{Diggle and Gratton (1984) process}
	\item{\code{'geyer'}}{Saturation process (Geyer, 1999).}
	\item{\code{'lookup'}}{General isotropic pairwise interaction process,
	with the interaction function specified via a ``lookup table''.}
      }
      See the section \bold{Extensions} for the possibility of extending
      this list of options.
    }
    \item{par}{
      A vector (or a list if the pattern is multitype) providing
      a set of parameter values appropriate to the conditional
      intensity function being invoked.  The structure of \code{par}
      should be as follows, for each of the available conditional
      intensity functions:

      \describe{
	\item{strauss:}{
	  (Strauss process.) A \bold{named} vector with components
	  \code{beta,gamma,r} which are respectively the ``base''
	  intensity, the pair-wise interaction parameter and the
	  interaction radius.  Note that \code{gamma} must be less than
	  or equal to 1.
	}
	\item{straush:}{
	  (Strauss process with hardcore.) A \bold{named} vector with
	  entries \code{beta,gamma,r,hc} where \code{beta}, \code{gamma},
	  and \code{r} are as for the Strauss process, and \code{hc} is
	  the hardcore radius.  Of course \code{hc} must be less than
	  \code{r}.
	}
	\item{sftcr:}{
	  (Softcore process.) A \bold{named} vector with components
	  \code{beta,sigma,kappa}.  Again
	  \code{beta} is a ``base'' intensity.  The pairwise
	  interaction between two points \eqn{u \neq v}{u != v} is
	  \deqn{
	    \exp \left \{
	    - \left ( \frac{\sigma}{||u-v||} \right )^{2/\kappa}
	    \right \}
	  }{-(sigma/||u-v||)^(2/kappa)}
	  Note that it is necessary that \eqn{0 < \kappa < 1}{0 < kappa <1}.
	}
	\item{straussm:}{
	  (Multitype Strauss process.) A \bold{named} list with components
	  \itemize{
	    \item
	    \code{beta}: 
	      A vector of ``base'' intensities, one for each possible
	      type.
	    \item
	    \code{gamma}:
	      A \bold{symmetric} matrix of interaction parameters,
	      with \eqn{\gamma_{ij}}{gamma_ij} pertaining to the interaction between
	      type \eqn{i} and type \eqn{j}.
	    \item
	    \code{radii}:
	      A \bold{symmetric} matrix of interaction radii, with
	      entries \eqn{r_{ij}}{r_ij} pertaining to the interaction between type
	      \eqn{i} and type \eqn{j}.
	   }
	 }
	\item{straushm:}{
	  (Multitype Strauss process with hardcore.)
	  A \bold{named} list with components \code{beta} and \code{gamma}
	  as for \code{straussm} and
	  \bold{two} ``radii'' components:
	  \itemize{
            \item \code{iradii}: the interaction radii
            \item \code{hradii}: the hardcore radii
	  }
	  which are both symmetric matrices of nonnegative numbers.
	  The entries of \code{hradii} must be less than the
	  corresponding entries
	  of \code{iradii}.
	}
	\item{dgs:}{
	  (Diggle, Gates, and Stibbard process.
	  See Diggle, Gates, and Stibbard (1987))
	  A \bold{named} vector with components
	  \code{beta} and \code{rho}.  This process has pairwise interaction
	  function equal to
	  \deqn{
	    e(t) = \sin^2\left(\frac{\pi t}{2\rho}\right)
	  }{
	    e(t) = sin^2((pi * t)/(2 * rho))
	  }
	  for \eqn{t < \rho}{t < rho}, and equal to 1
	  for \eqn{t \ge \rho}{t >= rho}.
	}
	\item{diggra:}{
	  (Diggle-Gratton process. See Diggle and Gratton (1984)
	  and Diggle, Gates and Stibbard (1987).)
	  A \bold{named} vector with components \code{beta},
	  \code{kappa}, \code{delta} and \code{rho}.  This process has
	  pairwise interaction function \eqn{e(t)} equal to 0
	  for \eqn{t < \delta}{t < delta}, equal to
	  \deqn{
	    \left(\frac{t-\delta}{\rho-\delta}\right)^\kappa
	  }{
	    ((t-delta)/(rho-delta))^kappa
	  }
	  for \eqn{\delta \le t < \rho}{delta <= t < rho},
	  and equal to 1 for \eqn{\delta \ge  \rho}{delta >= rho}.
	  Note that here we use the symbol
	  \eqn{\kappa}{kappa} where Diggle, Gates, and Stibbard use
	  \eqn{\beta}{beta} since we reserve the symbol \eqn{\beta}{beta}
	  for an intensity parameter.
	}
	\item{geyer:}{
	  (Geyer's saturation process. See Geyer (1999).)
	  A \bold{named} vector
	  with components \code{beta}, \code{gamma}, \code{r}, and \code{sat}.
	  The components \code{beta}, \code{gamma}, \code{r} are as for
	  the Strauss model, and \code{sat} is the ``saturation''
	  parameter.  The model is Geyer's ``saturation'' point process
	  model, a modification of the Strauss process in which
	  we effectively impose an upper limit (\code{sat}) on the number of
	  neighbours which will be counted as close to a given point.
	 
	  Explicitly, a saturation point process with interaction
	  radius \eqn{r}, saturation threshold \eqn{s}, and
	  parameters \eqn{\beta}{beta} and \eqn{\gamma}{gamma},
	  is the point process in which each point \eqn{x_i}{x[i]}
	  in the pattern \eqn{X} contributes a factor \deqn{\beta
	  \gamma^{\min(s, t(x_i,X))}}{beta gamma^min(s,t(x[i],X))}
	  to the probability density of the point pattern,
	  where \eqn{t(x_i,X)}{t(x[i],X)} denotes the number of
	  ``\eqn{r}-close neighbours'' of \eqn{x_i}{x[i]} in the
	  pattern \eqn{X}.
	}

	\item{lookup:}{
	  (Arbitrary pairwise interaction process with isotropic interaction.)
	  A \bold{named} list with components
	  \code{beta}, \code{r}, and \code{h}, or just with components
	  \code{beta} and \code{h}.

	  This model is the pairwise interaction process
	  with an isotropic interaction given by any chosen function \eqn{H}.
	  Each pair of points \eqn{x_i, x_j}{x[i], x[j]} in the
	  point pattern contributes
	  a factor \eqn{H(d(x_i, x_j))}{H(d(x[i],x[j]))}
	  to the probability density, where \eqn{d} denotes distance
	  and \eqn{H} is the pair interaction function.

	  The component \code{beta} is a
	  (positive) scalar which determines the ``base'' intensity
	  of the process.

	  In this implementation, \eqn{H} must be a step function.
	  It is specified by the user in one of two ways.
	  \itemize{
	    \item
	    \bold{as a vector of values:}
	    If \code{r} is present, then \code{r} is assumed to 
	    give the locations of jumps in the function \eqn{H},
	    while the vector \code{h} gives the corresponding
	    values of the function.

	    Specifically, the interaction function
	    \eqn{H(t)} takes the value \code{h[1]}
	    for distances \eqn{t} in the interval 
	    \code{[0, r[1])}; takes the value \code{h[i]}
	    for distances \eqn{t} in the interval 
	    \code{[r[i-1], r[i])} where
	    \eqn{i = 2,\ldots, n}{i = 2, ..., n};
	    and takes the value 1 for \eqn{t \ge r[n]}{t >= r[n]}.
	    Here \eqn{n} denotes the length of \code{r}.
	    
	    The components \code{r} and \code{h}
	    must be numeric vectors of equal length.
	    The \code{r} values must be strictly positive, and 
	    sorted in increasing order.

	    The entries of \code{h} must be non-negative. 
	    If any entry of \code{h} is greater than 1,
	    then the entry \code{h[1]} must be 0 (otherwise the specified
	    process is non-existent).

	    Greatest efficiency is achieved if the values of
	    \code{r} are equally spaced.
	    
	    [\bold{Note:} The usage of \code{r} and \code{h}
	    has \emph{changed} from the previous usage in \code{spatstat}
	    versions 1.4-7 to 1.5-1, in which ascending order was not required,
	    and in which the first entry of \code{r} had to be 0.]

	    \item
	    \bold{as a stepfun object:}
	    If \code{r} is absent, then \code{h} must be
	    an object of class \code{"stepfun"} specifying
	    a step function. Such objects are created by
	    \code{\link{stepfun}}. 

	    The stepfun object \code{h} must be right-continuous
	    (which is the default using \code{\link{stepfun}}.)

	    The values of the step function must all be nonnegative.
	    The values must all be less than 1
	    unless the function is identically zero on some initial
	    interval \eqn{[0,r)}. The rightmost value (the value of
	    \code{h(t)} for large \code{t}) must be equal to 1.

	    Greatest efficiency is achieved if the jumps (the
	    ``knots'' of the step function) are equally spaced.
	  }
	}
    }
    \item{trend}{
	A function or image (or a list of such if the model
	is multitype) to provide the value of the trend
	(if there is one) at an arbitrary point.  A trend
	function may be a function of any number of arguments,
	but the first two must be the spatial coordinates of
	a point.  The function \bold{must} be \bold{vectorized}.
	That is, it must be capable of accepting vector valued
	\code{x} and \code{y} arguments.  Put another way,
	it must be capable of calculating the trend value at a
	number of points, simultaneously, and should return the
	\bold{vector} of corresponding trend values.  An image (see
	\code{\link{im}()}) provides the trend values at a grid of
	points in the observation window and determines the trend
	value at other points as the value at the nearest grid point.

	Note that the trend or trends must be \bold{non-negative};
	no checking is done for this.

    }
    \item{w}{
      A specification of a window in which the pattern is
      to be generated.  If specified, it must be in a form
      which can be coerced to an object of class \code{owin}
      by \code{\link{as.owin}()}.
    }
  }
  }
  The argument \code{start} determines the initial state of the
  Metropolis-Hastings algorithm. Possible components are
    \describe{
      \item{n.start}{The number of ``initial'' points to be randomly
	(uniformly) generated in the window \code{w}.  For a
	multitype point process, \code{n.start} may be a vector
	(of length equal to the number of types) giving the number
	of points of each type to be generated.  Incompatible with
	\code{x.start}.

	The component \code{n.start} may be a scalar (integer)
        or, for a multitype process, a vector of integers of
	length equal to the number of types.

	A vector-valued \code{n.start} is meaningful \bold{only}
	if \code{p} (the probability of a shift as opposed to a birth or
	death) is equal to 1 (so that we are conditioning on the number
	of points).  When \eqn{p < 1}, if \code{n.start} is vector valued
	then it is effectively replaced by its sum.

	The resulting set of uniformly generated points gives
	the Metropolis-Hastings algorithm an initial state from
	which to start.  (Actually, when \eqn{p < 1}, the number
	\code{n.start} gets multiplied by the ratio of the area of
	the \bold{expanded} window to that of the original window.
	Then that many points are uniformly generated in the expanded
	window; see below for a discussion of the expanded window.)
	The value of \code{n.start} should be roughly equal to
	(an educated guess at) the expected number of points which
	will be generated inside the window.
      }
      \item{x.start}{
	Initial point pattern configuration.  A point pattern (an
	object of class \code{"ppp"}, or data which can be coerced
	to this class by \code{\link{as.ppp}}).  Incompatible with
	\code{n.start}.

	The component \code{x.start} is a point pattern (an object
	of class \code{ppp}, or an object which can be coerced
	to this class by \code{as.ppp()}).  This object provides
	an alternative means of specifying the initial ``state''
	or configuration for the Metropolis-Hastings algorithm.
	If \code{x.start} is specified, but \code{x.start$window}
	is \code{NULL}, then this gap is filled in by the component
	\code{w} of \code{start}.  If \code{x.start$window}
	is present, and if \code{w} is specified as well, the
	latter is used as a window to which to clip the final
	simulated pattern.  Thus in such circumstances it is only
	sensible to specify a value of \code{w} which is contained
	in \code{x.start$window}.  However \bold{no checking}
	is done for this.

	The simulated pattern is constructed in \code{x.start$window}.
	No expansion takes place.  (The argument \code{expand} is
	forced to equal 1.)  As indicated above, at the end of the
	simulation, the resulting pattern is clipped to the window
	\code{w} if this is given.
      }
      \item{iseed}{Seed for random number generator.
	A triple of integers.  If unspecified these are themselves
	generated, on the interval from 1 to 1 million, using the
	function \code{\link{sample}()}.
      }
    }
    The parameters \code{n.start} and \code{x.start} are \emph{incompatible}.

    The third argument \code{control} controls the simulation
    procedure, iterative behaviour, and termination of the
    Metropolis-Hastings algorithm. It is a list with components:
     \describe{
       \item{p}{The probability of of proposing a ``shift''
	 (as opposed to a birth or death) in the Metropolis-Hastings
	 algorithm.  If \eqn{p = 1} then we do nothing but shifts,
	 whence the number of points never changes, i.e. we are
	 simulating conditionally upon the number of points.  In this
	 case, for multitype processes, we also have the option of
	 simulating conditionally upon the number of points of each
	 type; this is effected by specifying \code{fixall} (see
	 below) to equal \code{TRUE}.  In this case, \code{n.start}
	 must be a vector whose entries are these numbers.

	 We can only condition on the number of points if the simulation
	 takes place in the original window (as opposed to taking place in
	 a larger window and then being clipped to the original).  Hence,
	 if \eqn{p = 1} then \code{expand} defaults to 1 and it is an
	 error to specify a value of \code{expand} which is greater than 1.
       }
       \item{q}{The probability of proposing a death (rather than a birth)
	 given that birth/death has been chosen over shift.  This is of
	 course ignored if \code{p} is equal to 1.
       }
       \item{nrep}{The number of repetitions or steps (changes of state)
	 to be made by the Metropolis-Hastings algorithm.  It should
	 be large.
       }
       \item{expand}{The factor by which the enclosing box of the window
	 \code{w} is to be expanded in order to better approximate
	 the simulation of a process existing in the whole plane,
	 rather than just in the window.  If \code{expand} equals 1,
	 then we are simulating the latter, unless \code{periodic}
	 (see below) is \code{TRUE}.  The larger \code{expand} is,
	 the better we approximate the former.	Note that any value
	 of \code{expand} smaller than 1 is treated as if it were 1.

	 The area of the expanded window is equal to \code{expand}
	 times the area of the enclosing box; width and height are
	 stretched proportionately.  Points are generated by the
	 Metropolis-Hastings algorithm in the expanded window, and
	 then ``clipped'' down to the original window when algorithm
	 has finished.	The argument \code{expand} defaults to 2
	 if \code{periodic} is \code{FALSE} and \eqn{p < 1} and
	 to 1 if \code{periodic} is \code{TRUE} or if \eqn{p <
	 1}, or if the starting configuration is specified via
	 \code{x.start}.  Trying to set \code{expand} greater
	 than 1 when \code{periodic} is \code{TRUE} or \eqn{p = 1}
	 generates an error.  A specified value of \code{expand}
	 is simply ignored if \code{x.start} is given.
       }
       \item{periodic}{A logical scalar; if \code{periodic} is \code{TRUE}
	 we simulate a process on the torus formed by
	 identifying opposite edges of the (rectangular) window.
	 If \code{periodic} is \code{TRUE} and the window is not
	 rectangular, an error is given.
       }
       \item{ptypes}{A vector of probabilities (summing to 1) to be used
	 in assigning a random type to a new point.  Defaults to a vector
	 each of whose entries is \eqn{1/nt} where \eqn{nt} is the number
	 of types for the process.  Convergence of the simulation
	 algorithm should be improved if \code{ptypes} is close to the
	 relative frequencies of the types which will result from the
	 simulation.
       }
       \item{fixall}{A logical scalar specifying whether to condition on
	 the number of points of each type.  Meaningful only if a marked
	 process is being simulated, and if \eqn{p = 1}.  A warning message
	 is given if \code{fixall} is set equal to \code{TRUE} when it is
	 not meaningful.
       }
       \item{nverb}{An integer specifying how often ``progress reports''
	 (which consist simply of the number of repetitions completed)
	 should be printed out.  If nverb is left at 0, the default,
	 the simulation proceeds silently.
       }
     }
   }
   
 
\references{
   Baddeley, A. and Turner, R. (2000) Practical maximum
   pseudolikelihood for spatial point patterns.
   \emph{Australian and New Zealand Journal of Statistics}
   \bold{42}, 283 -- 322.

   Diggle, P. J. (2003) \emph{Statistical Analysis of Spatial Point
   Patterns} (2nd ed.) Arnold, London.

   Diggle, P.J. and Gratton, R.J. (1984)
   Monte Carlo methods of inference for implicit statistical models.
   \emph{Journal of the Royal Statistical Society, series B}
   \bold{46}, 193 -- 212.

   Diggle, P.J., Gates, D.J., and Stibbard, A. (1987)
   A nonparametric estimator for pairwise-interaction point processes.
   Biometrika \bold{74}, 763 -- 770.

   Geyer, C.J. and M{\o}ller, J. (1994)
   Simulation procedures and likelihood inference for spatial
   point processes.
   \emph{Scandinavian Journal of Statistics} \bold{21}, 359--373.

   Geyer, C.J. (1999)
   Likelihood Inference for Spatial Point
   Processes. Chapter 3 in  O.E. Barndorff-Nielsen, W.S. Kendall and
   M.N.M. Van Lieshout (eds) \emph{Stochastic Geometry: Likelihood and
   Computation}, Chapman and Hall / CRC,  Monographs on Statistics and
   Applied Probability, number 80. Pages 79--140.
}

\section{Note}{
  It is possible to simulate conditionally upon the number of
  points, or in the case of multitype processes, upon the number of
  points of each type.  To condition upon the total number of points,
  set \code{p} (the probability of a shift) equal to 1, and specify
  \code{n.start} to be a scalar (as usual).  To condition upon the
  number of points of each type, set \code{p} equal to 1, \code{fixall}
  equal to \code{TRUE}, and specify \code{n.start} to be a vector of
  length \eqn{nt} where \eqn{nt} is the number of types.

  In these circumstances
  \itemize{
    \item
    The value of \code{expand} must be equal to 1; it
    defaults to 1, and it is an error to specify a value larger
    than 1.
    \item
    The resulting simulated pattern will have precisely
    the number of points (of each type) specified by
    \code{n.start}.
  }
}
    
\section{Warnings in Respect of ``lookup''}{

The syntax of \code{rmh.default} in respect of the \code{lookup} cif
has \emph{changed} from the previous release of \code{spatstat}
(versions 1.4-7 to 1.5-1).
Read the \emph{Details} carefully. In particular it is now required
that the first entry of the \code{r} component of \code{par}
be \emph{strictly positive}.  (This is the opposite of what was
required in the previous release, which was that this first entry
had to be 0.)

It is also now required that the entries of \code{r} be
sorted into ascending order.  (In the previous release it
was assumed that the entries of \code{r} and \code{h} were
in corresponding order and the two vectors were sorted
commensurately.  It was decided that this is dangerous sand
unnecessary.)

Note that if you specify the \code{lookup} pairwise interaction
function via \code{\link{stepfun}()} the arguments \code{x}
and \code{y} which are passed to \code{stepfun()} are slightly
different from \code{r} and \code{h}:  \code{length(y)} is equal
to \code{1+length(x)}; the final entry of \code{y} must be equal
to 1 --- i.e. this value is explicitly supplied by the user rather
than getting tacked on internally.

The step function returned by \code{stepfun()} must be right
continuous (this is the default behaviour of \code{stepfun()})
otherwise an error is given.
}

\section{Other Warnings}{

There is never a guarantee that the Metropolis-Hastings algorithm
has converged to the steady state.

If \code{x.start} is specified then \code{expand} is set equal to 1
and simulation takes place in \code{x.start$window}.  Any specified
value for \code{expand} is simply ignored.

The presence of both a component \code{w} of \code{model} and a
non-null value for \code{x.start$window} makes sense ONLY if \code{w}
is contained in \code{x.start$window}.  However \bold{no checking}
is done for this.

For multitype processes make sure that, even if there is to be no
trend corresponding to a particular type, there is still a component
(a NULL component) for that type, in the list.

No checking is done to verify non-negativity of any specified trend
or trends.
}

\seealso{
  \code{\link{rmh}},
  \code{\link{rmh.ppm}},
  \code{\link{ppp}},
  \code{\link{ppm}},
  \code{\link{Strauss}},
  \code{\link{Softcore}},
  \code{\link{StraussHard}},
  \code{\link{MultiStrauss}},
  \code{\link{MultiStraussHard}},
  \code{\link{DiggleGratton}}
}
\section{Extensions}{
  The argument \code{model$cif} matches the name of a Fortran
  subroutine which calculates the conditional intensity function
  for the model.  It is intended that more options will be
  added in the future.  The very brave user \bold{could} try
  to add her own.  Note that in addition to writing Fortran
  code for the new conditional intensity function, the user
  would have to modify the code in the files \code{cif.f} and
  \code{rmh.default.R} appropriately.  (And of course re-install
  the \code{spatstat} package so as to update the dynamically
  loadable shared object \code{spatstat.so}.)

  Note that the \code{lookup} conditional intensity function
  permits the simulation (in theory, to any desired degree
  of approximation) of any pairwise interaction process for
  which the interaction depends only on the distance between
  the pair of points.
}
\examples{
   \dontrun{
   require(spatstat)
   nr   <- 1e5
   nv  <- 5000
   }
   \testonly{
   nr  <- 10
   nv <- 5
   }
   set.seed(961018)
   
   # Strauss process.
   mod01 <- list(cif="strauss",par=c(beta=2,gamma=0.2,r=0.7),
                 w=c(0,10,0,10))
   X1.strauss <- rmh(model=mod01,start=list(n.start=80),
                     control=list(nrep=nr,nverb=nv))
   
   # Strauss process, conditioning on n = 80:
   X2.strauss <- rmh(model=mod01,start=list(n.start=80),
                     control=list(p=1,nrep=nr,nverb=nv))
   
   # Strauss process equal to pure hardcore:
   mod02 <- list(cif="strauss",par=c(beta=2,gamma=0,r=0.7),w=c(0,10,0,10))
   X3.strauss <- rmh(model=mod02,start=list(n.start=60),
                     control=list(nrep=nr,nverb=nv,iseed=c(42,17,69)))
   
   # Strauss process in a polygonal window.
   x     <- c(0.55,0.68,0.75,0.58,0.39,0.37,0.19,0.26,0.42)
   y     <- c(0.20,0.27,0.68,0.99,0.80,0.61,0.45,0.28,0.33)
   mod03 <- list(cif="strauss",par=c(beta=2000,gamma=0.6,r=0.07),
                w=owin(poly=list(x=x,y=y)))
   X4.strauss <- rmh(model=mod03,start=list(n.start=90),
                     control=list(nrep=nr,nverb=nv))
   
   # Strauss process in a polygonal window, conditioning on n = 80.
   X5.strauss <- rmh(model=mod03,start=list(n.start=90),
                     control=list(p=1,nrep=nr,nverb=nv))
   
   # Strauss process, starting off from X4.strauss, but with the
   # polygonal window replace by a rectangular one.  At the end,
   # the generated pattern is clipped to the original polygonal window.
   xxx <- X4.strauss
   xxx$window <- as.owin(c(0,1,0,1))
   X6.strauss <- rmh(model=mod03,start=list(x.start=xxx),
                     control=list(nrep=nr,nverb=nv))
   
   # Strauss with hardcore:
   mod04 <- list(cif="straush",par=c(beta=2,gamma=0.2,r=0.7,hc=0.3),
                w=c(0,10,0,10))
   X1.straush <- rmh(model=mod04,start=list(n.start=70),
                     control=list(nrep=nr,nverb=nv))
   
   # Another Strauss with hardcore (with a perhaps surprising result):
   mod05 <- list(cif="straush",par=c(beta=80,gamma=0.36,r=45,hc=2.5),
                w=c(0,250,0,250))
   X2.straush <- rmh(model=mod05,start=list(n.start=250),
                     control=list(nrep=nr,nverb=nv))
   
   # Pure hardcore (identical to X3.strauss).
   mod06 <- list(cif="straush",par=c(beta=2,gamma=1,r=1,hc=0.7),
                w=c(0,10,0,10))
   X3.straush <- rmh(model=mod06,start=list(n.start=60),
                     control=list(nrep=nr,nverb=nv,iseed=c(42,17,69)))
   
   # Soft core:
   par3 <- c(0.8,0.1,0.5)
   w    <- c(0,10,0,10)
   mod07 <- list(cif="sftcr",par=c(beta=0.8,sigma=0.1,kappa=0.5),
                w=c(0,10,0,10))
   X.sftcr <- rmh(model=mod07,start=list(n.start=70),
                  control=list(nrep=nr,nverb=nv))
   
   # Multitype Strauss:
   beta <- c(0.027,0.008)
   gmma <- matrix(c(0.43,0.98,0.98,0.36),2,2)
   r    <- matrix(c(45,45,45,45),2,2)
   mod08 <- list(cif="straussm",par=list(beta=beta,gamma=gmma,radii=r),
                w=c(0,250,0,250))
   X1.straussm <- rmh(model=mod08,start=list(n.start=80),
                      control=list(ptypes=c(0.75,0.25),nrep=nr,nverb=nv))
   
   # Multitype Strauss conditioning upon the total number
   # of points being 80:
   X2.straussm <- rmh(model=mod08,start=list(n.start=80),
                      control=list(p=1,ptypes=c(0.75,0.25),nrep=nr,
                                   nverb=nv))
   
   # Conditioning upon the number of points of type 1 being 60
   # and the number of points of type 2 being 20:
   X3.straussm <- rmh(model=mod08,start=list(n.start=c(60,20)),
                      control=list(fixall=TRUE,p=1,ptypes=c(0.75,0.25),
                                   nrep=nr,nverb=nv))
   
   # Multitype Strauss hardcore:
   rhc  <- matrix(c(9.1,5.0,5.0,2.5),2,2)
   mod09 <- list(cif="straushm",par=list(beta=beta,gamma=gmma,
                iradii=r,hradii=rhc),w=c(0,250,0,250))
   X.straushm <- rmh(model=mod09,start=list(n.start=80),
                     control=list(ptypes=c(0.75,0.25),nrep=nr,nverb=nv))
   
   # Multitype Strauss hardcore with trends for each type:
   beta  <- c(0.27,0.08)
   tr3   <- function(x,y){x <- x/250; y <- y/250;
   			   exp((6*x + 5*y - 18*x^2 + 12*x*y - 9*y^2)/6)
                         }
                         # log quadratic trend
   tr4   <- function(x,y){x <- x/250; y <- y/250;
                         exp(-0.6*x+0.5*y)}
                        # log linear trend
   mod10 <- list(cif="straushm",par=list(beta=beta,gamma=gmma,
                 iradii=r,hradii=rhc),w=c(0,250,0,250),
                 trend=list(tr3,tr4),tmax=list(1.5,1.65))
   X1.straushm.trend <- rmh(model=mod10,start=list(n.start=350),
                            control=list(ptypes=c(0.75,0.25),
                            nrep=nr,nverb=nv))
   
   # Multitype Strauss hardcore with trends for each type, given as images:
   x <- seq(0,250,length=51)
   xy <- expand.grid(x=x,y=x)
   i1 <- im(matrix(tr3(xy$x,xy$y),nrow=51),x,x)
   i2 <- im(matrix(tr4(xy$x,xy$y),nrow=51),x,x)
   mod11 <- list(cif="straushm",par=list(beta=beta,gamma=gmma,
                 iradii=r,hradii=rhc),w=c(0,250,0,250),
                 trend=list(i1,i2))
   X2.straushm.trend <- rmh(model=mod11,start=list(n.start=350),
                            control=list(ptypes=c(0.75,0.25),expand=1,
                            nrep=nr,nverb=nv))
   
   # Diggle, Gates, and Stibbard:
   mod12 <- list(cif="dgs",par=c(beta=3600,rho=0.08),w=c(0,1,0,1))
   X.dgs <- rmh(model=mod12,start=list(n.start=300),
                control=list(nrep=nr,nverb=nv))
   
   # Diggle-Gratton:
   mod13 <- list(cif="diggra",
                 par=c(beta=1800,kappa=3,delta=0.02,rho=0.04),
                 w=square(1))
   X.diggra <- rmh(model=mod13,start=list(n.start=300),
                   control=list(nrep=nr,nverb=nv))
   
   # Geyer:
   mod14 <- list(cif="geyer",par=c(beta=1.25,gamma=1.6,r=0.2,sat=4.5),
                 w=c(0,10,0,10))
   X1.geyer <- rmh(model=mod14,start=list(n.start=200),
                   control=list(nrep=nr,nverb=nv))
   
   # Geyer; same as a Strauss process with parameters
   # (beta=2.25,gamma=0.16,r=0.7):
   
   mod15 <- list(cif="geyer",par=c(beta=2.25,gamma=0.4,r=0.7,sat=10000),
                 w=c(0,10,0,10))
   X2.geyer <- rmh(model=mod15,start=list(n.start=200),
                   control=list(nrep=nr,nverb=nv))
   
   mod16 <- list(cif="geyer",par=c(beta=8.1,gamma=2.2,r=0.08,sat=3))
   data(redwood)
   X3.geyer <- rmh(model=mod16,start=list(x.start=redwood),
                   control=list(periodic=TRUE,nrep=nr,nverb=nv))
   
   # Geyer, starting from the redwood data set, simulating
   # on a torus, and conditioning on n:
   X4.geyer <- rmh(model=mod16,start=list(x.start=redwood),
                   control=list(p=1,periodic=TRUE,nrep=nr,nverb=nv))

   # Lookup (interaction function h_2 from page 76, Diggle (2003)):
      r <- seq(from=0,to=0.2,length=101)[-1] # Drop 0.
      h <- 20*(r-0.05)
      h[r<0.05] <- 0
      h[r>0.10] <- 1
      mod17 <- list(cif="lookup",par=list(beta=4000,h=h,r=r),w=c(0,1,0,1))
      X.lookup <- rmh(model=mod17,start=list(n.start=100),
                      control=list(nrep=nr,nverb=nv))
                   
   # Strauss with trend
   tr <- function(x,y){x <- x/250; y <- y/250;
   			   exp((6*x + 5*y - 18*x^2 + 12*x*y - 9*y^2)/6)
                         }
   beta <- 0.3
   gmma <- 0.5
   r    <- 45
   mod17 <- list(cif="strauss",par=c(beta=beta,gamma=gmma,r=r),w=c(0,250,0,250),
                 trend=tr3,tmax=1.5)
   X1.strauss.trend <- rmh(model=mod17,start=list(n.start=90),
                           control=list(nrep=nr,nverb=nv))
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rmh.ppm}
\alias{rmh.ppm}
\title{Simulate from a Fitted Point Process Model}
\description{
  Given a point process model fitted to data, 
  generate a random simulation of the model, 
  using the Metropolis-Hastings algorithm.
}

\usage{rmh.ppm(model,start=NULL,control=NULL,\dots, verbose=TRUE, project=TRUE) }

\arguments{
  \item{model}{A fitted point process model (object of class
    \code{"ppm"}, see \code{\link{ppm.object}}) which it is desired
    to simulate.  This fitted model is usually the result of a call
    to \code{\link{ppm}}.  See \bold{Details} below.
  }
  \item{start}{A list of arguments determining the initial state
    of the Metropolis-Hastings algorithm.  See
    \code{\link{rmh.default}} for description of these arguments.
    Defaults to list(x.start=model$Q$data)
  }
  \item{control}{A list of arguments controlling the running of
    the Metropolis-Hastings algorithm.  See \code{\link{rmh.default}}
    for description of these arguments.
  }
  \item{\dots}{
    Further arguments passed to \code{\link{rmh.default}}.
  }
  \item{verbose}{
    Logical flag indicating whether to print progress reports.
  }
  \item{project}{
    Logical flag indicating what to do if the fitted model is
    invalid (in the sense that the values of the fitted coefficients do not
    specify a valid point process).
    If \code{project=TRUE} the closest valid model will be simulated;
    if \code{project=FALSE} an error will occur.
  }
}

\value{A point pattern (an object of class \code{"ppp"}; see
  \code{\link{ppp.object}}).
}

\details{
  This function generates simulated realisations from a point
  process model that has been fitted to point pattern data.  It is
  a method for the generic function \code{\link{rmh}} for the
  class \code{"ppm"} of fitted point process models.  To simulate
  other kinds of point process models, see \code{\link{rmh}}
  or \code{\link{rmh.default}}.

  The argument \code{model} describes the fitted model.  It must be
  an object of class \code{"ppm"} (see \code{\link{ppm.object}}),
  and will typically be the result of a call to the point process
  model fitting function \code{\link{ppm}}.

  The current implementation enables simulation from any fitted model
  involving the interactions
  \code{\link{DiggleGratton}},
  \code{\link{Geyer}},
  \code{\link{MultiStrauss}},
  \code{\link{MultiStraussHard}},
  \code{\link{PairPiece}},
  \code{\link{Poisson}},
  \code{\link{Strauss}},
  \code{\link{StraussHard}}
  and \code{\link{Softcore}},
  including nonstationary models. See the examples.

  It is possible that the fitted coefficients of a point process model
  may be ``illegal'', i.e. that there may not exist a
  mathematically well-defined point process with the given parameter
  values. For example, a Strauss process with interaction
  parameter \eqn{\gamma > 1}{gamma > 1} does not exist,
  but the model-fitting procedure used in \code{\link{ppm}} will sometimes
  produce values of \eqn{\gamma}{gamma} greater than 1.
  In such cases, if \code{project=FALSE} then an error will occur,
  while if \code{project=TRUE} then \code{rmh.ppm} will find
  the nearest legal model and simulate
  this model instead. (The nearest legal model is obtained by
  projecting the vector of coefficients onto the set of
  valid coefficient vectors. The result is usually the Poisson process
  with the same fitted intensity.)
  
  The arguments \code{start} and \code{control} are lists of
  parameters determining the initial state and the iterative
  behaviour, respectively, of the Metropolis-Hastings algorithm.
  They are passed directly to \code{\link{rmh.default}}.
  See \code{\link{rmh.default}} for details of these parameters.
  Note that if the model has a trend then the \code{expand}
  component of \code{control} will be ignored.
  The value of \code{expand} must be equal to 1 in this setting.

  After extracting the relevant information from the fitted model
  object \code{model}, \code{rmh.ppm} simply invokes the default
  \code{rmh} algorithm \code{\link{rmh.default}}, unless the model
  is Poisson.  If the model is Poisson then \code{rmh.default} is
  not needed, and a stand-in function \code{pseudo.rmh} is invoked
  to do the simple simulation that is required.

  See \code{\link{rmh.default}} for further information about the
  implementation, or about the Metropolis-Hastings algorithm.
}

\section{Warnings}{
  See Warnings in \code{\link{rmh.default}}.
}

\seealso{
  \code{\link{rmh}},
  \code{\link{rmh.default}},
  \code{\link{ppp.object}},
  \code{\link{ppm}},
  \code{\link{PairPiece}},
  \code{\link{Poisson}},
  \code{\link{Strauss}},
  \code{\link{StraussHard}},
  \code{\link{Softcore}},
  \code{\link{Geyer}},
  \code{\link{DiggleGratton}}
}

\examples{
   data(swedishpines)
   X <- swedishpines
   plot(X, main="Swedish Pines data")

   # Poisson process
   fit <- ppm(X, ~1, Poisson())
   Xsim <- rmh(fit)
   plot(Xsim, main="simulation from fitted Poisson model")

   # Strauss process   
   fit <- ppm(X, ~1, Strauss(r=7), rbord=7)
   Xsim <- rmh(fit, start=list(n.start=X$n), control=list(nrep=1e3))
   plot(Xsim, main="simulation from fitted Strauss model")

   # Strauss - hard core process
   fit <- ppm(X, ~1, StraussHard(r=7,hc=2), rbord=7)
   Xsim <- rmh(fit, start=list(n.start=X$n), control=list(nrep=1e3))
   plot(Xsim, main="simulation from fitted Strauss hard core model")

   # Geyer saturation process
   fit <- ppm(X, ~1, Geyer(r=7,sat=2), rbord=7)
   Xsim <- rmh(fit, start=list(n.start=X$n), control=list(nrep=1e3))
   plot(Xsim, main="simulation from fitted Geyer model")

   # soft core interaction process
   Q <- quadscheme(X, nd=50)
   fit <- ppm(Q, ~1, Softcore(kappa=0.1))
   Xsim <- rmh(fit, start=list(n.start=X$n), control=list(nrep=1e3))
   plot(Xsim, main="simulation from fitted Soft Core model")

   data(cells)
   plot(cells)
   # Diggle-Gratton pairwise interaction model
   fit <- ppm(cells, ~1, DiggleGratton(0.05, 0.1))
   Xsim <- rmh(fit, start=list(n.start=cells$n), control=list(nrep=1e3))
   plot(Xsim, main="simulation from fitted Diggle-Gratton model")

   \dontrun{
   X <- rSSI(0.05, 100)
   plot(X, main="new data")

   # piecewise-constant pairwise interaction function
   fit <- ppm(X, ~1, PairPiece(seq(0.02, 0.1, by=0.01)))
   Xsim <- rmh(fit, start=list(n.start=X$n), control=list(nrep=1e3))
   plot(Xsim, main="simulation from fitted pairwise model")
   }

   # marked point pattern
   data(amacrine)
   Y <- amacrine
   plot(Y, main="Amacrine data")

   # marked Poisson models 
   fit <- ppm(Y)
   Ysim <- rmh(fit)
   plot(Ysim, main="simulation from ppm(Y)")

   fit <- ppm(Y,~marks)
   Ysim <- rmh(fit)
   plot(Ysim, main="simulation from ppm(Y, ~marks)")

   fit <- ppm(Y,~polynom(x,y,2))
   Ysim <- rmh(fit)
   plot(Ysim, main="simulation from ppm(Y, ~polynom(x,y,2))")

   fit <- ppm(Y,~marks+polynom(x,y,2))
   Ysim <- rmh(fit)
   plot(Ysim, main="simulation from ppm(Y, ~marks+polynom(x,y,2))")

   fit <- ppm(Y,~marks*polynom(x,y,2))
   Ysim <- rmh(fit)
   plot(Ysim, main="simulation from ppm(Y, ~marks*polynom(x,y,2))")

   # multitype Strauss models
   MS <- MultiStrauss(types = levels(Y$marks),
                      radii=matrix(0.07, ncol=2, nrow=2))
   fit <- ppm(Y, ~marks, MS)
   Ysim <- rmh(fit, start=list(n.start=X$n), control=list(nrep=1e3))
   plot(Ysim, main="simulation from fitted Multitype Strauss")

   fit <- ppm(Y,~marks*polynom(x,y,2), MS)
   Ysim <- rmh(fit, start=list(n.start=X$n), control=list(nrep=1e3))
   plot(Ysim, main="simulation from fitted inhomogeneous Multitype Strauss")

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rmpoint}
\alias{rmpoint}
\title{Generate N Random Multitype Points}
\description{
  Generate a random multitype point pattern
  with a fixed number of points, or a fixed number of points of each type.
}
\usage{
 rmpoint(n, f=1, fmax=NULL, win=unit.square(),
         types, ptypes,
         \dots, giveup=1000, verbose=FALSE)
}
\arguments{
  \item{n}{
    Number of marked points to generate.
    Either a single number specifying the total number of points,
    or a vector specifying the number of points of each type.
  }
  \item{f}{
    The probability density of the multitype points,
    usually un-normalised.
    Either a constant, a vector,
    a function \code{f(x,y,m, ...)}, a pixel image,
    a list of functions \code{f(x,y,...)}
    or a list of pixel images.
  }
  \item{fmax}{
    An upper bound on the values of \code{f}.
    If missing, this number will be estimated.
  }
  \item{win}{
    Window in which to simulate the pattern.
    Ignored if \code{f} is a pixel image or list of pixel images.
  }
  \item{types}{
    All the possible types for the multitype pattern. 
  }
  \item{ptypes}{
    Optional vector of probabilities for each type.
  }
  \item{\dots}{
    Arguments passed to \code{f} if it is a function.
  }
  \item{giveup}{
    Number of attempts in the rejection method after which
    the algorithm should stop trying to generate new points.
  }
  \item{verbose}{
    Flag indicating whether to report details of performance
    of the simulation algorithm.
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This function generates random multitype point patterns
  consisting of a fixed number of points.
  
  Three different models are available:
  \describe{
    \item{I. Random location and type:}{
      If \code{n} is a single number and the argument \code{ptypes} is missing,
      then \code{n} independent, identically distributed
      random multitype points are generated.
      Their locations
      \code{(x[i],y[i])} and types \code{m[i]} have
      joint probability density proportional to \eqn{f(x,y,m)}.
    }
    \item{II. Random type, and random location given type:}{
      If \code{n} is a single number and \code{ptypes} is given,
      then \code{n} independent, identically distributed
      random multitype points are generated.
      Their types \code{m[i]} have probability distribution
      \code{ptypes}. Given the types, the locations \code{(x[i],y[i])}
      have conditional probability density proportional to
      \eqn{f(x,y,m)}.
    }
    \item{III. Fixed types, and random location given type:}{
      If \code{n} is a vector, then we generate \code{n[i]}
      independent, identically distributed random points of type
      \code{types[i]}. For points of type \eqn{m} the conditional probability
      density of location \eqn{(x,y)} is proportional to
      \eqn{f(x,y,m)}.
    }
  }
  Note that the density \code{f} is normalised in different ways
  in Model I and Models II and III. In Model I the normalised
  joint density is \eqn{g(x,y,m)=f(x,y,m)/Z} where
  \deqn{
    Z = \sum_m \int\int \lambda(x,y,m) {\rm d}x \, {\rm d}y
  }{
    Z = sum_[m] integral lambda(x,y,m) dx dy
  }
  while in Models II and III the normalised conditional density
  is \eqn{g(x,y\mid m) = f(x,y,m)/Z_m}{g(x,y|m) = f(x,y,m)/Z[m]}
  where
  \deqn{
    Z_m = \int\int \lambda(x,y,m)  {\rm d}x \, {\rm d}y.
  }{
    Z[m] = integral lambda(x,y,m) dx dy.
  }
  In Model I, the marginal distribution of types
  is \eqn{p_m = Z_m/Z}{p[m] = Z[m]/Z}.
  
  The unnormalised density \code{f} may be specified
  in any of the following ways.
  \describe{
    \item{single number:}{
      If \code{f} is a single number, the conditional density of
      location given type is uniform. That is, the points of each type
      are uniformly distributed.
      In Model I, the marginal distribution of types is also uniform
      (all possible types have equal probability).
    }
    \item{vector:}{
      If \code{f} is a numeric vector, the conditional density of
      location given type is uniform. That is, the points of each type
      are uniformly distributed.
      In Model I, the marginal distribution of types is
      proportional to the vector \code{f}. In Model II, the marginal
      distribution of types is \code{ptypes}, that is, the values in
      \code{f} are ignored.
    }
    \item{function:}{
      If \code{f} is a function, it will be called in the form
      \code{f(x,y,m,\dots)} at spatial location \code{(x,y)}
      for points of type \code{m}.
      In Model I, the joint probability density of location and type is
      proportional to \code{f(x,y,m,\dots)}.
      In Models II and III, the conditional probability density of
      location \code{(x,y)} given type \code{m} is
      proportional to \code{f(x,y,m,\dots)}.
      The function \code{f} must work correctly with vectors \code{x},
      \code{y} and \code{m}, returning a vector of function values.
      (Note that \code{m} will be a factor
      with levels \code{types}.)
      The value \code{fmax} must be given and must be an upper bound on the 
      values of \code{f(x,y,m,\dots)} for all locations \code{(x, y)}
      inside the window \code{win} and all types \code{m}.
      The argument \code{types} must be given.
    }
    \item{list of functions:}{
      If \code{f} is a list of functions, then the functions will be
      called in the form \code{f[[i]](x,y,\dots)} at spatial
      location \code{(x,y)} for points of type \code{types[i]}.
      In Model I, the joint probability density of location and type is
      proportional to \code{f[[m]](x,y,\dots)}.
      In Models II and III, the conditional probability density of
      location \code{(x,y)} given type \code{m} is
      proportional to \code{f[[m]](x,y,\dots)}.
      The function \code{f[[i]]} must work correctly with vectors
      \code{x} and \code{y}, returning a vector of function values.
      The value \code{fmax} must be given and must be an upper bound on the 
      values of \code{f[[i]](x,y,\dots)} for all locations \code{(x, y)}
      inside the window \code{win}. 
      The argument \code{types} defaults to \code{seq(f)}.
    }
    \item{pixel image:}{
      If \code{f} is a pixel image object of class \code{"im"}
      (see \code{\link{im.object}}), the unnormalised density at a location
      \code{(x,y)} for points of any type is equal to the pixel value
      of \code{f} for the pixel nearest to \code{(x,y)}.
      In Model I, the marginal distribution of types is uniform.
      The argument \code{win} is ignored;
      the window of the pixel image is used instead.
      The argument \code{types} must be given.
    }
    \item{list of pixel images:}{
      If \code{f} is a list of pixel images,
      then the image \code{f[[i]]} determines the density values
      of points of type \code{types[i]}. 
      The argument \code{win} is ignored;
      the window of the pixel image is used instead.
      The argument \code{types} defaults to \code{factor(seq(f))}.
    }
  }
  The implementation uses the rejection method.
  For Model I, \code{\link{rmpoispp}} is called repeatedly
  until \code{n} points have been generated.
  It gives up after \code{giveup} calls
  if there are still fewer than \code{n} points.
  For Model II, the types are first generated according to
  \code{ptypes}, then
  the locations of the points of each type
  are generated using \code{\link{rpoint}}.
  For Model III,   the locations of the points of each type
  are generated using \code{\link{rpoint}}.
}
\seealso{
\code{\link{ppp.object}},
\code{\link{owin.object}}
}
\examples{

abc <- c("a","b","c")

##### Model I

rmpoint(25, types=abc)
rmpoint(25, 1, types=abc)
# 25 points, equal probability for each type, uniformly distributed locations

rmpoint(25, function(x,y,m) {rep(1, length(x))}, types=abc)
# same as above
rmpoint(25, list(function(x,y){rep(1, length(x))},
                 function(x,y){rep(1, length(x))},
                 function(x,y){rep(1, length(x))}),
             types=abc)
# same as above

rmpoint(25, function(x,y,m) { x }, types=abc)
# 25 points, equal probability for each type,
# locations nonuniform with density proportional to x

rmpoint(25, function(x,y,m) { ifelse(m == "a", 1, x) }, types=abc)
rmpoint(25, list(function(x,y) { rep(1, length(x)) },
                function(x,y) { x },
                function(x,y) { x }),
                types=abc)
# 25 points, UNEQUAL probabilities for each type,
# type "a" points uniformly distributed,
# type "b" and "c" points nonuniformly distributed.

##### Model II

rmpoint(25, 1, types=abc, ptypes=rep(1,3)/3)
rmpoint(25, 1, types=abc, ptypes=rep(1,3))
# 25 points, equal probability for each type,
# uniformly distributed locations

rmpoint(25, function(x,y,m) {rep(1, length(x))}, types=abc, ptypes=rep(1,3))
# same as above
rmpoint(25, list(function(x,y){rep(1, length(x))},
                 function(x,y){rep(1, length(x))},
                 function(x,y){rep(1, length(x))}),
             types=abc, ptypes=rep(1,3))
# same as above

rmpoint(25, function(x,y,m) { x }, types=abc, ptypes=rep(1,3))
# 25 points, equal probability for each type,
# locations nonuniform with density proportional to x

rmpoint(25, function(x,y,m) { ifelse(m == "a", 1, x) }, types=abc, ptypes=rep(1,3))
# 25 points, EQUAL probabilities for each type,
# type "a" points uniformly distributed,
# type "b" and "c" points nonuniformly distributed.

###### Model III

rmpoint(c(12, 8, 4), 1, types=abc)
# 12 points of type "a",
# 8 points of type "b",
# 4 points of type "c",
# each uniformly distributed

rmpoint(c(12, 8, 4), function(x,y,m) { ifelse(m=="a", 1, x)}, types=abc)
rmpoint(c(12, 8, 4), list(function(x,y) { rep(1, length(x)) },
                               function(x,y) { x },
                               function(x,y) { x }),
             types=abc)

# 12 points of type "a", uniformly distributed
# 8 points of type "b", nonuniform
# 4 points of type "c", nonuniform


#########

## Randomising an existing point pattern:
data(demopat)
X <- demopat

# same numbers of points of each type, uniform random locations (Model III)
rmpoint(table(X$marks), 1, types=levels(X$marks), win=X$window)

# same total number of points, distribution of types estimated from X,
# uniform random locations (Model II)
rmpoint(X$n, 1, types=levels(X$marks), win=X$window,
       ptypes=table(X$marks))

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rmpoispp}
\alias{rmpoispp}
\title{Generate Multitype Poisson Point Pattern}
\description{
  Generate a random point pattern using the
  (homogeneous or inhomogeneous) multitype Poisson process.
}
\usage{
 rmpoispp(lambda, lmax=NULL, win, types, \dots)
}
\arguments{
  \item{lambda}{
    Intensity of the multitype Poisson process.
    Either a single positive number, a vector, a \code{function(x,y,m, \dots)},
    a pixel image, a list of functions \code{function(x,y, \dots)},
    or a list of pixel images.
  }
  \item{lmax}{
    An upper bound for the value of \code{lambda}.
    May be omitted
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
    Ignored if \code{lambda} is a pixel image or list of images.
  }
  \item{types}{
    All the possible types for the multitype pattern.
  }
  \item{\dots}{
    Arguments passed to \code{lambda} if it is a function.
  }
}
\value{
  The simulated multitype point pattern (an object of class \code{"ppp"}
  with a component \code{marks} which is a factor).
}
\details{
  This function generates a realisation of the marked Poisson
  point process with intensity \code{lambda}.
  
  Note that the intensity function
  \eqn{\lambda(x,y,m)}{lambda(x,y,m)} is the
  average number of points \bold{of type m} per unit area
  near the location \eqn{(x,y)}.
  Thus a marked point process with a constant intensity of 10
  and three possible types will have an average of 30 points per unit
  area, with 10 points of each type on average.

  The intensity function may be specified in any of the following ways.
  \describe{
    \item{single number:}{
      If \code{lambda} is a single number,
      then this algorithm generates a realisation
      of the uniform marked Poisson process inside the window \code{win} with 
      intensity \code{lambda} for each type. The total intensity of
      points of all types is \code{lambda * length(types)}.
      The argument \code{types} must be given
      and determines the possible types in the multitype pattern.
    }
    \item{vector:}{
      If \code{lambda} is a numeric vector,
      then this algorithm generates a realisation
      of the stationary marked Poisson process inside the window
      \code{win} with intensity \code{lambda[i]} for points of type
      \code{types[i]}. The total intensity of points of all types
      is \code{sum(lambda)}.  The argument \code{types} defaults to
      \code{seq(lambda)}.
    }
    \item{function:}{
      If \code{lambda} is a function, the process has intensity
      \code{lambda(x,y,m,\dots)} at spatial location \code{(x,y)}
      for points of type \code{m}.
      The function \code{lambda} must work correctly with vectors \code{x},
      \code{y} and \code{m}, returning a vector of function values.
      (Note that \code{m} will be a factor
      with levels equal to \code{types}.)
      The value \code{lmax}, if present, must be an upper bound on the 
      values of \code{lambda(x,y,m,\dots)} for all locations \code{(x, y)}
      inside the window \code{win} and all types \code{m}.
      The argument \code{types} must be given.
    }
    \item{list of functions:}{
      If \code{lambda} is a list of functions,
      the process has intensity \code{lambda[[i]](x,y,\dots)} at spatial
      location \code{(x,y)} for points of type \code{types[i]}.
      The function \code{lambda[[i]]} must work correctly with vectors
      \code{x} and \code{y}, returning a vector of function values.
      The value \code{lmax}, if given, must be an upper bound on the 
      values of \code{lambda(x,y,\dots)} for all locations \code{(x, y)}
      inside the window \code{win}. 
      The argument \code{types} defaults to \code{seq(lambda)}.
    }
    \item{pixel image:}{
      If \code{lambda} is a pixel image object of class \code{"im"}
      (see \code{\link{im.object}}), the intensity at a location
      \code{(x,y)} for points of any type is equal to the pixel value
      of \code{lambda} for the pixel nearest to \code{(x,y)}.
      The argument \code{win} is ignored;
      the window of the pixel image is used instead.
      The argument \code{types} must be given.
    }
    \item{list of pixel images:}{
      If \code{lambda} is a list of pixel images,
      then the image \code{lambda[[i]]} determines the intensity
      of points of type \code{types[i]}. 
      The argument \code{win} is ignored;
      the window of the pixel image is used instead.
      The argument \code{types} defaults to \code{seq(lambda)}.
    }
  }
  If \code{lmax} is missing, an approximate upper bound will be calculated.
  
  To generate an inhomogeneous Poisson process
  the algorithm uses ``thinning'': it first generates a uniform
  Poisson process of intensity \code{lmax} for points of each type \code{m},
  then randomly deletes or retains each point independently,
  with retention probability
  \eqn{p(x,y,m) = \lambda(x,y,m)/\mbox{lmax}}{p(x,y,m) = lambda(x,y)/lmax}.
}
\seealso{
\code{\link{ppp.object}},
\code{\link{owin.object}}
}
\examples{
 # uniform bivariate Poisson process with total intensity 100 in unit square
 pp <- rmpoispp(50, types=c("a","b"))
 
 # stationary bivariate Poisson process with intensity A = 30, B = 70
 pp <- rmpoispp(c(30,70), types=c("A","B"))
 pp <- rmpoispp(c(30,70))

 # works in any window
 data(letterR)
 pp <- rmpoispp(c(30,70), win=letterR, types=c("A","B"))

 # inhomogeneous lambda(x,y,m)
 # note argument 'm' is a factor 
 lam <- function(x,y,m) { 50 * (x^2 + y^3) * ifelse(m=="A", 2, 1)}
 pp <- rmpoispp(lam, win=letterR, types=c("A","B"))
 # extra arguments
 lam <- function(x,y,m,scal) { scal * (x^2 + y^3) * ifelse(m=="A", 2, 1)}
 pp <- rmpoispp(lam, win=letterR, types=c("A","B"), scal=50)

 # list of functions lambda[[i]](x,y)
 lams <- list(function(x,y){50 * x^2}, function(x,y){20 * abs(y)})
 pp <- rmpoispp(lams, win=letterR, types=c("A","B"))
 pp <- rmpoispp(lams, win=letterR)
 # functions with extra arguments
 lams <- list(function(x,y,scal){5 * scal * x^2},
              function(x,y, scal){2 * scal * abs(y)})
 pp <- rmpoispp(lams, win=letterR, types=c("A","B"), scal=10)
 pp <- rmpoispp(lams, win=letterR, scal=10)

 # florid example
 lams <- list(function(x,y){
   			   100*exp((6*x + 5*y - 18*x^2 + 12*x*y - 9*y^2)/6)
                         }
                         # log quadratic trend
              ,
              function(x,y){
                         	   100*exp(-0.6*x+0.5*y)
                         }
                        # log linear trend
              )
  X <- rmpoispp(lams, win=unit.square(), types=c("on", "off"))   

 # pixel image
 Z <- as.im(function(x,y){30 * (x^2 + y^3)}, letterR)
 pp <- rmpoispp(Z, types=c("A","B"))

 # list of pixel images
 ZZ <- list(
          as.im(function(x,y){20 * (x^2 + y^3)}, letterR),
          as.im(function(x,y){40 * (x^3 + y^2)}, letterR))
 pp <- rmpoispp(ZZ, types=c("A","B"))
 pp <- rmpoispp(ZZ)
 
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rotate}
\alias{rotate}
\title{Rotate}
\description{
  Applies a rotation to any two-dimensional object,
  such as a point pattern or a window. 
}
\synopsis{
  rotate(X, \dots)
}
\usage{
 rotate(X, angle=pi/2)
}
\arguments{
  \item{X}{Any suitable dataset representing a two-dimensional
    object, such as a point pattern (object of class \code{"ppp"}),
    or a window (object of class \code{"owin"}).}
  \item{angle}{Angle of rotation.}
}
\value{
  Another object of the same type, representing the
  result of rotating \code{X} through the specified angle.
}
\details{
  This is generic. Methods are provided for
  point patterns (\code{\link{rotate.ppp}})
  and windows (\code{\link{rotate.owin}}).

  The angle of rotation is measured in radians, anticlockwise,
  and the centre of rotation is the origin.
}
\seealso{
  \code{\link{rotate.ppp}},
  \code{\link{rotate.owin}}
}
\examples{
  data(cells)
  X <- rotate(cells, pi/3)
  \dontrun{
  plot(X)
  plot(rotate(cells$window, pi/4))
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rotate.owin}
\alias{rotate.owin}
\title{Rotate a Window}
\description{
  Rotates a window
}
\usage{
 rotate.owin(X, angle=pi/2, \dots)
}
\arguments{
  \item{X}{A window (object of class \code{"owin"}).}
  \item{angle}{Angle of rotation.}
  \item{\dots}{Ignored.}
}
\value{
  Another object of class \code{"owin"} representing the
  rotated window.
}
\details{
  Rotates the window by the specified angle. Angles are measured in
  radians, anticlockwise. The default is to rotate the window 90 degrees
  anticlockwise. The centre of rotation is the origin.

  Rotation of binary image masks is not yet implemented.
}
\seealso{
  \code{\link{owin.object}}
}
\examples{
  w <- owin(c(0,1),c(0,1))
  v <- rotate(w, pi/3)
  \dontrun{
  plot(v)
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rotate.ppp}
\alias{rotate.ppp}
\title{Rotate a Point Pattern}
\description{
  Rotates a point pattern
}
\usage{
 rotate.ppp(X, angle=pi/2, \dots)
}
\arguments{
  \item{X}{A point pattern (object of class \code{"ppp"}).}
  \item{angle}{Angle of rotation.}
  \item{\dots}{Ignored.}
}
\value{
  Another object of class \code{"ppp"} representing the
  rotated point pattern.
}
\details{
  The points of the pattern, and the window of observation, 
  are rotated about the origin by the angle specified.
  Angles are measured in
  radians, anticlockwise. The default is to rotate the pattern 90 degrees
  anticlockwise. If the points carry marks, these are preserved.

  Rotation of binary image masks is not yet implemented.
}
\seealso{
  \code{\link{ppp.object}},
  \code{\link{rotate.owin}}
}
\examples{
  data(cells)
  X <- rotate(cells, pi/3)
  \dontrun{
  plot(X)
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rpoint}
\alias{rpoint}
\title{Generate N Random Points}
\description{
  Generate a random point pattern
  containing \eqn{n} independent, identically distributed random points
  with any specified distribution.
}
\usage{
 rpoint(n, f, fmax=NULL, win=unit.square(), \dots, giveup=1000, verbose=FALSE)
}
\arguments{
  \item{n}{
    Number of points to generate.
  }
  \item{f}{
    The probability density of the points,
    possibly un-normalised.
    Either a constant,
    a function \code{f(x,y,...)}, or a pixel image object.
  }
  \item{fmax}{
    An upper bound on the values of \code{f}.
    If missing, this number will be estimated.
  }
  \item{win}{
    Window in which to simulate the pattern.
    Ignored if \code{f} is a pixel image.
  }
  \item{\dots}{
    Arguments passed to the function \code{f}.
  }
  \item{giveup}{
    Number of attempts in the rejection method after which
    the algorithm should stop trying to generate new points.
  }
  \item{verbose}{
    Flag indicating whether to report details of performance
    of the simulation algorithm.
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This function generates \code{n} independent, identically distributed
  random points with common probability density proportional to
  \code{f}.

  The argument \code{f} may be
  \describe{
    \item{a numerical constant:}{
      uniformly distributed random points will
      be generated.
    }
    \item{a function:}{random points will be generated
      in the window \code{win} with probability density proportional
      to \code{f(x,y,...)} where \code{x} and \code{y} are the cartesian
      coordinates. The function \code{f} must accept 
      two \emph{vectors} of coordinates \code{x,y} and return the corresponding
      vector of function values. Additional arguments \code{...} of any kind
      may be passed to the function.
    }
    \item{a pixel image:}{if \code{f} is a pixel image object
      of class \code{"im"} (see \code{\link{im.object}}) then
      random points will be generated
      in the window of this pixel image, with probability density
      proportional to the pixel values of \code{f}.
    }
  }
  The algorithm is as follows:
  \itemize{
    \item
    If \code{f} is a constant, we invoke \code{\link{runifpoint}}.
    \item
    If \code{f} is a function, then we use the rejection method.
    Proposal points are generated from the uniform distribution.
    A proposal point \eqn{(x,y)} is accepted with probability
    \code{f(x,y,...)/fmax} and otherwise rejected.
    The algorithm continues until \code{n} points have been
    accepted. It gives up after \code{giveup * n} proposals
    if there are still fewer than \code{n} points.
    \item 
    If \code{f} is a pixel image, then a random sequence of 
    pixels is selected (using \code{\link{sample}})
    with probabilities proportional to the
    pixel values of \code{f}.  Then for each pixel in the sequence
    we generate a uniformly distributed random point in that pixel.
  }
  The algorithm for pixel images is more efficient than that for
  functions.
}
\seealso{
\code{\link{ppp.object}},
\code{\link{owin.object}},
\code{\link{runifpoint}}
}
\examples{
 # 100 uniform random points in the unit square
 X <- rpoint(100)

 # 100 random points with probability density proportional to x^2 + y^2
 X <- rpoint(100, function(x,y) { x^2 + y^2}, 1)

 # `fmax' may be omitted
 X <- rpoint(100, function(x,y) { x^2 + y^2})

 # irregular window
 data(letterR)
 X <- rpoint(100, function(x,y) { x^2 + y^2}, win=letterR)

 # make a pixel image 
 Z <- setcov(letterR)
 # 100 points with density proportional to pixel values
 X <- rpoint(100, Z)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{rpoispp}
\alias{rpoispp}
\title{Generate Poisson Point Pattern}
\description{
  Generate a random point pattern using the
  (homogeneous or inhomogeneous) Poisson process.
}
\usage{
 rpoispp(lambda, lmax, win, \dots)
}
\arguments{
  \item{lambda}{
    Intensity of the Poisson process.
    Either a single positive number, a \code{function(x,y, \dots)},
    or a pixel image.
  }
  \item{lmax}{
    An upper bound for the value of \code{lambda(x,y)},
    if \code{lambda} is a function.
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
    Ignored if \code{lambda} is a pixel image.
  }
  \item{\dots}{
    Arguments passed to \code{lambda} if it is a function.
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  If \code{lambda} is a single number,
  then this algorithm generates a realisation
  of the uniform Poisson process inside the window \code{win} with 
  intensity \code{lambda} (points per unit area).
 
  If \code{lambda} is a function, then this algorithm generates a realisation
  of the inhomogeneous Poisson process with intensity function
  \code{lambda(x,y,\dots)} at spatial location \code{(x,y)}
  inside the window \code{win}.
  The function \code{lambda} must work correctly with vectors \code{x}
  and \code{y}.
  The value \code{lmax} must be given and must be an upper bound on the 
  values of \code{lambda(x,y,\dots)} for all locations \code{(x, y)}
  inside the window \code{win}. 

  If \code{lambda} is a pixel image object of class \code{"im"}
  (see \code{\link{im.object}}), this algorithm generates a realisation
  of the inhomogeneous Poisson process with intensity equal to the
  pixel values of the image. (The value of the intensity function at an
  arbitrary location is the pixel value of the nearest pixel.)
  The argument \code{win} is ignored;
  the window of the pixel image is used instead.
  
  To generate an inhomogeneous Poisson process
  the algorithm uses ``thinning'': it first generates a uniform
  Poisson process of intensity \code{lmax},
  then randomly deletes or retains each point, independently of other points,
  with retention probability
  \eqn{p(x,y) = \lambda(x,y)/\mbox{lmax}}{p(x,y) = lambda(x,y)/lmax}.
}
\seealso{
\code{\link{ppp.object}},
\code{\link{owin.object}}
}
\examples{
 # uniform Poisson process with intensity 100 in the unit square
 pp <- rpoispp(100)
 
 # uniform Poisson process with intensity 1 in a 10 x 10 square
 pp <- rpoispp(1, win=owin(c(0,10),c(0,10)))
 # plots should look similar !
 
 # inhomogeneous Poisson process in unit square
 # with intensity lambda(x,y) = 100 * exp(-3*x)
 # Intensity is bounded by 100
 pp <- rpoispp(function(x,y) {100 * exp(-3*x)}, 100)

 # How to tune the coefficient of x
 lamb <- function(x,y,a) { 100 * exp( - a * x)}
 pp <- rpoispp(lamb, 100, a=3)

 # pixel image
 Z <- as.im(function(x,y){100 * sqrt(x+y)}, unit.square())
 pp <- rpoispp(Z)

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{runifpoint}
\alias{runifpoint}
\title{Generate N Uniform Random Points}
\description{
  Generate a random point pattern
  containing \eqn{n} independent uniform random points.
}
\usage{
 runifpoint(n, win=owin(c(0,1),c(0,1)), giveup=1000)
}
\arguments{
  \item{n}{
    Number of points.
  }
  \item{win}{
    Window in which to simulate the pattern.
    An object of class \code{"owin"}
    or something acceptable to \code{\link{as.owin}}.
  }
  \item{giveup}{
    Number of attempts in the rejection method after which
    the algorithm should stop trying to generate new points.
  }
}
\value{
  The simulated point pattern (an object of class \code{"ppp"}).
}
\details{
  This function generates \code{n} independent random points,
  uniformly distributed in the window \code{win}.
  (For nonuniform distributions, see \code{\link{rpoint}}.)

  The algorithm depends on the type of window, as follows:
  \itemize{
    \item
    If \code{win} is a rectangle then 
    \eqn{n} independent random points, uniformly distributed
    in the rectangle, are generated by assigning uniform random values to their
    cartesian coordinates.
    \item
    If \code{win} is a binary image mask, then a random sequence of 
    pixels is selected (using \code{\link{sample}})
    with equal probabilities. Then for each pixel in the sequence
    we generate a uniformly distributed random point in that pixel.
    \item
    If \code{win} is a polygonal window, the algorithm uses the rejection
    method. It finds a rectangle enclosing the window,
    generates points in this rectangle, and tests whether they fall in
    the desired window. It gives up when \code{giveup * n} tests
    have been performed without yielding \code{n} successes.
  }
  The algorithm for binary image masks is faster than the rejection
  method but involves discretisation.
}
\seealso{
\code{\link{ppp.object}},
\code{\link{owin.object}},
\code{\link{rpoispp}},
\code{\link{rpoint}}
}
\examples{
 # 100 random points in the unit square
 pp <- runifpoint(100)
 # irregular window
 data(letterR)
 # polygonal
 pp <- runifpoint(100, letterR)
 # binary image mask
 pp <- runifpoint(100, as.mask(letterR))
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{setmarks}
\alias{setmarks}
\alias{\%mark\%}
\title{Set or Reset the Marks in a Point Pattern}
\description{
  Create a marked point pattern from given point locations
  and given marks.
}
\synopsis{
  setmarks(X, m)
}
\usage{
  setmarks(X, m)
  X \%mark\% m
}
\arguments{
  \item{X}{
    Point pattern (object of class \code{"ppp"})
  }
  \item{m}{
    Vector of mark values (of any atomic mode)
  }
}
\value{
  Marked point pattern (object of class \code{"ppp"})
  identical to \code{X} except that it has marks equal to \code{m}.
}
\details{
  This function is a shortcut which creates a marked point pattern
  from a given point pattern \code{X} and a given vector \code{m} 
  by attaching the marks in \code{m} to the locations of the points
  in \code{X}.

  If \code{X} is already a marked point pattern, then its marks
  are ignored and replaced by the values in \code{m}.

  If \code{m} is a single value, then all points will be
  given this mark value. Otherwise, \code{m} must be a vector
  of length equal to the number of points in \code{X}, and
  the point \code{X[i]} will receive the mark \code{m[i]}.

  Use \code{\link{unmark}} to remove marks.
  Use \code{\link{ppp}} to create point patterns in more general
  situations.
}
\seealso{
  \code{\link{unmark}},
  \code{\link{ppp.object}},
  \code{\link{is.marked}},
  \code{\link{is.marked.ppp}}
}
\examples{
   data(cells)

   m <- runif(cells$n)

   Y <- setmarks(cells, m)
   Y <- cells \%mark\% m
   # equivalent

   \dontrun{plot(Y)}
   is.marked(Y)  #TRUE
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{shift}
\alias{shift}
\title{Apply Vector Translation}
\description{
  Applies a vector shift of the plane 
  to a geometrical object,
  such as a point pattern or a window. 
}
\synopsis{
  shift(X, \dots)
}
\usage{
 shift(X, vec=c(0,0))
}
\arguments{
  \item{X}{Any suitable dataset representing a two-dimensional
    object, such as a point pattern (object of class \code{"ppp"}),
    or a window (object of class \code{"owin"}).}
  \item{vec}{Vector of length 2 representing a translation.}
}
\value{
  Another object of the same type, representing the
  result of applying the shift.
}
\details{
  This is generic. Methods are provided for
  point patterns (\code{\link{shift.ppp}})
  and windows (\code{\link{shift.owin}}).

  The object is translated by the vector \code{vec}.
}
\seealso{
  \code{\link{shift.ppp}},
  \code{\link{shift.owin}},
  \code{\link{rotate}},
  \code{\link{affine}}
}
\examples{
  data(cells)
  X <- shift(cells, c(2,3))
  \dontrun{
  plot(X)
  # no discernible difference except coordinates are different
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{shift.im}
\alias{shift.im}
\title{Apply Vector Translation To Pixel Image}
\description{
  Applies a vector shift to a pixel image
}
\usage{
 shift.im(X, vec=c(0,0), \dots)
}
\arguments{
  \item{X}{Pixel image (object of class \code{"im"}).}
  \item{vec}{Vector of length 2 representing a translation.}
  \item{\dots}{Ignored}
}
\value{
  Another pixel image (of class \code{"im"}) representing the
  result of applying the vector shift.
}
\details{
  The spatial location of each pixel in the image
  is translated by the vector \code{vec}.
  This is a method for the generic function \code{\link{shift}}.
}
\seealso{
  \code{\link{shift}}
}
\examples{
 # make up an image
 X <- setcov(unit.square())
 plot(X)

 Y <- shift(X, c(10,10))
 plot(Y)
 # no discernible difference except coordinates are different
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{shift.owin}
\alias{shift.owin}
\title{Apply Vector Translation To Window}
\description{
  Applies a vector shift to a window
}
\usage{
 shift.owin(X, vec=c(0,0), \dots)
}
\arguments{
  \item{X}{Window (object of class \code{"owin"}).}
  \item{vec}{Vector of length 2 representing a translation.}
  \item{\dots}{Ignored}
}
\value{
  Another window (of class \code{"owin"}) representing the
  result of applying the vector shift.
}
\details{
  The window is translated by the vector \code{vec}.
  This is a method for the generic function \code{\link{shift}}.
}
\seealso{
  \code{\link{shift}},
  \code{\link{shift.ppp}},
  \code{\link{rotate}},
  \code{\link{affine}}
}
\examples{
  W <- owin(c(0,1),c(0,1))
  X <- shift(W, c(2,3))
  \dontrun{
  plot(W)
  # no discernible difference except coordinates are different
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{shift.ppp}
\alias{shift.ppp}
\title{Apply Vector Translation To Point Pattern}
\description{
  Applies a vector shift to a point pattern. 
}
\usage{
 shift.ppp(X, vec=c(0,0), \dots)
}
\arguments{
  \item{X}{Point pattern (object of class \code{"ppp"}).}
  \item{vec}{Vector of length 2 representing a translation.}
  \item{\dots}{Ignored}
}
\value{
  Another point pattern (of class \code{"ppp"}) representing the
  result of applying the vector shift.
}
\details{
  The point pattern, and its window, are
  translated by the vector \code{vec}.
  
  This is a method for the generic function \code{\link{shift}}.
}
\seealso{
  \code{\link{shift}},
  \code{\link{shift.owin}},
  \code{\link{rotate}},
  \code{\link{affine}}
}
\examples{
  data(cells)
  X <- shift(cells, c(2,3))
  \dontrun{
  plot(X)
  # no discernible difference except coordinates are different
  }
  Y <- superimpose(cells, shift(cells, c(0.1,0.1)))
  \dontrun{plot(Y)}
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{simdat}
\alias{simdat}
\title{
  Simulated Point Pattern
}
\description{
  This point pattern data set was simulated (using the
  Metropolis-Hastings algorithm)
  from a model fitted to the Numata
  Japanese black pine data set referred to in
  Baddeley and Turner (2000).
} 
\format{
  An object of class \code{"ppp"}
  in a square window of size 10 by 10 units.

  See \code{\link{ppp.object}} for details of the format of a
  point pattern object.
}
\usage{data(simdat)}
\source{Rolf Turner \email{rolf@math.unb.ca}}
\references{
  Baddeley, A. and Turner, R. (2000)
  Practical maximum pseudolikelihood for spatial point patterns.
  \emph{Australian and New Zealand Journal of Statistics}
  \bold{42}, 283--322.
}
\keyword{datasets}

\eof
\name{spatstat.options}
\alias{spatstat.options}
\title{Internal Options in Spatstat Package}
\description{
  Allows the user to examine and reset the values
  of global parameters which control actions in the
  \code{spatstat} package.
}
\usage{
  spatstat.options(...)
}
\arguments{
  \item{\dots}{
    Either empty,
    or a succession of parameter names in quotes,
    or a succession of \code{name=value} pairs.
    See below for the parameter names.
  }
}
\value{
  A list of parameters and their values.
}
\details{
  This function is analogous to \code{\link{options}}
  and calls the utility function \code{\link{check.options}}.

  If no arguments are given, 
  the current values of all parameters are returned.

  If a succession of parameter names is given,
  the current values of these parameters are returned.
  
  If \code{name=value} pairs are given, the named parameters
  are reset to the given values, and the \bold{previous} values of
  these parameters are returned.

  The parameters are:
  \describe{
    \item{npixel}{
      Controls the number of pixels in the discrete approximation
      of an irregular window by a binary pixel image as created by
      \code{\link{as.mask}}. Either an integer or a pair of integers
      giving the number of pixels in the \code{x} and \code{y}
      directions.
    }
    \item{maxedgewt}{
      Edge correction weights will be trimmed
      so as not to exceed this value.
      This applies to the weights computed by
      \code{\link{edge.Trans}} or \code{\link{edge.Ripley}}
      and used in \code{\link{Kest}} and its relatives.
    }
    \item{par.binary}{
      List of arguments to be passed to the function \code{\link{image}}
      when displaying a binary image mask (in \code{\link{plot.owin}}
      or \code{\link{plot.ppp}}).
      Typically used to reset the colours of foreground and background.
    }
    \item{par.persp}{
      List of arguments to be passed to the function \code{\link{persp}}
      when displaying a real-valued image, such as the fitted surfaces
      in \code{\link{plot.ppm}}.
    }
  }

}
\seealso{
  \code{\link{options}}
}
\examples{
  spatstat.options(npixel=150)
  spatstat.options(npixel=c(100,200))

  spatstat.options(par.binary=list(col=grey(c(0.5,1))))

  spatstat.options(par.persp=list(theta=-30,phi=40,d=4))
  # see help(persp.default) for other options

}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{split.ppp}
\alias{split.ppp}
\alias{split<-.ppp}
\alias{split}
\alias{split<-}
\title{Divide Point Pattern into Sub-patterns}
\description{
  Divides a point pattern into several sub-patterns,
  according to their marks, or according to any user-specified grouping.
}
\synopsis{
  split.ppp(x, f = x$marks)
}
\usage{
  split.ppp(x, f = x$marks)
  split(x, f) <- value
}
\arguments{
  \item{x}{
    A two-dimensional point pattern.
    An object of class \code{"ppp"}.
  }
  \item{f}{
    Factor determining the grouping. 
  }
  \item{value}{
    List of point patterns.
  }
} 
\value{
  The value of \code{split.ppp} is a list of point patterns.
  The components of the list are named by the levels of \code{f}.

  The assignment form \code{split<-.ppp} returns the updated
  point pattern \code{x}. 
}
\details{
  The function \code{split.ppp}
  divides up the points of the point pattern \code{x}
  into several sub-patterns according to the levels of the factor
  \code{f}. The result is a list of point patterns, one for each
  level of \code{f}.

  If \code{f} is present, it must be a factor, and its length
  must equal the number of points in \code{x}. The levels of \code{f}
  determine the destination of each point in \code{x}.
  The \code{i}th point of \code{x} will be placed in the sub-pattern
  \code{split.ppp(x)$l} where \code{l = f[i]}.

  If \code{f} is missing, then \code{x} must be a multitype point pattern
  (a marked point pattern whose marks vector is a factor).
  Then the effect is that the points of each type
  are separated into different point patterns.

  The result of \code{split.ppp} has class \code{"splitppp"}
  and can be plotted using \code{\link{plot.splitppp}}.

  The assignment function \code{split<-.ppp} 
  updates the point pattern \code{x} so that
  it satisfies \code{split(x, f) = value}. The argument \code{value}
  is expected to be a list of point patterns, one for each level of
  \code{f}. 

  Splitting can also be undone by the function \code{\link{superimpose}}.
}
\seealso{
  \code{\link{cut.ppp}},
  \code{\link{plot.splitppp}},
  \code{\link{superimpose}},
  \code{\link{ppp.object}}
}
\examples{

# Multitype point pattern: separate into types
 data(amacrine)
 u <- split(amacrine)

# the following are equivalent:
 amon <- amacrine[amacrine$marks == "on"]
 amon <- split(amacrine)$on
   
# plot them
 plot(split(amacrine))

# Scramble the 'on' cells
 u$on <- runifpoint(amon$n, amon$window)
 split(amacrine) <- u

# Point pattern with continuous marks
 data(longleaf)
 \testonly{
	# smaller dataset
	longleaf <- longleaf[seq(1, longleaf$n, by=80)]
 }
 # cut the range of tree diameters into three intervals
 long3 <- cut.ppp(longleaf, 3)
 # now split them
 long3split <- split(long3)

# Unmarked point pattern
  data(swedishpines)
# cut & split according to nearest neighbour distance
  f <- cut(nndist(swedishpines), 3)
  u <- split(swedishpines, f)
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{spokes}
\alias{spokes}
\title{Spokes pattern of dummy points}
\description{
  Generates a pattern of dummy points in a window,
  given a data point pattern.
  The dummy points lie on the radii of circles emanating from each
  data point.
}
\usage{
 spokes(x, y, nrad = 3, nper = 3, fctr = 1.5, Mdefault = 1)
}
\arguments{
  \item{x}{
    Vector of \eqn{x} coordinates of data points, or a list
    with components \code{x} and \code{y}, or a point pattern
    (an object of class \code{ppp}).
  }
  \item{y}{
    Vector of \eqn{y} coordinates of data points.  Ignored
    unless \code{x} is a vector.
  }
  \item{nrad}{
    Number of radii emanating from each data point.
  }
  \item{nper}{
    Number of dummy points per radius.
  }
  \item{fctr}{
    Scale factor.
    Length of largest spoke radius is \code{fctr * M}
    where \code{M} is the mean nearest neighbour distance
    for the data points.
  }
  \item{Mdefault}{
    Value of \code{M} to be used if \code{x} has length 1.
  }
}
\value{
  If argument \code{x} is a point pattern, a point pattern with
  window equal to that of \code{x}.  Otherwise a list with two
  components \code{x} and \code{y}.  In either case the components
  \code{x} and \code{y} of the value are numeric vectors giving
  the coordinates of the dummy points.
}
\details{
  This function is useful in creating dummy points for quadrature
  schemes (see \code{\link{quadscheme}}).

  Given the data points, the function creates a collection of
  \code{nrad * nper * length(x)} dummy points.

  Around each data point \code{(x[i],y[i])} there are
  \code{nrad * nper} dummy points, lying on \code{nrad} radii
  emanating from \code{(x[i],y[i])}, with \code{nper} dummy points
  equally spaced along each radius.

  The (equal) spacing of dummy points along each radius is
  controlled by the factor \code{fctr}. 
  The distance from a data point to the furthest of its associated
  dummy points is \code{fctr * M}
  where \code{M} is the mean nearest neighbour distance
  for the data points.

  If there is only one data point the nearest neighbour distance
  is infinite, so the value \code{Mdefault} will be used in place
  of \code{M}.

  If \code{x} is a point pattern, then the value returned is
  also a point pattern, which is clipped to the window
  of \code{x}.  Hence there may be fewer than
  \code{nrad * nper * length(x)} dummy points in the pattern
  returned.
}
\seealso{
  \code{\link{quad.object}},
  \code{\link{quadscheme}},
  \code{\link{inside.owin}},
  \code{\link{gridcentres}},
  \code{\link{stratrand}}
}
\examples{
  dat <- runifrect(10)
  \dontrun{
  plot(dat)
  }
  dum <- spokes(dat$x, dat$y)
  \dontrun{
  points(dum$x, dum$y, pch=".")
  }
  Q <- quadscheme(dat, dum)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{spruces}
\alias{spruces}
\title{
  Spruces Point Pattern
}
\description{
  The data give the locations of Norwegian spruce trees 
  in a natural forest stand in Saxonia, Germany.
  Each tree is marked with its diameter at breast height.
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of tree locations
  in a 56 x 38 metre sampling region. Each tree is marked
  with its diameter at breast height. All values are given in metres.

  See \code{\link{ppp.object}} for details of the format of a
  point pattern object. The marks are numeric.

  These data have been analysed by Fiksel (1984, 1988),
  Stoyan et al (1987), Penttinen et al (1992) and
  Goulard et al (1996).
}
\usage{data(spruces)}
\source{Stoyan et al (1987). Original source unknown.}
\examples{
     data(spruces)
     plot(spruces)
     # To reproduce Goulard et al. Figure 3
     plot(spruces, maxsize=5*max(spruces$marks))
     plot(unmark(spruces), add=TRUE)
}
\references{
  Fiksel, T. (1984)
  Estimation of parameterized pair potentials of marked and
  nonmarked Gibbsian point processes.
  \emph{Elektron. Informationsverarb. u. Kybernet.}
  \bold{20}, 270--278.
  
  Fiksel, T. (1988)
  Estimation of interaction potentials of Gibbsian point processes.
  \emph{Statistics}
  \bold{19}, 77-86
  
  Goulard, M., S\"arkk\"a, A. and Grabarnik, P. (1996)
  Parameter estimation for marked {G}ibbs point
  processes through the maximum pseudolikelihood method.
  \emph{Scandinavian Journal of Statistics}
  \bold{23}, 365--379.

  Penttinen, A., Stoyan, D. and Henttonen, H. (1992)
  Marked point processes in forest statistics.
  \emph{Forest Science} \bold{38}, 806--824.

  Stoyan, D., Kendall, W.S. and Mecke, J. (1987)
  \emph{Stochastic Geometry and its Applications}.
  Wiley.
}

}
\keyword{datasets}

\eof
\name{square}
\alias{square}
\alias{unit.square}
\title{Square Window}
\description{
Creates a square window
}
\usage{
 square(r=1)
 unit.square()
}
\arguments{
  \item{r}{The side length of the square.}
}
\value{
  An object of class \code{"owin"} (see \code{\link{owin.object}})
  specifying a window. 
}
\details{
  \code{square}
  is a shortcut for creating a window object
  representing the square 
  \eqn{[0,r] \times [0,r]}{[0,r] * [0,r]}.
  It is equivalent to the command
  \code{owin(c(0,r),c(0,r))}.

  \code{unit.square} creates the unit square
  \eqn{[0,1] \times [0,1]}{[0,1] * [0,1]}.
  It is equivalent to
  \code{square(1)} or \code{square()} or \code{owin(c(0,1),c(0,1))}.

  These commands are 
  included mainly to improve the readability of some code.
}
\seealso{
  \code{\link{owin.object}},
  \code{\link{owin}}
}
\examples{
 W <- square(10)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}
 
 

\eof
\name{stratrand}
\alias{stratrand}
\title{Stratified random point pattern}
\description{
  Generates a ``stratified random'' pattern of points in a window,
  by dividing the window into rectangular tiles and placing
  \code{k} random points in each tile.
}
\usage{
 stratrand(window, nx, ny, k = 1)
}
\arguments{
  \item{window}{A window. 
    An object of class \code{\link{owin}},
    or data in any format acceptable to \code{\link{as.owin}()}.
  }
  \item{nx}{Number of tiles in each row.
  }
  \item{ny}{Number of tiles in each column.
  }
  \item{k}{Number of random points to generate in each tile.
  }
}
\value{
  A list with two components \code{x} and \code{y}, which are numeric
  vectors giving the coordinates of the random points.
}
\details{
  The bounding rectangle of \code{window} is divided into
  a regular \eqn{nx \times ny}{nx * ny} grid of rectangular tiles.
  In each tile, \code{k} random points are generated independently
  with a uniform distribution in that tile. 

  Note that some of these grid points may lie outside the window,
  if \code{window} is not of type \code{"rectangle"}. The function
  \code{\link{inside.owin}} can be used to select those grid points
  which do lie inside the window. See the examples.

  This function is useful in creating dummy points for quadrature
  schemes (see \code{\link{quadscheme}}) as well as in simulating
  random point patterns.
}
\seealso{
  \code{\link{quad.object}},
  \code{\link{quadscheme}},
  \code{\link{inside.owin}},
  \code{\link{gridcentres}}
}
\examples{
  w <- unit.square()
  xy <- stratrand(w, 10, 10)
  \dontrun{
  plot(w)
  points(xy)
  }

  # polygonal boundary
  bdry <- list(x=c(0.1,0.3,0.7,0.4,0.2),
               y=c(0.1,0.1,0.5,0.7,0.3))
  w <- owin(c(0,1), c(0,1), poly=bdry)
  xy <- stratrand(w, 10, 10, 3)
  \dontrun{
  plot(w)
  points(xy)
  }
  # determine which grid points are inside polygon
  ok <- inside.owin(xy$x, xy$y, w)
  \dontrun{
  plot(w)
  points(xy$x[ok], xy$y[ok])
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{subset.fasp}
\alias{subset.fasp}
\alias{[.fasp}
\title{Extract Subset of Function Array}
\description{
  Extract a subset of a function array (an object of class
  \code{"fasp"}).
}
\synopsis{
  subset.fasp(x, I, J, drop,\dots)
}
\usage{
  subset.fasp(X, I, J, drop,\dots)
  subset.fasp(X, I, J)
  X[I]
  X[I, J]
}
\arguments{
  \item{X}{
    A function array. An object of class \code{"fasp"}.
  }
  \item{I}{
    any valid expression for a subset of the row indices of the array.
  }
  \item{J}{
    any valid expression for a subset of the column indices of the array.
  }
  \item{drop}{
    Ignored - this argument is required for consistency with other
    methods for \code{subset}.
  }
  \item{\dots}{
    Ignored - this argument is required for consistency with other
    methods for \code{subset}.
  }
} 
\value{
  A function array (of class \code{"fasp"}).
}
\details{
  A function array can be regarded as a matrix whose entries
  are functions. See \code{\link{fasp.object}} for an explanation of
  function arrays.

  This routine extracts a sub-array according to the usual
  conventions for matrix indexing.
}
\seealso{
  \code{\link{fasp.object}}
}
\examples{
 # Lansing woods data - multitype points with 6 types
 data(lansing)
 \dontrun{
 # compute 6 x 6 array of all cross-type K functions
   a <- alltypes(lansing, "K")
   plot(a)
 }
 \testonly{
 # smaller dataset
   sub <- lansing[ seq(1,lansing$n,by=40), ]
   a <- alltypes(sub, "K")
 }
 # first three marks only
 b <- a[1:3,1:3]
 \dontrun{plot(b)}
 # subset pertaining to hickories
 h <- a[levels(lansing$marks) == "hickory", ]
 \dontrun{plot(h)}
}

\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{subset.fv}
\alias{subset.fv}
\alias{[.fv}
\title{Extract Subset of Function Values}
\description{
  Extract a subset of an object of class \code{"fv"}.
}
\synopsis{
  subset.fv(x, i, j, \dots, drop=FALSE)
}
\usage{
  subset.fv(x, i, j, drop=FALSE)
  x[i, j]
}
\arguments{
  \item{x}{
    a function value object,
    of class \code{"fv"} (see \code{\link{fv.object}}).
    Essentially a data frame.
  }
  \item{i}{
    any appropriate subset index.
    Selects a subset of the rows of the data frame, i.e.
    a subset of the domain of the function(s) represented by \code{x}.
  }
  \item{j}{
    any appropriate subset index for the columns of the data frame.
    Selects some of the functions present in \code{x}.
  }
  \item{\dots}{
    Ignored - this argument is required for consistency with other
    methods for \code{"["}.
  }
  \item{drop}{
    Ignored - this argument is required for consistency with other
    methods for \code{"["}.
  }
} 
\value{
  A function value object (of class \code{"fv"}).
}
\details{
  This is a method for \code{"["} for the class \code{"fv"}.
  It is very similar to \code{\link{[.data.frame}}
  except for a few extra checks on the sanity of the result.
}
\seealso{
  \code{\link{fv.object}}
}
\examples{
 data(cells)
 K <- Kest(cells)

 # discard the estimates of K(r) for r  > 0.1
 Ksub <- K[K$r <= 0.1, ]

 # discard the border method estimator
 Ksub <- K[ , names(K) != "border"]
 
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{subset.im}
\alias{subset.im}
\alias{[.im}
\title{Extract Subset of Image}
\description{
  Extract a subset or subregion of a pixel image.
}
\synopsis{
  subset.im(x, i, j, drop=TRUE, \dots)
}
\usage{
  subset.im(X, w)
  X[w]
  X[w, drop=TRUE]
}
\arguments{
  \item{X}{
    A two-dimensional pixel image.
    An object of class \code{"im"}.
  }
  \item{w}{
    Object defining the subregion or subset to be extracted.
    Either a spatial window (an object of class \code{"owin"})
    or a point pattern (an object of class \code{"ppp"}).
  }
  \item{drop}{
    Logical value. 
    Locations in \code{w} that lie outside the spatial domain of the
    image \code{X} return a pixel value of \code{NA} if
    \code{drop=FALSE}, and are omitted if \code{drop=TRUE}.
  }
} 
\value{
  Either a pixel image or a vector of pixel values. See Details.
}
\details{
  This function extracts a subset of the pixel values in a
  pixel image. The image \code{X} must be an object of class
  \code{"im"} representing a pixel image defined inside a
  rectangle in two-dimensional space (see \code{\link{im.object}}).

  The subset to be extracted is determined by the argument \code{w}.
  If \code{w} is a spatial window (an object of class \code{"owin"}),
  the values of the image inside this window are extracted
  (after first clipping the window to the spatial domain of the image
  if necessary). If \code{w} is a point pattern (an object of class
  \code{"ppp"}), then the values of the pixel image at the points of
  this pattern are extracted.
  
  At locations outside the spatial domain of the image,
  the pixel value is undefined, and is taken to be \code{NA}. 
  The logical argument \code{drop} determines whether such \code{NA}
  values will be returned or omitted.
  It also influences the format of the return value. 

  If \code{w} is a point pattern, 
  \code{X[w, drop=FALSE]} is a numeric vector
  containing the pixel values at each of the points of the pattern.
  Its length is equal to the number of points in the pattern \code{w}.
  It may contain \code{NA}s corresponding to points which lie outside
  the spatial domain of the image \code{X}.
  By contrast, \code{X[w]} or \code{X[w, drop=TRUE]} contains only those
  pixel values which are not \code{NA}. It may be shorter.

  If \code{w} is a spatial window
  then \code{X[w, drop=FALSE]} is another pixel image
  of the same dimensions as \code{X} obtained by 
  setting all pixels outside the window \code{w} to have value
  \code{NA}. When the result is displayed by \code{\link{plot.im}} the effect
  is that the pixel image \code{X} is clipped to the window \code{w}.

  If \code{w} is a spatial window which is \emph{not} a rectangle
  (\code{w$type != "rectangle"}) then \code{X[w, drop=TRUE]}
  is a numeric vector containing the pixel values for all pixels
  that lie inside the window \code{w}.

  If \code{w} is a rectangle (a spatial window
  with \code{w$type = "rectangle"}) then \code{X[w, drop=TRUE]}
  is a pixel image. The spatial domain of this image is the
  intersection of \code{w} with the spatial domain of \code{X}.
}
\seealso{
  \code{\link{im.object}},
  \code{\link{ppp.object}},
  \code{\link{owin.object}},
  \code{\link{plot.im}}
}
\examples{
 # make up an image
 X <- setcov(unit.square())
 plot(X)

 # a rectangular subset
 W <- owin(c(0,0.5),c(0.2,0.8))
 Y <- X[W]
 plot(Y)

 # a polygonal subset
 data(letterR)
 R <- affine(letterR, diag(c(1,1)/2), c(-2,-0.7))
 Y <- X[R, drop=FALSE]
 plot(Y)

 # a point pattern
 P <- rpoispp(20)
 Y <- X[P]
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{subset.ppp}
\alias{subset.ppp}
\alias{[.ppp}
\alias{[<-.ppp}
\title{Extract or Replace Subset of Point Pattern}
\description{
  Extract or replace a subset of a point pattern.
  Extraction has the effect of thinning the 
  points and/or or trimming the window.
}
\synopsis{
  subset.ppp(x, subset, window, drop, \dots)
}
\usage{
  subset.ppp(x, subset, window, drop, \dots)
  subset.ppp(x, subset, window)
  x[subset]
  x[subset,window]
  x[subset] <- value
  x[subset, window] <- value
}
\arguments{
  \item{x}{
    A two-dimensional point pattern.
    An object of class \code{"ppp"}.
  }
  \item{subset}{
    logical vector indicating which points should be retained.
  }
  \item{window}{
    window (an object of class \code{"owin"})
    delineating a subset of the original observation window. 
  }
  \item{drop}{
    Ignored - this argument is required for consistency with other
    methods for \code{\link{[}}.
  }
  \item{\dots}{
    Ignored - this argument is required for consistency with other
    methods for \code{\link{[}}.
  }
  \item{value}{
    Replacement value for the subset. A point pattern.
  }
} 
\value{
  A point pattern (of class \code{"ppp"}).
}
\details{
  These functions extract a designated subset of a point pattern,
  or replace the designated subset with another point pattern.

  The function \code{[.ppp} is a method for \code{\link{[}} for the
  class \code{"ppp"}. It extracts a designated subset of a point pattern,
  either by ``\emph{thinning}''
  (retaining/deleting some points of a point pattern)
  or ``\emph{trimming}'' (reducing the window of observation
  to a smaller subregion and retaining only
  those points which lie in the subregion) or both.
 
  The pattern will be ``thinned''
  if  \code{subset} is specified. The points designated by \code{subset}
  will be retained. Here \code{subset} can be a numeric vector
  of positive indices (identifying the points to be retained),
  a numeric vector of negative indices (identifying the points
  to be deleted) or a logical vector of length equal to the number
  of points in the point pattern \code{x}. In the latter case,
  the points \code{(x$x[i], x$y[i])} for which 
  \code{subset[i]=TRUE} will be retained, and the others
  will be deleted.
 
  The pattern will be ``trimmed''
  if \code{window} is specified. This should
  be an object of class \code{\link{owin}} specifying a window of observation
  to which the point pattern \code{x} will be
  trimmed. The points of \code{x} lying inside the new
  \code{window} will be retained.
 
  Both ``thinning'' and ``trimming'' can be performed together.

  The function \code{[<-.ppp} is a method for \code{\link{[<-}} for the
  class \code{"ppp"}. It replaces the designated
  subset with the point pattern \code{value}.
  The subset of \code{x} to be replaced is designated by
  the arguments \code{subset} and \code{window} as above.

  The replacement point pattern \code{value} must lie inside the
  window of the original pattern \code{x}.
  The ordering of points in \code{x} will be preserved
  if the replacement pattern \code{value} has the same number of points
  as the subset to be replaced.  Otherwise the ordering is
  unpredictable.

  Use the function \code{\link{unmark}} to remove marks from a
  marked point pattern.

  Use the function \code{\link{split.ppp}} to select those points
  in a marked point pattern which have a specified mark.
}
\seealso{
  \code{\link{ppp.object}},
  \code{\link{owin.object}},
  \code{\link{unmark}},
  \code{\link{split.ppp}},
  \code{\link{cut.ppp}}
}
\section{Warnings}{
  The function does not check whether \code{window} is a subset of
  \code{x$window}. Nor does it check whether \code{value} lies
  inside \code{x$window}.
}
\examples{
 data(longleaf)
 # Longleaf pines data
 \dontrun{
 plot(longleaf)
 }
 \testonly{
	longleaf <- longleaf[seq(1,longleaf$n,by=10)]
 }
 # adult trees defined to have diameter at least 30 cm
 adult <- (longleaf$marks >= 30)
 longadult <- longleaf[adult]
 # equivalent to: longadult <- subset.ppp(longleaf, subset=adult)
 \dontrun{
 plot(longadult)
 }
 # note that the marks are still retained.
 # Use unmark(longadult) to remove the marks
 
 # New Zealand trees data
 data(nztrees)
 \dontrun{
 plot(nztrees)          # plot shows a line of trees at the far right
 abline(v=148, lty=2)   # cut along this line
 }
 nzw <- owin(c(0,148),c(0,95)) # the subwindow
 # trim dataset to this subwindow
 nzsub <- nztrees[,nzw]
 # equivalent to: nzsub <- subset.ppp(nztrees, window=nzw)
 \dontrun{
 plot(nzsub)
 }

 # Redwood data
 data(redwood) 
 \dontrun{
 plot(redwood)
 }
 # Random thinning: delete 60\% of data
 retain <- (runif(redwood$n) < 0.4)
 thinred <- redwood[retain]
 \dontrun{
 plot(thinred)
 }
 # Scramble 60\% of data
 modif <- (runif(redwood$n) < 0.6)
 scramble <- function(x) { runifpoint(x$n, x$window) }
 redwood[modif] <- scramble(redwood[modif])

 # Lansing woods data - multitype points
 data(lansing)
 \testonly{
    lansing <- lansing[seq(1, lansing$n, length=100)]
 }
 # hickory trees only
 hick <- lansing[lansing$marks == "hickory", ]
 # still a marked pattern -- remove marks
 hick <- unmark(hick)

 # scramble the hickories
 lansing[lansing$marks == "hickory"] <- scramble(hick)
  
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{summary.im}
\alias{summary.im}
\alias{print.summary.im}
\title{Summarizing a Pixel Image}
\description{
  \code{summary} method for class \code{"im"}.
}
\usage{
  summary.im(object, \dots)
  print.summary.im(x, \dots)
}
\arguments{
  \item{object}{A pixel image.}
  \item{\dots}{Ignored.}
  \item{x}{Object of class \code{"summary.im"} as returned by
    \code{summary.im}.
  }
}
\details{
  This is a method for the generic \code{\link{summary}}
  for the class \code{"im"}. An object of class \code{"im"}
  describes a pixel image. See \code{\link{im.object}})
  for details of this class. 
  
  \code{summary.im} extracts information about the pixel image,
  and \code{print.summary.im} prints this information in a
  comprehensible format.

  In normal usage, \code{print.summary.im} is invoked implicitly
  when the user calls \code{summary.im} without assigning its value
  to anything. See the examples.

  The information extracted by \code{summary.im} includes
  \describe{
    \item{range}{The range of the image values.}
    \item{mean}{The mean of the image values.}
    \item{integral}{The ``integral'' of the image values,
      calculated as the sum of the image values
      multiplied by the area of one pixel.}
    \item{dim}{The dimensions of the pixel array:
      \code{dim[1]} is the number of rows in the array,
      corresponding to the \bold{y} coordinate.}
  }
}
\value{
  \code{summary.im} returns an object of class \code{"summary.im"},
  while \code{print.summary.im} returns \code{NULL}.
}
\examples{
  # make an image
  X <- as.im(function(x,y) {x^2}, unit.square())
  # summarize it
  summary(X)
  # save the summary
  s <- summary(X)
  # print it
  print(X)
  s
  # extract stuff
  X$dim
  X$range
  X$integral
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{summary.owin}
\alias{summary.owin}
\title{Summary of a Spatial Window}
\description{
  Prints a useful description of a window object.
}
\synopsis{
  summary.owin(object, \dots)
}
\usage{
 summary.owin(object)
}
\arguments{
  \item{object}{Window (object of class \code{"owin"}).}
}
\details{
  A useful description of the window \code{object} is printed.

  This is a method for the generic function \code{\link{summary}}.
}
\seealso{
  \code{\link{summary}},
  \code{\link{summary.ppp}},
  \code{\link{print.owin}}
}
\examples{
  summary(owin())  # the unit square

  data(demopat)
  W <- demopat$window  # weird polygonal window
  summary(W)           # describes it

  summary(as.mask(W))  # demonstrates current pixel resolution
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{summary.ppm}
\alias{summary.ppm}
\alias{print.summary.ppm}
\title{Summarizing a Fitted Point Process Model}
\description{
  \code{summary} method for class \code{"ppm"}.
}
\usage{
  summary.ppm(object, \dots, quick=FALSE)
  print.summary.ppm(x, \dots)
}
\arguments{
  \item{object}{A fitted point process model.}
  \item{\dots}{Ignored.}
  \item{quick}{Logical flag controlling the scope of the summary.}
  \item{x}{Object of class \code{"summary.ppm"} as returned by
    \code{summary.ppm}.
  }
}
\details{
  This is a method for the generic \code{\link{summary}}
  for the class \code{"ppm"}. An object of class \code{"ppm"}
  describes a fitted point process model. See \code{\link{ppm.object}})
  for details of this class. 
  
  \code{summary.ppm} extracts information about the
  type of model that has been fitted, the data to which the model was
  fitted, and the values of the fitted coefficients.
  (If \code{quick=TRUE} then only the information about the type
  of model is extracted.)

  \code{print.summary.ppm} prints this information in a
  comprehensible format.

  In normal usage, \code{print.summary.ppm} is invoked implicitly
  when the user calls \code{summary.ppm} without assigning its value
  to anything. See the examples.
}
\value{
  \code{summary.ppm} returns an object of class \code{"summary.ppm"},
  while \code{print.summary.ppm} returns \code{NULL}.
}
\examples{
  # invent some data
  X <- rpoispp(42)
  # fit a model to it
  fit <- ppm(X, ~x, Strauss(r=0.1))
  # summarize the fitted model
  summary(fit)
  # `quick' option
  summary(fit, quick=TRUE)

  # save the full summary
  s <- summary(fit)
  # print it
  print(s)
  s
  # extract stuff
  names(s)
  s$args$correction
  s$name
  s$trend$value

  # multitype pattern
  data(demopat)
  fit <- ppm(demopat, ~marks, Poisson())
  summary(fit)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{summary.ppp}
\alias{summary.ppp}
\title{Summary of a Point Pattern Dataset}
\description{
  Prints a useful summary of a point pattern dataset.
}
\synopsis{
  summary.ppp(object, \dots)
}
\usage{
 summary.ppp(object)
}
\arguments{
  \item{object}{Point pattern (object of class \code{"ppp"}).}
}
\details{
  A useful summary of the point pattern \code{object} is printed.

  This is a method for the generic function \code{\link{summary}}.
}
\seealso{
  \code{\link{summary}},
  \code{\link{summary.owin}},
  \code{\link{print.ppp}}
}
\examples{
  data(cells)      # plain vanilla point pattern
  summary(cells)  

  data(lansing)    # multitype point pattern
  summary(lansing) # tabulates frequences of each mark
  
  data(longleaf)    # numeric marks
  summary(longleaf) # prints summary.default(x$marks)

  data(demopat)     # weird polygonal window
  summary(demopat)  # describes it
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{summary.quad}
\alias{summary.quad}
\alias{print.summary.quad}
\title{Summarizing a Quadrature Scheme}
\description{
  \code{summary} method for class \code{"quad"}.
}
\usage{
  summary.quad(object, \dots)
  print.summary.quad(x, \dots, dp=3)
}
\arguments{
  \item{object}{A quadrature scheme.}
  \item{\dots}{Ignored.}
  \item{dp}{Number of significant digits to print.} 
  \item{x}{Object of class \code{"summary.quad"} returned by
    \code{summary.quad}.}
}
\details{
  This is a method for the generic \code{\link{summary}}
  for the class \code{"quad"}. An object of class \code{"quad"}
  describes a quadrature scheme, used to fit a point process model.
  See \code{\link{quad.object}}) for details of this class. 
  
  \code{summary.quad} extracts information about the
  quadrature scheme,
  and \code{print.summary.quad} prints this information in a
  comprehensible format.

  In normal usage, \code{print.summary.quad} is invoked implicitly
  when the user calls \code{summary.quad} without assigning its value
  to anything. See the examples.
}
\value{
  \code{summary.quad} returns an object of class \code{"summary.quad"},
  while \code{print.summary.quad} returns \code{NULL}.
}
\examples{
  # make a quadrature scheme
  Q <- quadscheme(rpoispp(42))
  # summarize it
  summary(Q)
  # save the summary
  s <- summary(Q)
  # print it
  print(s)
  s
  # extract total quadrature weight
  s$w$all$sum
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{superimpose}
\alias{superimpose}
\title{Superimpose Several Point Patterns}
\description{
  Superimpose any number of point patterns.
}
\usage{
  superimpose(\dots)
}
\arguments{
  \item{\dots}{
    Any number of arguments, each of which represents a point pattern.
    Each argument must be either a point pattern
    object (of class \code{"ppp"}) or a structure
    containing elements \code{x} and \code{y}.
  }
}
\value{
  A point pattern (object of class \code{"ppp"}) representing the
  superposition (union) of all the point patterns.
}
\details{
  This function is used to superimpose two or more point patterns
  (see also \code{\link{concatxy}}). 
  
  It assumes that each of the arguments in
  \code{\dots} is either a point pattern object (of class \code{"ppp"})
  or a structure containing (at least) the elements
  \code{x} and \code{y}. All the point patterns are assumed to have
  the same window of observation.

  The first argument must be a point pattern
  object, and it determines the observation window
  for the result.

  If any of the arguments is a \emph{marked} point pattern,
  then all of them must be.
  In that case, the result is also a marked point pattern.

  If the arguments are given in the form \code{name=value},
  then the names will be used
  as marks attached to the corresponding points. See the last line
  in the Examples.
}
\seealso{
  \code{\link{concatxy}},
  \code{\link{quadscheme}}
}
\examples{
  dat <- runifrect(30)
  xy <- list(x=runif(10),y=runif(10))
  new <- superimpose(dat, xy)
  \dontrun{plot(new)}

  # how to make a 2-type point pattern with types "a" and "b"
  u <- superimpose(a = rpoispp(10), b = rpoispp(20))

  # how to make a 2-type point pattern with types 1 and 2
  u <- superimpose("1" = rpoispp(10), "2" = rpoispp(20))
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{swedishpines}
\alias{swedishpines}
\title{
  Swedish Pines Point Pattern
}
\description{
  The data give the locations of pine saplings
  in a Swedish forest. 
} 
\format{
  An object of class \code{"ppp"}
  representing the point pattern of tree locations
  in a 10 x 10 metre square.
  Cartesian coordinates are in decimetres (multiples of 0.1 metre).

  See \code{\link{ppp.object}} for details of the format of a
  point pattern object.
}
\usage{data(swedishpines)}
\source{Strand (1975), Ripley (1981)}
\section{Note}{
  For previous analyses see Ripley (1981, pp. 172-175),
  Venables and Ripley (1997, p. 483),
  Baddeley and Turner (2000).
}
\references{
  Baddeley, A. and Turner, R. (2000)
  Practical maximum pseudolikelihood for spatial point patterns.
  \emph{Australian and New Zealand Journal of Statistics}
  \bold{42}, 283--322.
 
  Ripley, B.D. (1981) 
  \emph{Spatial statistics}.
  John Wiley and Sons.

  Strand, L. (1972). 
  A model for stand growth.
  \emph{{IUFRO} Third Conference Advisory Group of Forest Statisticians},
  INRA, Institut National de la Recherche Agronomique, Paris.
  Pages 207--216.

  Venables, W.N. and Ripley, B.D. (1997)
  \emph{Modern applied statistics with S-PLUS}.
  Second edition. Springer Verlag. 
}
\keyword{datasets}

\eof
\name{union.quad}
\alias{union.quad}
\title{Union of Data and Dummy Points}
\description{
  Combines the data and dummy points of a quadrature scheme
  into a single point pattern.
}
\usage{
 union.quad(Q)
}
\arguments{
  \item{Q}{A quadrature scheme (an object of class \code{"quad"}).}
}
\value{
  A point pattern (of class \code{"ppp"}).
}
\details{
  The argument \code{Q} should be a quadrature scheme (an object of class
  \code{"quad"}, see \code{\link{quad.object}} for details).
  
  This function combines the data and dummy points of \code{Q}
  into a single point pattern. If either the data or the dummy points
  are marked, the result is a marked point pattern.

  The function \code{\link{as.ppp}} will perform the same task.
}
\seealso{
  \code{\link{quad.object}},
  \code{\link{as.ppp}}
}
\examples{
  data(simdat)
  Q <- quadscheme(simdat, default.dummy(simdat))
  U <- union.quad(Q)
  \dontrun{plot(U)}
  # equivalent:
  U <- as.ppp(Q)
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{unmark}
\alias{unmark}
\title{Remove Marks from a Marked Point Pattern}
\description{
  Removes the mark information from a marked point pattern
}
\usage{
 unmark(X)
}
\arguments{
  \item{X}{A point pattern. Either an object of class \code{"ppp"}
    or anything acceptable to \code{\link{as.ppp}}.
  }
}
\value{
  A point pattern (of class \code{"ppp"})
  with any mark information deleted.
}
\details{
  This is simply a convenience for those occasions in which we want to
  remove the marks from a marked point pattern.
}
\seealso{
  \code{\link{ppp.object}},
  \code{\link{as.ppp}}
}
\examples{
  data(lansing)
  hicks <- lansing[lansing$marks == "hickory", ]
  \dontrun{
  plot(hicks)  # still a marked point pattern, but only 1 value of marks
  plot(unmark(hicks)) # unmarked
  }
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
\name{update.ppm}
\alias{update.ppm}
\title{Update a Fitted Point Process Model}
\description{
  \code{update} method for class \code{"ppm"}.
}
\usage{
  update.ppm(object, \dots,
            Q, trend, interaction, covariates,
            correction, rbord, use.gam)
}
\arguments{
  \item{object}{
    An existing fitted point process model,
    typically produced by \code{\link{ppm}}.
  }
  \item{\dots}{
    Unnamed arguments - see Details.
  }
  \item{Q}{
    a new point pattern dataset or quadrature scheme
    to which the model should be fitted. An object of class
    \code{"ppp"} or \code{"quad"}.
  }
  \item{trend}{
    a new \code{formula} for the spatial trend of the model.
  }
  \item{interaction}{
    a new interpoint interaction structure (object of class
    \code{"interact"}) for the model. 
  }
  \item{covariates}{
    a new data frame of spatial covariates,
    or \code{NULL} to remove all spatial covariates.
  }
  \item{correction}{
    character string giving a new type of edge correction,
    or \code{NULL} to return to the default.
  }
  \item{rbord}{
    numerical value of the distance for the `border' edge correction,
    or \code{NULL} to suppress the border correction.
  }
  \item{use.gam}{
    logical value indicating whether to fit the model using
    \code{\link{gam}}. See \code{\link{ppm}}.
  }
}
\details{
  This is a method for the generic function \code{\link{update}}
  for the class \code{"ppm"}. An object of class \code{"ppm"}
  describes a fitted point process model. See \code{\link{ppm.object}})
  for details of this class.

  \code{update.ppm} will modify the point process model
  specified by \code{object} according to the new arguments given,
  then re-fit it.
  The actual re-fitting is performed by the model-fitting
  function \code{\link{ppm}}.

  If you are comparing several model fits to the same data,
  or fits of the same model to different data, it is
  strongly advisable to use \code{update.ppm}
  rather than trying to fit them by hand.
  This is because \code{update.ppm} re-fits the model
  in a way which is comparable to the original fit.

  The named arguments \code{Q}, \code{trend},
  \code{interaction}, \code{covariates}, \code{correction},
  \code{rbord}, \code{use.gam} are passed to \code{\link{ppm}}.
  Use \code{name=NULL} to remove the argument \code{name} from the
  call.

  The unnamed arguments \code{...} may include
  \itemize{
    \item
    exactly one argument of class \code{"ppp"} or \code{"quad"},
    which will be interpreted as the named argument \code{Q};
    \item
    exactly one argument of class \code{"formula"}, which will be
    interpreted as the named argument \code{trend};
    \item
    exactly one argument of class \code{"interact"}, which will be
    interpreted as the named argument \code{interaction};
    \item
    exactly one argument of class \code{"data.frame"}, which will be
    interpreted as the named argument \code{covariates}.
  }
}
\value{
  Another fitted point process model (object of class \code{"ppm"}).
}
\examples{
  data(nztrees)
  data(cells)

  # fit the stationary Poisson process
  fit <- ppm(nztrees, ~ 1)

  # fit a nonstationary Poisson process
  fitP <- update(fit, trend=~x)
  fitP <- update(fit, ~x)

  # fit a stationary Strauss process
  fitS <- update(fit, interaction=Strauss(13))
  fitS <- update(fit, Strauss(13))

  # oops, forgot the edge correction
  fitS <- update(fitS, rbord=13)

  # re-fit the model to a subset
  # of the original point pattern
  nzw <- owin(c(0,148),c(0,95))
  nzsub <- nztrees[,nzw]
  fut <- update(fitS, Q=nzsub)
  fut <- update(fitS, nzsub)

  # WARNING: the point pattern argument is called 'Q'
}
\author{Adrian Baddeley
  \email{adrian@maths.uwa.edu.au}
  \url{http://www.maths.uwa.edu.au/~adrian/}
  and Rolf Turner
  \email{rolf@math.unb.ca}
  \url{http://www.math.unb.ca/~rolf}
}
\keyword{spatial}

\eof
